/*
 * SalomeTMF is a Test Management Framework
 * Copyright (C) 2007 EDF / France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * @author Jeremie DEFAYE
 *
 * Contact: mikael.marche@rd.francetelecom.com
 */

package salomeTMF_plug.pluginxlsxml.Commun;

import java.io.IOException;
import java.io.File;

import jxl.Cell;
import jxl.CellView;
import jxl.Workbook;
import jxl.format.Border;
import jxl.write.Number;
import jxl.format.Alignment;
import jxl.format.BorderLineStyle;
import jxl.format.Colour;
import jxl.format.VerticalAlignment;
import jxl.write.Label;
import jxl.write.NumberFormats;
import jxl.write.WritableCellFeatures;
import jxl.write.WritableCellFormat;
import jxl.write.WritableFont;
import jxl.write.WritableSheet;
import jxl.write.WritableWorkbook;
import jxl.write.WriteException;
import jxl.write.biff.RowsExceededException;

import salomeTMF_plug.pluginxlsxml.language.Language;
import salomeTMF_plug.pluginxlsxml.Commun.TestPresencePlugin;

/**
 * 
 * 
 * @author adm_dfej
 * 
 * @covers SFD_ForgeORTF_EXG_EXP_000070 - 2.7.11
 * @covers SFD_ForgeORTF_EXG_EXP_000080 - 2.7.11
 * Jira : FORTF - 47
 */
public class EcritEntete {

	private static final int CAMPAGNE_NOM_TEST_LIGHT = 4;
	private static final int CAMPAGNE_SUITE_TEST_LIGHT = 3;
	private static final int CAMPAGNE_FAMILLE_TEST_LIGHT = 2;
	private static final int CAMPAGNE_DESCRIPTION_LIGHT = 1;
	private static final int CAMPAGNE_NOM_LIGHT = 0;
	private static final int TEST_EXIGENCE_ASSOCIEE_LIGHT = 9;
	private static final int TEST_TYPE_SCRIPT_AUTOMATIQUE_LIGHT = 7;
	private static final int TEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE_LIGHT = 8;
	private static final int TEST_RESULTAT_ATTENDU_LIGHT = 6;
	private static final int TEST_ACTION_A_REALISER_LIGHT = 5;
	private static final int TEST_NUMERO_LIGHT = 4;
	private static final int TEST_CAS_DE_TESTS_LIGHT = 2;
	private static final int TEST_DESCRIPTION_TESTS_LIGHT = 3;
	private static final int TEST_SUITE_TESTS_LIGHT = 1;
	private static final int TEST_FAMILLE_TESTS_LIGHT = 0;

	private int numeroColonneFeuilleExigence = 0;
	private int numeroLigne = 0;

	private WritableWorkbook workbook;
	private WritableSheet requirementSheet;
	private WritableSheet testSheet;
	private WritableSheet paramSheet;
	private WritableSheet enviroSheet;
	private WritableSheet campagneSheet;
	private WritableSheet execCampSheet;
	private WritableSheet AnomaliesSheet;

	private WritableFont arial11Font;
	private WritableFont celluleNorm;

	private WritableCellFormat arial11Format;
	private WritableCellFeatures cellFeatures;

	private Label label;

	private Number nombre;

	/**
	 * Format de celule normale encadree
	 */
	private WritableCellFormat celluleNormale;
	private WritableCellFormat celluleNormaleNombre;
	private WritableCellFormat celulleCentreeHetV;
	private WritableCellFormat celluleDescritpion;
	private WritableCellFormat celluleNormaleNombreH;

	//20100119 - Dbut modification Forge ORTF
	private static int EXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION = 1;
	private static int EXIGENCE_DIFFERENCE_COLONNE_CATEGORIE = 2;
	private static int EXIGENCE_DIFFERENCE_COLONNE_PRIORITE = 3;
	private static int EXIGENCE_DIFFERENCE_COLONNE_COMPLEXITE = 4;
	private static int EXIGENCE_DIFFERENCE_COLONNE_CRITICITE = 5;
	private static int EXIGENCE_DIFFERENCE_COLONNE_COMPREHENSION = 6;
	private static int EXIGENCE_DIFFERENCE_COLONNE_PROPRIETAIRE = 7;
	private static int EXIGENCE_DIFFERENCE_COLONNE_ETAT = 8;
	private static int EXIGENCE_DIFFERENCE_COLONNE_VALIDE_PAR = 9;
	private static int EXIGENCE_DIFFERENCE_COLONNE_VERSION = 10;	
	private static int EXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE = 11;
	private static int EXIGENCE_DIFFERENCE_COLONNE_PIECE_JOINTE = 12;	
	private static int EXIGENCE_DIFFERENCE_COLONNE_ORIGINE = 13;
	private static int EXIGENCE_DIFFERENCE_COLONNE_VERIFWAY = 14;
	private static int EXIGENCE_DIFFERENCE_COLONNE_REFERENCE = 15;
	//20100119 - Fin modification Forge ORTF
	private static int TEST_FAMILLE_TESTS = 0;
	private static int TEST_DESCRIPTION_FAMILLE_TESTS = 1;
	private static int TEST_SUITE_TESTS = 2;
	private static int TEST_DESCRIPTION_SUITE_TESTS = 3;
	private static int TEST_CAS_DE_TESTS = 4;
	private static int TEST_DESCRIPTION_TESTS = 5;
	private static int TEST_LIEN_HYPERTEXTE = 6;
	private static int TEST_PIECE_JOINTE = 7;
	private static int TEST_NUMERO = 8;
	private static int TEST_ACTION_A_REALISER = 9;
	private static int TEST_RESULTAT_ATTENDU = 10;
	private static int TEST_EXECUTE = 11;
	private static int TEST_TYPE_SCRIPT_AUTOMATIQUE = 12;
	private static int TEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE = 13;
	private static int TEST_LIEN_HYPERTEXTE_ACTION = 14;
	private static int TEST_PIECE_JOINTE_ACTION = 15;
	private static int TEST_EXIGENCE_ASSOCIEE = 16;
	private static int PARAMETRE_NOM = 0;
	private static int PARAMETRE_DESCRIPTION = 1;
	private static int ENVIRONNEMENT_NOM = 0;
	private static int ENVIRONNEMENT_DESCRIPTION = 1;
	private static int ENVIRONNEMENT_NOM_PARAMETRE = 2;
	private static int ENVIRONNEMENT_VALEUR_PARAMETRE = 3;
	private static int ENVIRONNEMENT_LIEN_HYPERTEXTE = 4;
	private static int ENVIRONNEMENT_PIECE_JOINTE = 5;
	private static int CAMPAGNE_NOM = 0;
	private static int CAMPAGNE_DESCRIPTION = 1;
	private static int CAMPAGNE_NOM_JEU_DONNEES = 2;
	private static int CAMPAGNE_DESCRIPTION_JEU_DONNEES = 3;
	private static int CAMPAGNE_JEU_DONNEES_PARAMETRE = 4;
	private static int CAMPAGNE_JEU_DONNEES_VALEURPARAMETRE = 5;
	private static int CAMPAGNE_FAMILLE_TEST = 6;
	private static int CAMPAGNE_SUITE_TEST = 7;
	private static int CAMPAGNE_NOM_TEST = 8;
	private static int CAMPAGNE_LIEN_HYPERTEXTE = 9;
	private static int CAMPAGNE_PIECE_JOINTE = 10;
	private static int CAMPAGNEEEXECUTION_NOM = 0;
	private static int CAMPAGNEEEXECUTION_NOM_EXECUTION = 1;
	private static int CAMPAGNEEEXECUTION_ENVIRONNEMENT = 2;
	private static int CAMPAGNEEEXECUTION_NOM_JEU_DONNEES = 3;
	private static int CAMPAGNEEEXECUTION_LIEN_HYPERTEXTE = 4;
	private static int CAMPAGNEEEXECUTION_PIECE_JOINTE = 5;
	private static int CAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION = 6;
	private static int CAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION = 7;
	private static int CAMPAGNEEEXECUTION_FAMILLE_TEST = 8;
	private static int CAMPAGNEEEXECUTION_SUITE_TEST = 9;
	private static int CAMPAGNEEEXECUTION_NOM_TEST = 10;
	private static int CAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST = 11;
	private static int LIEN_HYPERTEXTE_TEST_EXECUTE_CAMPAGNEEEXECUTION = 12;
	private static int PIECE_JOINTE_TEST_EXECUTE_CAMPAGNEEEXECUTION = 13;
	private static int NUMERO_ACTION_TEST_CAMPAGNEEEXECUTION = 14;
	private static int RESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION = 15;
	private static int RESULTAT_OBTENU_CAMPAGNEEEXECUTION = 16;

	private static int ID_ANOMALIE = 0;
	private static int URL_ANOMALIE = 1;
	private static int RESUME_ANOMALIE = 2;
	private static int DESCRIPTION_ANOMALIE = 3;
	private static int REPORTER_ANOMALIE = 4;
	private static int PROPRIETAIRE_ANOMALIE = 5;


	private static int TAILLE_PETITE_COLONNE = 10;
	private static int TAILLE_MOYENNE_COLONNE = 25;
	private static int TAILLE_GRANDE_COLONNE = 50;

	/**
	 * Nom des feuilles du classeur Excel
	 */
	private String[] nomFeuilles;

	private int colonneExigenceDansFeuilleTest;

	/*
	 * Function that generate a blank spread sheet for example @param Exigencelu
	 * Requirement for example @throws jxl.write.WriteException Write Exception
	 */
	/**
	 * Ecrit la premiere ligne de la feuille Excel (nom des colonnes)
	 * @param nombreMaxBranche nombre maximal de branches encastres pour les exigences
	 * @param presenceFeuilleAnomalie Indique la presence de la feuille anomalie pour generation de cette feuille
	 * @param fichierDeSortieXLS Fichier de sortie excel
	 * @param typeExport Fichier de sortie excel en version complete ou legere
	 * @throws jxl.write.WriteException Exceltion d'ecriture
	 */
	public EcritEntete(int nombreMaxBranche, File fichierDeSortieXLS, boolean presenceFeuilleAnomalie, String typeExport)throws WriteException {
		Label label;
		try {

			workbook = Workbook.createWorkbook(fichierDeSortieXLS);
			AnomaliesSheet =  workbook.createSheet(Language.getInstance().getText("Anomalies"), 0);
			execCampSheet =  workbook.createSheet(Language.getInstance().getText("Execution_campagnes"), 0);
			campagneSheet =  workbook.createSheet(Language.getInstance().getText("Campagnes"), 0);
			enviroSheet =  workbook.createSheet(Language.getInstance().getText("Environnements"), 0);
			paramSheet = workbook.createSheet(Language.getInstance().getText("Parametres"), 0);
			testSheet = workbook.createSheet(Language.getInstance().getText("Tests"), 0);
			requirementSheet = workbook.createSheet(Language.getInstance().getText("Exigences"), 0);
		} catch (IOException ex) {
			ex.printStackTrace();
		}

		// Definit la police de la premiere ligne
		arial11Font = new WritableFont(WritableFont.ARIAL, 11, WritableFont.BOLD);
		arial11Format = new WritableCellFormat(arial11Font);

		// arial11Format.setBackground(Colour.LIGHT_GREEN);
		arial11Format.setBackground(Colour.LIGHT_ORANGE);
		arial11Format.setWrap(true);
		// Pour Encadrer les celulles
		arial11Format.setBorder(Border.ALL, BorderLineStyle.THIN);
		// Pour alignement horizontal
		arial11Format.setAlignment(Alignment.CENTRE);
		// Pour alignement Vertical
		arial11Format.setVerticalAlignment(VerticalAlignment.CENTRE);

		celluleNorm = new WritableFont(WritableFont.ARIAL, 10);
		celluleNormale = new WritableCellFormat(celluleNorm);
		// Met retour a la ligne automatique
		celluleNormale.setWrap(true);
		// Pour Encadrer les celulles
		celluleNormale.setBorder(Border.ALL, BorderLineStyle.THIN);

		celluleNormaleNombre = new WritableCellFormat(NumberFormats.INTEGER);
		// Met retour a la ligne automatique
		celluleNormaleNombre.setWrap(true);
		// Pour Encadrer les celulles
		celluleNormaleNombre.setBorder(Border.ALL, BorderLineStyle.THIN);

		celulleCentreeHetV = new WritableCellFormat(celluleNorm);
		// Met retour a la ligne automatique
		celulleCentreeHetV.setWrap(true);
		// Pour Encadrer les celulles
		celulleCentreeHetV.setBorder(Border.ALL, BorderLineStyle.THIN);
		// Pour alignement horizontal
		celulleCentreeHetV.setAlignment(Alignment.CENTRE);
		// Pour alignement Vertical
		celulleCentreeHetV.setVerticalAlignment(VerticalAlignment.CENTRE);

		celluleNormaleNombreH = new WritableCellFormat(NumberFormats.INTEGER);
		// Met retour a la ligne automatique
		celluleNormaleNombreH.setWrap(true);
		// Pour Encadrer les celulles
		celluleNormaleNombreH.setBorder(Border.ALL, BorderLineStyle.THIN);
		// Pour alignement horizontal
		celluleNormaleNombreH.setAlignment(Alignment.CENTRE);

		celluleDescritpion = new WritableCellFormat(celluleNorm);
		// Met retour a la ligne automatique
		celluleDescritpion.setWrap(true);
		// Pour Encadrer les celulles
		celluleDescritpion.setBorder(Border.ALL, BorderLineStyle.THIN);
		// Pour alignement horizontal
		celluleDescritpion.setAlignment(Alignment.JUSTIFY);
		// Pour alignement Vertical
		celluleDescritpion.setVerticalAlignment(VerticalAlignment.TOP);

		// Pour inserer des commentaires
		cellFeatures = new WritableCellFeatures();
		if (typeExport.equals(Language.getInstance().getText("Feuille_Excel_Entiere"))) {
			CreeToutesLesColonnes(nombreMaxBranche, presenceFeuilleAnomalie);
		}else {
			CreeColonnesPrincipales(nombreMaxBranche, presenceFeuilleAnomalie);
		}

	}

	/**
	  * Fonctionn remplissant un modele vierge pour exemple
	 * 
	 * @throws jxl.write.WriteException
	 *             Erreur Ecriture Excel
	 */
	public void makeExampleLight() throws WriteException {

		// page exigences
		numeroLigne = 1;
		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence")+ " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description"), celluleNormale);
		requirementSheet.addCell(label);
		numeroLigne++;

		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description"), celluleNormale);
		requirementSheet.addCell(label);
		numeroLigne++;

		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence") + " 3", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description"), celluleNormale);
		requirementSheet.addCell(label);
		numeroLigne++;

		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence") + " 4", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description"), celluleNormale);
		requirementSheet.addCell(label);
		numeroLigne++;

		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence") + " 5", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description"), celluleNormale);
		requirementSheet.addCell(label);
		for (int i = 0; i < requirementSheet.getColumns(); i++) {
			for (int j = 1; j < requirementSheet.getRows(); j++) {
				if (requirementSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					requirementSheet.addCell(label);

				}
			}
		}

		// page test
		numeroLigne = 1;
		label = new Label(getTEST_FAMILLE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_SUITE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		testSheet.addCell(label);

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT(), numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT() +1 , numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 1", celluleNormale);
			testSheet.addCell(label);
		}

		label = new Label(getTEST_CAS_DE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_DESCRIPTION_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Description_Test") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_NUMERO_LIGHT(), numeroLigne, " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER_LIGHT(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU_LIGHT(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 1", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		label = new Label(getTEST_NUMERO_LIGHT(), numeroLigne, " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER_LIGHT(), numeroLigne, Language.getInstance() .getText("Action_A_realiser") + " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU_LIGHT(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 2", celluleNormale);
		numeroLigne++;

		label = new Label(getTEST_NUMERO_LIGHT(), numeroLigne, " 3", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER_LIGHT(), numeroLigne, Language.getInstance() .getText("Action_A_realiser") + " 3", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU_LIGHT(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 3", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		label = new Label(getTEST_FAMILLE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_SUITE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		testSheet.addCell(label);

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT(), numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT() + 1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 1", celluleNormale);
			testSheet.addCell(label);
		}

		label = new Label(getTEST_CAS_DE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_NUMERO_LIGHT(), numeroLigne, " A1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER_LIGHT(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 4", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU_LIGHT(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 4", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT(), numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT() + 1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 2", celluleNormale);
			testSheet.addCell(label);
		}

		label = new Label(getTEST_NUMERO_LIGHT(), numeroLigne, " A2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER_LIGHT(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 5", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU_LIGHT(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 5", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT(), numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT() + 1, numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 3", celluleNormale);
			testSheet.addCell(label);
		}
		numeroLigne++;

		label = new Label(getTEST_FAMILLE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Famille") + " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_SUITE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		testSheet.addCell(label);

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT(), numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE_LIGHT() + 1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 4", celluleNormale);
			testSheet.addCell(label);
		}

		label = new Label(getTEST_CAS_DE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 5", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_NUMERO_LIGHT(), numeroLigne, " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER_LIGHT(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 6", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU_LIGHT(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 6", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		label = new Label(getTEST_NUMERO_LIGHT(), numeroLigne, " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER_LIGHT(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 7", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU_LIGHT(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 7", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		if(TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner()==true||TestPresencePlugin.testDeLaPresenceDuPluginBeanShell()==true||TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit()==true){
			label = new Label(getTEST_FAMILLE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Famille") + " 3", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_SUITE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_CAS_DE_TESTS_LIGHT(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 6", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_TYPE_SCRIPT_AUTOMATIQUE_LIGHT(), numeroLigne, Language.getInstance().getText("Beanshell"), celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE_LIGHT(), numeroLigne, Language.getInstance().getText("Script_path"), celluleNormale);
			testSheet.addCell(label);
		}
		for (int i = 0; i < testSheet.getColumns(); i++) {
			for (int j = 1; j < testSheet.getRows(); j++) {
				if (testSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					testSheet.addCell(label);
				}
			}
		}

		//page parametre
		numeroLigne = 1;
		label = new Label(getPARAMETRE_NOM(), numeroLigne, Language.getInstance().getText("Parametre") +  " 1", celluleNormale);
		paramSheet.addCell(label);
		label = new Label(getPARAMETRE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Parametres") + " 1", celluleNormale);
		paramSheet.addCell(label);
		numeroLigne++;
		label = new Label(getPARAMETRE_NOM(), numeroLigne, Language.getInstance().getText("Parametre") +  " 2", celluleNormale);
		paramSheet.addCell(label);
		label = new Label(getPARAMETRE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Parametres") + " 2", celluleNormale);
		paramSheet.addCell(label);
		numeroLigne++;
		label = new Label(getPARAMETRE_NOM(), numeroLigne, Language.getInstance().getText("Parametre") +  " 3", celluleNormale);
		paramSheet.addCell(label);
		label = new Label(getPARAMETRE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Parametres") + " 3", celluleNormale);
		paramSheet.addCell(label);

//		page environnement
		numeroLigne = 1;
		label = new Label(getENVIRONNEMENT_NOM(), numeroLigne, Language.getInstance().getText("Environnement") +  " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Environnement") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM(), numeroLigne, Language.getInstance().getText("Environnement") +  " 2", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Environnement") + " 2", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 2", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 2", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 3", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 3", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM(), numeroLigne, Language.getInstance().getText("Environnement") +  " 3", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Environnement") + " 3", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 3", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		enviroSheet.addCell(label);

		for (int i = 0; i < enviroSheet.getColumns(); i++) {
			for (int j = 1; j < enviroSheet.getRows(); j++) {
				if (enviroSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					enviroSheet.addCell(label);
				}
			}
		}

		//page Campagne
		numeroLigne = 1;
		label = new Label(getCAMPAGNE_NOM_LIGHT(), numeroLigne, Language.getInstance().getText("Campagne") +  " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION_LIGHT(), numeroLigne, Language.getInstance().getText("Description") +  " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_FAMILLE_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_SUITE_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		numeroLigne++;
		label = new Label(getCAMPAGNE_FAMILLE_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_SUITE_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 2", celluleNormale);
		campagneSheet.addCell(label);
		numeroLigne++;
		label = new Label(getCAMPAGNE_NOM_LIGHT(), numeroLigne, Language.getInstance().getText("Campagne") +  " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION_LIGHT(), numeroLigne, Language.getInstance().getText("Description") +  " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_FAMILLE_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_SUITE_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		numeroLigne++;
		label = new Label(getCAMPAGNE_NOM_LIGHT(), numeroLigne, Language.getInstance().getText("Campagne") +  " 3", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION_LIGHT(), numeroLigne, Language.getInstance().getText("Description") +  " 3", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_FAMILLE_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("Famille") + " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_SUITE_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_TEST_LIGHT(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 5", celluleNormale);
		campagneSheet.addCell(label);
		for (int i = 0; i < campagneSheet.getColumns(); i++) {
			for (int j = 1; j < campagneSheet.getRows(); j++) {
				if (campagneSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					campagneSheet.addCell(label);
				}
			}
		}
	}

	/**
	 * Fonction qui cre les colonnes principales de la feuille Excel
	 * @param nombreMaxBranche Nombre de branches maximal pour la feuille Exigence
	 * @param presenceFeuilleAnomalie  True/false Prsence de la feuille anomalie 
	 * @throws WriteException
	 */
	public void CreeColonnesPrincipales(int nombreMaxBranche, boolean presenceFeuilleAnomalie) throws WriteException {
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			for (int i = 0; i < nombreMaxBranche; i++) {
				//Commentaire colonne Branche
				creeColonne(requirementSheet, numeroColonneFeuilleExigence, Language.getInstance().getText("Branche"),Language.getInstance().getText("Branche_Comment"), TAILLE_PETITE_COLONNE);
				numeroColonneFeuilleExigence++;
			}		

			creeColonne(requirementSheet, numeroColonneFeuilleExigence, Language.getInstance().getText("Exigence"),Language.getInstance().getText("Exigence_Comment"), TAILLE_GRANDE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), Language.getInstance().getText("Description"),Language.getInstance().getText("Description_Comment"), TAILLE_GRANDE_COLONNE);
		}
		
		// colonnes speciales tests
		creeColonne(testSheet, getTEST_FAMILLE_TESTS_LIGHT(), Language.getInstance().getText("Famille"),Language.getInstance().getText("Famille_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(testSheet, getTEST_SUITE_TESTS_LIGHT(), Language.getInstance().getText("Suite"),Language.getInstance().getText("Suite_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(testSheet, getTEST_CAS_DE_TESTS_LIGHT(), Language.getInstance().getText("cas_de_tests"),Language.getInstance().getText("cas_de_tests_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(testSheet, getTEST_DESCRIPTION_TESTS_LIGHT(), Language.getInstance().getText("Description_Test"),Language.getInstance().getText("Description_Test_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(testSheet, getTEST_NUMERO_LIGHT(), Language.getInstance().getText("Numero"),Language.getInstance().getText("Numero_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(testSheet, getTEST_ACTION_A_REALISER_LIGHT(), Language.getInstance().getText("Action_A_realiser"),Language.getInstance().getText("Action_A_realiser_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(testSheet, getTEST_RESULTAT_ATTENDU_LIGHT(), Language.getInstance().getText("Resultat_Attendu"),Language.getInstance().getText("Resultat_Attendu_Comment"), TAILLE_MOYENNE_COLONNE);
		if(TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner()==true||TestPresencePlugin.testDeLaPresenceDuPluginBeanShell()==true||TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit()==true){
			creeColonne(testSheet, getTEST_TYPE_SCRIPT_AUTOMATIQUE_LIGHT(), Language.getInstance().getText("Type_Test_Automatique"),Language.getInstance().getText("Type_Test_Automatique_Comment"), TAILLE_MOYENNE_COLONNE);
			creeColonne(testSheet, getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE_LIGHT(), Language.getInstance().getText("Emplacement_Test_Automatique"),Language.getInstance().getText("Emplacement_Test_Automatique_Comment"), TAILLE_GRANDE_COLONNE);			
		}
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			for (int i = 0; i < nombreMaxBranche; i++) {
				creeColonne(testSheet, getTEST_EXIGENCE_ASSOCIEE_LIGHT() + i, Language.getInstance().getText("Branche"),Language.getInstance().getText("Branche_Comment"), TAILLE_PETITE_COLONNE);
			}
		}			

		colonneExigenceDansFeuilleTest = getTEST_EXIGENCE_ASSOCIEE_LIGHT() + nombreMaxBranche;

		creeColonne(testSheet, colonneExigenceDansFeuilleTest, Language.getInstance().getText("Exigence"),Language.getInstance().getText("Exigence_Comment"), TAILLE_GRANDE_COLONNE);

		//permet d'initialiser les colonnes de la feuille parametre
		creeColonne(paramSheet, getPARAMETRE_NOM(), Language.getInstance().getText("Nom_Parametres"),Language.getInstance().getText("Nom_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(paramSheet, getPARAMETRE_DESCRIPTION(), Language.getInstance().getText("Description_Parametres"),Language.getInstance().getText("Description_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);

		//permet d'initialiser les colonnes de la feuille Environnements
		creeColonne(enviroSheet, getENVIRONNEMENT_NOM(), Language.getInstance().getText("Nom_Environnement"),Language.getInstance().getText("Nom_Environnement_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(enviroSheet, getENVIRONNEMENT_DESCRIPTION(), Language.getInstance().getText("Description_Environnement"),Language.getInstance().getText("Description_Environnement_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(enviroSheet, getENVIRONNEMENT_NOM_PARAMETRE(), Language.getInstance().getText("Nom_Parametres"),Language.getInstance().getText("Nom_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(enviroSheet, getENVIRONNEMENT_VALEUR_PARAMETRE(), Language.getInstance().getText("Valeur_Parametres"),Language.getInstance().getText("Valeur_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);

		//permet d'initialiser les colonnes de la feuille Campagnes
		creeColonne(campagneSheet, getCAMPAGNE_NOM_LIGHT(), Language.getInstance().getText("Nom_Campagne"),Language.getInstance().getText("Nom_Campagne_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_DESCRIPTION_LIGHT(), Language.getInstance().getText("Description_Campagne"),Language.getInstance().getText("Description_Campagne_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_FAMILLE_TEST_LIGHT(), Language.getInstance().getText("Famille"),Language.getInstance().getText("Famille_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_SUITE_TEST_LIGHT(), Language.getInstance().getText("Suite"),Language.getInstance().getText("Suite_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_NOM_TEST_LIGHT(), Language.getInstance().getText("cas_de_tests"),Language.getInstance().getText("cas_de_tests_Comment"), TAILLE_GRANDE_COLONNE);

	}



	private int getCAMPAGNE_NOM_TEST_LIGHT() {
		return CAMPAGNE_NOM_TEST_LIGHT;
	}


	private int getCAMPAGNE_SUITE_TEST_LIGHT() {
		return CAMPAGNE_SUITE_TEST_LIGHT;
	}


	private int getCAMPAGNE_FAMILLE_TEST_LIGHT() {
		return CAMPAGNE_FAMILLE_TEST_LIGHT;
	}


	private int getCAMPAGNE_DESCRIPTION_LIGHT() {
		return CAMPAGNE_DESCRIPTION_LIGHT;
	}


	private int getCAMPAGNE_NOM_LIGHT() {
		return CAMPAGNE_NOM_LIGHT;
	}


	private int getTEST_TYPE_SCRIPT_AUTOMATIQUE_LIGHT() {
		return TEST_TYPE_SCRIPT_AUTOMATIQUE_LIGHT;
	}


	private int getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE_LIGHT() {
		return TEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE_LIGHT;
	}


	private int getTEST_RESULTAT_ATTENDU_LIGHT() {
		return TEST_RESULTAT_ATTENDU_LIGHT;
	}


	private int getTEST_ACTION_A_REALISER_LIGHT() {
		return TEST_ACTION_A_REALISER_LIGHT;
	}


	private int getTEST_NUMERO_LIGHT() {
		return TEST_NUMERO_LIGHT;
	}


	private int getTEST_CAS_DE_TESTS_LIGHT() {
		return TEST_CAS_DE_TESTS_LIGHT;
	}


	private int getTEST_DESCRIPTION_TESTS_LIGHT() {
		return TEST_DESCRIPTION_TESTS_LIGHT;
	}


	private int getTEST_SUITE_TESTS_LIGHT() {
		return TEST_SUITE_TESTS_LIGHT;
	}

	private int getTEST_FAMILLE_TESTS_LIGHT() {
		return TEST_FAMILLE_TESTS_LIGHT;
	}

	/**
	 * Fonction qui cre les toutes les colonnes de la feuille Excel
	 * @param nombreMaxBranche Nombre de branches maximal pour la feuille Exigence
	 * @param presenceFeuilleAnomalie  True/false Prsence de la feuille anomalie 
	 * @throws WriteException
	 */
	public void CreeToutesLesColonnes(int nombreMaxBranche, boolean presenceFeuilleAnomalie) throws WriteException {
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			for (int i = 0; i < nombreMaxBranche; i++) {
				//Commentaire colonne Branche
				creeColonne(requirementSheet, numeroColonneFeuilleExigence, Language.getInstance().getText("Branche"),Language.getInstance().getText("Branche_Comment"), TAILLE_PETITE_COLONNE);
				numeroColonneFeuilleExigence++;
				creeColonne(requirementSheet, numeroColonneFeuilleExigence, Language.getInstance().getText("Description_Branche"),Language.getInstance().getText("Description_Branche_Comment"), TAILLE_MOYENNE_COLONNE);
				numeroColonneFeuilleExigence++;
			}		

			creeColonne(requirementSheet, numeroColonneFeuilleExigence, Language.getInstance().getText("Exigence"),Language.getInstance().getText("Exigence_Comment"), TAILLE_GRANDE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), Language.getInstance().getText("Description"),Language.getInstance().getText("Description_Comment"), TAILLE_GRANDE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE(), Language.getInstance().getText("Lien_Hypertexte"),Language.getInstance().getText("Lien_Hypertexte_Comment"), TAILLE_GRANDE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PIECE_JOINTE(), Language.getInstance().getText("Piece_Jointe"),Language.getInstance().getText("Piece_Jointe_Comment"), TAILLE_GRANDE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE(), Language.getInstance().getText("Priorite"),Language.getInstance().getText("Priorite_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_VERSION(), Language.getInstance().getText("Version"),Language.getInstance().getText("Version_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_CATEGORIE(), Language.getInstance().getText("Categorie"),Language.getInstance().getText("Categorie_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_COMPLEXITE(), Language.getInstance().getText("Complexitee"),Language.getInstance().getText("Complexite_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_ETAT(), Language.getInstance().getText("Etat"),Language.getInstance().getText("Etat_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_ORIGINE(), Language.getInstance().getText("Origine"),Language.getInstance().getText("Origine_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_VERIFWAY(), Language.getInstance().getText("VerifWay"),Language.getInstance().getText("VerifWay_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_REFERENCE(), Language.getInstance().getText("Reference"),Language.getInstance().getText("Reference_Comment"), TAILLE_PETITE_COLONNE);
			//20100119 - Dbut modification Forge ORTF
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_CRITICITE(), Language.getInstance().getText("Criticite"),Language.getInstance().getText("Criticite_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_COMPREHENSION(), Language.getInstance().getText("Comprehension"),Language.getInstance().getText("Comprehension_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PROPRIETAIRE(), Language.getInstance().getText("Proprietaire"),Language.getInstance().getText("Proprietaire_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(requirementSheet, numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_VALIDE_PAR(), Language.getInstance().getText("Valide_par"),Language.getInstance().getText("Valide_par_Comment"), TAILLE_PETITE_COLONNE);
			//20100119 - Fin modification Forge ORTF
		}
		// colonnes speciales tests
		creeColonne(testSheet, getTEST_FAMILLE_TESTS(), Language.getInstance().getText("Famille"),Language.getInstance().getText("Famille_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(testSheet, getTEST_DESCRIPTION_FAMILLE_TESTS(), Language.getInstance().getText("Description_Famille"),Language.getInstance().getText("Description_Famille_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(testSheet, getTEST_SUITE_TESTS(), Language.getInstance().getText("Suite"),Language.getInstance().getText("Suite_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(testSheet, getTEST_DESCRIPTION_SUITE_TESTS(), Language.getInstance().getText("Description_Suite"),Language.getInstance().getText("Description_Suite_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(testSheet, getTEST_CAS_DE_TESTS(), Language.getInstance().getText("cas_de_tests"),Language.getInstance().getText("cas_de_tests_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(testSheet, getTEST_DESCRIPTION_TESTS(), Language.getInstance().getText("Description_Test"),Language.getInstance().getText("Description_Test_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(testSheet, getTEST_NUMERO(), Language.getInstance().getText("Numero"),Language.getInstance().getText("Numero_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(testSheet, getTEST_ACTION_A_REALISER(), Language.getInstance().getText("Action_A_realiser"),Language.getInstance().getText("Action_A_realiser_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(testSheet, getTEST_RESULTAT_ATTENDU(), Language.getInstance().getText("Resultat_Attendu"),Language.getInstance().getText("Resultat_Attendu_Comment"), TAILLE_MOYENNE_COLONNE);
		if(TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner()==true||TestPresencePlugin.testDeLaPresenceDuPluginBeanShell()==true||TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit()==true){
			creeColonne(testSheet, getTEST_TYPE_SCRIPT_AUTOMATIQUE(), Language.getInstance().getText("Type_Test_Automatique"),Language.getInstance().getText("Type_Test_Automatique_Comment"), TAILLE_MOYENNE_COLONNE);
			creeColonne(testSheet, getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE(), Language.getInstance().getText("Emplacement_Test_Automatique"),Language.getInstance().getText("Emplacement_Test_Automatique_Comment"), TAILLE_GRANDE_COLONNE);			
		}
		creeColonne(testSheet, getTEST_EXECUTE(), Language.getInstance().getText("Test_Execute"),Language.getInstance().getText("Test_Execute_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(testSheet, getTEST_LIEN_HYPERTEXTE(), Language.getInstance().getText("Lien_Hypertexte"),Language.getInstance().getText("Lien_Hypertexte_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(testSheet, getTEST_PIECE_JOINTE(), Language.getInstance().getText("Piece_Jointe"),Language.getInstance().getText("Piece_Jointe_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(testSheet, getTEST_LIEN_HYPERTEXTE_ACTION(), Language.getInstance().getText("Lien_Hypertexte_Action"),Language.getInstance().getText("Lien_Hypertexte_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(testSheet, getTEST_PIECE_JOINTE_ACTION(), Language.getInstance().getText("Piece_Jointe_Action"),Language.getInstance().getText("Piece_Jointe_Comment"), TAILLE_GRANDE_COLONNE);


		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			for (int i = 0; i < nombreMaxBranche; i++) {
				creeColonne(testSheet, getTEST_EXIGENCE_ASSOCIEE() + i, Language.getInstance().getText("Branche"),Language.getInstance().getText("Branche_Comment"), TAILLE_PETITE_COLONNE);
			}
		}			

		colonneExigenceDansFeuilleTest = getTEST_EXIGENCE_ASSOCIEE() + nombreMaxBranche;

		creeColonne(testSheet, colonneExigenceDansFeuilleTest, Language.getInstance().getText("Exigence"),Language.getInstance().getText("Exigence_Comment"), TAILLE_GRANDE_COLONNE);

		//permet d'initialiser les colonnes de la feuille parametre
		creeColonne(paramSheet, getPARAMETRE_NOM(), Language.getInstance().getText("Nom_Parametres"),Language.getInstance().getText("Nom_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(paramSheet, getPARAMETRE_DESCRIPTION(), Language.getInstance().getText("Description_Parametres"),Language.getInstance().getText("Description_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);

		//permet d'initialiser les colonnes de la feuille Environnements
		creeColonne(enviroSheet, getENVIRONNEMENT_NOM(), Language.getInstance().getText("Nom_Environnement"),Language.getInstance().getText("Nom_Environnement_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(enviroSheet, getENVIRONNEMENT_DESCRIPTION(), Language.getInstance().getText("Description_Environnement"),Language.getInstance().getText("Description_Environnement_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(enviroSheet, getENVIRONNEMENT_NOM_PARAMETRE(), Language.getInstance().getText("Nom_Parametres"),Language.getInstance().getText("Nom_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(enviroSheet, getENVIRONNEMENT_VALEUR_PARAMETRE(), Language.getInstance().getText("Valeur_Parametres"),Language.getInstance().getText("Valeur_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(enviroSheet, getENVIRONNEMENT_LIEN_HYPERTEXTE(), Language.getInstance().getText("Lien_Hypertexte"),Language.getInstance().getText("Lien_Hypertexte_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(enviroSheet, getENVIRONNEMENT_PIECE_JOINTE(), Language.getInstance().getText("Piece_Jointe"),Language.getInstance().getText("Piece_Jointe_Comment"), TAILLE_GRANDE_COLONNE);

		//permet d'initialiser les colonnes de la feuille Campagnes
		creeColonne(campagneSheet, getCAMPAGNE_NOM(), Language.getInstance().getText("Nom_Campagne"),Language.getInstance().getText("Nom_Campagne_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_DESCRIPTION(), Language.getInstance().getText("Description_Campagne"),Language.getInstance().getText("Description_Campagne_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_NOM_JEU_DONNEES(), Language.getInstance().getText("Nom_Jeu_de_donnees"),Language.getInstance().getText("Nom_Jeu_de_donnees_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_DESCRIPTION_JEU_DONNEES(), Language.getInstance().getText("Description_Jeu_de_donnees"),Language.getInstance().getText("Description_Jeu_de_donnees_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_JEU_DONNEES_PARAMETRE(), Language.getInstance().getText("Nom_Parametres"),Language.getInstance().getText("Nom_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_JEU_DONNEES_VALEURPARAMETRE(), Language.getInstance().getText("Valeur_Parametres"),Language.getInstance().getText("Valeur_Parametres_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_FAMILLE_TEST(), Language.getInstance().getText("Famille"),Language.getInstance().getText("Famille_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_SUITE_TEST(), Language.getInstance().getText("Suite"),Language.getInstance().getText("Suite_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_NOM_TEST(), Language.getInstance().getText("cas_de_tests"),Language.getInstance().getText("cas_de_tests_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_LIEN_HYPERTEXTE(), Language.getInstance().getText("Lien_Hypertexte"),Language.getInstance().getText("Lien_Hypertexte_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(campagneSheet, getCAMPAGNE_PIECE_JOINTE(), Language.getInstance().getText("Piece_Jointe"),Language.getInstance().getText("Piece_Jointe_Comment"), TAILLE_GRANDE_COLONNE);

		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_NOM(), Language.getInstance().getText("Nom_Campagne"),Language.getInstance().getText("Nom_Campagne_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_NOM_EXECUTION(), Language.getInstance().getText("Nom_Execution"),Language.getInstance().getText("Nom_Execution_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_ENVIRONNEMENT(), Language.getInstance().getText("Nom_Environnement"),Language.getInstance().getText("Nom_Environnement_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_NOM_JEU_DONNEES(), Language.getInstance().getText("Nom_Jeu_de_donnees"),Language.getInstance().getText("Nom_Jeu_de_donnees_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE(), Language.getInstance().getText("Lien_Hypertexte"),Language.getInstance().getText("Lien_Hypertexte_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_PIECE_JOINTE(), Language.getInstance().getText("Piece_Jointe"),Language.getInstance().getText("Piece_Jointe_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION(), Language.getInstance().getText("Nom_Resultat_Execution"),Language.getInstance().getText("Nom_Resultat_Execution_Comment"), TAILLE_MOYENNE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION(), Language.getInstance().getText("Resultat_Execution"),Language.getInstance().getText("Resultat_Execution_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_FAMILLE_TEST(), Language.getInstance().getText("Famille"),Language.getInstance().getText("Famille_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_SUITE_TEST(), Language.getInstance().getText("Suite"),Language.getInstance().getText("Suite_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_NOM_TEST(), Language.getInstance().getText("cas_de_tests"),Language.getInstance().getText("cas_de_tests_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(execCampSheet, getCAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST(), Language.getInstance().getText("Test_Execute"),Language.getInstance().getText("Test_Execute_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(execCampSheet, getLIEN_HYPERTEXTE_TEST_EXECUTE_CAMPAGNEEEXECUTION(), Language.getInstance().getText("Lien_Hypertexte_Test_Execute"),Language.getInstance().getText("Lien_Hypertexte_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(execCampSheet, getPIECE_JOINTE_TEST_EXECUTE_CAMPAGNEEEXECUTION(), Language.getInstance().getText("Piece_Jointe_Test_Execute"),Language.getInstance().getText("Piece_Jointe_Comment"), TAILLE_GRANDE_COLONNE);
		creeColonne(execCampSheet, getNUMERO_ACTION_TEST_CAMPAGNEEEXECUTION(), Language.getInstance().getText("Numero"),Language.getInstance().getText("Numero_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(execCampSheet, getRESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION(), Language.getInstance().getText("Action_Execute"),Language.getInstance().getText("Action_Execute_Comment"), TAILLE_PETITE_COLONNE);
		creeColonne(execCampSheet, getRESULTAT_OBTENU_CAMPAGNEEEXECUTION(), Language.getInstance().getText("Action_Obtenue"),Language.getInstance().getText("Action_Obtenue_Comment"), TAILLE_MOYENNE_COLONNE);

		if (presenceFeuilleAnomalie){
			creeColonne(AnomaliesSheet, getID_ANOMALIE(), Language.getInstance().getText("ID_Anomalie"),Language.getInstance().getText("ID_Anomalie_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(AnomaliesSheet, getURL_ANOMALIE(), Language.getInstance().getText("URL_Anomalie"),Language.getInstance().getText("URL_Anomalie_Comment"), TAILLE_GRANDE_COLONNE);
			creeColonne(AnomaliesSheet, getRESUME_ANOMALIE(), Language.getInstance().getText("Resume_Anomalie"),Language.getInstance().getText("Resume_Anomalie_Comment"), TAILLE_MOYENNE_COLONNE);
			creeColonne(AnomaliesSheet, getDESCRIPTION_ANOMALIE(), Language.getInstance().getText("Description_Anomalie"),Language.getInstance().getText("Description_Anomalie_Comment"), TAILLE_GRANDE_COLONNE);
			creeColonne(AnomaliesSheet, getREPORTER_ANOMALIE(), Language.getInstance().getText("Reporter_Anomalie"),Language.getInstance().getText("Reporter_Anomalie_Comment"), TAILLE_PETITE_COLONNE);
			creeColonne(AnomaliesSheet, getPROPRIETAIRE_ANOMALIE(), Language.getInstance().getText("Proprietaire_Anomalie"),Language.getInstance().getText("Proprietaire_Anomalie_Comment"), TAILLE_PETITE_COLONNE);
		}
	}



	/**
	 * Cree les colonnes des feuilles de calcul Excel
	 * @param feuilleExcel Nom de la feuille Excel
	 * @param colonne Numero de la colonne
	 * @param nomColonne Nom a afficher pour la colonne
	 * @param commentaireColonne commentaire a inserer
	 * @param taillecolonne largeur de la colonne
	 * @throws jxl.write.biff.RowsExceededException exception Excel
	 * @throws jxl.write.WriteException Exception d'ecriture
	 */
	public void creeColonne(WritableSheet feuilleExcel, int colonne, String nomColonne, String commentaireColonne, int taillecolonne) throws RowsExceededException, WriteException {
		label = new Label(colonne, numeroLigne, nomColonne.toUpperCase(), arial11Format);
		cellFeatures = new WritableCellFeatures();
		cellFeatures.setComment(commentaireColonne);
		feuilleExcel.setColumnView(colonne, taillecolonne);
		label.setCellFeatures(cellFeatures);
		feuilleExcel.addCell(label);
	}


	/**
	 * Ferme la feuille excel
	 * @param presenceFeuilleAnomalie Verifie la presence de la feuille Anomalie
	 * @param typeExport Dfinit si la feuille Excel est entire ou lgre
	 * @throws jxl.write.WriteException Exceltion d'ecriture
	 */
	public void closeWorkbook(boolean presenceFeuilleAnomalie, String typeExport) throws WriteException {
		if (!TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			//Supprime la feuille Exigences	
			nomFeuilles = workbook.getSheetNames();
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Exigences"))) {
					workbook.removeSheet(g);
				}
			}
		}
		if (presenceFeuilleAnomalie == false){
			//Supprime la feuille Exigences	
			nomFeuilles = workbook.getSheetNames();
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Anomalies"))) {
					workbook.removeSheet(g);
				}
			}
		}
		if (typeExport.equals(Language.getInstance().getText("Feuille_Excel_Legere"))){
			//Supprime la feuille Exigences	
			nomFeuilles = workbook.getSheetNames();
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Execution_campagnes"))) {
					workbook.removeSheet(g);
				}
			}
		}
		try {
			workbook.write();
			workbook.close();
		} catch (IOException ex) {
			ex.printStackTrace();
		}

	}


	/**
	 * Fonction permettant a la volee de rajouter des colonnes de sous categorie
	 * lors de la creation de la feuille Excel
	 * 
	 * @throws jxl.write.WriteException
	 *             Exceltion exriture Excel
	 */
	public void AddAColumnForLevel() throws WriteException {
		requirementSheet.insertColumn(numeroColonneFeuilleExigence);
		creeColonne(requirementSheet, numeroColonneFeuilleExigence, Language.getInstance().getText("Branche"),Language.getInstance().getText("Branche_Comment"), TAILLE_PETITE_COLONNE);
		numeroColonneFeuilleExigence++;
		requirementSheet.insertColumn(numeroColonneFeuilleExigence);
		creeColonne(requirementSheet, numeroColonneFeuilleExigence, Language.getInstance().getText("Description_Branche"),Language.getInstance().getText("Description_Branche_Comment"), TAILLE_MOYENNE_COLONNE);
		numeroColonneFeuilleExigence++;

		creeColonne(testSheet, colonneExigenceDansFeuilleTest, Language.getInstance().getText("Branche"),Language.getInstance().getText("Branche_Comment"), TAILLE_PETITE_COLONNE);
		colonneExigenceDansFeuilleTest++;
	}

	/**
	 * Fonctionn remplissant un modele vierge pour exemple
	 * 
	 * @throws jxl.write.WriteException
	 *             Erreur Ecriture Excel
	 */
	public void makeExample() throws WriteException {

		// page exigences
		numeroLigne = 1;
		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Description_Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(2, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(3, numeroLigne, Language.getInstance().getText("Description_Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence")+ " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE(), numeroLigne, "1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description"), celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE(), numeroLigne, Language.getInstance().getText("Url_Exemple"), celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PIECE_JOINTE(), numeroLigne, Language.getInstance().getText("Document") + ".doc", celluleNormale);
		requirementSheet.addCell(label);
		numeroLigne++;

		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Description_Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(2, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(3, numeroLigne, Language.getInstance().getText("Description_Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE(), numeroLigne, "10", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE(), numeroLigne, Language.getInstance().getText("Url_Exemple"), celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PIECE_JOINTE(), numeroLigne, Language.getInstance().getText("Document") + ".doc", celluleNormale);
		requirementSheet.addCell(label);
		numeroLigne++;

		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Description_Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(2, numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(3, numeroLigne, Language.getInstance().getText("Description_Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence") + " 3", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE(), numeroLigne, "100", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description"), celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE(), numeroLigne, Language.getInstance().getText("Url_Exemple") + "\n" + Language.getInstance().getText("Url_Exemple2"), celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PIECE_JOINTE(), numeroLigne, Language.getInstance().getText("Document") + ".doc " + "\n" + Language.getInstance().getText("Document") + ".xls", celluleNormale);
		requirementSheet.addCell(label);
		numeroLigne++;

		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Description_Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(2, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(3, numeroLigne, Language.getInstance().getText("Description_Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence") + " 4", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE(), numeroLigne, "10", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_VERSION(), numeroLigne, "1", celluleNormale);
		requirementSheet.addCell(label);
		numeroLigne++;

		label = new Label(0, numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(1, numeroLigne, Language.getInstance().getText("Description_Branche") + " 2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(2, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(3, numeroLigne, Language.getInstance().getText("Description_Branche") + " 1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence, numeroLigne, Language.getInstance().getText("Exigence") + " 5", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE(), numeroLigne, "1", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_VERSION(), numeroLigne, "2", celluleNormale);
		requirementSheet.addCell(label);
		label = new Label(numeroColonneFeuilleExigence + getEXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE(), numeroLigne, Language.getInstance().getText("Url_Exemple2"), celluleNormale);
		requirementSheet.addCell(label);
		for (int i = 0; i < requirementSheet.getColumns(); i++) {
			for (int j = 1; j < requirementSheet.getRows(); j++) {
				if (requirementSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					requirementSheet.addCell(label);

				}
			}
		}

		// page test
		numeroLigne = 1;
		label = new Label(getTEST_FAMILLE_TESTS(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_DESCRIPTION_FAMILLE_TESTS(), numeroLigne, Language.getInstance().getText("Description_Famille") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_SUITE_TESTS(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_DESCRIPTION_SUITE_TESTS(), numeroLigne, Language.getInstance().getText("Description_Suite") + " 1", celluleNormale);
		testSheet.addCell(label);

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE(), numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE() +1 , numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 1", celluleNormale);
			testSheet.addCell(label);
		}

		label = new Label(getTEST_CAS_DE_TESTS(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_DESCRIPTION_TESTS(), numeroLigne, Language.getInstance().getText("Description_Test") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_NUMERO(), numeroLigne, " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 1", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		label = new Label(getTEST_NUMERO(), numeroLigne, " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER(), numeroLigne, Language.getInstance() .getText("Action_A_realiser") + " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 2", celluleNormale);
		numeroLigne++;

		label = new Label(getTEST_NUMERO(), numeroLigne, " 3", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER(), numeroLigne, Language.getInstance() .getText("Action_A_realiser") + " 3", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 3", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		label = new Label(getTEST_FAMILLE_TESTS(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_DESCRIPTION_FAMILLE_TESTS(), numeroLigne, Language.getInstance().getText("Description_Famille") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_SUITE_TESTS(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_DESCRIPTION_SUITE_TESTS(), numeroLigne, Language.getInstance().getText("Description_Suite") + " 1", celluleNormale);
		testSheet.addCell(label);

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE(), numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE() + 1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 1", celluleNormale);
			testSheet.addCell(label);
		}

		label = new Label(getTEST_CAS_DE_TESTS(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_NUMERO(), numeroLigne, " A1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 4", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 4", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE(), numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE() + 1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 2", celluleNormale);
			testSheet.addCell(label);
		}

		label = new Label(getTEST_NUMERO(), numeroLigne, " A2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 5", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 5", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE(), numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE() + 1, numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 3", celluleNormale);
			testSheet.addCell(label);
		}
		numeroLigne++;

		label = new Label(getTEST_FAMILLE_TESTS(), numeroLigne, Language.getInstance().getText("Famille") + " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_DESCRIPTION_FAMILLE_TESTS(), numeroLigne, Language.getInstance().getText("Description_Famille") + " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_SUITE_TESTS(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_DESCRIPTION_SUITE_TESTS(), numeroLigne, Language.getInstance().getText("Description_Suite") + " 1", celluleNormale);
		testSheet.addCell(label);

		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			label = new Label(getTEST_EXIGENCE_ASSOCIEE(), numeroLigne, Language.getInstance().getText("Branche") + " 2", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EXIGENCE_ASSOCIEE() + 1, numeroLigne, Language.getInstance().getText("Branche") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(colonneExigenceDansFeuilleTest, numeroLigne, Language.getInstance().getText("Exigence") + " 4", celluleNormale);
			testSheet.addCell(label);
		}

		label = new Label(getTEST_CAS_DE_TESTS(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 5", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_NUMERO(), numeroLigne, " 1", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 6", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 6", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		label = new Label(getTEST_NUMERO(), numeroLigne, " 2", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_ACTION_A_REALISER(), numeroLigne, Language.getInstance().getText("Action_A_realiser") + " 7", celluleNormale);
		testSheet.addCell(label);
		label = new Label(getTEST_RESULTAT_ATTENDU(), numeroLigne, Language.getInstance().getText("Resultat_Attendu") + " 7", celluleNormale);
		testSheet.addCell(label);
		numeroLigne++;

		if(TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner()==true||TestPresencePlugin.testDeLaPresenceDuPluginBeanShell()==true||TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit()==true){
			label = new Label(getTEST_FAMILLE_TESTS(), numeroLigne, Language.getInstance().getText("Famille") + " 3", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_SUITE_TESTS(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_CAS_DE_TESTS(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 6", celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_TYPE_SCRIPT_AUTOMATIQUE(), numeroLigne, Language.getInstance().getText("Beanshell"), celluleNormale);
			testSheet.addCell(label);
			label = new Label(getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE(), numeroLigne, Language.getInstance().getText("Script_path"), celluleNormale);
			testSheet.addCell(label);
		}
		for (int i = 0; i < testSheet.getColumns(); i++) {
			for (int j = 1; j < testSheet.getRows(); j++) {
				if (testSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					testSheet.addCell(label);
				}
			}
		}

		//page parametre
		numeroLigne = 1;
		label = new Label(getPARAMETRE_NOM(), numeroLigne, Language.getInstance().getText("Parametre") +  " 1", celluleNormale);
		paramSheet.addCell(label);
		label = new Label(getPARAMETRE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Parametres") + " 1", celluleNormale);
		paramSheet.addCell(label);
		numeroLigne++;
		label = new Label(getPARAMETRE_NOM(), numeroLigne, Language.getInstance().getText("Parametre") +  " 2", celluleNormale);
		paramSheet.addCell(label);
		label = new Label(getPARAMETRE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Parametres") + " 2", celluleNormale);
		paramSheet.addCell(label);
		numeroLigne++;
		label = new Label(getPARAMETRE_NOM(), numeroLigne, Language.getInstance().getText("Parametre") +  " 3", celluleNormale);
		paramSheet.addCell(label);
		label = new Label(getPARAMETRE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Parametres") + " 3", celluleNormale);
		paramSheet.addCell(label);

//		page environnement
		numeroLigne = 1;
		label = new Label(getENVIRONNEMENT_NOM(), numeroLigne, Language.getInstance().getText("Environnement") +  " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Environnement") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_LIEN_HYPERTEXTE(), numeroLigne, Language.getInstance().getText("Url_Exemple"), celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_PIECE_JOINTE(), numeroLigne, Language.getInstance().getText("Document") + ".doc", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM(), numeroLigne, Language.getInstance().getText("Environnement") +  " 2", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Environnement") + " 2", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 2", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 2", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 3", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 3", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM(), numeroLigne, Language.getInstance().getText("Environnement") +  " 3", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description_Environnement") + " 3", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		enviroSheet.addCell(label);
		numeroLigne++;
		label = new Label(getENVIRONNEMENT_NOM_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 3", celluleNormale);
		enviroSheet.addCell(label);
		label = new Label(getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		enviroSheet.addCell(label);

		for (int i = 0; i < enviroSheet.getColumns(); i++) {
			for (int j = 1; j < enviroSheet.getRows(); j++) {
				if (enviroSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					enviroSheet.addCell(label);
				}
			}
		}

		//page Campagne
		numeroLigne = 1;
		label = new Label(getCAMPAGNE_NOM(), numeroLigne, Language.getInstance().getText("Campagne") +  " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description") +  " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_JEU_DONNEES(), numeroLigne, Language.getInstance().getText("Nom_Jeu_de_donnees") +  " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION_JEU_DONNEES(), numeroLigne, Language.getInstance().getText("Description_Jeu_de_donnees") +  " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_JEU_DONNEES_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_JEU_DONNEES_VALEURPARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 1", celluleNormale);
		campagneSheet.addCell(label);		
		label = new Label(getCAMPAGNE_FAMILLE_TEST(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_SUITE_TEST(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_TEST(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_LIEN_HYPERTEXTE(), numeroLigne, Language.getInstance().getText("Url_Exemple"), celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_PIECE_JOINTE(), numeroLigne, Language.getInstance().getText("Document") + ".doc", celluleNormale);
		campagneSheet.addCell(label);
		numeroLigne++;
		label = new Label(getCAMPAGNE_NOM_JEU_DONNEES(), numeroLigne, Language.getInstance().getText("Nom_Jeu_de_donnees") +  " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION_JEU_DONNEES(), numeroLigne, Language.getInstance().getText("Description_Jeu_de_donnees") +  " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_FAMILLE_TEST(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_SUITE_TEST(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_JEU_DONNEES_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_JEU_DONNEES_VALEURPARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_TEST(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 2", celluleNormale);
		campagneSheet.addCell(label);
		numeroLigne++;
		label = new Label(getCAMPAGNE_NOM(), numeroLigne, Language.getInstance().getText("Campagne") +  " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description") +  " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_JEU_DONNEES(), numeroLigne, Language.getInstance().getText("Nom_Jeu_de_donnees") +  " 3", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION_JEU_DONNEES(), numeroLigne, Language.getInstance().getText("Description_Jeu_de_donnees") +  " 3", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_JEU_DONNEES_PARAMETRE(), numeroLigne, Language.getInstance().getText("Parametre") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_JEU_DONNEES_VALEURPARAMETRE(), numeroLigne, Language.getInstance().getText("Valeur") + " 3", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_FAMILLE_TEST(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_SUITE_TEST(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_TEST(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		numeroLigne++;
		label = new Label(getCAMPAGNE_NOM(), numeroLigne, Language.getInstance().getText("Campagne") +  " 3", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_DESCRIPTION(), numeroLigne, Language.getInstance().getText("Description") +  " 3", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_FAMILLE_TEST(), numeroLigne, Language.getInstance().getText("Famille") + " 2", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_SUITE_TEST(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		campagneSheet.addCell(label);
		label = new Label(getCAMPAGNE_NOM_TEST(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 5", celluleNormale);
		campagneSheet.addCell(label);
		for (int i = 0; i < campagneSheet.getColumns(); i++) {
			for (int j = 1; j < campagneSheet.getRows(); j++) {
				if (campagneSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					campagneSheet.addCell(label);
				}
			}
		}

		//Page execution des campagnes
		numeroLigne=1;
		label = new Label(getCAMPAGNEEEXECUTION_NOM(), numeroLigne, Language.getInstance().getText("Campagne") + " 1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_NOM_EXECUTION(), numeroLigne, Language.getInstance().getText("Nom_Execution") + " 1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_ENVIRONNEMENT(), numeroLigne, Language.getInstance().getText("Environnement") + " 3", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_NOM_JEU_DONNEES(), numeroLigne, Language.getInstance().getText("Nom_Jeu_de_donnees") + " 3", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE(), numeroLigne, Language.getInstance().getText("Url_Exemple") , celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_PIECE_JOINTE(), numeroLigne, Language.getInstance().getText("Document") + ".doc", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION(), numeroLigne, Language.getInstance().getText("Nom_Resultat_Execution") + " 1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION(), numeroLigne, Language.getInstance().getText("terminee"), celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_FAMILLE_TEST(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_SUITE_TEST(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_NOM_TEST(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST(), numeroLigne, Language.getInstance().getText("passed"), celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getLIEN_HYPERTEXTE_TEST_EXECUTE_CAMPAGNEEEXECUTION(), numeroLigne, Language.getInstance().getText("Url_Exemple") , celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getPIECE_JOINTE_TEST_EXECUTE_CAMPAGNEEEXECUTION(), numeroLigne, Language.getInstance().getText("Document") + ".doc", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getNUMERO_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, "1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getRESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, Language.getInstance().getText("passed"), celluleNormale);
		execCampSheet.addCell(label);
		numeroLigne++;
		label = new Label(getNUMERO_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, "2", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getRESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, Language.getInstance().getText("passed"), celluleNormale);
		execCampSheet.addCell(label);
		numeroLigne++;
		label = new Label(getNUMERO_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, "3", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getRESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, Language.getInstance().getText("passed"), celluleNormale);
		execCampSheet.addCell(label);
		numeroLigne++;
		label = new Label(getCAMPAGNEEEXECUTION_FAMILLE_TEST(), numeroLigne, Language.getInstance().getText("Famille") + " 1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_SUITE_TEST(), numeroLigne, Language.getInstance().getText("Suite") + " 1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_NOM_TEST(), numeroLigne, Language.getInstance().getText("cas_de_tests") + " 2", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getCAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST(), numeroLigne, Language.getInstance().getText("passed"), celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getNUMERO_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, "A1", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getRESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, Language.getInstance().getText("passed"), celluleNormale);
		execCampSheet.addCell(label);
		numeroLigne++;
		label = new Label(getNUMERO_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, "A2", celluleNormale);
		execCampSheet.addCell(label);
		label = new Label(getRESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroLigne, Language.getInstance().getText("passed"), celluleNormale);
		execCampSheet.addCell(label);
		for (int i = 0; i < execCampSheet.getColumns(); i++) {
			for (int j = 1; j < execCampSheet.getRows(); j++) {
				if (execCampSheet.getCell(i, j).getContents() == "") {
					label = new Label(i, j, "", celluleNormale);
					execCampSheet.addCell(label);
				}
			}
		}
	}

	/**
	 * Recupere la feuille Excel
	 * 
	 * @return Feuille Excel
	 */
	public WritableWorkbook getWorkbookHeading() {
		return workbook;
	}


	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getNumeroColonneFeuilleExigence() {
		return numeroColonneFeuilleExigence;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getNumeroColonneExigenceFeuilleExigenceTest() {
		return numeroColonneFeuilleExigence/2;
	}


	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @param nombre Numro de la colonne exigence
	 */
	public void setNumeroColonneFeuilleExigence(int nombre) {
		numeroColonneFeuilleExigence = nombre;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE() {
		return EXIGENCE_DIFFERENCE_COLONNE_PRIORITE;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_VERSION() {
		return EXIGENCE_DIFFERENCE_COLONNE_VERSION;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION() {
		return EXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_CATEGORIE() {
		return EXIGENCE_DIFFERENCE_COLONNE_CATEGORIE;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE() {
		return EXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_PIECE_JOINTE() {
		return EXIGENCE_DIFFERENCE_COLONNE_PIECE_JOINTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_COMPLEXITE() {
		return EXIGENCE_DIFFERENCE_COLONNE_COMPLEXITE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_ETAT() {
		return EXIGENCE_DIFFERENCE_COLONNE_ETAT;
	}
	//20100120 - Dbut modification Forge ORTF
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_CRITICITE() {
		return EXIGENCE_DIFFERENCE_COLONNE_CRITICITE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_COMPREHENSION() {
		return EXIGENCE_DIFFERENCE_COLONNE_COMPREHENSION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_PROPRIETAIRE() {
		return EXIGENCE_DIFFERENCE_COLONNE_PROPRIETAIRE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_VALIDE_PAR() {
		return EXIGENCE_DIFFERENCE_COLONNE_VALIDE_PAR;
	}
	//20100120 - Fin modification Forge ORTF
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_ORIGINE() {
		return EXIGENCE_DIFFERENCE_COLONNE_ORIGINE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_VERIFWAY() {
		return EXIGENCE_DIFFERENCE_COLONNE_VERIFWAY;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getEXIGENCE_DIFFERENCE_COLONNE_REFERENCE() {
		return EXIGENCE_DIFFERENCE_COLONNE_REFERENCE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_CAS_DE_TESTS() {
		return TEST_CAS_DE_TESTS;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_NUMERO() {
		return TEST_NUMERO;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_ACTION_A_REALISER() {
		return TEST_ACTION_A_REALISER;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_RESULTAT_ATTENDU() {
		return TEST_RESULTAT_ATTENDU;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_LIEN_HYPERTEXTE() {
		return TEST_LIEN_HYPERTEXTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_DESCRIPTION_SUITE_TESTS() {
		return TEST_DESCRIPTION_SUITE_TESTS;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_DESCRIPTION_FAMILLE_TESTS() {
		return TEST_DESCRIPTION_FAMILLE_TESTS;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_PIECE_JOINTE_ACTION() {
		if(TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner()==true||TestPresencePlugin.testDeLaPresenceDuPluginBeanShell()==true||TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit()==true){
			return TEST_PIECE_JOINTE_ACTION;	
		}else {
			return TEST_PIECE_JOINTE_ACTION-2;
		}
	}/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_LIEN_HYPERTEXTE_ACTION() {
		if(TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner()==true||TestPresencePlugin.testDeLaPresenceDuPluginBeanShell()==true||TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit()==true){
			return TEST_LIEN_HYPERTEXTE_ACTION;	
		}else {
			return TEST_LIEN_HYPERTEXTE_ACTION-2;
		}
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_PIECE_JOINTE() {
		return TEST_PIECE_JOINTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_DESCRIPTION_TESTS() {
		return TEST_DESCRIPTION_TESTS;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_EXIGENCE_ASSOCIEE() {
		if(TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner()==true||TestPresencePlugin.testDeLaPresenceDuPluginBeanShell()==true||TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit()==true){
			return TEST_EXIGENCE_ASSOCIEE;	
		}else {
			return TEST_EXIGENCE_ASSOCIEE-2;
		}
	}

	/**
	 * Renvoie le numro de la colonne Exigence pour l'criture dans la feuille Tests
	 * @return entier
	 */
	public int getTEST_EXIGENCE_ASSOCIEE_LIGHT() {
		if(TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner()==true||TestPresencePlugin.testDeLaPresenceDuPluginBeanShell()==true||TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit()==true){
			return TEST_EXIGENCE_ASSOCIEE_LIGHT;	
		}else {
			return TEST_EXIGENCE_ASSOCIEE_LIGHT-2;
		}
	}
	/**
	 * Fonction permettant d''obtenir le format de la cellule
	 * @return format de la cellule
	 */
	public WritableCellFormat getcelluleNormale() {
		return celluleNormale;
	}

	/**
	 * Fonction permettant d''obtenir le format de la cellule
	 * @return format de la cellule
	 */
	public WritableCellFormat getcelluleNormaleNombre() {
		return celluleNormaleNombre;
	}

	/**
	 * Fonction permettant d''obtenir le format de la cellule
	 * @return format de la cellule
	 */
	public WritableCellFormat getcelulleCentreeHetV() {
		return celulleCentreeHetV;
	}

	/**
	 * Fonction permettant d''obtenir le format de la cellule
	 * @return format de la cellule
	 */
	public WritableCellFormat getcelluleNormaleNombreH() {
		return celluleNormaleNombreH;
	}

	/**
	 * Fonction permettant d''obtenir le format de la cellule
	 * @return format de la cellule
	 */
	public WritableCellFormat getcelluleDescritpion() {
		return celluleDescritpion;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getPARAMETRE_DESCRIPTION() {
		return PARAMETRE_DESCRIPTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getPARAMETRE_NOM() {
		return PARAMETRE_NOM;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getENVIRONNEMENT_NOM() {
		return ENVIRONNEMENT_NOM;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getENVIRONNEMENT_DESCRIPTION() {
		return ENVIRONNEMENT_DESCRIPTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getENVIRONNEMENT_NOM_PARAMETRE() {
		return ENVIRONNEMENT_NOM_PARAMETRE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getENVIRONNEMENT_VALEUR_PARAMETRE() {
		return ENVIRONNEMENT_VALEUR_PARAMETRE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getENVIRONNEMENT_LIEN_HYPERTEXTE() {
		return ENVIRONNEMENT_LIEN_HYPERTEXTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getENVIRONNEMENT_PIECE_JOINTE() {
		return ENVIRONNEMENT_PIECE_JOINTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_NOM() {
		return CAMPAGNE_NOM;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_DESCRIPTION() {
		return CAMPAGNE_DESCRIPTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_NOM_JEU_DONNEES() {
		return CAMPAGNE_NOM_JEU_DONNEES;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_DESCRIPTION_JEU_DONNEES() {
		return CAMPAGNE_DESCRIPTION_JEU_DONNEES;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_FAMILLE_TEST() {
		return CAMPAGNE_FAMILLE_TEST;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_SUITE_TEST() {
		return CAMPAGNE_SUITE_TEST;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_NOM_TEST() {
		return CAMPAGNE_NOM_TEST;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_LIEN_HYPERTEXTE() {
		return CAMPAGNE_LIEN_HYPERTEXTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_PIECE_JOINTE() {
		return CAMPAGNE_PIECE_JOINTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_JEU_DONNEES_PARAMETRE() {
		return CAMPAGNE_JEU_DONNEES_PARAMETRE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNE_JEU_DONNEES_VALEURPARAMETRE() {
		return CAMPAGNE_JEU_DONNEES_VALEURPARAMETRE;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_NOM() {
		return CAMPAGNEEEXECUTION_NOM;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_NOM_EXECUTION() {
		return CAMPAGNEEEXECUTION_NOM_EXECUTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_ENVIRONNEMENT() {
		return CAMPAGNEEEXECUTION_ENVIRONNEMENT;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE() {
		return CAMPAGNEEEXECUTION_LIEN_HYPERTEXTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_PIECE_JOINTE() {
		return CAMPAGNEEEXECUTION_PIECE_JOINTE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION() {
		return CAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_FAMILLE_TEST() {
		return CAMPAGNEEEXECUTION_FAMILLE_TEST;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_SUITE_TEST() {
		return CAMPAGNEEEXECUTION_SUITE_TEST;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_NOM_TEST() {
		return CAMPAGNEEEXECUTION_NOM_TEST;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST() {
		return CAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getNUMERO_ACTION_TEST_CAMPAGNEEEXECUTION() {
		return NUMERO_ACTION_TEST_CAMPAGNEEEXECUTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getRESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION() {
		return RESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_NOM_JEU_DONNEES() {
		return CAMPAGNEEEXECUTION_NOM_JEU_DONNEES;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION() {
		return CAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getRESULTAT_OBTENU_CAMPAGNEEEXECUTION() {
		return RESULTAT_OBTENU_CAMPAGNEEEXECUTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_EXECUTE() {
		return TEST_EXECUTE;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE_TEST_EXECUTE() {
		return LIEN_HYPERTEXTE_TEST_EXECUTE_CAMPAGNEEEXECUTION;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getPIECE_JOINTE_TEST_EXECUTE_CAMPAGNEEEXECUTION() {
		return PIECE_JOINTE_TEST_EXECUTE_CAMPAGNEEEXECUTION;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getCAMPAGNEEEXECUTION_PIECE_JOINTE_TEST_EXECUTE() {
		return PIECE_JOINTE_TEST_EXECUTE_CAMPAGNEEEXECUTION;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_FAMILLE_TESTS() {
		return TEST_FAMILLE_TESTS;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_SUITE_TESTS() {
		return TEST_SUITE_TESTS;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE() {
		return TEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE;
	}

	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getTEST_TYPE_SCRIPT_AUTOMATIQUE() {
		return TEST_TYPE_SCRIPT_AUTOMATIQUE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getLIEN_HYPERTEXTE_TEST_EXECUTE_CAMPAGNEEEXECUTION() {
		return LIEN_HYPERTEXTE_TEST_EXECUTE_CAMPAGNEEEXECUTION;
	}


	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getID_ANOMALIE() {
		return ID_ANOMALIE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getURL_ANOMALIE() {
		return URL_ANOMALIE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getRESUME_ANOMALIE() {
		return RESUME_ANOMALIE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getDESCRIPTION_ANOMALIE() {
		return DESCRIPTION_ANOMALIE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getREPORTER_ANOMALIE() {
		return REPORTER_ANOMALIE;
	}
	/**
	 * Fonction permettant d''obtenir le numero de la colonne
	 * @return numero de la colonne
	 */
	public int getPROPRIETAIRE_ANOMALIE() {
		return PROPRIETAIRE_ANOMALIE;
	}


	/**
	 * Function that organise XLS file (merge cells, ...)
	 * @param feuilleExcel spreadsheet name
	 */
	public void masqueColonnesVides(WritableSheet feuilleExcel){
		// Supprime les colonnes vides
		boolean TestContenu;
		for (int i = 0; i <= feuilleExcel.getColumns(); i++) {
			TestContenu = false;
			for (int j = 1; j <= feuilleExcel.getRows() && TestContenu == false; j++) {
				Cell RequirementTest = feuilleExcel.getCell(i, j);
				if (feuilleExcel.getCell(i, j).getContents().length() > 0) {
					TestContenu = true;
				}			
			}

			if (TestContenu == false) {
				CellView colonneMasquee = new CellView();
				colonneMasquee.setHidden(true);
				feuilleExcel.setColumnView(i, colonneMasquee);

			}
		}
	}

	/**
	 * Function that organise XLS file (merge cells, ...)
	 * @param selectionExportEnvironnement parametre case a cocher
	 * @param selectionExportCampagne parametre case a cocher
	 * @param selectionExportExecutionCampagne parametre case a cocher
	 * @param selectionExportAnomalies parametre case a cocher
	 * @param selectionExportParametre parametre case a cocher
	 * @param selectionExportExigence parametre case a cocher
	 * @param selectionExportTest parametre case a cocher
	 * @param masquageColonnes True/false effectue le masquage et la fusion des cellules vides
	 * @throws jxl.write.WriteException Write Exception
	 */
	public void organizeXLSfile(boolean selectionExportExigence, boolean selectionExportTest,boolean selectionExportParametre, boolean selectionExportEnvironnement, boolean selectionExportCampagne, boolean selectionExportExecutionCampagne, boolean selectionExportAnomalies, boolean masquageColonnes) throws WriteException {

		int i = 0;
		int j = 0;

		if (masquageColonnes){
			masqueColonnesVides(requirementSheet);
			masqueColonnesVides(testSheet);
			masqueColonnesVides(enviroSheet);
			masqueColonnesVides(campagneSheet);
			masqueColonnesVides(execCampSheet);
		}
		if (selectionExportExigence){

			// Fonction permettant de fussionner les cellules de tableau d'exigences
			// pour faire une jolie presentation
			i = 0;
			j = 0;
			int CelulleAvecTexteColumn = 0;
			boolean celluleFusionne = false;

			for (j = 0; j < requirementSheet.getRows(); j++) {
				celluleFusionne = false;
				CelulleAvecTexteColumn = 0;
				for (i = 0; i < getNumeroColonneFeuilleExigence(); i++) {

					if (requirementSheet.getCell(i, j).getContents().length() == 0) {
						if (i > 0) {
							if (requirementSheet.getCell(i - 1, j).getContents().length() == 0) {
								CelulleAvecTexteColumn = i;
							} else {
								i = getNumeroColonneFeuilleExigence();

							}

						} else {
							CelulleAvecTexteColumn = i;
						}

					}
				}
				if (CelulleAvecTexteColumn != 0) {
					label = new Label(0, j, "", getcelulleCentreeHetV());
					requirementSheet.addCell(label);
					requirementSheet.mergeCells(0, j, CelulleAvecTexteColumn, j);
					celluleFusionne = true;
				}
				// partie pour fusionner le reste des colonnes sous themes vides
				if (requirementSheet.getCell(getNumeroColonneFeuilleExigence() - 1, j).getContents().length() == 0) {
					CelulleAvecTexteColumn = getNumeroColonneFeuilleExigence() - 1;

					while (requirementSheet.getCell(CelulleAvecTexteColumn, j).getContents().length() == 0&& CelulleAvecTexteColumn > 0) {
						CelulleAvecTexteColumn--;
					}

					CelulleAvecTexteColumn++;
					if ((celluleFusionne == false)&& (CelulleAvecTexteColumn < getNumeroColonneFeuilleExigence())) {
						label = new Label(CelulleAvecTexteColumn, j, "",getcelulleCentreeHetV());
						requirementSheet.addCell(label);
						requirementSheet.mergeCells(CelulleAvecTexteColumn, j, getNumeroColonneFeuilleExigence() - 1, j);
						celluleFusionne = true;
					}
				}

			}
		}


		// Fonction permettant de fussionner les cellules de tableau des tests
		//Supprime les colonnes vides
		if (selectionExportTest){
			Cell test;

			// Fonction permettant de fusionner les cellules de tableau environnement pour
			// faire une jolie presentation
			i =  getTEST_FAMILLE_TESTS();
			j = 0;



			for (j = 1; j < testSheet.getRows(); j++) {
				int CelulleAvecTexteRow = 0;
				test = testSheet.getCell(i, j);
				if (test.getContents().length() != 0){
					while(testSheet.getCell(i, j+CelulleAvecTexteRow+1).getContents().length() == 0 && (j+CelulleAvecTexteRow<testSheet.getRows())){
						CelulleAvecTexteRow++;
					}
					if (j+CelulleAvecTexteRow==testSheet.getRows()){
						CelulleAvecTexteRow--;
					}
					if (CelulleAvecTexteRow!=0){
						testSheet.mergeCells(getTEST_FAMILLE_TESTS(), j, getTEST_FAMILLE_TESTS(), j + CelulleAvecTexteRow);
						testSheet.mergeCells(getTEST_DESCRIPTION_FAMILLE_TESTS(), j, getTEST_DESCRIPTION_FAMILLE_TESTS(), j + CelulleAvecTexteRow);
						testSheet.mergeCells(getTEST_SUITE_TESTS(), j, getTEST_SUITE_TESTS(), j + CelulleAvecTexteRow);
						testSheet.mergeCells(getTEST_DESCRIPTION_SUITE_TESTS(), j, getTEST_DESCRIPTION_SUITE_TESTS(), j + CelulleAvecTexteRow);
						testSheet.mergeCells(getTEST_CAS_DE_TESTS(), j, getTEST_CAS_DE_TESTS(), j + CelulleAvecTexteRow);
						testSheet.mergeCells(getTEST_LIEN_HYPERTEXTE(), j, getTEST_LIEN_HYPERTEXTE(), j + CelulleAvecTexteRow);
						testSheet.mergeCells(getTEST_PIECE_JOINTE(), j, getTEST_PIECE_JOINTE(), j + CelulleAvecTexteRow);
						testSheet.mergeCells(getTEST_DESCRIPTION_TESTS(), j, getTEST_DESCRIPTION_TESTS(), j + CelulleAvecTexteRow);
						if ((testSheet.getCell(getTEST_TYPE_SCRIPT_AUTOMATIQUE(), j).getContents().length() == 0) && (testSheet.getCell(getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE(), j).getContents().length() == 0)){
							label = new Label(getTEST_TYPE_SCRIPT_AUTOMATIQUE(), j, "", getcelulleCentreeHetV());
							testSheet.addCell(label); 
							label = new Label(getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE(), j, "", getcelulleCentreeHetV());
							testSheet.addCell(label); 
							testSheet.mergeCells(getTEST_TYPE_SCRIPT_AUTOMATIQUE(), j, getTEST_TYPE_SCRIPT_AUTOMATIQUE(), j + CelulleAvecTexteRow);
							testSheet.mergeCells(getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE(), j, getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE(), j + CelulleAvecTexteRow);
						}
						j = j + CelulleAvecTexteRow;
					}	
				}
			}
			for (j = 0; j < testSheet.getRows(); j++) {
				//	fusionne de la colonne numero action a action executee
				if ((testSheet.getCell(getTEST_NUMERO(), j).getContents().length() == 0) && (testSheet.getCell(getTEST_ACTION_A_REALISER(), j).getContents().length() == 0) && (testSheet.getCell(getTEST_RESULTAT_ATTENDU(), j).getContents().length() == 0)){
					label = new Label(getTEST_NUMERO(), j, "", getcelulleCentreeHetV());
					testSheet.addCell(label);
					testSheet.mergeCells(getTEST_NUMERO(), j, getTEST_EXECUTE(), j);
				}
				// partie pour fusionner le reste des colonnes branches vides
				int minVide=0;
				int maxVide=0;
				for (int k= getTEST_EXIGENCE_ASSOCIEE(); k<= getTEST_EXIGENCE_ASSOCIEE() + getNumeroColonneExigenceFeuilleExigenceTest(); k++){
					if (testSheet.getCell(k, j).getContents().length() == 0){
						if (minVide==0){
							minVide= k;
						}
						maxVide=k;
					}
				}
				if ((minVide!=maxVide) && (minVide!=0)) {
					label = new Label(minVide, j, "", getcelulleCentreeHetV());
					testSheet.addCell(label);
					testSheet.mergeCells(minVide, j, maxVide, j);
				}
			}
		}


		//Partie parametre
		//Supprime les colonnes vides
		if (selectionExportParametre) {
			masqueColonnesVides(paramSheet);
		}


		//Partie environnement
		//Supprime les colonnes vides
		if (selectionExportEnvironnement) {
			Cell enviroTest;

			// Fonction permettant de fusionner les cellules de tableau environnement pour
			// faire une jolie presentation
			i =  getENVIRONNEMENT_NOM();
			j = 0;

			for (j = 1; j < enviroSheet.getRows(); j++) {
				int CelulleAvecTexteRow = 0;
				enviroTest = enviroSheet.getCell(i, j);
				if (enviroTest.getContents().length() > 0){
					while(enviroSheet.getCell(i, j+CelulleAvecTexteRow+1).getContents().length() == 0 && (j+CelulleAvecTexteRow<enviroSheet.getRows())){
						CelulleAvecTexteRow++;
					}
					if (j+CelulleAvecTexteRow==enviroSheet.getRows()){
						CelulleAvecTexteRow--;
					}
					if (CelulleAvecTexteRow!=0){
						//Merge nom environement
						enviroSheet.mergeCells(getENVIRONNEMENT_NOM(), j, getENVIRONNEMENT_NOM(), j + CelulleAvecTexteRow);
						//Merge Description
						enviroSheet.mergeCells(getENVIRONNEMENT_DESCRIPTION(), j, getENVIRONNEMENT_DESCRIPTION(), j + CelulleAvecTexteRow);
						//Merge Colonne URL
						enviroSheet.mergeCells(getENVIRONNEMENT_LIEN_HYPERTEXTE(), j, getENVIRONNEMENT_LIEN_HYPERTEXTE(), j + CelulleAvecTexteRow);
						//Merge Colonne File
						enviroSheet.mergeCells(getENVIRONNEMENT_PIECE_JOINTE(), j, getENVIRONNEMENT_PIECE_JOINTE(), j + CelulleAvecTexteRow);

						j = j + CelulleAvecTexteRow;
					}	
				}
			}
		}

//		Partie Campagnes
		//Supprime les colonnes vides
		if (selectionExportCampagne) {
			Cell campagneTest;

			//Fonction permettant de fusionner les cellules de tableau Camapgnes pour
			// faire une jolie presentation
			i =  getCAMPAGNE_NOM();
			j = 0;
			for (j = 1; j < campagneSheet.getRows(); j++) {
				//Fusions les lignes jeux de donnees
				if ((campagneSheet.getCell(getCAMPAGNE_NOM_JEU_DONNEES(),j).getContents().length() ==0)&&(campagneSheet.getCell(getCAMPAGNE_DESCRIPTION_JEU_DONNEES(),j).getContents().length() ==0)){
					label = new Label(getCAMPAGNE_NOM_JEU_DONNEES(),j, "", getcelulleCentreeHetV());
					campagneSheet.addCell(label);
					campagneSheet.mergeCells(getCAMPAGNE_NOM_JEU_DONNEES(),j,getCAMPAGNE_DESCRIPTION_JEU_DONNEES(),j);
				}
				if ((campagneSheet.getCell(getCAMPAGNE_JEU_DONNEES_PARAMETRE(),j).getContents().length() ==0)&&(campagneSheet.getCell(getCAMPAGNE_JEU_DONNEES_VALEURPARAMETRE(),j).getContents().length() ==0)){
					label = new Label(getCAMPAGNE_JEU_DONNEES_PARAMETRE(),j, "", getcelulleCentreeHetV());
					campagneSheet.addCell(label);
					campagneSheet.mergeCells(getCAMPAGNE_JEU_DONNEES_PARAMETRE(),j,getCAMPAGNE_JEU_DONNEES_VALEURPARAMETRE(),j);
				}
				if ((campagneSheet.getCell(getCAMPAGNE_FAMILLE_TEST(),j).getContents().length() ==0)&&(campagneSheet.getCell(getCAMPAGNE_SUITE_TEST(),j).getContents().length() ==0)&&(campagneSheet.getCell(getCAMPAGNE_NOM_TEST(),j).getContents().length() ==0)){
					label = new Label(getCAMPAGNE_FAMILLE_TEST(),j, "", getcelulleCentreeHetV());
					campagneSheet.addCell(label);
					campagneSheet.mergeCells(getCAMPAGNE_FAMILLE_TEST(),j,getCAMPAGNE_NOM_TEST(),j);
				}
			}

			for (j = 1; j < campagneSheet.getRows(); j++) {
				int CelulleAvecTexteRow = 0;
				campagneTest = campagneSheet.getCell(i, j);
				if (campagneTest.getContents().length() != 0){
					while(campagneSheet.getCell(i, j+CelulleAvecTexteRow+1).getContents().length() == 0 && (j+CelulleAvecTexteRow<campagneSheet.getRows())){
						CelulleAvecTexteRow++;
					}
					if (j+CelulleAvecTexteRow==campagneSheet.getRows()){
						CelulleAvecTexteRow--;
					}
					if (CelulleAvecTexteRow!=0){
						//Merge nom environement
						campagneSheet.mergeCells(getCAMPAGNE_NOM(), j, getCAMPAGNE_NOM(), j + CelulleAvecTexteRow);
						//Merge Description
						campagneSheet.mergeCells(getCAMPAGNE_DESCRIPTION(), j, getCAMPAGNE_DESCRIPTION(), j + CelulleAvecTexteRow);
						//Merge Colonne URL
						campagneSheet.mergeCells(getCAMPAGNE_LIEN_HYPERTEXTE(), j, getCAMPAGNE_LIEN_HYPERTEXTE(), j + CelulleAvecTexteRow);
						//Merge Colonne File
						campagneSheet.mergeCells(getCAMPAGNE_PIECE_JOINTE(), j, getCAMPAGNE_PIECE_JOINTE(), j + CelulleAvecTexteRow);

						j = j + CelulleAvecTexteRow;
					}	
				}
			}
		}

//		Partie Executions des Campagnes
		//Supprime les colonnes vides
		if (selectionExportExecutionCampagne){
			Cell execCampTest;

//			Fonction permettant de fusionner les cellules de tableau Execution des Campagnes pour
			// faire une jolie presentation	
			i =  getCAMPAGNEEEXECUTION_NOM();
			j = 0;

			for (j = 1; j < execCampSheet.getRows(); j++) {
				int CelulleAvecTexteRow = 0;
				execCampTest = execCampSheet.getCell(i, j);
				if (execCampTest.getContents().length() != 0){
					while(execCampSheet.getCell(i, j+CelulleAvecTexteRow+1).getContents().length() == 0 && (j+CelulleAvecTexteRow<execCampSheet.getRows())){
						CelulleAvecTexteRow++;
					}
					if (j+CelulleAvecTexteRow==execCampSheet.getRows()){
						CelulleAvecTexteRow--;
					}
					if (CelulleAvecTexteRow!=0){
						//Merge nom environement
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_NOM(), j, getCAMPAGNEEEXECUTION_NOM(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_NOM_EXECUTION(), j, getCAMPAGNEEEXECUTION_NOM_EXECUTION(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_ENVIRONNEMENT(), j, getCAMPAGNEEEXECUTION_ENVIRONNEMENT(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_NOM_JEU_DONNEES(), j, getCAMPAGNEEEXECUTION_NOM_JEU_DONNEES(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE(), j, getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_PIECE_JOINTE(), j, getCAMPAGNEEEXECUTION_PIECE_JOINTE(), j + CelulleAvecTexteRow);
						j = j + CelulleAvecTexteRow;
					}	
				}
			}

			i =  getCAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION();
			j = 0;
			for (j = 1; j < execCampSheet.getRows(); j++) {
				int CelulleAvecTexteRow = 0;
				execCampTest = execCampSheet.getCell(i, j);
				if (execCampTest.getContents().length() != 0){
					while(execCampSheet.getCell(i, j+CelulleAvecTexteRow+1).getContents().length() == 0 && (j+CelulleAvecTexteRow<execCampSheet.getRows())){
						CelulleAvecTexteRow++;
					}
					if (j+CelulleAvecTexteRow==execCampSheet.getRows()){
						CelulleAvecTexteRow--;
					}
					if (CelulleAvecTexteRow!=0){
						//Merge nom environnement
						execCampSheet.mergeCells(getCAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION(), j, getCAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION(), j, getCAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION(), j + CelulleAvecTexteRow);
						j = j + CelulleAvecTexteRow;
					}	
				}
			}

			i =  getCAMPAGNEEEXECUTION_FAMILLE_TEST();
			j = 0;
			for (j = 1; j < execCampSheet.getRows(); j++) {
				int CelulleAvecTexteRow = 0;
				execCampTest = execCampSheet.getCell(i, j);
				if (execCampTest.getContents().length() != 0){
					while(execCampSheet.getCell(i, j+CelulleAvecTexteRow+1).getContents().length() == 0 && (j+CelulleAvecTexteRow<execCampSheet.getRows())){
						CelulleAvecTexteRow++;
					}
					if (j+CelulleAvecTexteRow==execCampSheet.getRows()){
						CelulleAvecTexteRow--;
					}
					if (CelulleAvecTexteRow!=0){
						//Merge nom environement
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_FAMILLE_TEST(), j, getCAMPAGNEEEXECUTION_FAMILLE_TEST(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_SUITE_TEST(), j, getCAMPAGNEEEXECUTION_SUITE_TEST(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_NOM_TEST(), j, getCAMPAGNEEEXECUTION_NOM_TEST(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST(), j, getCAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE_TEST_EXECUTE(), j, getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE_TEST_EXECUTE(), j + CelulleAvecTexteRow);
						execCampSheet.mergeCells(getCAMPAGNEEEXECUTION_PIECE_JOINTE_TEST_EXECUTE(), j, getCAMPAGNEEEXECUTION_PIECE_JOINTE_TEST_EXECUTE(), j + CelulleAvecTexteRow);
						j = j + CelulleAvecTexteRow;
					}	
				}
			}
		}		
		nomFeuilles = workbook.getSheetNames();
		if (selectionExportExigence == false) {
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Exigences"))) {
					workbook.removeSheet(g);
				}
			}
		}
		nomFeuilles = workbook.getSheetNames();
		if (selectionExportTest == false) {
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Tests"))) {
					workbook.removeSheet(g);
				}
			}
		}
		nomFeuilles = workbook.getSheetNames();
		if (selectionExportParametre == false) {
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Parametres"))) {
					workbook.removeSheet(g);
				}
			}
		}
		nomFeuilles = workbook.getSheetNames();
		if (selectionExportEnvironnement == false) {
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Environnements"))) {
					workbook.removeSheet(g);
				}
			}
		}
		nomFeuilles = workbook.getSheetNames();
		if (selectionExportCampagne == false) {
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Campagnes"))) {
					workbook.removeSheet(g);
				}
			}
		}
		nomFeuilles = workbook.getSheetNames();
		if (selectionExportExecutionCampagne == false) {
			for (int g = 0; g < nomFeuilles.length; g++) {
				if (nomFeuilles[g].equals(Language.getInstance().getText("Execution_campagnes"))) {
					workbook.removeSheet(g);
				}
			}
		}
	}


	/**
	 * Function that organise XLS file (merge cells, ...)
	 * @param selectionExportEnvironnement parametre case a cocher
	 * @param selectionExportCampagne parametre case a cocher
	 * @param selectionExportExecutionCampagne parametre case a cocher
	 * @param selectionExportAnomalies parametre case a cocher
	 * @param selectionExportParametre parametre case a cocher
	 * @param selectionExportExigence parametre case a cocher
	 * @param selectionExportTest parametre case a cocher
	 * @param masquageColonnes True/false effectue le masquage et la fusion des cellules vides
	 * @throws jxl.write.WriteException Write Exception
	 */
	public void organizeXLSfileLight(boolean selectionExportExigence, boolean selectionExportTest,boolean selectionExportParametre, boolean selectionExportEnvironnement, boolean selectionExportCampagne, boolean selectionExportExecutionCampagne, boolean selectionExportAnomalies, boolean masquageColonnes) throws WriteException {

		int i = 0;
		int j = 0;

		if (selectionExportExigence){

			// Fonction permettant de fussionner les cellules de tableau d'exigences
			// pour faire une jolie presentation
			for (j = 1; j < requirementSheet.getRows(); j++) {
				for (i = 0; i < requirementSheet.getColumns(); i++) {
					if (requirementSheet.getCell(i,j).getContents().length()==0){
						label = new Label(i, j, "", getcelulleCentreeHetV());
						requirementSheet.addCell(label);
					}
				}
			}
		}	
		// Fonction permettant de fussionner les cellules de tableau des tests
		//Supprime les colonnes vides
		if (selectionExportTest){
			for (j = 1; j < testSheet.getRows(); j++) {
				for (i = 0; i < testSheet.getColumns(); i++) {
					if (testSheet.getCell(i,j).getContents().length()==0){
						label = new Label(i, j, "", getcelulleCentreeHetV());
						testSheet.addCell(label);
					}
				}		
			}
		}

		//Partie parametre
		//Supprime les colonnes vides
		if (selectionExportParametre) {
			for (j = 1; j < paramSheet.getRows(); j++) {
				for (i = 0; i < paramSheet.getColumns(); i++) {
					if (paramSheet.getCell(i,j).getContents().length()==0){
						label = new Label(i, j, "", getcelulleCentreeHetV());
						paramSheet.addCell(label);
					}
				}
			}
		}


		//Partie environnement
		//Supprime les colonnes vides
		if (selectionExportEnvironnement) {
			for (j = 1; j < enviroSheet.getRows(); j++) {
				for (i = 0; i < enviroSheet.getColumns(); i++) {
					if (enviroSheet.getCell(i,j).getContents().length()==0){
						label = new Label(i, j, "", getcelulleCentreeHetV());
						enviroSheet.addCell(label);
					}
				}
			}
		}



		//	Partie Campagnes
		//Supprime les colonnes vides
		if (selectionExportCampagne) {
			for (j = 1; j < campagneSheet.getRows(); j++) {
				for (i = 0; i < campagneSheet.getColumns(); i++) {
					if (campagneSheet.getCell(i,j).getContents().length()==0){
						label = new Label(i, j, "", getcelulleCentreeHetV());
						campagneSheet.addCell(label);
					}
				}
			}
		}


//		Partie Executions des Campagnes
		//Supprime les colonnes vides
		if (selectionExportExecutionCampagne){
			for (j = 1; j < execCampSheet.getRows(); j++) {
				for (i = 0; i < execCampSheet.getColumns(); i++) {
					if (execCampSheet.getCell(i,j).getContents().length()==0){
						label = new Label(i, j, "", getcelulleCentreeHetV());
						execCampSheet.addCell(label);
					}
				}
			}	
		}

	}


}
