/*
 * SalomeTMF is a Test Management Framework
 * Copyright (C) 2007 EDF / France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * @author Jrmie DEFAYE
 *
 * Contact: mikael.marche@rd.francetelecom.com
 */

package salomeTMF_plug.pluginxlsxml.Export;

import org.dom4j.Document;
import org.objectweb.salome_tmf.plugins.IPlugObject;
import salomeTMF_plug.docXML.export.Contexte;
import salomeTMF_plug.docXML.export.XmlGenerator;
import salomeTMF_plug.docXML.export.Contexte.OutFormat;

/**
 * Class which call DocXml plugin to import or Export Data
 * 
 * @author adm_dfej
 */

public class CallPackageDocXML {

    /**
     * Class that call package DocXML to parse XML file
     */
	public enum OutFormat {XML, HTML, DOCBOOK, EXCEL};
	private OutFormat outputFormat; 
	
	boolean initSelection = false;

	/**
	 * Get the File Separator (different between Unix and Windows)
	 */
	private String fs = System.getProperties().getProperty("file.separator");

	/**
	 * Creates a new instance of CallPackageDocXML
	 * 
	 * @param pIhm
	 *            Interface Homme Machine
	 * @param saveFileName2
	 *            Name of the XML file
	 */
	public CallPackageDocXML(IPlugObject pIhm, String saveFileName2) {

		final String xlsDirName = saveFileName2.substring(0, saveFileName2.lastIndexOf(fs));
		Document doc;
//		final Contexte pContexte = new Contexte(xlsDirName, null, "ISO-8859-1", outputFormat.EXCEL);
		final Contexte pContexte = new Contexte(xlsDirName, null, "ISO-8859-1", null);

		XmlGenerator generator;
		generator = new XmlGenerator(pIhm, pContexte);
		generator.addDocType = false;
		try {
			if (!isInitSelection()) {
				doc = generator.toDocumentDyna(null, null);
			} else {
				doc = generator.toDocument(null, null, null);
			}
			generator.documentToXML(doc, saveFileName2);

		} catch (final Exception ex) {
			ex.printStackTrace();
		}

	}

	/**
	 * Return initSelection
	 * 
	 * @return initSelection
	 */
	public boolean isInitSelection() {
		return initSelection;
	}

	/**
	 * Set initSelection
	 * 
	 * @param initSelection
	 *            The initSelection to set.
	 */
	public void setInitSelection(boolean initSelection) {
		this.initSelection = initSelection;
	}
}
