//20100128 - Dbut modification Forge ORTF v1.0.0
package salomeTMF_plug.pluginxlsxml.Export;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.UnsupportedEncodingException;
import java.net.URL;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.Vector;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JTextField;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import jxl.Cell;
import jxl.CellType;
import jxl.Workbook;
import jxl.WorkbookSettings;
import jxl.format.Alignment;
import jxl.format.VerticalAlignment;
import jxl.write.Label;
import jxl.write.WritableCell;
import jxl.write.WritableCellFormat;
import jxl.write.WritableSheet;
import jxl.write.WritableWorkbook;

import org.objectweb.salome_tmf.api.Util;
import org.objectweb.salome_tmf.api.data.FileAttachementWrapper;
import org.objectweb.salome_tmf.api.data.UrlAttachementWrapper;
import org.objectweb.salome_tmf.data.Test;
import org.objectweb.salome_tmf.data.UrlAttachment;
import org.objectweb.salome_tmf.ihm.main.SalomeTMFContext;
import org.objectweb.salome_tmf.ihm.main.datawrapper.DataModel;
import org.objectweb.salome_tmf.ihm.models.ScriptFileFilter;
import org.objectweb.salome_tmf.ihm.tools.Tools;
import org.objectweb.salome_tmf.plugins.core.ReqManager;

import salomeTMF_plug.pluginxlsxml.language.Language;
import salomeTMF_plug.pluginxlsxml.sqlWrapper.SQLWrapper;
import salomeTMF_plug.requirements.data.ReqFamily;
import salomeTMF_plug.requirements.data.ReqLeaf;
import salomeTMF_plug.requirements.data.Requirement;

/**
 * @author hchauvin
 *
 */
public class ExportCMMIDialog extends JDialog {

	/**
	 * Exigences sheet name in model.
	 */
	private final static String EXI_SHEET_NAME = "Exigences";
	
	private static String[] CMMI_FAMILY;
	
	/**
	 * Array of all predefine familly in model
	 */
	static {
		try {
			String[] tab = { new String("Metier".getBytes("UTF-8"), "UTF-8"), 
					new String("Ergonomie ".getBytes("UTF-8"), "UTF-8"), 
							new String("Technique".getBytes("UTF-8"), "UTF-8"), 
									new String("Performance".getBytes("UTF-8"), "UTF-8"), 
											new String("Securite".getBytes("UTF-8"), "UTF-8"), 
													new String("Documentaire".getBytes("UTF-8"), "UTF-8") };
			CMMI_FAMILY = tab;
		} catch (UnsupportedEncodingException e) {
			Util.err(e);
		}
	}

	private final static int ID_COLUMN = 0;
	private final static int NAME_COLUMN = 1; //match description in excel...
	private final static int STAT_COLUMN = 2;
	private final static int VERSION_COLUMN = 3;
	private final static int SRC_DOC_COLUMN = 4;
	private final static int VAL_BY_COLUMN = 5;
	private final static int PRIORITY_COLUMN = 6;
	private final static int COMPLEXITY_COLUMN = 7;
	private final static int CRITICITY_COLUMN = 8;
	private final static int COMPREHENTION_COLUMN = 9;
	private final static int OWNER_COLUMN = 10;
	private final static int TEST_CASE_COLUMN = 11;
	private final static int HISTORY_COLUMN = 13;
	
	/**
	 * Treatemetn duration for the progress bar.
	 */
	private final static int FINISH_TREATEMENT_COUNT = 3;
	
	/**
	 * The destination xls file.
	 */
	private String xlsFile;

	/**
	 * The temp file
	 */
	private File reportFile;

	/**
	 * Path to the dest file.
	 */
	private JTextField sauvTF;

	/**
	 * OK button
	 */
	private JButton valider;

	/**
	 * Cancel button
	 */
	private JButton annuler;

	/**
	 * Save button
	 */
	private JButton sauvButton;

	/**
	 * The progress bar
	 */
	private JProgressBar progress;

	/**
	 * Manager of the requirement plugin.
	 */
	private ReqManager reqManager;
	
	/**
	 * Number maximum of sub familly
	 */
	private int nbOfSSFamilles;
	
	/**
	 * Current Excel workbook
	 */
	private WritableWorkbook workbook;
	
	/**
	 * The family level of the actual Requirement tree node.
	 */
	private int actualFamilyLevel = 0;
	
	/**
	 * The sheet row actually treated
	 */
	private int actualRow = 0;

	/**
	 * Path to the conf file.
	 */
	final String XLS_XML_CFG_FILE = "/plugins/pluginxlsxml/cfg/Cfgxlsxml.properties";
	
	/**
	 * Conf.
	 */
	Properties cfg_prop = null;

	/**
	 * The exigences sheet.
	 */
	private WritableSheet exiSheet;

	/**
	 * Requirement tree root node.
	 */
	private DefaultMutableTreeNode reqRootNode;
	
	/**
	 * Number of node in the tree.
	 */
	private int treeSize = 0;
	
	/**
	 * Map with the current line of each predifine family.
	 */
	private Map<String, Integer> familyLines = new HashMap<String, Integer>();

	/**
	 * Create and display the export CMMI dialog.
	 * 
	 * @param reqMan Requirement plugin manager.
	 */
	public ExportCMMIDialog(ReqManager reqMan) {
		super(SalomeTMFContext.getInstance().getSalomeFrame(), true);
		reqManager = reqMan;
		// Fin rajout
		DataModel.reloadFromBase(false);

		JLabel sauvLabel = new JLabel(Language.getInstance().getText(
				"Fichier_de_sauvegarde"));
		sauvTF = new JTextField(30);
		sauvButton = new JButton(Language.getInstance().getText("Choisir"));
		sauvButton.addActionListener(new ActionListener() {

			public void actionPerformed(ActionEvent e) {
				JFileChooser fileChooser = new JFileChooser();
				fileChooser.addChoosableFileFilter(new ScriptFileFilter(
						Language.getInstance().getText("Fichier_XLS____xls_"),
						".xls"));
				int returnVal = fileChooser.showDialog(ExportCMMIDialog.this,
						Language.getInstance().getText("Selectionner"));
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					xlsFile = fileChooser.getSelectedFile().getAbsolutePath();
					if (xlsFile.indexOf(".") != -1) {
						if (!xlsFile.substring(xlsFile.lastIndexOf("."))
								.equals(".xls")) {
							xlsFile += ".xls";
						}
					} else {
						xlsFile += ".xls";
					}
					sauvTF.setText(xlsFile);
				}
			}
		});

		valider = new JButton(Language.getInstance().getText("OK"));
		valider.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if (sauvTF.getText().equals("")) {

					JOptionPane.showMessageDialog(ExportCMMIDialog.this,
							Language.getInstance().getText(
									"Vous_devez_entrez_un_nom_de_fichier"),
							Language.getInstance().getText("Erreur_"),
							JOptionPane.ERROR_MESSAGE);

				} else {

					Thread t = new Thread() {
						public void run() {
							// Instanciation et lancement du traitement
							try {
								sauvButton.setEnabled(false);
								valider.setEnabled(false);
								annuler.setEnabled(false);
								sauvTF.setEnabled(false);
								export();
							} catch (Exception ex) {
								Tools.ihmExceptionView(ex);
								progress.setIndeterminate(false);
								progress.setValue(0);
								sauvButton.setEnabled(true);
								valider.setEnabled(true);
								annuler.setEnabled(true);
								sauvTF.setEnabled(true);
							}
						}
					};
					t.start();

				}
			}
		});

		annuler = new JButton(Language.getInstance().getText("Annuler"));
		annuler.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				ExportCMMIDialog.this.dispose();
			}
		});

		// Gestion de la progressbar
		progress = new JProgressBar();
		JPanel progression = new JPanel(new FlowLayout(FlowLayout.CENTER));
		progression.add(progress);

		// Gestion des boutons
		JPanel sauvLabelPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		sauvLabelPanel.add(sauvLabel);
		JPanel sauvTFPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		sauvTFPanel.add(sauvTF);
		JPanel sauvButtonPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		sauvButtonPanel.add(sauvButton);

		JPanel sauvPanel = new JPanel();
		sauvPanel.setLayout(new BoxLayout(sauvPanel, BoxLayout.Y_AXIS));
		sauvPanel.setBorder(BorderFactory.createTitledBorder(""));
		sauvPanel.add(sauvLabelPanel);
		sauvPanel.add(sauvTFPanel);
		sauvPanel.add(sauvButtonPanel);

		JPanel buttons = new JPanel();
		buttons.add(valider);
		buttons.add(annuler);

		JPanel page = new JPanel();
		page.setLayout(new BoxLayout(page, BoxLayout.Y_AXIS));
		page.add(Box.createVerticalStrut(10));
		page.add(sauvPanel);
		page.add(Box.createVerticalStrut(10));
		page.add(progression);
		page.add(buttons);

		Container contentPaneFrame = this.getContentPane();
		contentPaneFrame.add(page, BorderLayout.CENTER);

		// setLocation(400, 100);
		setTitle(Language.getInstance().getText("Export_au_format_XLS") + " "
				+ Language.getInstance().getText("Version_Plugin"));
		centerScreen();
	}

	protected void centerScreen() {
		Dimension dim = getToolkit().getScreenSize();
		this.pack();
		Rectangle abounds = getBounds();
		setLocation((dim.width - abounds.width) / 2,
				(dim.height - abounds.height) / 2);
		this.setVisible(true);
		requestFocus();
	}

	/**
	 * Launch the export treatment.
	 */
	private void export() {
		Util.log("Start CMMI export.");
		progress.setIndeterminate(true);
		if (init()) {
			initMaxFamilyNumber();
			initFamilyLineTable();
			progress.setIndeterminate(false);
			progress.setMaximum(treeSize + FINISH_TREATEMENT_COUNT);
			progress.setValue(0);
			actualFamilyLevel = 0;
			insertRequirement(reqRootNode);
			copyFile();
		}
		Util.log("Finish CMMI export.");
		dispose();
	}
	
	/**
	 * Init the maiximum number of sub family.
	 */
	private void initMaxFamilyNumber(){
		nbOfSSFamilles = getNbMaxFamily(reqRootNode, 0);
		if(nbOfSSFamilles > 3){
			Util.log("Must add family columns to model");
			for(int i = 3; i < nbOfSSFamilles; i++){
				insertFamilyColumn(i);
			}
		} else {
			// model as by default 3 family column
			nbOfSSFamilles = 3;
		}
	}
	
	/**
	 * Get the line number for each predefine family.
	 */
	private void initFamilyLineTable(){
		for(int i = 0; i < CMMI_FAMILY.length; i++){
			Util.debug("Search base familly in model " + CMMI_FAMILY[i]);
			Cell cell = exiSheet.findLabelCell(CMMI_FAMILY[i]);
			if(cell == null){
				Util.err("CMMI model invalid, missing base familly " + CMMI_FAMILY[i]);
			} else {
				familyLines.put(CMMI_FAMILY[i], cell.getRow());
			}
		}
		int maxRow = exiSheet.getRows();
		if(maxRow < familyLines.get(CMMI_FAMILY[CMMI_FAMILY.length -1]) + 2){
			Util.log("Add new row to get Max row two line after last family");
			//add missing row
			WritableCell blankCell = new Label(maxRow + 1, 0, "");
			WritableCell blankCell2 = new Label(maxRow + 2, 0, "");
			try {
				exiSheet.addCell(blankCell);
				exiSheet.addCell(blankCell2);
			} catch (Exception e) {
				Util.err("Problem inserting new row: " + e.getMessage());
			}
		}
	}
	
	/**
	 * Update line number of predefine family.
	 * 
	 * @param row Row inserted.
	 */
	private void updateFamilyLines(int row){
		Integer line;
		String key;
		for(int i = 0; i < CMMI_FAMILY.length; i++){
			key = CMMI_FAMILY[i];
			line = familyLines.get(key);
			if(line >= row){
				familyLines.remove(key);
				familyLines.put(key, line + 1);
			}
		}
	}
	
	/**
	 * Add a sub family column.
	 * 
	 * @param column
	 */
	private void insertFamilyColumn(int column){
		Util.log("Add a sub family column.");
		exiSheet.insertColumn(column);
		exiSheet.setColumnView(column, exiSheet.getColumnView(column -1));
		try{
			for(int i = 0; i < exiSheet.getRows(); i++){
				exiSheet.addCell(exiSheet.getWritableCell(column -1, i).copyTo(column, i));
			}
		} catch(Exception e){
			Util.err("Erreur copying column cell: " + e.getMessage());
		}
		WritableCell titleCell = exiSheet.getWritableCell(column, 8);
		if (titleCell.getType() == CellType.LABEL){
			((Label) titleCell).setString("S/" + titleCell.getContents()); 
        }else {
        	Util.debug("This cell is not a label: " + titleCell.getType());
        	WritableCell newCell = new Label(column, actualRow, "S/" + titleCell.getContents());
        	if(titleCell.getCellFormat() != null)
        		newCell.setCellFormat(titleCell.getCellFormat());
        	if(titleCell.getWritableCellFeatures() != null)
        		newCell.setCellFeatures(titleCell.getWritableCellFeatures());
        	try {
				exiSheet.addCell(newCell);
			} catch (Exception e) {
				Util.err("Failled to change type to label: " + e.getMessage());
			}
        }
		System.out.println("Title set");
		
	}
	
	private void insertRow(){
		Util.debug("insert row at " + actualRow);
		exiSheet.insertRow(actualRow);
		updateFamilyLines(actualRow);
		try{
			exiSheet.setRowView(actualRow, exiSheet.getRowView(actualRow +1));
			for(int i = 0; i < exiSheet.getColumns(); i++){
				exiSheet.addCell(exiSheet.getWritableCell(i, actualRow +1).copyTo(i, actualRow));
			}
			// Reset first column row (family)
			WritableCell familyCell = exiSheet.getWritableCell(0, actualRow);
			if (familyCell.getType() == CellType.LABEL){
				((Label) familyCell).setString(""); 
	        }else {
	        	Util.debug("This cell is not a label: " + familyCell.getType());
	        	WritableCell newCell = new Label(0, actualRow, "");
	        	if(familyCell.getCellFormat() != null)
	        		newCell.setCellFormat(familyCell.getCellFormat());
	        	if(familyCell.getWritableCellFeatures() != null)
	        		newCell.setCellFeatures(familyCell.getWritableCellFeatures());
	        	try {
					exiSheet.addCell(newCell);
				} catch (Exception e) {
					Util.err("Failled to change type to label: " + e.getMessage());
				}
	        }
		} catch(Exception e){
			Util.err("Erreur copying row cell: " + e.getMessage());
		}
	}
	
	/**
	 * Get the number of sub family in requirement tree node.
	 * 
	 * @param parentNode
	 * @param actualNb
	 * @return The number of sub family in requirement tree node.
	 */
	private int getNbMaxFamily(DefaultMutableTreeNode parentNode, int actualNb){
		DefaultMutableTreeNode child;
		treeSize+= parentNode.getChildCount();
		List<Integer> nbFound = new ArrayList<Integer>();
		for(int i=0; i < parentNode.getChildCount(); i++){
			child = (DefaultMutableTreeNode) parentNode.getChildAt(i);
			if(child.getUserObject() instanceof ReqFamily){
				nbFound.add(new Integer(getNbMaxFamily(child, actualNb + 1)));
			}
		}
		if(nbFound.size() == 0)
			return actualNb;
		int temp;
		for(Iterator<Integer> iter = nbFound.iterator(); iter.hasNext();){
			temp = ((Integer) iter.next()).intValue();
			actualNb = Math.max(actualNb, temp);
		}
		return actualNb;
	}
	
	/**
	 * Fill the family column.
	 * @param familyName
	 */
	private void updateFamilyRow(String familyName){
		Util.debug("Update family: " + actualFamilyLevel + " " + actualRow + " with " + familyName);
		WritableCell familyCell = exiSheet.getWritableCell(actualFamilyLevel, actualRow);
		if (familyCell.getType() == CellType.LABEL){
			((Label) familyCell).setString(familyName); 
        } else {
        	Util.debug("This cell is not a label: " + familyCell.getType());
        	WritableCell newCell = new Label(actualFamilyLevel, actualRow, familyName);
        	if(familyCell.getCellFormat() != null)
        		newCell.setCellFormat(familyCell.getCellFormat());
        	if(familyCell.getWritableCellFeatures() != null)
        		newCell.setCellFeatures(familyCell.getWritableCellFeatures());
        	try {
				exiSheet.addCell(newCell);
			} catch (Exception e) {
				Util.err("Failled to change type to label: " + e.getMessage());
			}
        }
	}
	
	/**
	 * Fill the excel with the current requirement tree node.
	 * 
	 * @param parentNode
	 */
	private void insertRequirement(DefaultMutableTreeNode parentNode){
		DefaultMutableTreeNode child;
		boolean precWasFamily = false;
		for(int i = 0; i < parentNode.getChildCount(); i++){
			child = ((DefaultMutableTreeNode)parentNode.getChildAt(i));
			Object value = child.getUserObject();
			if(value instanceof ReqFamily){
				// it is a family or sub family
				precWasFamily = true;
				String family = ((ReqFamily) value).getNameFromModel();
				System.out.println("Family child: " + family);
				if(actualFamilyLevel == 0){
					// it is a new family -> insert new row
					actualRow = getFamilyLine(family);
					insertRow();
				} else {
					// it is a sub family
					if(i != 0){
						// it is a new sub family -> insert new row
						insertRow();
					}
				}
				// fill the matching family column with family name
				updateFamilyRow(family);
				actualFamilyLevel++;
				// treat family child
				insertRequirement(child);
				actualFamilyLevel--;
			} else {
				if(value instanceof ReqLeaf){
					// it is a requirement
					ReqLeaf req = (ReqLeaf) value;
					if(actualFamilyLevel == 0){
						// new req without family.
						actualRow = getFamilyLine(null);
						insertRow();
					} else {
						if(i != 0){
							//it is a new requirement
							insertRow();
							if(precWasFamily && !parentNode.equals(reqRootNode)){
								// it is a req after a sub family, we must rewrite in the new row is own family path
								actualFamilyLevel--;
								updateFamilyRow(((ReqFamily)parentNode.getUserObject()).getNameFromModel());
								actualFamilyLevel++;
							}
						}
					}
					// update row with requirement.
					updateLeaf(req);
					actualRow++;
					precWasFamily = false;
				} else {
					Util.err("Invalid Node: " + value);
				}
			}
			progress.setValue(progress.getValue() +1);
		}
	}
	
	/**
	 * Fill Excel with current requirement.
	 * 
	 * @param requirement
	 */
	private void updateLeaf(ReqLeaf requirement){
		int id = requirement.getIdBdd();
		PreparedStatement prep;
		ResultSet stmtRes;
//		ID
		updateReqCell(ID_COLUMN + nbOfSSFamilles, Integer.toString(id));
//		NAME
		updateReqCell(NAME_COLUMN + nbOfSSFamilles, requirement.getNameFromModel());
//		STAT
		try {
			prep = SQLWrapper.getSQLSelectQuery("recupStatByID");
			prep.setInt(1, requirement.getStateFromModel());
			stmtRes = SQLWrapper.runSelectQuery(prep);
			if(stmtRes.next()){
				updateReqCell(STAT_COLUMN + nbOfSSFamilles, stmtRes.getString("name"));
			}
		} catch (Exception e) {
			Util.err(e);
		}
//		VERSION
		updateReqCell(VERSION_COLUMN + nbOfSSFamilles, requirement.getVersionFromModel());
//		SRC_DOC
		try{
			int nbrAttach = 0;
			String srcDoc = "";
			Vector urls = requirement.getAttachUrlsFromDB();
			UrlAttachementWrapper urlWrap = null;
			for(Iterator iter = urls.iterator(); iter.hasNext();){
				urlWrap = (UrlAttachementWrapper) iter.next();
				srcDoc += "url:" + new UrlAttachment(urlWrap).getUrl() +"\n";
				nbrAttach++;
			}
			Vector attachs = requirement.getAttachFilesFromDB();
			FileAttachementWrapper fileWrap = null;
			prep = SQLWrapper.getSQLSelectQuery("selectFileAttachFromDB");
			for(Iterator iter = attachs.iterator(); iter.hasNext();){
				fileWrap = (FileAttachementWrapper) iter.next();
				prep.setString(1, Integer.toString(fileWrap.getIdBDD()));
				stmtRes = SQLWrapper.runSelectQuery(prep);
				if (stmtRes.next()) {
					srcDoc += stmtRes.getString("url_attach") +"\n";
					nbrAttach++;
				}
			}
			if(srcDoc.length()>0){
				srcDoc = srcDoc.substring(0, srcDoc.length() -1);
			}
			updateReqCell(SRC_DOC_COLUMN + nbOfSSFamilles, srcDoc);
			// update cell size
			if(nbrAttach > 0){
				int size = exiSheet.getRowView(actualRow).getSize();
				exiSheet.setRowView(actualRow, size * nbrAttach);
			}
			// allow break line
			WritableCell reqCell = exiSheet.getWritableCell(SRC_DOC_COLUMN + nbOfSSFamilles, actualRow);
			WritableCellFormat format = new WritableCellFormat(reqCell.getCellFormat());
			format.setWrap(true);
			format.setAlignment(Alignment.LEFT);
			format.setVerticalAlignment(VerticalAlignment.TOP);
			reqCell.setCellFormat(format);
		} catch (Exception e) {
			Util.err(e);
		}
//		VAL_BY
		try {
			prep = SQLWrapper.getSQLSelectQuery("recupValidByByID");
			prep.setInt(1, requirement.getValidByFromModel());
			stmtRes = SQLWrapper.runSelectQuery(prep);
			if(stmtRes.next()){
				updateReqCell(VAL_BY_COLUMN + nbOfSSFamilles, stmtRes.getString("name"));
			}
		} catch (Exception e) {
			Util.err(e);
		}
//		PRIORITY
		try {
			prep = SQLWrapper.getSQLSelectQuery("recupPriorityByID");
			prep.setInt(1, requirement.getPriorityFromModel());
			stmtRes = SQLWrapper.runSelectQuery(prep);
			if(stmtRes.next()){
				updateReqCell(PRIORITY_COLUMN + nbOfSSFamilles, stmtRes.getString("name"));
			}
		} catch (Exception e) {
			Util.err(e);
		}
//		COMPLEXITY
		try {
			prep = SQLWrapper.getSQLSelectQuery("recupComplexityByID");
			prep.setInt(1, requirement.getComplexeFromModel());
			stmtRes = SQLWrapper.runSelectQuery(prep);
			if(stmtRes.next()){
				updateReqCell(COMPLEXITY_COLUMN + nbOfSSFamilles, stmtRes.getString("name"));
			}
		} catch (Exception e) {
			Util.err(e);
		}
//		CRITICAL
		try {
			prep = SQLWrapper.getSQLSelectQuery("recupCriticityByID");
			prep.setInt(1, requirement.getCriticalFromModel());
			stmtRes = SQLWrapper.runSelectQuery(prep);
			if(stmtRes.next()){
				updateReqCell(CRITICITY_COLUMN + nbOfSSFamilles, stmtRes.getString("name"));
			}
		} catch (Exception e) {
			Util.err(e);
		}
//		UNDERSTADING
		try {
			prep = SQLWrapper.getSQLSelectQuery("recupUnderstandingByID");
			prep.setInt(1, requirement.getUnderstandingFromModel());
			stmtRes = SQLWrapper.runSelectQuery(prep);
			if(stmtRes.next()){
				updateReqCell(COMPREHENTION_COLUMN + nbOfSSFamilles, stmtRes.getString("name"));
			}
		} catch (Exception e) {
			Util.err(e);
		}
//		OWNER
		try {
			prep = SQLWrapper.getSQLSelectQuery("recupOwnerByID");
			prep.setInt(1, requirement.getOwnerFromModel());
			stmtRes = SQLWrapper.runSelectQuery(prep);
			if(stmtRes.next()){
				updateReqCell(OWNER_COLUMN + nbOfSSFamilles, stmtRes.getString("name"));
			}
		} catch (Exception e) {
			Util.err(e);
		}
//		TEST_CASE_COLUMN
		try {
			prep = SQLWrapper.getSQLSelectQuery("recupCaseTestID");
			prep.setInt(1, requirement.getIdBdd());
			stmtRes = SQLWrapper.runSelectQuery(prep);
			String testCase;
			String testCases = "";
			ResultSet res;
			PreparedStatement prep2;
			int count = 0;
			while(stmtRes.next()){
				testCase = "";
				prep2 = SQLWrapper.getSQLSelectQuery("recupCaseTest");
				prep2.setInt(1, stmtRes.getInt("CAS_TEST_id_cas"));
				res = SQLWrapper.runSelectQuery(prep2);
				if(res.next()){
					testCase = res.getString("nom_cas");
					prep2 = SQLWrapper.getSQLSelectQuery("recupSuiteTest");
					prep2.setInt(1, res.getInt("SUITE_TEST_id_suite"));
					res = SQLWrapper.runSelectQuery(prep2);
					if(res.next()){
						testCase = res.getString("nom_suite") + "/" + testCase;
						prep2 = SQLWrapper.getSQLSelectQuery("recupFamille");
						prep2.setInt(1, res.getInt("FAMILLE_TEST_id_famille"));
						res = SQLWrapper.runSelectQuery(prep2);
						if(res.next()){
							testCase = res.getString("nom_famille") + "/" + testCase;
							if (count == 0)
								testCases = testCase;
							else
								testCases += "\n" + testCase;
							count++;
						}
					}
				}
			}
			if(!testCases.equalsIgnoreCase("")){
				updateReqCell(TEST_CASE_COLUMN + nbOfSSFamilles, testCases);
				// update cell size
				int size = exiSheet.getRowView(actualRow).getSize();
				exiSheet.setRowView(actualRow, size * count);
				WritableCell reqCell = exiSheet.getWritableCell(TEST_CASE_COLUMN + nbOfSSFamilles, actualRow);
				// allow break line
				WritableCellFormat format = new WritableCellFormat(reqCell.getCellFormat());
				format.setWrap(true);
				format.setAlignment(Alignment.LEFT);
				format.setVerticalAlignment(VerticalAlignment.TOP);
				reqCell.setCellFormat(format);
			}
			
		} catch (Exception e) {
			Util.err(e);
		}
//		not need of IMPACTED_DOC_COLUMN
//		HISTORY_COLUMN
//		try{
//			String history = "";
//			HistoryWrapper[] historys = requirement.getHistory();
//			HistoryWrapper wrap;
//			for(int k= 0; k < historys.length; k++){
//				wrap = historys[k];
//				history += wrap.getDate().toString() + " / " + Requirement.getStringCodeValue(wrap.getCode()) 
//					+ " / " + convertHistoryValue(wrap.getValeur(), wrap.getCode());
//				if(k != historys.length -1){
//					history += "\n";
//				}
//			}
//			if(!history.equalsIgnoreCase("")){
//				updateReqCell(HISTORY_COLUMN + nbOfSSFamilles, history);
//				WritableCell reqCell = exiSheet.getWritableCell(HISTORY_COLUMN + nbOfSSFamilles, actualRow);
//				WritableCellFormat format = new WritableCellFormat(reqCell.getCellFormat());
//				format.setWrap(true);
//				format.setAlignment(Alignment.LEFT);
//				format.setVerticalAlignment(VerticalAlignment.TOP);
//				reqCell.setCellFormat(format);
//			}
//		} catch (Exception e) {
//			e.printStackTrace();
//		}
		
	}
	
	
	/**
	 * Ugly method that return true history value...
	 * 
	 * @param value id of value
	 * @param code type of value
	 * @return true history value
	 */
	private String convertHistoryValue(String value, int code){
		String valeur = value;
		PreparedStatement prep;
		ResultSet result;
		if (Requirement.isTestIdValeur(code)){
			Test pTest = (Test) DataModel.getCurrentProject().getTestFromModel(new Integer(valeur).intValue());
			if (pTest != null){
				valeur = pTest.getNameFromModel();
			}
		} else if (Requirement.isStateValeur(code)){
			int state = new Integer(valeur).intValue();
			try {
				prep = SQLWrapper.getSQLSelectQuery("recupStatByID");
				prep.setInt(1, state);
				result = SQLWrapper.runSelectQuery(prep);
				if (result.next()){
					valeur = result.getString(1);
				}
			} catch (Exception e1) {
				Util.err(e1);
			}
		} else if (Requirement.isPriorityValeur(code)){
			int priority = new Integer(valeur).intValue();
			try {
				prep = SQLWrapper.getSQLSelectQuery("recupPriorityByID");
				prep.setInt(1, priority);
				result = SQLWrapper.runSelectQuery(prep);
				if (result.next()){
					valeur = result.getString(1);
				}
			} catch (Exception e1) {
				Util.err(e1);
			}
		} else if (Requirement.isComplexityValeur(code)){
			int comp = new Integer(valeur).intValue();
			try {
				prep = SQLWrapper.getSQLSelectQuery("recupComplexityByID");
				prep.setInt(1, comp);
				result = SQLWrapper.runSelectQuery(prep);
				if (result.next()){
					valeur = result.getString(1);
				}
			} catch (Exception e1) {
				Util.err(e1);
			}
		} else if (Requirement.isCategoryValeur(code)){
			int cat = new Integer(valeur).intValue();
			try {
				prep = SQLWrapper.getSQLSelectQuery("recupCategoryByID");
				prep.setInt(1, cat);
				result = SQLWrapper.runSelectQuery(prep);
				if (result.next()){
					valeur = result.getString(1);
				}
			} catch (Exception e1) {
				Util.err(e1);
			}
		} else if (Requirement.isValidByValeur(code)){
			int validBy = new Integer(valeur).intValue();
			try {
				prep = SQLWrapper.getSQLSelectQuery("recupValidByByID");
				prep.setInt(1, validBy);
				result = SQLWrapper.runSelectQuery(prep);
				if (result.next()){
					valeur = result.getString(1);
				}
			} catch (Exception e1) {
				Util.err(e1);
			}
		} else if (Requirement.isCriticalValeur(code)){
			int critical = new Integer(valeur).intValue();
			try {
				prep = SQLWrapper.getSQLSelectQuery("recupCriticityByID");
				prep.setInt(1, critical);
				result = SQLWrapper.runSelectQuery(prep);
				if (result.next()){
					valeur = result.getString(1);
				}
			} catch (Exception e1) {
				Util.err(e1);
			}
		} else if (Requirement.isUnderstandingValeur(code)){
			int understanding = new Integer(valeur).intValue();
			try {
				prep = SQLWrapper.getSQLSelectQuery("recupUnderstandingByID");
				prep.setInt(1, understanding);
				result = SQLWrapper.runSelectQuery(prep);
				if (result.next()){
					valeur = result.getString(1);
				}
			} catch (Exception e1) {
				Util.err(e1);
			}
		} else if (Requirement.isOwnerValeur(code)){
			int owner = new Integer(valeur).intValue();
			try {
				prep = SQLWrapper.getSQLSelectQuery("recupOwnerByID");
				prep.setInt(1, owner);
				result = SQLWrapper.runSelectQuery(prep);
				if (result.next()){
					valeur = result.getString(1);
				}
			} catch (Exception e1) {
				Util.err(e1);
			}
		}
		return valeur;
	}
	
	/**
	 * Method to fill an excel cell
	 * 
	 * @param column
	 * @param value
	 */
	private void updateReqCell(int column, String value){
		Util.debug("Update cell: " + column + " " + actualRow);
		WritableCell reqCell = exiSheet.getWritableCell(column, actualRow);
		if (reqCell.getType() == CellType.LABEL){
			((Label) reqCell).setString(value); 
        } else {
        	Util.debug("This cell is not a label: " + reqCell.getType());
        	WritableCell newCell = new Label(column, actualRow, value);
        	if(reqCell.getCellFormat() != null)
        		newCell.setCellFormat(reqCell.getCellFormat());
        	if(reqCell.getWritableCellFeatures() != null)
        		newCell.setCellFeatures(reqCell.getWritableCellFeatures());
        	try {
				exiSheet.addCell(newCell);
			} catch (Exception e) {
				Util.err("Failled to change type to label: " + e.getMessage());
			}
        }
	}
	
	/**
	 * Get the line of a predefine family.
	 * 
	 * @param familyName
	 * @return The line of a predefine family.
	 */
	private int getFamilyLine(String familyName){
		System.out.println("Search line for " + familyName);
		if(familyName != null){
			Integer line = familyLines.get(familyName);
			if(line != null){
				return line;
			}
		}
		return exiSheet.getRows();
	}

	/**
	 * Get the Excel workbook model.
	 * 
	 * @return
	 */
	private boolean init() {
		initWorkingModelOfWorkbook();
		if (workbook != null) {
			exiSheet = workbook.getSheet(0);
			Util.debug("Exigences sheet found: "
					+ exiSheet.getName());
			if (exiSheet.getName().trim().equalsIgnoreCase(
					EXI_SHEET_NAME)) {
				Util.debug("Sheet name OK");
				if (setReqRootNode(reqManager)) {
					Util.debug("Root req model OK");
					return true;
				}
			}
		}
		Util.err("Failed to get a temp excel file");
		return false;
	}

	/**
	 * Init a temp excel file, copy of the model.
	 * 
	 */
	private void initWorkingModelOfWorkbook() {
		try {
			URL _urlBase = SalomeTMFContext.getInstance().getUrlBase();
			String url_txt = _urlBase.toString();
			url_txt = url_txt.substring(0, url_txt.lastIndexOf("/"));
			URL urlBase = new URL(url_txt);

			java.net.URL url_cfg = new java.net.URL(urlBase + XLS_XML_CFG_FILE);
			try {
				cfg_prop = Util.getPropertiesFile(url_cfg);
			} catch (Exception ex) {
				cfg_prop = Util.getPropertiesFile(XLS_XML_CFG_FILE);
			}

			URL url = new java.net.URL(urlBase
					+ cfg_prop.getProperty("Modele_CMMI"));
			
			Util.debug("File URL of model " + url.getFile());
			InputStream in = url.openStream();
			File downloadFile = File.createTempFile("downloadCMMI", ".xls");
			Util.debug("Downloaded file at  " + downloadFile.getAbsolutePath());
			FileOutputStream writenFile = new FileOutputStream(downloadFile);
			byte[] buff = new byte[1024];
			int l = in.read(buff);
			while (l > 0) {
				writenFile.write(buff, 0, l);
				l = in.read(buff);
			}
			writenFile.flush();
			writenFile.close();
			in.close();
			reportFile = File.createTempFile("exportCMMI", ".xls");
			Util.debug("Temp file at  " + reportFile.getAbsolutePath());
			Workbook model = Workbook.getWorkbook(downloadFile);
			WorkbookSettings setting = new WorkbookSettings();
			setting.setCellValidationDisabled(true);
			setting.setIgnoreBlanks(true);
			setting.setDrawingsDisabled(false);
			setting.setPropertySets(false);
			setting.setFormulaAdjust(true);
			System.out.println("setting ok");
			workbook = Workbook.createWorkbook(reportFile, model, setting);
		} catch (Exception ex) {
			System.out.println("Exception occur during create temp file " + ex.getMessage());
			Tools.ihmExceptionView(ex);
		}
	}

	/**
	 * Retrieve the requirement tree root.
	 * 
	 * @param reqManager
	 * @return
	 */
	private boolean setReqRootNode(ReqManager reqManager) {
		String projectName = DataModel.getCurrentProject().getNameFromModel();
		reqRootNode = (DefaultMutableTreeNode) ((DefaultTreeModel) reqManager
				.getTreeRequirement().getModel()).getRoot();
		return ((ReqFamily) reqRootNode.getUserObject()).getNameFromModel()
				.equalsIgnoreCase("Requirements_" + projectName);
	}

	/**
	 * Write the final Excel file.
	 */
	private void copyFile() {
		try {
			File exit = new File(xlsFile);
			if(exit.exists()){
				exit.delete();
			}
			exit.createNewFile();
			progress.setValue(progress.getValue() + 1);
			workbook.setOutputFile(exit);
			workbook.write();
			workbook.close();
			progress.setValue(progress.getValue() + 1);
			reportFile.delete();
			progress.setValue(progress.getValue() + 1);
		} catch (Exception ex) {
			Util.err(ex);
			Tools.ihmExceptionView(ex);
		}
	}

}
//20100128 - Fin modification Forge ORTF v1.0.0
