/*
 * SalomeTMF is a Test Management Framework
 * Copyright (C) 2007 EDF / France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * @author Jeremie DEFAYE
 *
 * Contact: mikael.marche@rd.francetelecom.com
 */

package salomeTMF_plug.pluginxlsxml.Export;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Vector;

import javax.swing.JCheckBox;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JTabbedPane;
import javax.swing.JTextField;
import javax.swing.tree.DefaultMutableTreeNode;

import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.java.plugin.Extension;
import org.objectweb.salome_tmf.ihm.main.SalomeTMFContext;
import org.objectweb.salome_tmf.ihm.main.datawrapper.DataModel;
import org.objectweb.salome_tmf.ihm.models.ScriptFileFilter;
import org.objectweb.salome_tmf.ihm.tools.Tools;
import org.objectweb.salome_tmf.plugins.IPlugObject;
import org.objectweb.salome_tmf.plugins.JPFManager;
import org.objectweb.salome_tmf.plugins.core.XMLLoaderPlugin;
import org.objectweb.salome_tmf.plugins.core.XMLPrinterPlugin;

import salomeTMF_plug.pluginxlsxml.Commun.TestPresencePlugin;
import salomeTMF_plug.pluginxlsxml.language.Language;
import salomeTMF_plug.requirements.ImportXMLReq;
import salomeTMF_plug.requirements.ReqPlugin;
import salomeTMF_plug.requirements.ihm.RequirementPanel;

import salomeTMF_plug.docXML.export.*;

/**
 * Open a dialog box for selecting a XlS file to export data
 *
 * @author Jeremie DEFAYE
 */
public class ExportXLSDialog extends JDialog {

	// Salome GUI
	private IPlugObject pIhm = null;

	private URL urlBase;

	private String url_txt;
	private String fichierDeSortieXLS;
	private String xlsFile;

	private JLabel sauvLabel;
	private JLabel choixExport;

	private JTextField sauvTF;

	private JButton sauvButton;

	private JCheckBox exportTest;
	private JCheckBox exportExigence;
	private JCheckBox exportParametre;
	private JCheckBox exportEnvironnement;
	private JCheckBox exportCampagne;
	private JCheckBox exportExecutionCampagne;
	private JCheckBox exportAnomalies;
	private JCheckBox fusionCellule;

	private File fichierDeSortieXML;

	private Document doc;

	private JProgressBar progress;

	private JButton valider;
	private JButton annuler;

	private boolean isAnnule = false;
	private boolean isInitSelection = false;

	private ArrayList suiteSelectionList;
	private ArrayList familySelectionList;
	private ArrayList testSelectionList;

	private DefaultMutableTreeNode chosenRoot;

	/**
	 * Get the File Separator (different between Unix and Windows)
	 */
	private String fs = System.getProperties().getProperty("file.separator");

	// Partie ImportXML
	private XMLPrinterPlugin pXMLPrinterPlugin;

	private Vector listXMLPlugin = new Vector();

	Vector panelsPluginsForImport = new Vector();


	/**
	 * Creates a new instance of ExportDialog
	 *
	 * @param vt
	 *            Interface Homme Machine
	 */
	public ExportXLSDialog(IPlugObject vt) {
		super(SalomeTMFContext.getInstance().getSalomeFrame(), true);
		setTitle(Language.getInstance().getText("Export_des_exigences"));
		pIhm = vt;
		urlBase = SalomeTMFContext.getInstance().getUrlBase();
		String _urlBase = urlBase.toString();
		url_txt = _urlBase.substring(0, _urlBase.lastIndexOf("/"));

		// Rajout SalomeV3
		Vector listExtXMLPlugin = pIhm.getXMLPrintersExtension();
		int size = listExtXMLPlugin.size();
		for (int i = 0; i < size; i++) {
			Extension pXMLExt = (Extension) listExtXMLPlugin.elementAt(i);
			JPFManager pJPFManager = pIhm.getPluginManager();
			try {
				pXMLPrinterPlugin = (XMLPrinterPlugin) pJPFManager
						.activateExtension(pXMLExt);
				if (!listXMLPlugin.contains(pXMLPrinterPlugin)) {
					listXMLPlugin.add(pXMLPrinterPlugin);
				}
				JPanel pPanel = pXMLPrinterPlugin.getExportOptionPanel();
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		// Fin rajout

		DataModel.reloadFromBase(false);

		fusionCellule = new JCheckBox(Language.getInstance().getText("fusion_Cellule"));
		fusionCellule.setSelected(true);

		sauvLabel = new JLabel(Language.getInstance().getText(
				"Fichier_de_sauvegarde"));
		sauvTF = new JTextField(30);
		sauvButton = new JButton(Language.getInstance().getText("Choisir"));
		sauvButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				JFileChooser fileChooser = new JFileChooser();
				fileChooser.addChoosableFileFilter(new ScriptFileFilter(
						Language.getInstance().getText("Fichier_XLS____xls_"),
						".xls"));
				int returnVal = fileChooser.showDialog(ExportXLSDialog.this,
						Language.getInstance().getText("Selectionner"));
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					xlsFile = fileChooser.getSelectedFile().getAbsolutePath();
					if (xlsFile.indexOf(".") != -1) {
						if (!xlsFile.substring(xlsFile.lastIndexOf("."))
								.equals(".xls")) {
							xlsFile += ".xls";
						}
					} else {
						xlsFile += ".xls";
					}
					sauvTF.setText(xlsFile);
				}
			}
		});

		valider = new JButton(Language.getInstance().getText("OK"));
		valider.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				if ((!selectionExportTest()) && (!selectionExportExigence()) && (!selectionExportParametre()) && (!selectionExportEnvironnement()) && (!selectionExportCampagne()) && (!selectionExportExecutionCampagne()) && (!selectionExportAnomalies())) {
					JOptionPane.showMessageDialog(ExportXLSDialog.this,
									Language.getInstance().getText("Vous_devez_selectionner_un_element_a_exporter"),
									Language.getInstance().getText("Erreur_"),
									JOptionPane.ERROR_MESSAGE);

				} else if (sauvTF.getText().equals("")) {

					JOptionPane.showMessageDialog(ExportXLSDialog.this, Language
							.getInstance().getText(
									"Vous_devez_entrez_un_nom_de_fichier"),
							Language.getInstance().getText("Erreur_"),
							JOptionPane.ERROR_MESSAGE);

				} else {

					Thread t = new Thread() {
						public void run() {
							// Instanciation et lancement du traitement
							try {
								progress.setIndeterminate(true);
								sauvButton.setEnabled(false);
								valider.setEnabled(false);
								annuler.setEnabled(false);
								exportTest.setEnabled(false);
								exportExigence.setEnabled(false);
								exportParametre.setEnabled(false);
								exportEnvironnement.setEnabled(false);
								exportCampagne.setEnabled(false);
								exportExecutionCampagne.setEnabled(false);
								exportAnomalies.setEnabled(false);
								sauvTF.setEnabled(false);
								fusionCellule.setEnabled(false);
								export();
							} catch (Exception ex) {
								Tools.ihmExceptionView(ex);
							}
						}
					};
					t.start();

				}
			}
		});

		annuler = new JButton(Language.getInstance().getText("Annuler"));
		annuler.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				ExportXLSDialog.this.dispose();
			}
		});

		// Gestion du choix d'export
		choixExport = new JLabel(Language.getInstance().getText("Exporter"));
		exportTest = new JCheckBox(Language.getInstance().getText("Tests"));
		exportTest.setSelected(true);

		exportExigence = new JCheckBox(Language.getInstance().getText("Exigences"));
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			exportExigence.setSelected(true);
		}else {
			exportExigence.setSelected(false);
		}

		exportParametre = new JCheckBox(Language.getInstance().getText("Parametres"));
		exportParametre.setSelected(true);

		exportEnvironnement = new JCheckBox(Language.getInstance().getText("Environnements"));
		exportEnvironnement.setSelected(true);

		exportCampagne = new JCheckBox(Language.getInstance().getText("Campagnes"));
		exportCampagne.setSelected(true);

		exportExecutionCampagne = new JCheckBox(Language.getInstance().getText("Execution_campagnes"));
		exportExecutionCampagne.setSelected(true);

		exportAnomalies = new JCheckBox(Language.getInstance().getText("Anomalies"));
		exportAnomalies.setSelected(true);

		JPanel importTestPanel = new JPanel();
		importTestPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		importTestPanel.add(choixExport);

		JPanel selectTestPanel = new JPanel();
		selectTestPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		selectTestPanel.add(exportTest);

		JPanel selectExigencePanel = new JPanel();
		selectExigencePanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		selectExigencePanel.add(exportExigence);

		JPanel selectParametrePanel = new JPanel();
		selectParametrePanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		selectParametrePanel.add(exportParametre);

		JPanel selectEnvironnementPanel = new JPanel();
		selectEnvironnementPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		selectEnvironnementPanel.add(exportEnvironnement);

		JPanel selectCampagnePanel = new JPanel();
		selectCampagnePanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		selectCampagnePanel.add(exportCampagne);

		JPanel selectExecutionCampagnePanel = new JPanel();
		selectExecutionCampagnePanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		selectExecutionCampagnePanel.add(exportExecutionCampagne);

		JPanel selectAnomaliesPanel = new JPanel();
		selectAnomaliesPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		selectAnomaliesPanel.add(exportAnomalies);

		JPanel selectTexteExportPanel = new JPanel();
		selectTexteExportPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		selectTexteExportPanel.add(importTestPanel);


		JPanel importPanel = new JPanel();
		importPanel.setLayout(new GridLayout(4,2));
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			importPanel.add(selectExigencePanel);
		} else {
			exportExigence.setSelected(false);
		}
		importPanel.add(selectTestPanel);
		importPanel.add(selectParametrePanel);
		importPanel.add(selectEnvironnementPanel);
		importPanel.add(selectCampagnePanel);
		importPanel.add(selectExecutionCampagnePanel);
		importPanel.add(selectAnomaliesPanel);

		JPanel selectPanel = new JPanel();
		selectPanel.setLayout(new BoxLayout(selectPanel, BoxLayout.Y_AXIS));
		selectPanel.setBorder(BorderFactory.createTitledBorder(""));
		selectPanel.add(selectTexteExportPanel);
		selectPanel.add(importPanel);

		// Gestion de la progressbar
		progress = new JProgressBar();
		JPanel progression = new JPanel(new FlowLayout(FlowLayout.CENTER));
		progression.add(progress);

		// Gestion des boutons
		JPanel sauvLabelPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		sauvLabelPanel.add(sauvLabel);
		JPanel sauvTFPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		sauvTFPanel.add(sauvTF);
		JPanel sauvButtonPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		sauvButtonPanel.add(sauvButton);

		JPanel sauvPanel = new JPanel();
		sauvPanel.setLayout(new BoxLayout(sauvPanel, BoxLayout.Y_AXIS));
		sauvPanel.setBorder(BorderFactory.createTitledBorder(""));
		sauvPanel.add(sauvLabelPanel);
		sauvPanel.add(sauvTFPanel);
		sauvPanel.add(sauvButtonPanel);

		JPanel buttons = new JPanel();
		buttons.add(valider);
		buttons.add(annuler);

		JPanel checkBoxFusion = new JPanel();
		checkBoxFusion.setLayout(new FlowLayout(FlowLayout.LEFT));
		checkBoxFusion.setBorder(BorderFactory.createTitledBorder(""));
		checkBoxFusion.add(fusionCellule);

		JPanel page = new JPanel();
		page.setLayout(new BoxLayout(page, BoxLayout.Y_AXIS));
		page.add(Box.createVerticalStrut(10));
		page.add(sauvPanel);
		page.add(Box.createVerticalStrut(10));
		page.add(selectTexteExportPanel);
		page.add(selectPanel);
		page.add(Box.createVerticalStrut(10));
		page.add(checkBoxFusion);
		page.add(Box.createVerticalStrut(10));
		page.add(progression);
		page.add(buttons);

		Container contentPaneFrame = this.getContentPane();
		contentPaneFrame.add(page, BorderLayout.CENTER);

		//setLocation(400, 100);
		setTitle(Language.getInstance().getText("Export_au_format_XLS") + " " + Language.getInstance().getText("Version_Plugin"));
		centerScreen();
	}

	protected void centerScreen() {
		Dimension dim = getToolkit().getScreenSize();
		this.pack();
		Rectangle abounds = getBounds();
		setLocation((dim.width - abounds.width) / 2, (dim.height - abounds.height) / 2);
		this.setVisible(true);
		requestFocus();
	}
	/**
	 * Start exporting data process
	 */
	public void export() {
		boolean ok = true;
		String fichierXML = null;
		setInitSelection(false);
		if (sauvTF.getText().equals("")) {

			JOptionPane.showMessageDialog(ExportXLSDialog.this,
					Language.getInstance().getText("Vous_devez_entrez_un_nom_de_fichier"),
					Language.getInstance().getText("Erreur_"),
					JOptionPane.ERROR_MESSAGE);
			ok = false;

		} else {

			String saveFileName = sauvTF.getText().trim();
			fichierXML = createXmlFile(saveFileName);
			CallPackageDocXML test = new CallPackageDocXML(pIhm, fichierXML);

			try {

				FromXmlToExcel Transformation = new FromXmlToExcel(fichierXML, selectionExportExigence(), selectionExportTest(), selectionExportParametre(), selectionExportEnvironnement(), selectionExportCampagne(), selectionExportExecutionCampagne(), selectionExportAnomalies(), selectionFusionCellule());
				isAnnule = Transformation.getWriteErrorXLS();
				fichierDeSortieXLS = Transformation.getfichierDeSortieXLS();
			} catch (DocumentException ex) {
				ex.printStackTrace();
			} catch (Exception ex) {
				ex.printStackTrace();
			}
		}

		// supprime fichier temporaire XML
		File file = new File(fichierXML);
		file.delete();

		// Test si export echec
		File file2 = new File(fichierDeSortieXLS);
		if (!file2.canRead()) {
			file2.delete();
			progress.setIndeterminate(false);
			JOptionPane.showMessageDialog(ExportXLSDialog.this,
					Language.getInstance().getText("Erreur_Durant_Export."),
					Language.getInstance().getText("Erreur_"),
					JOptionPane.INFORMATION_MESSAGE);
			ExportXLSDialog.this.dispose();
		}

		if (ok && !isAnnule) {
			progress.setIndeterminate(false);
			JOptionPane.showMessageDialog(ExportXLSDialog.this,
					Language.getInstance().getText("L_export_s_est_terminee_avec_succes"),
					Language.getInstance().getText("Information"),
					JOptionPane.INFORMATION_MESSAGE);
			ExportXLSDialog.this.dispose();
		} else {
			JOptionPane.showMessageDialog(ExportXLSDialog.this,
					Language.getInstance().getText("Erreur_Durant_Export."),
					Language.getInstance().getText("Erreur_"),
					JOptionPane.INFORMATION_MESSAGE);
			ExportXLSDialog.this.dispose();
		}
	}

	/**
	 * Get chosenRoot
	 *
	 * @return Returns the chosenRoot.
	 */
	public DefaultMutableTreeNode getChosenRoot() {
		return chosenRoot;
	}

	/**
	 * Set chosenRoot
	 *
	 * @param chosenRoot
	 *            The chosenRoot to set.
	 */
	public void setChosenRoot(DefaultMutableTreeNode chosenRoot) {
		this.chosenRoot = chosenRoot;
	}

	/**
	 * Get familySelectionList
	 *
	 * @return Returns the familySelectionList.
	 */
	public ArrayList getFamilySelectionList() {
		return familySelectionList;
	}

	/**
	 * Set familySelectionList
	 *
	 * @param familySelectionList
	 *            The familySelectionList to set.
	 */
	public void setFamilySelectionList(ArrayList familySelectionList) {
		this.familySelectionList = familySelectionList;
	}

	/**
	 * Get suiteSelectionList
	 *
	 * @return Returns the suiteSelectionList.
	 */
	public ArrayList getSuiteSelectionList() {
		return suiteSelectionList;
	}

	/**
	 * Set suiteSelectionList
	 *
	 * @param suiteSelectionList
	 *            The suiteSelectionList to set.
	 */
	public void setSuiteSelectionList(ArrayList suiteSelectionList) {
		this.suiteSelectionList = suiteSelectionList;
	}

	/**
	 * Get testSelectionList
	 *
	 * @return Returns the testSelectionList.
	 */
	public ArrayList getTestSelectionList() {
		return testSelectionList;
	}

	/**
	 * Set testSelectionList
	 *
	 * @param testSelectionList
	 *            The testSelectionList to set.
	 */
	public void setTestSelectionList(ArrayList testSelectionList) {
		this.testSelectionList = testSelectionList;
	}

	/**
	 * Get isInitSelection
	 *
	 * @return Returns the isInitSelection.
	 */
	public boolean isInitSelection() {
		return isInitSelection;
	}

	/**
	 * Return true si case a cocher tests est selectionnee
	 *
	 * @return true
	 */
	public boolean getTestSelection() {
		return false;
	}

	/**
	 * Return true si case a cocher Exigence est selectionnee
	 *
	 * @return isSelectionExportExigence
	 */
	public boolean getExigenceSelection() {
		return selectionExportExigence();
	}

	/**
     * Set isInitSelection
     * @param initSelection initSelection
     */
	public void setInitSelection(boolean initSelection) {
		this.isInitSelection = initSelection;
	}

	/**
	 * Creat a temporary XML file
	 *
	 * @param nomFichierXml
	 *            XLS file Name
	 * @return XML file Name
	 */
	public String createXmlFile(String nomFichierXml) {

		// Cree nom Fichier XML a partir nom Excel
		nomFichierXml = nomFichierXml.substring(0, nomFichierXml.lastIndexOf(".xls")) + ".xml";

		// Tente de creer le fichier XML
		fichierDeSortieXML = new File(nomFichierXml);
		int i = 0;
		while (fichierDeSortieXML.exists()) {
			if (i == 0) {
				System.out.println(Language.getInstance().getText("FileName_Already_Exists"));
					nomFichierXml = nomFichierXml.substring(0, nomFichierXml.lastIndexOf(".")) + Language.getInstance().getText("Underscore") + Integer.toString(i) + ".xml";
			} else {
				nomFichierXml = nomFichierXml.substring(0, nomFichierXml.lastIndexOf(Language.getInstance().getText("Underscore"))) + Language.getInstance().getText("Underscore") + Integer.toString(i) + ".xml";
			}

			fichierDeSortieXML = new File(nomFichierXml);
			i++;
		}
		System.out.println(Language.getInstance().getText("Fichier_Sortie_XML") + fichierDeSortieXML.toString());
		try {
			fichierDeSortieXML.createNewFile();
		} catch (IOException ex) {
			System.out.println(Language.getInstance().getText("Erreur_Fichier_Sortie_XML") + fichierDeSortieXML.toString());
			ex.printStackTrace();
		}
		return fichierDeSortieXML.toString();
	}
	/**
	 * Fonction qui retourne si la case Tests est coch�e pour l'export
	 * @return boolean
	 */
	public boolean selectionExportTest(){
		return exportTest.isSelected();
	}
	/**
	 * Fonction qui retourne si la case Exigences est coch�e pour l'export
	 * @return boolean
	 */
	public boolean selectionExportExigence(){
		return exportExigence.isSelected();
	}
	/**
	 * Fonction qui retourne si la case Param�tres est coch�e pour l'export
	 * @return boolean
	 */
	public boolean selectionExportParametre(){
		return exportParametre.isSelected();
	}
	/**
	 * Fonction qui retourne si la case Environnements est coch�e pour l'export
	 * @return boolean
	 */
	public boolean selectionExportEnvironnement(){
		return exportEnvironnement.isSelected();
	}
	/**
	 * Fonction qui retourne si la case Campagnes est coch�e pour l'export
	 * @return boolean
	 */
	public boolean selectionExportCampagne(){
		return exportCampagne.isSelected();
	}
	/**
	 * Fonction qui retourne si la case Execution des campagnes est coch�e pour l'export
	 * @return boolean
	 */
	public boolean selectionExportExecutionCampagne(){
		return exportExecutionCampagne.isSelected();
	}
	/**
	 * Fonction qui retourne si la case Anomalies est coch�e pour l'export
	 * @return boolean
	 */
	public boolean selectionExportAnomalies(){
		return exportAnomalies.isSelected();
	}
	/**
	 * Fonction qui retourne si la case Fusion des cellules est coch�e pour l'export
	 * @return boolean
	 */
	public boolean selectionFusionCellule(){
		return fusionCellule.isSelected();
	}
}
