/*
 * SalomeTMF is a Test Management Framework
 * Copyright (C) 2007 EDF / France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * @author Jeremie DEFAYE
 *
 * Contact: mikael.marche@rd.francetelecom.com
 */

package salomeTMF_plug.pluginxlsxml.Export;

import java.io.File;
import java.io.IOException;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;

import jxl.Cell;
import jxl.write.WritableSheet;

import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.dom4j.XPath;
import org.dom4j.io.SAXReader;

import jxl.write.Number;
import jxl.CellView;
import jxl.write.Formula;
import jxl.write.Label;
import jxl.write.WritableWorkbook;
import jxl.write.WriteException;
import jxl.write.biff.RowsExceededException;

import salomeTMF_plug.pluginxlsxml.Commun.EcritEntete;
import salomeTMF_plug.pluginxlsxml.Commun.TestPresencePlugin;
import salomeTMF_plug.pluginxlsxml.language.Language;

/**
 * Read a XML file, generated by SalomeTMF via DocXML Plugin, having
 * requirements and test cases, and transform it in XLS file
 * 
 * @author adm_dfej
 * 
 * @covers SFD_ForgeORTF_EXG_EXP_000070 - 2.7.11
 * @covers SFD_ForgeORTF_EXG_EXP_000080 - 2.7.11
 * Jira : FORTF - 47
 */
public class FromXmlToExcel {
	private WritableWorkbook workbook;
	private WritableSheet requirementSheet;
	private WritableSheet testSheet;
	private WritableSheet paramSheet;
	private WritableSheet enviroSheet;
	private WritableSheet campagneSheet;
	private WritableSheet execCampSheet;
	private WritableSheet anomaliesSheet;

	private Document documentXml;
	private File fichierDeSortieXLS;
	private int numeroColonne = 0;
	private int numeroLigne = 0;
	private int nombreLigneRequirementLu = 0;
	private int numeroColonneSheetExigence = 0;
	private int numeroColonneSheetBranche = 0;
	private int numeroColonneSheetTest = 0;
	private int nombreExigenceParCasDeTests = 0;
	private int nombreActionsParCasDeTests = 0;
	private Label label;
	private Number nombre;
	private String nomFichierXLS;
//	private String themeValue;
	private ArrayList<String> brancheID = new ArrayList<String>();
	private ArrayList<String> descriptionBrancheID = new ArrayList<String>();
	
	private EcritEntete ecritEntete;
	private String resulEffectif = "";
	private String resulActionEffectif= "";
	private boolean isErreurEcritureXLS = false;
	private boolean masquageColonne = true;
	private String xmlDir;
//	private String[] nomFeuilles;
	
	/**
	 * Get the File Separator (different between Unix and Windows)
	 */
	private String fs = System.getProperties().getProperty("file.separator");

	/**
	 * Function that transform the XML file to a XLS file
	 * @param selectionExportParametre parametre case a cocher
	 * @param selectionExportEnvironnement parametre case a cocher
	 * @param selectionExportCampagne parametre case a cocher
	 * @param selectionExportExecutionCampagne parametre case a cocher
	 * @param selectionExportAnomalies parametre case a cocher
	 * @param selectionExportExigence parametre case a cocher
	 * @param selectionExportTest parametre case a cocher
	 * @param fichierXml Name of the XML file
	 * @param selectionfusionCellule Choix pour la fusion des cellules
	 * @throws org.dom4j.DocumentException DocumentException
	 * @throws java.lang.Exception Lang.Exception
	 * @throws java.io.IOException IOException
	 */
	public FromXmlToExcel(String fichierXml, boolean selectionExportExigence, boolean selectionExportTest, boolean selectionExportParametre, boolean selectionExportEnvironnement, boolean selectionExportCampagne, boolean selectionExportExecutionCampagne, boolean selectionExportAnomalies, boolean selectionfusionCellule) throws DocumentException, Exception,	IOException {

		openXmlFile(fichierXml);
		nomFichierXLS = createXlsFile(fichierXml);
		xmlDir = nomFichierXLS.substring(0, nomFichierXLS.lastIndexOf(fs));

		writeXLSHeading(selectionExportAnomalies);

		if (selectionExportExigence == true) {
			readXMLFileRequirement(documentXml, selectionExportAnomalies);
		}
		if (selectionExportTest == true) {
			readXMLFileTest(documentXml, selectionExportAnomalies);
		}

		if (selectionExportParametre == true) {
			readXMLFileParametre(documentXml);
		}

		if (selectionExportEnvironnement == true) {
			readXMLFileEnvironnement(documentXml);
		}

		if (selectionExportCampagne == true) {
			readXMLFileCampagne(documentXml);
		}

		if (selectionExportExecutionCampagne == true) {
			readXMLFileExecutionCampagne(documentXml);
		}

		if (selectionExportAnomalies == true) {
			readXMLFileAnomalies(documentXml);
		}

	//organizeXLSfile(selectionExportExigence, selectionExportTest, selectionExportParametre, selectionExportEnvironnement, selectionExportCampagne, selectionExportExecutionCampagne, selectionExportAnomalies);
		if (selectionfusionCellule== true) {
			ecritEntete.organizeXLSfile(selectionExportExigence, selectionExportTest, selectionExportParametre, selectionExportEnvironnement, selectionExportCampagne, selectionExportExecutionCampagne, selectionExportAnomalies, masquageColonne);
		} 
		ecritEntete.closeWorkbook(selectionExportAnomalies, Language.getInstance().getText("Feuille_Excel_Entiere"));
		}


	/**
	 * Function that parse Xml file to read Bugs
	 * @param documentXml document Xml
	 * @throws org.dom4j.DocumentException DocumentException
	 * @throws java.lang.Exception Exception
	 */
	public void readXMLFileAnomalies(Document documentXml) throws DocumentException, Exception {
		int numeroLigne = 1;
		// doc a exporter
		XPath xpathSelector0 = DocumentHelper.createXPath("//Defects/Defect");
		XPath sortXpath = DocumentHelper.createXPath("@id");
		List results0 = xpathSelector0.selectNodes(documentXml);
		sortXpath.sort(results0);
		for (Iterator iter0 = results0.iterator(); iter0.hasNext();) {
			Element element0 = (Element) iter0.next();
			label = new Label(ecritEntete.getID_ANOMALIE(), numeroLigne, element0.attributeValue("id").replace("Bug_", " "), ecritEntete.getcelluleNormale());
			anomaliesSheet.addCell(label);
			XPath xpathSelector1 = DocumentHelper.createXPath("//Defects/Defect[@id='" + element0.attributeValue("id") + "']/MantisURL");
			List results1 = xpathSelector1.selectNodes(documentXml);
			for (Iterator iter1 = results1.iterator(); iter1.hasNext();) {
				Element element1 = (Element) iter1.next();
				Formula f = new Formula( ecritEntete.getURL_ANOMALIE(), numeroLigne, "HYPERLINK(\"" + element1.attributeValue("url") + "\",\"" + element1.attributeValue("url") + "\")", ecritEntete.getcelluleNormale());
				anomaliesSheet.addCell(f);

			}
			label = new Label(ecritEntete.getRESUME_ANOMALIE(), numeroLigne, element0.attributeValue("summary"), ecritEntete.getcelluleNormale());
			anomaliesSheet.addCell(label);
			XPath xpathSelector2 = DocumentHelper.createXPath("//Defects/Defect[@id='" + element0.attributeValue("id") + "']/Description");
			List results2 = xpathSelector2.selectNodes(documentXml);
			for (Iterator iter2 = results2.iterator(); iter2.hasNext();) {
				Element element2 = (Element) iter2.next();
				String valeurDescriptionAnomalies = element2.getText();
				valeurDescriptionAnomalies = valeurDescriptionAnomalies.replaceAll("\\\\n", "\n");
				
				label = new Label(ecritEntete.getDESCRIPTION_ANOMALIE(), numeroLigne, valeurDescriptionAnomalies, ecritEntete.getcelluleNormale());
				anomaliesSheet.addCell(label);
			}
			label = new Label(ecritEntete.getREPORTER_ANOMALIE(), numeroLigne, element0.attributeValue("reporter"), ecritEntete.getcelluleNormale());
			anomaliesSheet.addCell(label);
			label = new Label(ecritEntete.getPROPRIETAIRE_ANOMALIE(), numeroLigne, element0.attributeValue("handler"), ecritEntete.getcelluleNormale());
			anomaliesSheet.addCell(label);

			numeroLigne++;

		}
	}




	/**
	 * function that tries to open the XML File
	 * 
	 * @param fichierXml
	 *            Name of the XML File
	 * @throws org.dom4j.DocumentException
	 *             DocumentException
	 */
	public void openXmlFile(String fichierXml) throws DocumentException {
		SAXReader xmlreader = new SAXReader();
		documentXml = xmlreader.read(new File(fichierXml));
		
	}



	/**
	 * Function that parse Xml file to read Campaigns executions
	 * @param documentXml document Xml
	 * @throws org.dom4j.DocumentException DocumentException
	 * @throws java.lang.Exception Exception
	 */
	public void readXMLFileExecutionCampagne(Document documentXml) throws DocumentException, Exception {
		int numeroLigne = 1;
		// doc a exporter
		XPath xpathSelector0 = DocumentHelper.createXPath("//CampagneTests/CampagneTest");
		XPath sortXpath = DocumentHelper.createXPath("@id_camp");
		List results0 = xpathSelector0.selectNodes(documentXml);
		sortXpath.sort(results0);
		for (Iterator iter0 = results0.iterator(); iter0.hasNext();) {
			Element element0 = (Element) iter0.next();
			XPath xpathSelector1 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest");
			XPath sortXpath1 = DocumentHelper.createXPath("@id_exec_camp");
			List results1 = xpathSelector1.selectNodes(documentXml);
			sortXpath1.sort(results1);
			for (Iterator iter1 = results1.iterator(); iter1.hasNext();) {
				Element element1 = (Element) iter1.next();
				label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_NOM(), numeroLigne, element0.elementText("Nom"), ecritEntete.getcelluleNormale());
				execCampSheet.addCell(label);
				label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_NOM_EXECUTION(), numeroLigne, element1.elementText("Nom"), ecritEntete.getcelluleNormale());
				execCampSheet.addCell(label);
				XPath xpathSelector2 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/EnvironnementEx");
				List results2 = xpathSelector2.selectNodes(documentXml);
				for (Iterator iter2 = results2.iterator(); iter2.hasNext();) {
					Element element2 = (Element) iter2.next();
					label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_ENVIRONNEMENT(), numeroLigne, element2.elementText("Nom"), ecritEntete.getcelluleNormale());
					execCampSheet.addCell(label);
				}
				XPath xpathSelector3 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/JeuDonneesEx");
				List results3 = xpathSelector3.selectNodes(documentXml);
				for (Iterator iter3 = results3.iterator(); iter3.hasNext();) {
					Element element3 = (Element) iter3.next();
					label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_NOM_JEU_DONNEES(), numeroLigne, element3.elementText("Nom"), ecritEntete.getcelluleNormale());
					execCampSheet.addCell(label);
				}
				if (results3.isEmpty()){
					label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_NOM_JEU_DONNEES(), numeroLigne, "", ecritEntete.getcelluleNormale());
					execCampSheet.addCell(label);
				}
				readURLAttachements("//ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/Attachements/UrlAttachement", ecritEntete.getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE(), numeroLigne, execCampSheet);
				readFileAttachements("//ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/Attachements/FileAttachement", ecritEntete.getCAMPAGNEEEXECUTION_PIECE_JOINTE(), numeroLigne, execCampSheet);

				label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION(), numeroLigne, element1.attributeValue("statut"), ecritEntete.getcelluleNormale());
				execCampSheet.addCell(label);

				XPath xpathSelector4 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/JeuDonneesEx");
				List results4 = xpathSelector4.selectNodes(documentXml);
				for (Iterator iter4 = results4.iterator(); iter4.hasNext();) {
					Element element4 = (Element) iter4.next();
					label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_NOM_JEU_DONNEES(), numeroLigne, element4.elementText("Nom"), ecritEntete.getcelluleNormale());
					execCampSheet.addCell(label);
				}


				//A completer pour les resultats d'execution
				int numeroligneExecution = numeroLigne;
				String testprecedent = "";
				XPath xpathSelector5 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/ResulExecCampTests/ResulExecCampTest");
				List results5 = xpathSelector5.selectNodes(documentXml);
				for (Iterator iter5 = results5.iterator(); iter5.hasNext();) {
					Element element5 = (Element) iter5.next();
					label = new Label(ecritEntete.getCAMPAGNEEXECUTION_NOM_RESULTAT_EXECUTION(), numeroligneExecution, element5.elementText("Nom"), ecritEntete.getcelluleNormale());
					execCampSheet.addCell(label);
					label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_NOM_RESULTAT_EXECUTION(), numeroligneExecution, element5.attributeValue("statut"), ecritEntete.getcelluleNormale());
					execCampSheet.addCell(label);
					XPath xpathSelector6 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/ResulExecCampTests/ResulExecCampTest[@id_exec_res='" + element5.attributeValue("id_exec_res")+ "']/ResulActionTests/ResulActionTest");
					List results6 = xpathSelector6.selectNodes(documentXml);
					for (Iterator iter6 = results6.iterator(); iter6.hasNext();) {
						Element element6 = (Element) iter6.next();
						XPath xpathSelector7 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/ResulExecCampTests/ResulExecCampTest[@id_exec_res='" + element5.attributeValue("id_exec_res")+ "']/ResulActionTests/ResulActionTest[@refAction='" + element6.attributeValue("refAction")+ "']/RefAction");
						List results7 = xpathSelector7.selectNodes(documentXml);
						for (Iterator iter7 = results7.iterator(); iter7.hasNext();) {
							Element element7 = (Element) iter7.next();
							String test = element7.elementText("NomFamille")+Language.getInstance().getText("_") + element7.elementText("NomSuite")+ Language.getInstance().getText("_") +element7.elementText("NomTest");
							if (!testprecedent.equals(test)){
								label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_FAMILLE_TEST(), numeroligneExecution, element7.elementText("NomFamille"), ecritEntete.getcelluleNormale());
								execCampSheet.addCell(label);
								label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_SUITE_TEST(), numeroligneExecution, element7.elementText("NomSuite"), ecritEntete.getcelluleNormale());
								execCampSheet.addCell(label);
								label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_NOM_TEST(), numeroligneExecution, element7.elementText("NomTest"), ecritEntete.getcelluleNormale());
								execCampSheet.addCell(label);
								
								XPath xpathSelector8 = DocumentHelper.createXPath("//Familles/Famille/SuiteTests/SuiteTest/Tests/Test/TestManuel/ActionTest[@id_action='" + element6.attributeValue("refAction")+ "']");
								List results8 = xpathSelector8.selectNodes(documentXml);
								for (Iterator iter8 = results8.iterator(); iter8.hasNext();) {
									Element element8 = (Element) iter8.next();
									
									XPath xpathSelector9 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/ResulExecCampTests/ResulExecCampTest[@id_exec_res='" + element5.attributeValue("id_exec_res")+ "']/ResulExecs/ResulExec[@refTest='" + element8.getParent().getParent().attributeValue("id_test")+ "']");
									List results9 = xpathSelector9.selectNodes(documentXml);
									for (Iterator iter9 = results9.iterator(); iter9.hasNext();) {
										Element element9 = (Element) iter9.next();
										label = new Label(ecritEntete.getCAMPAGNEEEXECUTION_RESULTAT_EXECUTION_TEST(), numeroligneExecution, element9.attributeValue("res"), ecritEntete.getcelluleNormale());
										execCampSheet.addCell(label);
										readURLAttachements("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/ResulExecCampTests/ResulExecCampTest[@id_exec_res='" + element5.attributeValue("id_exec_res")+ "']/ResulExecs/ResulExec[@refTest='" + element8.getParent().getParent().attributeValue("id_test")+ "']/Attachements/UrlAttachement", ecritEntete.getCAMPAGNEEEXECUTION_LIEN_HYPERTEXTE_TEST_EXECUTE(), numeroligneExecution, execCampSheet);
										readFileAttachements("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/ExecCampTests/ExecCampTest[@id_exec_camp='" + element1.attributeValue("id_exec_camp")+ "']/ResulExecCampTests/ResulExecCampTest[@id_exec_res='" + element5.attributeValue("id_exec_res")+ "']/ResulExecs/ResulExec[@refTest='" + element8.getParent().getParent().attributeValue("id_test")+ "']/Attachements/FileAttachement", ecritEntete.getCAMPAGNEEEXECUTION_PIECE_JOINTE_TEST_EXECUTE(), numeroligneExecution, execCampSheet);
										
									}
									
								}
								
								testprecedent =element7.elementText("NomFamille")+ Language.getInstance().getText("_") +element7.elementText("NomSuite")+ Language.getInstance().getText("_") +element7.elementText("NomTest");
							}
							label = new Label(ecritEntete.getRESULTAT_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroligneExecution, element6.attributeValue("res"), ecritEntete.getcelluleNormale());
							execCampSheet.addCell(label);
							label = new Label(ecritEntete.getNUMERO_ACTION_TEST_CAMPAGNEEEXECUTION(), numeroligneExecution, element7.elementText("NomAction"), ecritEntete.getcelluleNormale());
							execCampSheet.addCell(label);
							label = new Label(ecritEntete.getRESULTAT_OBTENU_CAMPAGNEEEXECUTION(), numeroligneExecution, element6.elementText("ResulEffectif"), ecritEntete.getcelluleNormale());
							execCampSheet.addCell(label);

						}


						numeroligneExecution++;
					}

					if (numeroligneExecution>numeroLigne){
						numeroLigne= numeroligneExecution;
					}else{
						numeroLigne++;
					}
				}

			}
		}
	}



	/**
	 * Function that parse Xml file to read campaigns
	 * @param documentXml document Xml
	 * @throws org.dom4j.DocumentException DocumentException
	 * @throws java.lang.Exception Exception
	 */
	public void readXMLFileCampagne(Document documentXml) throws DocumentException, Exception {
		int numeroLigne = 1;
		// doc a exporter
		XPath xpathSelector0 = DocumentHelper.createXPath("//CampagneTests/CampagneTest");
		XPath sortXpath = DocumentHelper.createXPath("@id_camp");
		List results0 = xpathSelector0.selectNodes(documentXml);
		sortXpath.sort(results0);

		for (Iterator iter0 = results0.iterator(); iter0.hasNext();) {
			Element element0 = (Element) iter0.next();
			//ecrit le nom du parametre
			label = new Label(ecritEntete.getCAMPAGNE_NOM(), numeroLigne, element0.elementText("Nom"), ecritEntete.getcelluleNormale());
			campagneSheet.addCell(label);
			// Lit description
			//String valeurDescription = RemiseEnFormeDescription(element0.element("Description").asXML());
			//label = new Label(numeroColonne	+ ecritEntete.getCAMPAGNE_DESCRIPTION(), numeroLigne, valeurDescription, ecritEntete.getcelluleNormale());
			try{
				label = new Label(numeroColonne	+ ecritEntete.getCAMPAGNE_DESCRIPTION(), numeroLigne, RemiseEnFormeDescription(element0.element("Description").asXML()), ecritEntete.getcelulleCentreeHetV());
			}catch (NullPointerException npe){
				label = new Label(numeroColonne	+ ecritEntete.getCAMPAGNE_DESCRIPTION(), numeroLigne, "", ecritEntete.getcelulleCentreeHetV());
			}
			
			campagneSheet.addCell(label);
			
			readURLAttachements("//CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/Attachements/UrlAttachement", ecritEntete.getCAMPAGNE_LIEN_HYPERTEXTE(), numeroLigne, campagneSheet);
			readFileAttachements("//CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/Attachements/FileAttachement", ecritEntete.getCAMPAGNE_PIECE_JOINTE(), numeroLigne, campagneSheet);

			XPath xpathSelector1 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/JeuxDonnees/JeuDonnees");
			XPath sortXpath1 = DocumentHelper.createXPath("@id_jeu");
			List results1 = xpathSelector1.selectNodes(documentXml);
			sortXpath1.sort(results1);
			int numeroLigneJeuDeDonnees = numeroLigne;
			for (Iterator iter1 = results1.iterator(); iter1.hasNext();) {
				Element element1 = (Element) iter1.next();
				label = new Label(ecritEntete.getCAMPAGNE_NOM_JEU_DONNEES(), numeroLigneJeuDeDonnees, element1.elementText("Nom"), ecritEntete.getcelluleNormale());
				campagneSheet.addCell(label);
				
				String valeurDescriptionJeuDonnees = "";
				if (element1.elementText("Description") != null){
					valeurDescriptionJeuDonnees = element1.elementText("Description");
					valeurDescriptionJeuDonnees = valeurDescriptionJeuDonnees.replaceAll("\\\\n", "\n");
				}else {
					valeurDescriptionJeuDonnees = "";
				}
				
				label = new Label(ecritEntete.getCAMPAGNE_DESCRIPTION_JEU_DONNEES(), numeroLigneJeuDeDonnees, valeurDescriptionJeuDonnees, ecritEntete.getcelluleNormale());
				campagneSheet.addCell(label);
				XPath xpathSelector2 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/JeuxDonnees/JeuDonnees[@id_jeu='" + element1.attributeValue("id_jeu")+ "']/ValeurParams/ValeurParam");
				XPath sortXpath2 = DocumentHelper.createXPath("@ref");
				List results2 = xpathSelector2.selectNodes(documentXml);
				sortXpath2.sort(results2);
				for (Iterator iter2 = results2.iterator(); iter2.hasNext();) {
					Element element2 = (Element) iter2.next();
					label = new Label(ecritEntete.getCAMPAGNE_JEU_DONNEES_PARAMETRE(), numeroLigneJeuDeDonnees, element2.elementText("Nom"), ecritEntete.getcelluleNormale());
					campagneSheet.addCell(label);
					label = new Label(ecritEntete.getCAMPAGNE_JEU_DONNEES_VALEURPARAMETRE(), numeroLigneJeuDeDonnees, element2.attributeValue("valeur"), ecritEntete.getcelluleNormale());
					campagneSheet.addCell(label);
					numeroLigneJeuDeDonnees++;
				}
				if (results2.isEmpty()){
					numeroLigneJeuDeDonnees++;
				}
			}
			XPath xpathSelector2 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/FamillesCamp/FamilleRef");
			//XPath sortXpath2 = DocumentHelper.createXPath("@ref");
			List results2 = xpathSelector2.selectNodes(documentXml);
			//sortXpath2.sort(results2);
			int numeroLigneCasTest= numeroLigne;
			for (Iterator iter2 = results2.iterator(); iter2.hasNext();) {
				Element element2 = (Element) iter2.next();
				XPath xpathSelector3 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/FamillesCamp/FamilleRef[@ref='" + element2.attributeValue("ref")+ "']/SuiteTestsCamp/SuiteTestRef");
				//XPath sortXpath3 = DocumentHelper.createXPath("@ref");
				List results3 = xpathSelector3.selectNodes(documentXml);
				//sortXpath3.sort(results3);
				for (Iterator iter3 = results3.iterator(); iter3.hasNext();) {
					Element element3 = (Element) iter3.next();
					XPath xpathSelector4 = DocumentHelper.createXPath("//CampagneTests/CampagneTest[@id_camp='" + element0.attributeValue("id_camp")+ "']/FamillesCamp/FamilleRef[@ref='" + element2.attributeValue("ref")+ "']/SuiteTestsCamp/SuiteTestRef[@ref='" + element3.attributeValue("ref")+ "']/TestsCamp/TestRef");
					//XPath sortXpath4 = DocumentHelper.createXPath("@ref");
					List results4 = xpathSelector4.selectNodes(documentXml);
					//sortXpath4.sort(results4);
					for (Iterator iter4 = results4.iterator(); iter4.hasNext();) {
						Element element4 = (Element) iter4.next();
						label = new Label(ecritEntete.getCAMPAGNE_FAMILLE_TEST(), numeroLigneCasTest, element2.elementText("Nom"), ecritEntete.getcelluleNormale());
						campagneSheet.addCell(label);
						label = new Label(ecritEntete.getCAMPAGNE_SUITE_TEST(), numeroLigneCasTest, element3.elementText("Nom"), ecritEntete.getcelluleNormale());
						campagneSheet.addCell(label);
						label = new Label(ecritEntete.getCAMPAGNE_NOM_TEST(), numeroLigneCasTest, element4.elementText("Nom"), ecritEntete.getcelluleNormale());
						campagneSheet.addCell(label);
						numeroLigneCasTest++;
					}	
				}
			}

			if (numeroLigneJeuDeDonnees>numeroLigneCasTest){
				numeroLigne= numeroLigneJeuDeDonnees;
			}else{
				numeroLigne= numeroLigneCasTest;
			}
		}
	}

	/**
	 * Function that read file attachements for all spreadsheets
	 * @param pathXML Xml directory path
	 * @param colonneURL Column number to read
	 * @param numeroLigne line number to read
	 * @param feuilleExcel Excel Spreadsheet to read
	 * @throws jxl.write.biff.RowsExceededException Excel Exception
	 * @throws jxl.write.WriteException Write Exception
	 */
	public void readFileAttachements(String pathXML, int colonneURL, int numeroLigne, WritableSheet feuilleExcel) throws RowsExceededException, WriteException {

		// Lit FileAttachements
		XPath xpathSelectorFile = DocumentHelper.createXPath(pathXML);
		List resultsFile = xpathSelectorFile.selectNodes(documentXml);
		String DifferentPJ = null;
		if (resultsFile.size() == 1) {
			Iterator iterFile = resultsFile.iterator();
			Element elementFile = (Element) iterFile.next();
			DifferentPJ = "file:///" + xmlDir + fs + elementFile.attributeValue("dir");
			try {
		//		Formula f = new Formula( colonneURL, numeroLigne, "HYPERLINK(\"" + DifferentPJ + "\",\"" + DifferentPJ + "\")", ecritEntete.getcelluleNormale());
				Formula f = new Formula( colonneURL, numeroLigne, "HYPERLINK(\"" + DifferentPJ + "\",\"" +  fs + elementFile.attributeValue("dir") + "\")", ecritEntete.getcelluleNormale());
				feuilleExcel.addCell(f);
			} catch (Exception fe) {
				isErreurEcritureXLS = setErreurEcritureXLS();
			}
		} else if (resultsFile.isEmpty()) {
			label = new Label(colonneURL, numeroLigne, null, ecritEntete.getcelluleNormale());
			feuilleExcel.addCell(label);
		} else {
			for (Iterator iterFile = resultsFile.iterator(); iterFile.hasNext();) {
				Element elementFile = (Element) iterFile.next();
				// Ecrit URL
			//	if (DifferentPJ == null) {
			//		DifferentPJ = xmlDir + fs + elementFile.attributeValue("dir");
			//	} else {
			//		DifferentPJ = DifferentPJ + "\n" + xmlDir + fs + elementFile.attributeValue("dir");
			//	}

			//	label = new Label(colonneURL, numeroLigne, DifferentPJ, ecritEntete.getcelluleNormale());
				label = new Label(colonneURL, numeroLigne,  fs + elementFile.attributeValue("dir"), ecritEntete.getcelluleNormale());
				feuilleExcel.addCell(label);
			}

		}	
	}
	/**
	 * Function that read URL attachements for all spreadsheets
	 * @param pathXML Xml directory path
	 * @param colonneURL Column number to read
	 * @param numeroLigne line number to read
	 * @param feuilleExcel Excel Spreadsheet to read
	 * @throws jxl.write.biff.RowsExceededException Excel Exception
	 * @throws jxl.write.WriteException Write Exception
	 */
	public void readURLAttachements(String pathXML, int colonneURL, int numeroLigne, WritableSheet feuilleExcel) throws RowsExceededException, WriteException {
		// Lit URLAttachements
		XPath xpathSelectorURL = DocumentHelper.createXPath(pathXML);
		List resultsURL = xpathSelectorURL.selectNodes(documentXml);
		String DifferentURL = null;

		if (resultsURL.size() == 1) {
			Iterator iterURL = resultsURL.iterator();
			Element elementURL = (Element) iterURL.next();
			try {
				Formula f = new Formula( colonneURL, numeroLigne, "HYPERLINK(\"" + elementURL.attributeValue("url") + "\",\"" + elementURL.attributeValue("url") + "\")", ecritEntete.getcelluleNormale());
				feuilleExcel.addCell(f);
			} catch (Exception fe) {
				isErreurEcritureXLS = setErreurEcritureXLS();
			}
		} else if (resultsURL.isEmpty()) {
			label = new Label( colonneURL, numeroLigne, null, ecritEntete.getcelluleNormale());
			feuilleExcel.addCell(label);
		} else {
			for (Iterator iterURL = resultsURL.iterator(); iterURL.hasNext();) {
				Element elementURL = (Element) iterURL.next();
				// Ecrit URL
				if (DifferentURL == null) {
					DifferentURL = elementURL.attributeValue("url");
				} else {
					DifferentURL = DifferentURL + "\n" + elementURL.attributeValue("url");
				}
				label = new Label( colonneURL , numeroLigne, DifferentURL, ecritEntete.getcelluleNormale());
				feuilleExcel.addCell(label);
			}

		}
	}



	/**
	 * Function that parse Xml file to read environnements
	 * 
	 * @param documentXml
	 *            document Xml
	 * @throws org.dom4j.DocumentException
	 *             DocumentException
	 * @throws java.lang.Exception
	 *             Exception
	 */
	public void readXMLFileEnvironnement(Document documentXml) throws DocumentException, Exception {
		int numeroLigne = 1;
		// doc a exporter
		XPath xpathSelector0 = DocumentHelper.createXPath("//Environnements/Environnement");
		XPath sortXpath = DocumentHelper.createXPath("@idEnv");
		List results0 = xpathSelector0.selectNodes(documentXml);
		sortXpath.sort(results0);

		for (Iterator iter0 = results0.iterator(); iter0.hasNext();) {
			Element element0 = (Element) iter0.next();
			//ecrit le nom du parametre
			label = new Label(ecritEntete.getENVIRONNEMENT_NOM(), numeroLigne, element0.elementText("Nom"), ecritEntete.getcelluleNormale());
			enviroSheet.addCell(label);

			// Lit description
			String valeurDescription;
			try {
			valeurDescription = element0.elementText("Description");
			valeurDescription = valeurDescription.replaceAll("\\\\n", "\n");
		}catch (NullPointerException npe){
			valeurDescription = "";
		}
			label = new Label(ecritEntete.getENVIRONNEMENT_DESCRIPTION(), numeroLigne, valeurDescription, ecritEntete.getcelluleNormale());
			enviroSheet.addCell(label);
			
			//Lit les parametres
			int numeroLigneParemetreParEnvironnement = 0;
			XPath xpathSelector2 = DocumentHelper.createXPath("//Environnement[@idEnv='" + element0.attributeValue("idEnv")+ "']/ValeurParams/ValeurParam");
			XPath sortXpath2 = DocumentHelper.createXPath("@ref");
			List results2 = xpathSelector2.selectNodes(documentXml);
			sortXpath2.sort(results2);
			for (Iterator iter2 = results2.iterator(); iter2.hasNext();) {
				Element element2 = (Element) iter2.next();
				label = new Label(ecritEntete.getENVIRONNEMENT_NOM_PARAMETRE(),numeroLigne + numeroLigneParemetreParEnvironnement, element2.elementText("Nom"), ecritEntete.getcelluleNormale());
				enviroSheet.addCell(label);
				try {
					int testNombre = Integer.parseInt(element2.attributeValue("valeur"));
					nombre = new Number(ecritEntete.getENVIRONNEMENT_VALEUR_PARAMETRE(), numeroLigne + numeroLigneParemetreParEnvironnement, testNombre, ecritEntete.getcelluleNormaleNombre());
					enviroSheet.addCell(nombre);
				} catch (NumberFormatException nfe) {
					label = new Label(ecritEntete.getENVIRONNEMENT_VALEUR_PARAMETRE(),numeroLigne + numeroLigneParemetreParEnvironnement, element2.attributeValue("valeur"), ecritEntete.getcelluleNormale());
					enviroSheet.addCell(label);
				}
				numeroLigneParemetreParEnvironnement++;
			}
			readURLAttachements("//Environnement[@idEnv='" + element0.attributeValue("idEnv")+ "']/Attachements/UrlAttachement", ecritEntete.getENVIRONNEMENT_LIEN_HYPERTEXTE(), numeroLigne, enviroSheet);
			readFileAttachements("//Environnement[@idEnv='" + element0.attributeValue("idEnv")+ "']/Attachements/FileAttachement", ecritEntete.getENVIRONNEMENT_PIECE_JOINTE(), numeroLigne, enviroSheet);


			if (numeroLigneParemetreParEnvironnement==0){
				label = new Label(ecritEntete.getENVIRONNEMENT_NOM_PARAMETRE(),numeroLigne + numeroLigneParemetreParEnvironnement,"", ecritEntete.getcelluleNormale());
				enviroSheet.addCell(label);
				label = new Label(ecritEntete.getENVIRONNEMENT_VALEUR_PARAMETRE(),numeroLigne + numeroLigneParemetreParEnvironnement, "", ecritEntete.getcelluleNormale());
				enviroSheet.addCell(label);
				numeroLigne++;
			}else {
				numeroLigne = numeroLigne+ numeroLigneParemetreParEnvironnement;
			}

		}

	}






	/**
	 * Function that parse Xml file to read parameters
	 * 
	 * @param documentXml
	 *            document Xml
	 * @throws org.dom4j.DocumentException
	 *             DocumentException
	 * @throws java.lang.Exception
	 *             Exception
	 */
	public void readXMLFileParametre(Document documentXml) throws DocumentException, Exception {
		int numeroLigne = 1;
		// doc a exporter
		XPath xpathSelector0 = DocumentHelper.createXPath("//Params/Param");
		XPath sortXpath = DocumentHelper.createXPath("@id_param");
		List results0 = xpathSelector0.selectNodes(documentXml);
		sortXpath.sort(results0);

		for (Iterator iter0 = results0.iterator(); iter0.hasNext();) {
			Element element0 = (Element) iter0.next();
			//ecrit le nom du parametre
			label = new Label(ecritEntete.getPARAMETRE_NOM(), numeroLigne, element0.elementText("Nom"), ecritEntete.getcelluleNormale());
			paramSheet.addCell(label);
			String valeurDescription = "";
			if (element0.elementText("Description") !=null){
				valeurDescription = element0.elementText("Description");
				valeurDescription = valeurDescription.replaceAll("\\\\n", "\n");
			}
							
			label = new Label(ecritEntete.getPARAMETRE_DESCRIPTION(), numeroLigne, valeurDescription, ecritEntete.getcelluleNormale());
			paramSheet.addCell(label);
			numeroLigne++;
		}
	}


	/**
	 * Function that parse Xml file to read tests
	 * @param selectionExportAnomalies Veryfy bug spreadsheet presence
	 * @param documentXml document Xml
	 * @throws org.dom4j.DocumentException DocumentException
	 * @throws java.lang.Exception Exception
	 */
	public void readXMLFileTest(Document documentXml, boolean selectionExportAnomalies) throws DocumentException,Exception {

		int numeroLigne = 1;
		XPath xpathSelector = DocumentHelper.createXPath("//Familles/Famille/SuiteTests/SuiteTest/Tests/Test");
		List results = xpathSelector.selectNodes(documentXml);
		for (Iterator iter = results.iterator(); iter.hasNext();) {
			Element element = (Element) iter.next();

			numeroColonneSheetExigence = ecritEntete.getTEST_EXIGENCE_ASSOCIEE() + ecritEntete.getNumeroColonneExigenceFeuilleExigenceTest();
			numeroColonneSheetBranche = ecritEntete.getTEST_EXIGENCE_ASSOCIEE();

			// ecrit le nom du cas test
			label = new Label(ecritEntete.getTEST_CAS_DE_TESTS(), numeroLigne, element.elementText("Nom"), ecritEntete.getcelulleCentreeHetV());
			testSheet.addCell(label);

			numeroColonne = 0;

			// Recupere la famille du test
			Element elementFamille = element.getParent().getParent().getParent().getParent();
			// ecrit la famille
			label = new Label(numeroColonne, numeroLigne, elementFamille.elementText("Nom"), ecritEntete.getcelulleCentreeHetV());
			testSheet.addCell(label);
			numeroColonne++;
			try{
				label = new Label(numeroColonne, numeroLigne, RemiseEnFormeDescription(elementFamille.element("Description").asXML()), ecritEntete.getcelulleCentreeHetV());
			}catch (NullPointerException npe){
				label = new Label(numeroColonne, numeroLigne, "", ecritEntete.getcelulleCentreeHetV());
			}
			testSheet.addCell(label);
			numeroColonne++;
			// Recupere la suite du test
			Element elementSuite = element.getParent().getParent();
			// ecrit la suite
			label = new Label(numeroColonne, numeroLigne, elementSuite.elementText("Nom"), ecritEntete.getcelulleCentreeHetV());
			testSheet.addCell(label);
			numeroColonne++;
			try{
				label = new Label(numeroColonne, numeroLigne, RemiseEnFormeDescription(elementSuite.element("Description").asXML()), ecritEntete.getcelulleCentreeHetV());
			}catch (NullPointerException npe){
				label = new Label(numeroColonne, numeroLigne, "", ecritEntete.getcelulleCentreeHetV());
			}
			testSheet.addCell(label);
			numeroColonne++;	
		
			nombreExigenceParCasDeTests = 0;

			XPath xpathSelector3 = DocumentHelper.createXPath("//Familles/Famille/SuiteTests/SuiteTest/Tests/Test[@id_test='" + element.attributeValue("id_test") + "']/LinkRequirement/RequirementRef/Nom");
			List results3 = xpathSelector3.selectNodes(documentXml);
			if (!results3.isEmpty()) {
				for (Iterator iter3 = results3.iterator(); iter3.hasNext();) {
					Element element3 = (Element) iter3.next();

					XPath xpathSelector35 = DocumentHelper.createXPath("//Requirement[@id_req='" + element3.getParent().attributeValue("ref")  + "']/Nom");
					List results35 = xpathSelector35.selectNodes(documentXml);
					for (Iterator iter35 = results35.iterator(); iter35.hasNext();) {
						Element element35 = (Element) iter35.next();

						// ecrit une exigence
						numeroColonne = numeroColonneSheetTest + numeroColonneSheetBranche;

						//themeValue="";
						brancheID.clear();
						Element elementTemp = element35.getParent();
						if (elementTemp.getParent().getName()!="Requirements"){
							brancheID.add(elementTemp.getParent().element("Nom").getText());
							//themeValue = elementTemp.getParent().element("Nom").getText();
							while (!elementTemp.getParent().attributeValue("id_req_parent").equals("Req_0")){
								brancheID.add(0, elementTemp.getParent().getParent().element("Nom").getText());
								//themeValue= elementTemp.getParent().getParent().element("Nom").getText() + Language.getInstance().getText("_") + themeValue;
								elementTemp= elementTemp.getParent();
							}
						}

						//StringTokenizer stv = new StringTokenizer(themeValue, Language.getInstance().getText("_"));
						//while (stv.hasMoreTokens()) {
						//	label = new Label(numeroColonne, numeroLigne + nombreExigenceParCasDeTests, stv.nextToken(), ecritEntete.getcelluleNormale());
						//	testSheet.addCell(label);
						//	numeroColonne++;
						//}
						for (int i=0;i< brancheID.size();i++){
							label = new Label(numeroColonne, numeroLigne + nombreExigenceParCasDeTests, brancheID.get(i), ecritEntete.getcelluleNormale());
							testSheet.addCell(label);
							numeroColonne++;
						}
						
						label = new Label(numeroColonneSheetTest + numeroColonneSheetExigence, numeroLigne + nombreExigenceParCasDeTests, element35.getText(),	ecritEntete.getcelluleNormale()); 
						testSheet.addCell(label);
						numeroColonne= numeroColonneSheetTest;
						nombreExigenceParCasDeTests++;
						
					/*	StringTokenizer st = new StringTokenizer(element35.getText(), Language.getInstance().getText("_"));

						while (st.hasMoreTokens()) {
							 //Pour ecrire l'exigence dans la colonne Exigence;
							if (st.countTokens() == 1) {
								// Pour encadrer les celules vides des sous themes
								// d'exigenxes
								while (numeroColonne < numeroColonneSheetExigence) {
									label = new Label(numeroColonne, numeroLigne + nombreExigenceParCasDeTests, "", ecritEntete.getcelluleNormale());
									testSheet.addCell(label);
									numeroColonne++;
								}
							}
							String exigence = st.nextToken();
							// exigence.replaceAll("\'","\\'");
							label = new Label(numeroColonneSheetTest + numeroColonneSheetExigence, numeroLigne + nombreExigenceParCasDeTests, exigence,	ecritEntete.getcelluleNormale()); 
							testSheet.addCell(label);
							numeroColonne= numeroColonneSheetTest;
							nombreExigenceParCasDeTests++;
						}	*/		
					}
				}
			}	else {
				numeroColonne = numeroColonneSheetTest;
				nombreExigenceParCasDeTests++;
			}

			nombreActionsParCasDeTests = 0;
			XPath xpathSelector4 = DocumentHelper.createXPath("//Test[@id_test='" + element.attributeValue("id_test") + "']/TestManuel/ActionTest");
			List results4 = xpathSelector4.selectNodes(documentXml);
			for (Iterator iter4 = results4.iterator(); iter4.hasNext();) {
				Element element4 = (Element) iter4.next();
				// Ecrit Numero cas
				try {
					int testNombre = Integer.parseInt(element4.elementText("Nom"));
					nombre = new Number(numeroColonne + ecritEntete.getTEST_NUMERO(), numeroLigne + nombreActionsParCasDeTests, testNombre, ecritEntete.getcelluleNormaleNombreH());
					testSheet.addCell(nombre);
				} catch (NumberFormatException nfe) {
					label = new Label(numeroColonne + ecritEntete.getTEST_NUMERO(), numeroLigne + nombreActionsParCasDeTests, element4.elementText("Nom"), ecritEntete.getcelulleCentreeHetV());
					testSheet.addCell(label);
				}

				label = new Label(numeroColonne + ecritEntete.getTEST_ACTION_A_REALISER(), numeroLigne + nombreActionsParCasDeTests, element4.elementText("Description"), ecritEntete.getcelluleNormale());
				testSheet.addCell(label);

				label = new Label(numeroColonne+ ecritEntete.getTEST_RESULTAT_ATTENDU(), numeroLigne + nombreActionsParCasDeTests, element4.elementText("ResultAttendu"), ecritEntete.getcelluleNormale());
				testSheet.addCell(label);

				// Recupere etat Execute ou pas
				Element element3 = element.getParent();
				label = new Label(numeroColonne + ecritEntete.getTEST_EXECUTE(), numeroLigne + nombreActionsParCasDeTests, element3.elementText("Executed"), ecritEntete.getcelluleNormale());
				testSheet.addCell(label);
				
				readURLAttachements("//Test[@id_test='" + element.attributeValue("id_test")+ "']/TestManuel/ActionTest[@id_action='" + element4.attributeValue("id_action")+ "']/Attachements/UrlAttachement", numeroColonne + ecritEntete.getTEST_LIEN_HYPERTEXTE_ACTION(), numeroLigne + nombreActionsParCasDeTests, testSheet);
				readFileAttachements("//Test[@id_test='" + element.attributeValue("id_test")+ "']/TestManuel/ActionTest[@id_action='" + element4.attributeValue("id_action")+ "']/Attachements/FileAttachement", numeroColonne + ecritEntete.getTEST_PIECE_JOINTE_ACTION(), numeroLigne + nombreActionsParCasDeTests, testSheet);

				nombreActionsParCasDeTests++;

			}

			XPath xpathSelector8 = DocumentHelper.createXPath("//Test[@id_test='" + element.attributeValue("id_test") + "']/TestAuto");
			List results8 = xpathSelector8.selectNodes(documentXml);
			for (Iterator iter8 = results8.iterator(); iter8.hasNext();) {
				Element element8= (Element) iter8.next();
				// Ecrit Numero cas


				label = new Label(numeroColonne + ecritEntete.getTEST_TYPE_SCRIPT_AUTOMATIQUE(), numeroLigne , element8.attributeValue("plug_ext").replace(".TestDriver", ""), ecritEntete.getcelluleNormale());
				testSheet.addCell(label);

				XPath xpathSelector9 = DocumentHelper.createXPath("//Test[@id_test='" + element.attributeValue("id_test") + "']/TestAuto/Script");
				List results9 = xpathSelector9.selectNodes(documentXml);
				for (Iterator iter9 = results9.iterator(); iter9.hasNext();) {
					Element element9= (Element) iter9.next();
					String emplacementScript = "file:///" + xmlDir + fs + element9.attributeValue("dir");
					try {
						Formula f = new Formula( numeroColonne+ ecritEntete.getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE(), numeroLigne, "HYPERLINK(\"" + emplacementScript + "\",\"" + emplacementScript + "\")", ecritEntete.getcelluleNormale());
						testSheet.addCell(f);
					} catch (Exception fe) {
						isErreurEcritureXLS = setErreurEcritureXLS();
					}
				}

			}
			if (results8.isEmpty()){
				label = new Label(numeroColonne + ecritEntete.getTEST_TYPE_SCRIPT_AUTOMATIQUE(), numeroLigne ,"", ecritEntete.getcelluleNormale());
				testSheet.addCell(label);
				label = new Label(numeroColonne + ecritEntete.getTEST_EMPLACEMENT_SCRIPT_AUTOMATIQUE(), numeroLigne ,"", ecritEntete.getcelluleNormale());
				testSheet.addCell(label);
			}

			readURLAttachements("//Test[@id_test='" + element.attributeValue("id_test")+ "']/Attachements/UrlAttachement", numeroColonne + ecritEntete.getTEST_LIEN_HYPERTEXTE(), numeroLigne, testSheet);
			readFileAttachements("//Test[@id_test='" + element.attributeValue("id_test")+ "']/Attachements/FileAttachement", numeroColonne + ecritEntete.getTEST_PIECE_JOINTE(), numeroLigne, testSheet);
			

			// Recupere Description
			XPath xpathSelector7 = DocumentHelper.createXPath("//Familles/Famille/SuiteTests/SuiteTest/Tests/Test[@id_test='" + element.attributeValue("id_test") + "']/Description");
			List results7 = xpathSelector7.selectNodes(documentXml);
			for (Iterator iter7 = results7.iterator(); iter7.hasNext();) {
				Element element7 = (Element) iter7.next();
				String valeurDescription = RemiseEnFormeDescription(element7.asXML());
				label = new Label(numeroColonne + ecritEntete.getTEST_DESCRIPTION_TESTS(), numeroLigne, valeurDescription, ecritEntete.getcelluleDescritpion());
				testSheet.addCell(label);

			}
			if (results7.isEmpty()){
				label = new Label(numeroColonne + ecritEntete.getTEST_DESCRIPTION_TESTS(), numeroLigne, "", ecritEntete.getcelluleDescritpion());
				testSheet.addCell(label);
			}
				
			// Lit description
			//String valeurDescription = RemiseEnFormeDescription(element.element("Description").asXML());
			//label = new Label(numeroColonne	+ ecritEntete.getTEST_DESCRIPTION_TESTS(), numeroLigne, valeurDescription, ecritEntete.getcelluleNormale());
			//testSheet.addCell(label);
			
			// prepare une nouvelle ligne
			if (nombreActionsParCasDeTests >= nombreExigenceParCasDeTests) {
				numeroLigne = numeroLigne + nombreActionsParCasDeTests;
			} else {
				numeroLigne = numeroLigne + nombreExigenceParCasDeTests;
			}
		}

	}



	/**
	 * Modify a string to pass special characters like quote
	 * 
	 * @param chaineAModifier
	 *            A string for argument
	 * @return A string
	 */
	public String removeSpecialCharacters(String chaineAModifier) {

		StringTokenizer st = new StringTokenizer(chaineAModifier, "'");
		if (st.countTokens() > 1) {
			chaineAModifier = "concat(";
			while (st.hasMoreTokens()) {
				chaineAModifier = chaineAModifier + "'" + st.nextToken() + "'";
				chaineAModifier = chaineAModifier + ",\"'\",";
			}
			chaineAModifier = chaineAModifier.substring(0, chaineAModifier
					.length() - 5);
			chaineAModifier = chaineAModifier + ")";
		} else {
			chaineAModifier = "'" + chaineAModifier + "'";
		}
		return chaineAModifier;
	}

	/**
	 * Function that parse Xml file to read requirements
	 * @param selectionExportAnomalies Veryfy bug spreadsheet presence
	 * @param documentXml document Xml
	 * @throws org.dom4j.DocumentException DocumentException
	 * @throws java.lang.Exception Exception
	 */
	public void readXMLFileRequirement(Document documentXml, boolean selectionExportAnomalies) throws DocumentException, Exception {

		numeroColonneSheetExigence = ecritEntete.getNumeroColonneFeuilleExigence();

		XPath xpathSelector = DocumentHelper.createXPath("//Requirement/Nom");
		List results = xpathSelector.selectNodes(documentXml);

		for (Iterator iter = results.iterator(); iter.hasNext();) {
			Element element = (Element) iter.next();
			// ecrit une exigence
			numeroColonne = 0;
			numeroLigne++;
			Element elementTemp = element.getParent();
			//themeValue="";
			brancheID.clear();
			descriptionBrancheID.clear();

			if (elementTemp.getParent().getName()!="Requirements"){
				brancheID.add(elementTemp.getParent().element("Nom").getText());
				try{
					descriptionBrancheID.add(elementTemp.getParent().element("Description").asXML());
					}catch (NullPointerException npe){
						descriptionBrancheID.add("");
				}
				//themeValue = elementTemp.getParent().element("Nom").getText();
				while (!elementTemp.getParent().attributeValue("id_req_parent").equals("Req_0")){
					brancheID.add(0, elementTemp.getParent().getParent().element("Nom").getText());
					try{
					descriptionBrancheID.add(0, elementTemp.getParent().getParent().element("Description").asXML());
					}catch (NullPointerException npe){
						descriptionBrancheID.add("");
						}
					//themeValue= elementTemp.getParent().getParent().element("Nom").getText() + Language.getInstance().getText("_") + themeValue;
					elementTemp= elementTemp.getParent();
				}
			}

			//StringTokenizer stv = new StringTokenizer(themeValue, Language.getInstance().getText("_"));
			//while (stv.hasMoreTokens()) {
			//	label = new Label(numeroColonne, numeroLigne, stv.nextToken(), ecritEntete.getcelluleNormale());
			//	requirementSheet.addCell(label);
			//	numeroColonne++;
			//}
			for (int i=0;i< brancheID.size();i++){
				label = new Label(numeroColonne, numeroLigne, brancheID.get(i), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
				numeroColonne++;
				label = new Label(numeroColonne, numeroLigne, RemiseEnFormeDescription(descriptionBrancheID.get(i)), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
				numeroColonne++;
			}
			StringTokenizer st = new StringTokenizer(element.getText(), Language.getInstance().getText("_"));

			while (st.hasMoreTokens()) {
				// Pour ecrire l'exigence dans la colonne Exigence;
				if (st.countTokens() == 1) {
					// Pour encadrer les celules vides des sous themes
					// d'exigences
					while (numeroColonne < numeroColonneSheetExigence) {
						label = new Label(numeroColonne, numeroLigne, "", ecritEntete.getcelluleNormale());
						requirementSheet.addCell(label);
						numeroColonne++;
					}
					numeroColonne = numeroColonneSheetExigence;
				}
				String exigence = st.nextToken();
				label = new Label(numeroColonne, numeroLigne, exigence,	ecritEntete.getcelluleNormale()); 
				requirementSheet.addCell(label);
				numeroColonne++;

			}

			numeroColonne = numeroColonneSheetExigence;
			readRequirementsSettings(element.getParent().attributeValue("id_req"));

		}


	}

	/**
	 * Read requirement options
	 * @param ParsingRequirementID ID requirememnt
	 * @throws jxl.write.WriteException Erreur Ecriture Excel
	 */
	public void readRequirementsSettings(String ParsingRequirementID) throws WriteException {
		XPath xpathSelector3 = DocumentHelper.createXPath("//Requirement[@id_req='" + ParsingRequirementID + "']");
		List results3 = xpathSelector3.selectNodes(documentXml);
		for (Iterator iter3 = results3.iterator(); iter3.hasNext();) {
			Element element3 = (Element) iter3.next();
			//20100120 - Dbut modification Forge ORTF
			// Ecrit priorite
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE(), numeroLigne, Integer.parseInt(element3.attributeValue("priority")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe) {
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_PRIORITE(), numeroLigne, element3.attributeValue("priority"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}

			// Ecrit Version
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_VERSION(), numeroLigne, Integer.parseInt(element3.attributeValue("version")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe) {
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_VERSION(), numeroLigne, element3.attributeValue("version"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}

			// Ecrit Categorie
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_CATEGORIE(), numeroLigne, Integer.parseInt(element3.attributeValue("category")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe){
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_CATEGORIE(), numeroLigne, element3.attributeValue("category"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}

			// Ecrit Complexite
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_COMPLEXITE(), numeroLigne, Integer.parseInt(element3.attributeValue("complexity")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe) {
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_COMPLEXITE(), numeroLigne, element3.attributeValue("complexity"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}

			// Ecrit Etat
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_ETAT(), numeroLigne, Integer.parseInt(element3.attributeValue("state")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe) {
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_ETAT(), numeroLigne, element3.attributeValue("state"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}
			
			// Ecrit Criticite
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_CRITICITE(), numeroLigne, Integer.parseInt(element3.attributeValue("criticity")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe) {
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_CRITICITE(), numeroLigne, element3.attributeValue("criticity"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}
			
			// Ecrit Comprehension
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_COMPREHENSION(), numeroLigne, Integer.parseInt(element3.attributeValue("understanding")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe) {
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_COMPREHENSION(), numeroLigne, element3.attributeValue("understanding"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}
			
			// Ecrit Proprietaire
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_PROPRIETAIRE(), numeroLigne, Integer.parseInt(element3.attributeValue("owner")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe) {
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_PROPRIETAIRE(), numeroLigne, element3.attributeValue("owner"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}
			//20100120 - Fin modification Forge ORTF

			// Ecrit Valide par
			try {
				nombre = new Number(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_VALIDE_PAR(), numeroLigne, Integer.parseInt(element3.attributeValue("checkedBy")), ecritEntete.getcelluleNormaleNombre());
				requirementSheet.addCell(nombre);
			} catch (NumberFormatException nfe) {
				label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_VALIDE_PAR(), numeroLigne, element3.attributeValue("checkedBy"), ecritEntete.getcelluleNormale());
				requirementSheet.addCell(label);
			}
			
			// Ecrit Origine
			label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_ORIGINE(), numeroLigne, element3.attributeValue("origine"), ecritEntete.getcelluleNormale());
			requirementSheet.addCell(label);

			// Ecrit VerifWay
			label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_VERIFWAY(), numeroLigne, element3.attributeValue("verifway"), ecritEntete.getcelluleNormale());
			requirementSheet.addCell(label);

			// Ecrit Reference
			label = new Label(numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_REFERENCE(), numeroLigne, element3.attributeValue("Reference"), ecritEntete.getcelluleNormale());
			requirementSheet.addCell(label);
		
			// Lit description
			//String valeurDescription = RemiseEnFormeDescription(element3.element("Description").asXML());
			//label = new Label(numeroColonne	+ ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, valeurDescription, ecritEntete.getcelluleNormale());
			//requirementSheet.addCell(label);

		}

		// Lit description
		XPath xpathSelector4 = DocumentHelper
		.createXPath("//Requirement[@id_req='" + ParsingRequirementID + "']/Description");
		List results4 = xpathSelector4.selectNodes(documentXml);
		for (Iterator iter4 = results4.iterator(); iter4.hasNext();) {
			Element element4 = (Element) iter4.next();
			String valeurDescription = RemiseEnFormeDescription(element4.asXML());
			label = new Label(numeroColonne	+ ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, valeurDescription, ecritEntete.getcelluleNormale());
			requirementSheet.addCell(label);
		}
		if (results4.isEmpty()){
			label = new Label(numeroColonne	+ ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_DESCRIPTION(), numeroLigne, "", ecritEntete.getcelluleNormale());
			requirementSheet.addCell(label);
		}

		readURLAttachements("//Requirement[@id_req='" + ParsingRequirementID+ "']/Attachements/UrlAttachement", numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_LIEN_HYPERTEXTE(), numeroLigne, requirementSheet);
		readFileAttachements("//Requirement[@id_req='" + ParsingRequirementID+ "']/Attachements/FileAttachement", numeroColonne + ecritEntete.getEXIGENCE_DIFFERENCE_COLONNE_PIECE_JOINTE(), numeroLigne, requirementSheet);


		// Preparation pour nouvelle ligne
		nombreLigneRequirementLu++;
	}
	
	/**
	 * Permet d'enlever les espaces en trop d'une chaine de caracteres pour la cellule Description
	 * @param valeurDescription chaine a modifier
	 * @return chaine modifiee
	 */
	public String RemiseEnFormeDescription (String valeurDescription){
		if(valeurDescription!=null)	{
		while (valeurDescription.contains("  ")){
			valeurDescription = valeurDescription.replace("  ", " ");
		}
		
		valeurDescription = valeurDescription.replaceAll("<Description isHTML=\"true\">", "");
		valeurDescription = valeurDescription.replaceAll("<Description isHTML=\"true\"/>", "");
		valeurDescription = valeurDescription.replaceAll("</Description>", "");
		valeurDescription = valeurDescription.replaceAll("<Description>", "");
		valeurDescription = valeurDescription.replaceAll("\n ", "\n");
		valeurDescription = valeurDescription.replaceAll("", "'");
		valeurDescription = valeurDescription.replaceAll("", "-");
				
		if (valeurDescription.endsWith("\n")){
			valeurDescription = valeurDescription.substring(0, valeurDescription.lastIndexOf("\n"));		
		}
		return valeurDescription;
	} else {
		return "";
	}
	}

	/**
	 * Function that write XLS heading
	 * @param selectionExportAnomalies Veryfy bug spreadsheet presence
	 * @throws jxl.write.WriteException WriteException
	 */
	public void writeXLSHeading (boolean selectionExportAnomalies) throws WriteException {
		int nombreElementBranche = 0;
		if(TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			// Fonction permettant de creer suffisament de colonnes sous themes par
			// doc a exporter
			XPath xpathSelector0 = DocumentHelper.createXPath("//Requirement/Nom");
			List results0 = xpathSelector0.selectNodes(documentXml);
			for (Iterator iter0 = results0.iterator(); iter0.hasNext();) {
				Element element0 = (Element) iter0.next();
				int comteurNiveauBranches=0;
				element0 = element0.getParent();
				while (element0.getParent().getName()=="RequirementFamily"){
					comteurNiveauBranches++;
					element0 = element0.getParent();
				}
				if (comteurNiveauBranches > nombreElementBranche) {
					nombreElementBranche = comteurNiveauBranches;
				}
			}
		}
		try {
			ecritEntete = new EcritEntete(nombreElementBranche, fichierDeSortieXLS, selectionExportAnomalies, Language.getInstance().getText("Feuille_Excel_Entiere"));
			// EcritEntete.getWorkbookHeading();
		} catch (WriteException ex) {
			ex.printStackTrace();
		}

		workbook = ecritEntete.getWorkbookHeading();
		requirementSheet = workbook.getSheet(Language.getInstance().getText("Exigences"));
		testSheet = workbook.getSheet(Language.getInstance().getText("Tests"));
		paramSheet = workbook.getSheet(Language.getInstance().getText("Parametres"));
		enviroSheet = workbook.getSheet(Language.getInstance().getText("Environnements"));
		campagneSheet = workbook.getSheet(Language.getInstance().getText("Campagnes"));
		execCampSheet = workbook.getSheet(Language.getInstance().getText("Execution_campagnes"));
		if (selectionExportAnomalies){
			anomaliesSheet = workbook.getSheet(Language.getInstance().getText("Anomalies"));

		}

	}

	/**
	 * Get ErreurEcritureXLS
	 * 
	 * @return ErreurEcritureXLS
	 */
	public boolean getWriteErrorXLS() {
		return isErreurEcritureXLS;
	}

	/**
	 * Set ErreurEcriturXLs to True
	 * 
	 * @return True
	 */
	public boolean setErreurEcritureXLS() {
		return true;
	}

	/**
	 * Function that create a XLS File
	 * 
	 * @param nomFichierSortie
	 *            Name of the XML File
	 * @return The real name of the XLS file generated
	 */
	public String createXlsFile(String nomFichierSortie) {

		// Cree nom Fichier Excel a partir nom XML
		nomFichierSortie = nomFichierSortie.substring(0, nomFichierSortie.lastIndexOf(".xml")) + ".xls";

		// Tente de creer le fichier excel
		fichierDeSortieXLS = new File(nomFichierSortie);
		int i = 0;
		while (fichierDeSortieXLS.exists()) {
			if (i == 0) {
				System.out.println(Language.getInstance().getText("FileName_Already_Exists"));
				nomFichierSortie = nomFichierSortie.substring(0, nomFichierSortie.lastIndexOf(".")) + Language.getInstance().getText("Underscore") + Integer.toString(i) + ".xls";
			} else {
				nomFichierSortie = nomFichierSortie.substring(0,
						nomFichierSortie.lastIndexOf(Language.getInstance().getText("Underscore"))) + Language.getInstance().getText("Underscore") + Integer.toString(i) + ".xls";
			}

			fichierDeSortieXLS = new File(nomFichierSortie);
			i++;
		}
		System.out.println(Language.getInstance().getText("Fichier_Sortie_XLS") + fichierDeSortieXLS.toString());
		try {
			fichierDeSortieXLS.createNewFile();
		} catch (IOException ex) {
			System.out.println(Language.getInstance().getText("Erreur_Fichier_Sortie_XML") + fichierDeSortieXLS.toString());
			ex.printStackTrace();
		}
		return fichierDeSortieXLS.toString();

	}

	/*
	 * Function that only return the name of the XLS File @return Name of the
	 * XLS File
	 */
	/**
	 * recupere fichierDeSortieXLS
	 * @return fichierDeSortieXLS
	 */
	public String getfichierDeSortieXLS() {
		return fichierDeSortieXLS.toString();
	}
}