/*
 * SalomeTMF is a test Management Framework
 * Copyright (C) 2007 EDF / France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * @author Jeremie DEFAYE
 *
 * Contact: mikael.marche@rd.francetelecom.com
 */

package salomeTMF_plug.pluginxlsxml.Import;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.nio.channels.FileChannel;
import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;

import javax.swing.JOptionPane;
import javax.swing.tree.DefaultMutableTreeNode;

import jxl.Cell;
import jxl.CellType;
import jxl.FormulaCell;
import jxl.Sheet;
import jxl.Workbook;
import jxl.biff.formula.FormulaException;
import jxl.read.biff.BiffException;

import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.dom4j.XPath;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.SAXReader;
import org.dom4j.io.XMLWriter;
import org.objectweb.salome_tmf.api.Util;
import org.objectweb.salome_tmf.plugins.IPlugObject;

import salomeTMF_plug.pluginxlsxml.Commun.PopUpFormalismeExcel;
import salomeTMF_plug.pluginxlsxml.Commun.TestPresencePlugin;
import salomeTMF_plug.pluginxlsxml.Export.CallPackageDocXML;
import salomeTMF_plug.pluginxlsxml.language.Language;

/**
 * Read a Spreadsheet having requirements and test cases, and transform them in
 * XML to be imported by Doc XML in SalomeTMF
 * 
 * @author Jeremie DEFAYE
 * @version 1.0
 * @deprecated no
 * 
 * @covers SFD_ForgeORTF_EXG_IMP_000010 - 2.4.10
 * @covers SFD_ForgeORTF_EXG_IMP_000020 - 2.4.10
 * @covers SFD_ForgeORTF_EXG_IMP_000030 - 2.4.10
 * @covers SFD_ForgeORTF_EXG_IMP_000040 - 2.4.10
 * Jira : FORTF - 41
 */
public class FromExcelToXml {

	private ArrayList<String> actionID = new ArrayList<String>();
	private ArrayList<String> campagneID = new ArrayList<String>();
	private ArrayList<String> environnementID = new ArrayList<String>();
	private ArrayList<String> exigenceID = new ArrayList<String>();
	private ArrayList<String> brancheDescriptionID = new ArrayList<String>();
	private ArrayList<String> jeuDeDonneesID = new ArrayList<String>();
	private ArrayList<String> listeExigencesCampagnes = new ArrayList<String>();
	private ArrayList<String> listeFamille = new ArrayList<String>();
	private ArrayList<String> listeParametre = new ArrayList<String>();
	private ArrayList<String> listePourCampagne = new ArrayList<String>();
	private ArrayList<String> listeTestsPourCampagne = new ArrayList<String>();
	private ArrayList<String> valeurLienHypertexte = new ArrayList<String>();
	private ArrayList<String> valeurPieceJointe = new ArrayList<String>();
	private ArrayList<String> familleIDSuiteID = new ArrayList<String>();
	private ArrayList<String> numeroActionDesTests = new ArrayList<String>();
	private ArrayList<String> numeroColonneBranche = new ArrayList<String>();
	private ArrayList<String> numeroColonneBrancheDescription = new ArrayList<String>();
	private ArrayList<String> parametreActionsTests = new ArrayList<String>();
	
	private ArrayList suiteSelectionList;
	private ArrayList familySelectionList;
	private ArrayList testSelectionList;

	private boolean isErreurFormalismeExcel = false;
	private boolean isErreurImportFichier;
	private boolean isErreurTraitementImport = false;
	private boolean isPresenceColonneActionARealiser = false;
	private boolean isPresenceColonneResultatAttendu = false;
	private boolean isPresenceColonneActionExecuteeExecutionCamp;
	private boolean isPresenceColonneActionObtenueExecutionCamp;
	private boolean isPresenceColonneBranche = false;
	private boolean isPresenceColonneBrancheTests = false;
	private boolean isPresenceColonneCasDeTestCampagne;
	private boolean isPresenceColonneCasDeTests = false;
	private boolean isPresenceColonneCasDeTestsExecutionCamp;
	private boolean isPresenceColonneCategorie = false;
	private boolean isPresenceColonneComplexite = false;
	private boolean isPresenceColonneDescription = false;
	private boolean isPresenceColonneDescriptionCampagne;
	private boolean isPresenceColonneDescriptionEnvironnement= false;
	private boolean isPresenceColonneDescriptionJeuDeDonneesCampagne;
	private boolean isPresenceColonneDescriptionParametre = false;
	private boolean isPresenceColonneDescriptionTest = false;
	private boolean isPresenceColonneEmplacementTestAutomatique;
	private boolean isPresenceColonneEtat = false;
	private boolean isPresenceColonneExigence = false;
	private boolean isPresenceColonneExigenceTests = false;
	private boolean isPresenceColonneFamilleDeTests;
	private boolean isPresenceColonneFamilleDeTestsExecutionCamp;
	private boolean isPresenceColonneFamilleTestCampagne;
	private boolean isPresenceColonneJeuDeDonneesCampagne;
	private boolean isPresenceColonneJeuDeDonneesExecutionCamp;
	private boolean isPresenceColonneLienHypertexte = false;
	private boolean isPresenceColonneLienHypertexteCampagne;
	private boolean isPresenceColonneLienHypertexteEnvironnement;
	private boolean isPresenceColonneLienHypertexteExecutionCamp;
	private boolean isPresenceColonneLienHypertexteExecutionCampTestExecute;
	private boolean isPresenceColonneNomCampagne;
	private boolean isPresenceColonneNomCampagneExecutionCamp;
	private boolean isPresenceColonneNomEnvironnement= false;
	private boolean isPresenceColonneNomEnvironnementExecutionCamp;
	private boolean isPresenceColonneNomExecutionExecutionCamp;
	private boolean isPresenceColonneNomParametre = false;
	private boolean isPresenceColonneNomParametreEnvironnement= false;
	private boolean isPresenceColonneNomParametreCampagne = false;
	private boolean isPresenceColonneNomResultatExecutionExecutionCamp;
	private boolean isPresenceColonneNumeroExecutionCamp;
	private boolean isPresenceColonneNumeroTests = false;
	private boolean isPresenceColonneOrigine = false;
	private boolean isPresenceColonnePieceJointe = false;
	private boolean isPresenceColonnePieceJointeCampagne;
	private boolean isPresenceColonnePieceJointeEnvironnement;
	private boolean isPresenceColonnePieceJointeExecutionCamp;
	private boolean isPresenceColonnePieceJointeExecutionCampTestExecute;
	private boolean isPresenceColonnePriorite = false;
	private boolean isPresenceColonneReference = false;
	private boolean isPresenceColonneResultatExecutionExecutionCamp;
	private boolean isPresenceColonneResultatTestExecuteExecutionCamp;
	private boolean isPresenceColonneSuiteDeTests = false;
	private boolean isPresenceColonneSuiteDeTestsExecutionCamp;
	private boolean isPresenceColonneSuiteTestCampagne;
	private boolean isPresenceColonneTestLienHypertexte = false;
	private boolean isPresenceColonneTestPieceJointe = false;
	private boolean isPresenceColonneTestLienHypertexteAction = false;
	private boolean isPresenceColonneTestPieceJointeAction = false;
	private boolean isPresenceColonneTypeTestAutomatique;
	private boolean isPresenceColonneValeurParametreEnvironnement = false;
	private boolean isPresenceColonneValeurParametreCampagne = false;
	private boolean isPresenceColonneVerifWay = false;
	private boolean isPresenceColonneVersion = false;
	private boolean presenceFeuilleCampagne = false;
	private boolean presenceFeuilleEnvironnements = false;
	private boolean presenceFeuilleExecutionCamp = false;
	private boolean presenceFeuilleExigence = false;
	private boolean presenceFeuilleParametres = false;
	private boolean presenceFeuilleTest = false;
	private boolean isInitSelection = false;
	private boolean isSelectionExportExigence = true;
	private boolean isPresenceColonneBrancheDescription = false;
	private boolean isPresenceColonneDescriptionFamilleDeTests = false;
	private boolean isPresenceColonneDescriptionSuiteDeTests = false;
	//20100121 - Dbut modification Forge ORTF
	private boolean isPresenceColonneUnderstanding = false;
	private boolean isPresenceColonneOwner = false;
	private boolean isPresenceColonneValidBy = false;
	private boolean isPresenceColonneCritical = false;
	//20100121 - Fin modification Forge ORTF
	private Cell celluleLu;

	private DefaultMutableTreeNode chosenRoot;

	private Document documentXml;

	private Element actionTest;
	private Element CampagneTest;
	private Element ExecCampTest;
	private Element Environnements;
	private Element famille;
	private Element familles;
	private Element familyRequirement;
	private Element LinkRequirement;
	private Element projetVT;
	private Element requirements;
	private Element ResulActionTests;
	private Element ResulExecCampTest;
	private Element ResulExecs;
	private Element SuiteTest;
	private Element test;
	private Element TestAuto;
	private Element testManuel;
	private Element tests;
	private Element params;
	private Element familyRequirementName;


	private File fichierDeSortieXML;

	private int debutCampagne;
	private int debutEnvironnement;
//	private int debutExecutionCamp;
	private int debutExecutionCampagne;
//	private int debutNomResultatExecutionCamp;
	private int debutResultatExecutionCampagne;
	private int debutTestExecutionCampagne;
	private int hauteurCampagne;
	private int hauteurEnvironnement;
//	private int hauteurExecutionCamp;
	private int hauteurExecutionCampagne;
//	private int hauteurNomResultatExecutionCamp;
	private int hauteurResultatExecutionCampagne;
	private int hauteurTestExecutionCampagne;
	private int indiceActionTest = 5;
	private int indiceCampagne = 6;
	private int indiceEnvironnement = 9;
	private int indiceExecCampagne = 7;
	private int indiceExecutionCamp = 10;
	private int indiceFamilleTest = 2;
	private int indiceJeuDeDonnees = 9;
	private int indiceParametre = 8;
	private int indiceRequirement = 1;
	private int indiceResultatExecution =11;
	private int indiceSuiteTest = 3;
	private int indiceTestTest = 4;
	private int ligneDebutTableauCampagne = 0;
	private int ligneDebutTableauEnvironnement = 0;
	private int ligneDebutTableauExecutionCamp;
	private int ligneDebutTableauParametre = 0;
	private int ligneDebutTableauRequirement = 0;
	private int ligneDebutTableauTest = 0;
	private int nombreColonneTableau = 0;
	private int nombreColonneTableauCampagne;
	private int nombreColonneTableauEnvironnements;
	private int nombreColonneTableauExecutionCamp;
	private int nombreColonneTableauParametres = 0;
	private int nombreColonneTableauTests = 0;
	private int nombreLigneTableau = 0;
	private int nombreLigneTableauCampagne;
	private int nombreLigneTableauEnvironnements;
	private int nombreLigneTableauExecutionCamp;
	private int nombreLigneTableauParametres = 0;
	private int nombreLigneTableauTests = 0;
	private int numeroColonneActionARealiser;
	private int numeroColonneResultatAttendu;
	private int numeroColonneActionExecuteeExecutionCamp;
	private int numeroColonneActionObtenueExecutionCamp;
	private int numeroColonneCasDeTestCampagne;
	private int numeroColonneCasDeTests;
	private int numeroColonneCasDeTestsExecutionCamp;
	private int numeroColonneCategorie;
	private int numeroColonneComplexite;
	private int numeroColonneDescription;
	private int numeroColonneDescriptionCampagne;
	private int numeroColonneDescriptionEnvironnement;
	private int numeroColonneDescriptionJeuDeDonneesCampagne;
	private int numeroColonneDescriptionParametre;
	private int numeroColonneDescriptionTest;
	private int numeroColonneEmplacementTestAutomatique;
	private int numeroColonneEtat;
	private int numeroColonneExigence;
	private int numeroColonneExigenceTests;
	private int numeroColonneFamilleDeTests;
	private int numeroColonneFamilleDeTestsExecutionCamp;
	private int numeroColonneFamilleTestCampagne;
	private int numeroColonneJeuDeDonneesCampagne;
	private int numeroColonneJeuDeDonneesExecutionCamp;
	private int numeroColonneLienHypertexte;
	private int numeroColonneLienHypertexteCampagne;
	private int numeroColonneLienHypertexteEnvironnement;
	private int numeroColonneLienHypertexteExecutionCamp;
	private int numeroColonneNomCampagne;
	private int numeroColonneNomCampagneExecutionCamp;
	private int numeroColonneNomEnvironnement;
	private int numeroColonneNomEnvironnementExecutionCamp;
	private int numeroColonneNomExecutionExecutionCamp;
	private int numeroColonneNomParametre;
	private int numeroColonneNomParametreEnvironnement;
	private int numeroColonneNomResultatExecutionExecutionCamp;
	private int numeroColonneNumeroExecutionCamp;
	private int numeroColonneNumeroTests;
	private int numeroColonneOrigine;
	private int numeroColonnePieceJointe;
	private int numeroColonnePieceJointeCampagne;
	private int numeroColonnePieceJointeEnvironnement;
	private int numeroColonnePieceJointeExecutionCamp;
	private int numeroColonnePriorite;
	private int numeroColonneReference;
	private int numeroColonneResultatExecutionExecutionCamp;
	private int numeroColonneResultatTestExecuteExecutionCamp;
	private int numeroColonneSuiteDeTests;
	private int numeroColonneSuiteDeTestsExecutionCamp;
	private int numeroColonneSuiteTestCampagne;
	private int numeroColonneTestLienHypertexte;
	private int numeroColonneTestPieceJointe;
	private int numeroColonneTestLienHypertexteAction;
	private int numeroColonneTestPieceJointeAction;
	private int numeroColonneTypeTestAutomatique;
	private int numeroColonneValeurParametreEnvironnement;
	private int numeroColonneVerifWay;
	private int numeroColonneVersion;
	private int numeroColonneLienHypertexteExecutionCampTestExecute;
	private int numeroColonnePieceJointeExecutionCampTestExecute;
	private int numeroColonneNomParametreCampagne;
	private int numeroColonneValeurParametreCampagne;
	private int hauteurJeuxDonnees;
	private int debutJeuxDonnees;
	private int numeroColonneDescriptionSuiteDeTests;
	private int numeroColonneDescriptionFamilleDeTests;
	//20100121 - Dbut modification Forge ORTF
	private int numeroColonneCritical;
	private int numeroColonneUnderstanding;
	private int numeroColonneOwner;
	private int numeroColonneValidBy;
	//20100121 - Fin modification Forge ORTF

	private IPlugObject pIPlugObject;

	private Sheet campagneSheet;
	private Sheet enviroSheet;
	private Sheet execCampSheet;
	private Sheet paramSheet;
	private Sheet requirementSheet;
	private Sheet testSheet;

	private String exigenceAEcrire = "";
	private String exigenceLu;
	private String exigenceLuTest;
	private String exigenceNonTrouvePourTest = "";
	private String familleEnCours;
	private String familleEnCoursTests;
	private String famillePrecedente = Language.getInstance().getText("Pas_De_Famille");
	private String fichiersNonImportes = "";
	private String fs = System.getProperties().getProperty("file.separator");
	private String IDAction;
	private String IDCampagne;
	private String IDParametreEnvironnement;
	private String IDTest;
	private String indiceRequirementFamilleEnCours;
	private String listeCampagneNonTrouve = "";
	private String nomFichierXML;
	private String nomParametreEnvironnement="";
	//private String numeroColonneBranche=null;
	//private String numeroColonneBrancheDescription=null;
	private String numeroColonneBrancheTests = null;
	private String ResultatExecution;
	private String Sortie;
	private String suitePrecedente;
	private String valeurActionARealiser;
	private String valeurActionAttendue;
	private String valeurCasDeTests;
	private String valeurCategorie;
	private String valeurComplexite;
	private String valeurDescription;
	private String valeurDescriptionTest;
	private String valeurEmplacementTestAutomatique;
	private String valeurEtat;
	private String valeurFamilleDeTests;
	private String valeurNomCampagne;
	private String valeurNomCasDeTestExecutionCampagne;
	private String valeurNomEnvironnement;
	private String valeurNomExecutionCampagne;
	private String valeurNomFamilleTestExecutionCampagne;
	private String valeurNomSuiteTestExecutionCampagne;
	private String valeurNumeroExecuteExecutionCampagne;
	private String valeurNumeroTests;
	private String valeurOrigine;
	private String valeurParametreEnvironnement;
	//private String valeurParametreCampagne;
	private String valeurPriorite;
	private String valeurReference;
	private String valeurResultatTestExecuteExecutionCampagne;
	private String valeurSuiteDeTests;
	private String valeurTypeTestAutomatique;
	private String valeurVerifWay;
	private String valeurVersion;
	private String xmlDir;
	//20100121 - Dbut modification Forge ORTF
	private String valeurCritical;	
	private String valeurUnderstanding;
	private String valeurOwner;
	private String valeurValidBy;
	//20100121 - Fin modification Forge ORTF

	private Workbook workbook;
	private String valeurDescriptionParam;
	private String valeurDescriptionEnviro;
	private String valeurDescriptionJeuDonnees;
	private String valeurDescriptionCampagne;
	private String nomParametreCampagne;
	private String IDParametreCampagne;
	private String ValeurNomJeuDeDonnees;
	private String valeurDescriptionFamilleDeTests;
	private String valeurDescriptionSuiteDeTests;


	/**
	 * Read a Spreadsheet having requirements ans test cases, and transform them
	 * in XML to be imported by Doc XML in SalomeTMF
	 * @param selectionImportParametre parametre case a cocher
	 * @param selectionImportEnvironnement parametre case a cocher
	 * @param selectionExecutionCampagnes parametre case a cocher
	 * @param selectionImportExigence parametre case a cocher
	 * @param selectionImportTest parametre case a cocher
	 * @param creationCampagne parametre case a cocher
	 * @param fichierExcel Name of the spreadsheet file
	 * @throws java.lang.Exception Language Exception
	 */
	public FromExcelToXml(String fichierExcel, boolean selectionImportExigence, boolean selectionImportTest, boolean selectionImportParametre, boolean selectionImportEnvironnement, String creationCampagne, boolean selectionExecutionCampagnes, boolean selectionAssociationExigencesSalome, IPlugObject vt) throws Exception {

		pIPlugObject = vt;

		openXLSFile(fichierExcel);
		if (isErreurFormalismeExcel == false) {
			nomFichierXML = createXmlFile(fichierExcel);
			writeXmlHeading();

			if (selectionImportExigence == true && !isErreurTraitementImport) {
				testColumnsPresenceRequirement();
			}

			if (selectionImportTest == true && !isErreurTraitementImport) {
				testColumnsPresenceTests();
			}

			if (selectionImportParametre == true && !isErreurTraitementImport) {
				testColumnsPresenceParametre();
			}

			if (selectionImportEnvironnement == true && !isErreurTraitementImport) {
				testColumnsPresenceEnvironnement();
			}

			if (creationCampagne == Language.getInstance().getText("Importer_Campagnes") && !isErreurTraitementImport) {
				testColumnsPresenceCampagnes();
			}
			if (selectionExecutionCampagnes == true && !isErreurTraitementImport) {
				testColumnsPresenceExecutionCampagnes();
			}

			if (selectionAssociationExigencesSalome == true && !isErreurTraitementImport) {
				updateRequirementList(pIPlugObject);
			}

			if (selectionImportExigence == true && !isErreurTraitementImport){
				readXlsTableRequirement();
			}

			if (selectionImportParametre == true && !isErreurTraitementImport) {
				readXlsTableParametre();
			}
			
			if (selectionImportExigence == false && selectionAssociationExigencesSalome == true ){
				WriteRequirementsFromSalome();
			}

			if (selectionImportTest == true && !isErreurTraitementImport) {
				readXlsTableTest(selectionImportExigence, selectionAssociationExigencesSalome, selectionImportParametre);
			}

			if (selectionImportEnvironnement == true && !isErreurTraitementImport) {
				readXlsTableEnvironnement(selectionImportParametre,selectionImportTest);
			}


			if ((creationCampagne != Language.getInstance().getText("Pas_De_Campagne"))&&(creationCampagne != Language.getInstance().getText("Importer_Campagnes"))&& !isErreurTraitementImport) {
				creeCampagnes(creationCampagne, selectionImportEnvironnement);
			} else if (creationCampagne == Language.getInstance().getText("Importer_Campagnes")&& !isErreurTraitementImport) {
				readXlsTableCampagnes(selectionImportExigence,selectionImportParametre,selectionExecutionCampagnes);

			}


			closeXmlAndXlsFiles();
		} 

	}


	/**
	 * Function that write requirements read in SalomeTMF
	 * 
	 * @throws java.lang.Exception
	 *             Language Exception
	 */
	public void WriteRequirementsFromSalome() throws Exception {
		// Gestion des exigences
		requirements = projetVT.addElement("Requirements")
		.addAttribute("id_req", "Req_0");
		for (int i = 0; i< exigenceID.size(); i= i+4) {
			if (exigenceID.get(i+2).equals("RequirementFamily")) {
				writeFamilyRequirement(exigenceID.get(i));
			}
			if (exigenceID.get(i+2).equals("Requirement")) {
				boolean ExigenceAttacheFamille = false;
				if (exigenceID.get(i).contains(Language.getInstance().getText("_"))){
					ExigenceAttacheFamille = true;
				}
				if(exigenceID.get(i) !=null){
					writeRequirement(ExigenceAttacheFamille, removeSpecialCharacters(exigenceID.get(i).toString()), 65536);
				}
			}

		}
	}


	public void updateRequirementList(IPlugObject pIPlugObject) throws DocumentException{
		String fichierXMLTemp = createXmlFile(nomFichierXML.substring(0, nomFichierXML.lastIndexOf(".xml")) + "_temp.xls");
		setInitSelection(false);
		CallPackageDocXML test = new CallPackageDocXML(pIPlugObject, fichierXMLTemp);
		SAXReader xmlreader = new SAXReader();
		Document documentXmlTemp = xmlreader.read(new File(fichierXMLTemp));
		XPath xpathSelector = DocumentHelper.createXPath("//Requirement/Nom");
		List results = xpathSelector.selectNodes(documentXmlTemp);

		for (Iterator iter = results.iterator(); iter.hasNext();) {
			Element element = (Element) iter.next();
			Element elementTemp = element.getParent();
			String themeValue = "";
			String idValue= "";
			while(!elementTemp.getParent().getName().equals("Requirements")){
				if (themeValue.equals("")){
					themeValue = elementTemp.getParent().element("Nom").getText();
				}else{
					themeValue= elementTemp.getParent().element("Nom").getText() + Language.getInstance().getText("_") + themeValue;
				}
				if (idValue.equals("")){
					idValue =  elementTemp.getParent().attributeValue("id_req").replace("Req_", "");	
				}else {
					idValue =  elementTemp.getParent().attributeValue("id_req").replace("Req_", "") + Language.getInstance().getText("_") + idValue;
				}
				if(!brancheDescriptionID.contains(elementTemp.getParent().attributeValue("id_req").replace("Req_", ""))){
					brancheDescriptionID.add(elementTemp.getParent().attributeValue("id_req").replace("Req_", ""));
					brancheDescriptionID.add(RemiseEnFormeDescription(elementTemp.getParent().element("Description").asXML()));

				}
				elementTemp= elementTemp.getParent();
			}

			StringTokenizer stTheme = new StringTokenizer(themeValue,Language.getInstance().getText("_"));
			StringTokenizer stIdValue = new StringTokenizer(idValue,Language.getInstance().getText("_"));
			String tempThemeValue = "";
			String tempIdValue= "";

			while (stTheme.hasMoreTokens()){
				if (tempThemeValue.equals("")){
					tempThemeValue = stTheme.nextToken();
					tempIdValue = stIdValue.nextToken();		
				}else {
					tempThemeValue = tempThemeValue + Language.getInstance().getText("_") + stTheme.nextToken();
					tempIdValue = tempIdValue + Language.getInstance().getText("_") + stIdValue.nextToken();
				}
				if(!exigenceID.contains(tempThemeValue)){
					exigenceID.add(tempThemeValue);
					exigenceID.add(tempIdValue);
					exigenceID.add(elementTemp.getName());	
				}
			}
			exigenceID.add(themeValue + Language.getInstance().getText("_") + removeSpecialCharacters(element.getText()));
			exigenceID.add(idValue + Language.getInstance().getText("_") + element.getParent().attributeValue("id_req").replace("Req_", ""));
			exigenceID.add(element.getParent().getName());

		}

		File file = new File (fichierXMLTemp);
		if (file.exists()){
			file.delete();
		}
	}

	/**
	 * Lit les executions des campagnes
	 * @param debutExecutionCampagne Debut ligne
	 * @param hauteurExecutionCampagne nombre de lignes a lire
	 */
	public void litLesExecutions(int debutExecutionCampagne, int hauteurExecutionCampagne){
		for (int i = debutExecutionCampagne; i < debutExecutionCampagne + hauteurExecutionCampagne; i++) {
			celluleLu = execCampSheet.getCell(numeroColonneNomResultatExecutionExecutionCamp, i);
			valeurNomExecutionCampagne = celluleLu.getContents();
			if (valeurNomExecutionCampagne.length()>0){
				Element ResulExecCampTests = ExecCampTest.addElement("ResulExecCampTests");
				if (isPresenceColonneResultatExecutionExecutionCamp){
					celluleLu = execCampSheet.getCell(numeroColonneResultatExecutionExecutionCamp, i);
					ResultatExecution = celluleLu.getContents();
				}else {
					ResultatExecution = Language.getInstance().getText("INCOMPLETE");
				}
				celluleLu = execCampSheet.getCell(numeroColonneResultatExecutionExecutionCamp, i);
				if (isPresenceColonneNomResultatExecutionExecutionCamp){
					ResulExecCampTest = ResulExecCampTests.addElement("ResulExecCampTest")
					.addAttribute("id_exec_res", "ResExecCamp__" + indiceResultatExecution)
					.addAttribute("statut", ResultatExecution);
					Element Testeur = ResulExecCampTest.addElement("Testeur")
					.addText(Language.getInstance().getText("pluginxlsxml"));
					Element NomResulExecCampTests = ResulExecCampTest.addElement("Nom")
					.addText(valeurNomExecutionCampagne);
					// Generation de la date
					DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.MONTH_FIELD);
					Element dateCrea = ResulExecCampTest.addElement("Date_crea").addText(dateFormat.format(new Date()));
					DateFormat dateFormat2 = DateFormat.getTimeInstance(DateFormat.MEDIUM);
					Element heureCrea = ResulExecCampTest.addElement("Heure_crea").addText(dateFormat2.format(new Date()));
					ResulExecs = ResulExecCampTest.addElement("ResulExecs");

					hauteurResultatExecutionCampagne = 1;
					debutResultatExecutionCampagne = i;
					if (i	+ hauteurExecutionCampagne< execCampSheet.getRows()){
						celluleLu = execCampSheet.getCell(numeroColonneNomResultatExecutionExecutionCamp, i	+ hauteurResultatExecutionCampagne);

						while ((celluleLu.getContents().length() == 0) && (hauteurResultatExecutionCampagne + debutResultatExecutionCampagne < nombreLigneTableauExecutionCamp - 1)) {
							hauteurResultatExecutionCampagne++;
							celluleLu = execCampSheet.getCell(numeroColonneNomResultatExecutionExecutionCamp, i + hauteurResultatExecutionCampagne);
						}

						if ((debutResultatExecutionCampagne == nombreLigneTableauExecutionCamp - 1) && (execCampSheet.getCell(numeroColonneNomResultatExecutionExecutionCamp,nombreLigneTableauExecutionCamp - 1).getContents().length() != 0)) {
							hauteurResultatExecutionCampagne++;
						}
						if ((debutResultatExecutionCampagne + hauteurResultatExecutionCampagne == nombreLigneTableauExecutionCamp - 1) && (execCampSheet.getCell(numeroColonneNomResultatExecutionExecutionCamp,nombreLigneTableauExecutionCamp - 1).getContents().length() == 0)) {
							hauteurResultatExecutionCampagne++;
						}

						litLesResultatExecutionsTests(debutResultatExecutionCampagne, hauteurResultatExecutionCampagne);
					}
				}
			}

			indiceResultatExecution++;					
		}
	}

	/**
	 * Lit les resultats d'executions des campagnes
	 * @param debutResultatExecutionCampagne Debut ligne
	 * @param hauteurResultatExecutionCampagne nombre de lignes a lire
	 */
	public void litLesResultatExecutionsTests(int debutResultatExecutionCampagne, int hauteurResultatExecutionCampagne){
		for (int i = debutResultatExecutionCampagne; i < debutResultatExecutionCampagne + hauteurResultatExecutionCampagne; i++) {
			celluleLu = execCampSheet.getCell(numeroColonneFamilleDeTestsExecutionCamp, i);
			valeurNomFamilleTestExecutionCampagne = celluleLu.getContents();
			celluleLu = execCampSheet.getCell(numeroColonneSuiteDeTestsExecutionCamp, i);
			valeurNomSuiteTestExecutionCampagne = celluleLu.getContents();
			celluleLu = execCampSheet.getCell(numeroColonneCasDeTestsExecutionCamp, i);
			valeurNomCasDeTestExecutionCampagne = celluleLu.getContents();
			if (isPresenceColonneResultatTestExecuteExecutionCamp){
				celluleLu = execCampSheet.getCell(numeroColonneResultatTestExecuteExecutionCamp, i);
				valeurResultatTestExecuteExecutionCampagne = celluleLu.getContents();
			}else {
				valeurResultatTestExecuteExecutionCampagne=Language.getInstance().getText("INCOMPLETE");
			}

			if (valeurNomCasDeTestExecutionCampagne.length() > 0) {
				boolean IDTestTrouve=false;
				for (int j=0;j<listeTestsPourCampagne.size();j=j+8){
					if((listeTestsPourCampagne.get(j).equals(valeurNomFamilleTestExecutionCampagne)) && (listeTestsPourCampagne.get(j+2).equals(valeurNomSuiteTestExecutionCampagne))&& (listeTestsPourCampagne.get(j+4).equals(valeurNomCasDeTestExecutionCampagne)) && (IDTestTrouve==false)) {
						IDTestTrouve =true;
						IDTest = listeTestsPourCampagne.get(j+5);
					}
				}
				if (IDTestTrouve){
					Element ResulExec = ResulExecs.addElement("ResulExec")
					.addAttribute("refTest", "Test_" + IDTest)
					.addAttribute("res", valeurResultatTestExecuteExecutionCampagne);

					litPJetURL(ResulExec, execCampSheet, i, isPresenceColonneLienHypertexteExecutionCampTestExecute, numeroColonneLienHypertexteExecutionCampTestExecute, isPresenceColonnePieceJointeExecutionCampTestExecute, numeroColonnePieceJointeExecutionCampTestExecute, Language.getInstance().getText("Campagnes") + fs + IDCampagne + fs + execCampSheet.getCell(numeroColonneNomCampagneExecutionCamp,i).getContents().trim() + fs + valeurNomCasDeTestExecutionCampagne.trim());


					Element RefTest = ResulExec.addElement("RefTest");
					if (isPresenceColonneCasDeTestsExecutionCamp){
						Element NomTest = RefTest.addElement("NomTest")
						.addText(valeurNomCasDeTestExecutionCampagne);
					}
					if (isPresenceColonneSuiteDeTestsExecutionCamp){
						Element NomSuite = RefTest.addElement("NomSuite")
						.addText(valeurNomSuiteTestExecutionCampagne);
					}
					if (isPresenceColonneFamilleDeTestsExecutionCamp){
						Element NomFamille = RefTest.addElement("NomFamille")
						.addText(valeurNomFamilleTestExecutionCampagne);
					}
					ResulActionTests = ResulExecCampTest.addElement("ResulActionTests");

					//A completer
					if (valeurNomCasDeTestExecutionCampagne.length() > 0) {
						hauteurTestExecutionCampagne = 1;
						debutTestExecutionCampagne = i;
						if ((hauteurTestExecutionCampagne + debutTestExecutionCampagne < nombreLigneTableauExecutionCamp - 1)){
							celluleLu = execCampSheet.getCell(numeroColonneCasDeTestsExecutionCamp, i + hauteurTestExecutionCampagne);
							while ((celluleLu.getContents().length() == 0) && (hauteurTestExecutionCampagne + debutTestExecutionCampagne < nombreLigneTableauExecutionCamp - 1)) {
								hauteurTestExecutionCampagne++;
								celluleLu = execCampSheet.getCell(numeroColonneCasDeTestsExecutionCamp, i + hauteurTestExecutionCampagne);
							}

							if ((debutTestExecutionCampagne == nombreLigneTableauExecutionCamp - 1) && (execCampSheet.getCell(numeroColonneCasDeTestsExecutionCamp,nombreLigneTableauExecutionCamp - 1).getContents().length() != 0)) {
								hauteurTestExecutionCampagne++;
							}
							if ((debutTestExecutionCampagne + hauteurTestExecutionCampagne == nombreLigneTableauExecutionCamp - 1) && (execCampSheet.getCell(numeroColonneCasDeTestsExecutionCamp,nombreLigneTableauExecutionCamp - 1).getContents().length() == 0)) {
								hauteurTestExecutionCampagne++;
							}
						}

						litLesActionsExecutionsTests(debutTestExecutionCampagne, hauteurTestExecutionCampagne);

					}
				}
			}
		}
	}

	private void litLesActionsExecutionsTests(int debutTestExecutionCampagne, int hauteurTestExecutionCampagne) {
		for (int i = debutTestExecutionCampagne; i < debutTestExecutionCampagne + hauteurTestExecutionCampagne; i++) {
			celluleLu = execCampSheet.getCell(numeroColonneNumeroExecutionCamp, i);

			valeurNumeroExecuteExecutionCampagne = celluleLu.getContents();
			boolean IDActionTrouve=false;
			for (int j=0;j<actionID.size();j=j+5){
				if((actionID.get(j).equals(IDTest)) && (actionID.get(j+1).equals(valeurNumeroExecuteExecutionCampagne)) && (IDActionTrouve==false)) {
					IDActionTrouve =true;
					IDAction = actionID.get(j+2);
					valeurActionARealiser= actionID.get(j+3);
					valeurActionAttendue = actionID.get(j+4);
				}
			}
			celluleLu = execCampSheet.getCell(numeroColonneActionExecuteeExecutionCamp, i);

			Element ResulActionTest = ResulActionTests.addElement("ResulActionTest")
			.addAttribute("refAction", "Action_" + IDAction)
			.addAttribute("res", celluleLu.getContents());
			Element RefAction = ResulActionTest.addElement("RefAction");
			Element NomAction = RefAction.addElement("NomAction")
			.addText(valeurNumeroExecuteExecutionCampagne);
			Element NomTest = RefAction.addElement("NomTest")
			.addText(valeurNomCasDeTestExecutionCampagne);
			Element NomSuite = RefAction.addElement("NomSuite")
			.addText(valeurNomSuiteTestExecutionCampagne);
			Element NomFamille = RefAction.addElement("NomFamille")
			.addText(valeurNomFamilleTestExecutionCampagne);
			Element Description = ResulActionTest.addElement("Description")
			.addText(valeurActionARealiser);
			Element ResultAttendu = ResulActionTest.addElement("ResultAttendu")
			.addText(valeurActionAttendue);

			celluleLu = execCampSheet.getCell(numeroColonneActionObtenueExecutionCamp, i);
			if (celluleLu.getContents().length()>0){
				Element ResulEffectif = ResulActionTest.addElement("ResulEffectif")
				.addText(celluleLu.getContents());
			}


		}
	}

	/**
	 * Lit la feuille executions des campagnes
	 * @param valeurNomCampagne Nom de la campagne
	 */
	public void readXlsTableExecutionCampagnes(String valeurNomCampagne){
		for (int i = ligneDebutTableauExecutionCamp + 1; i < nombreLigneTableauExecutionCamp; i++) {
			celluleLu = execCampSheet.getCell(numeroColonneNomCampagneExecutionCamp, i);
			if (celluleLu.getContents().length()>0 && valeurNomCampagne.equals(celluleLu.getContents())){
				// lit le nom de la campagne
				/*		boolean campagneTrouve =false;
				for (int j=0; j <campagneID.size();j=j+2){
					if (celluleLu.getContents().equals(campagneID.get(j))){
						campagneTrouve=true;
						valeurNomCampagne = celluleLu.getContents();
						IDCampagne = campagneID.get(j+1);
					}
				}*/

				/*	if(campagneTrouve){
					Element CampagneTest  = CampagneTests.addElement("CampagneTest")
					.addAttribute("id_camp", "Camp_" + IDCampagne);*/
				Element ExecCampTests = CampagneTest.addElement("ExecCampTests");
				ExecCampTest = ExecCampTests.addElement("ExecCampTest")
				.addAttribute("id_exec_camp", "ExecCamp_" + indiceExecutionCamp);

				celluleLu = execCampSheet.getCell(numeroColonneNomExecutionExecutionCamp, i);
				Element NomExecCamp = ExecCampTest.addElement("Nom")
				.addText(celluleLu.getContents());
				celluleLu = execCampSheet.getCell(numeroColonneNomEnvironnementExecutionCamp, i);
				for (int k=0; k <environnementID.size();k=k+2){
					if (celluleLu.getContents().equals(environnementID.get(k))){
						Element EnvironnementEx = ExecCampTest.addElement("EnvironnementEx")
						.addAttribute("ref", "Env_" + environnementID.get(k+1));
						Element NomEnvironnementEx = EnvironnementEx.addElement("Nom")
						.addText(celluleLu.getContents());
					}
				}
				celluleLu = execCampSheet.getCell(numeroColonneJeuDeDonneesExecutionCamp, i);
				for (int k=0; k <jeuDeDonneesID.size();k=k+2){
					if (celluleLu.getContents().equals(jeuDeDonneesID.get(k))){
						Element JeuDonneesEx = ExecCampTest.addElement("JeuDonneesEx")
						.addAttribute("ref", "Jeu_" + jeuDeDonneesID.get(k+1));
						Element NomJeuDonneesEx = JeuDonneesEx.addElement("Nom")
						.addText(celluleLu.getContents());

					}
				}

				litPJetURL(ExecCampTest, execCampSheet, i, isPresenceColonneLienHypertexteExecutionCamp, numeroColonneLienHypertexteExecutionCamp, isPresenceColonnePieceJointeExecutionCamp, numeroColonnePieceJointeExecutionCamp, Language.getInstance().getText("Campagnes") + fs + IDCampagne + fs + execCampSheet.getCell(numeroColonneNomCampagneExecutionCamp,i).getContents().trim());
				if (valeurNomCampagne.length() > 0) {
					hauteurExecutionCampagne = 1;
					debutExecutionCampagne = i;
					if (i	+ hauteurExecutionCampagne< execCampSheet.getRows()){
						celluleLu = execCampSheet.getCell(numeroColonneNomCampagneExecutionCamp, i	+ hauteurExecutionCampagne);
					}
					while ((celluleLu.getContents().length() == 0) && (hauteurExecutionCampagne + debutExecutionCampagne < nombreLigneTableauExecutionCamp - 1)) {
						hauteurExecutionCampagne++;
						celluleLu = execCampSheet.getCell(numeroColonneNomCampagneExecutionCamp, i + hauteurExecutionCampagne);

					}

					if ((debutExecutionCampagne == nombreLigneTableauExecutionCamp - 1) && (execCampSheet.getCell(numeroColonneNomCampagneExecutionCamp,nombreLigneTableauExecutionCamp - 1).getContents().length() != 0)) {
						hauteurExecutionCampagne++;
					}
					if ((debutExecutionCampagne + hauteurExecutionCampagne == nombreLigneTableauExecutionCamp - 1) && (execCampSheet.getCell(numeroColonneNomCampagneExecutionCamp,nombreLigneTableauExecutionCamp - 1).getContents().length() == 0)) {
						hauteurExecutionCampagne++;
					}

					litLesExecutions(debutExecutionCampagne, hauteurExecutionCampagne);

				}


				/*	}else{
					listeCampagneNonTrouve = listeCampagneNonTrouve + celluleLu.getContents() + "\n";
				} */
				indiceExecutionCamp++;

			}	
		}

	}

	/**
	 * Function that Verify the presence of Execution campaigns columns in the Execution campaign spreadsheet
	 */
	public void testColumnsPresenceExecutionCampagnes() {


		StringTokenizer st;
		// Recupere ligne debut tableau
		boolean ExecutionCampagneTrouve = false;
		for (int j = 0; j < nombreLigneTableauExecutionCamp; j++) {
			for (int i = 0; i < nombreColonneTableauExecutionCamp; i++) {
				celluleLu = execCampSheet.getCell(i, j);
				st = new StringTokenizer(Language.getInstance().getText("nom_Campagne_Liste").toLowerCase(), ",");
				while (st.hasMoreTokens() && ExecutionCampagneTrouve == false) {
					if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
						ligneDebutTableauExecutionCamp = celluleLu.getRow();
						ExecutionCampagneTrouve = true;
					}
				}

			}
		}

		// test presence des differents colonnes
		for (int i = 0; i < nombreColonneTableauExecutionCamp; i++) {
			celluleLu = execCampSheet.getCell(i, ligneDebutTableauExecutionCamp);

			// test presence  nom Campagne
			st = new StringTokenizer(Language.getInstance().getText("nom_Campagne_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomCampagneExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomCampagneExecutionCamp = true;
					numeroColonneNomCampagneExecutionCamp = i;
				}
			}
			//test presence nom de l'execution
			st = new StringTokenizer(Language.getInstance().getText("nom_Execution_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomExecutionExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomExecutionExecutionCamp = true;
					numeroColonneNomExecutionExecutionCamp = i;
				}
			}
			//test presence nom de l'environnement
			st = new StringTokenizer(Language.getInstance().getText("nom_Environnements_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomEnvironnementExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomEnvironnementExecutionCamp = true;
					numeroColonneNomEnvironnementExecutionCamp = i;
				}
			}

			//test presence Jeu de donnees 
			st = new StringTokenizer(Language.getInstance().getText("jeu_de_donnees_Campagne_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneJeuDeDonneesExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneJeuDeDonneesExecutionCamp = true;
					numeroColonneJeuDeDonneesExecutionCamp = i;
				}
			}

			// test presence des colonnes Lien Hypertexte
			st = new StringTokenizer(Language.getInstance().getText("Lien_Hypertexte_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneLienHypertexteExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneLienHypertexteExecutionCamp = true;
					numeroColonneLienHypertexteExecutionCamp = i;
				}
			}

			// test presence des colonnes Piece Jointe
			st = new StringTokenizer(Language.getInstance().getText("Piece_Jointe_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonnePieceJointeExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonnePieceJointeExecutionCamp = true;
					numeroColonnePieceJointeExecutionCamp = i;
				}
			}

			// test presence des colonnes NOM DU ReSULTAT DE L'EXeCUTION
			st = new StringTokenizer(Language.getInstance().getText("Nom_du_resultat_de_lexecution_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomResultatExecutionExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomResultatExecutionExecutionCamp = true;
					numeroColonneNomResultatExecutionExecutionCamp = i;
				}
			}
			// test presence des colonnes ReSULTAT EXeCUTION
			st = new StringTokenizer(Language.getInstance().getText("Resultat_de_lexecution_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneResultatExecutionExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneResultatExecutionExecutionCamp = true;
					numeroColonneResultatExecutionExecutionCamp = i;
				}
			}
			// test presence des Famille de tests
			st = new StringTokenizer(Language.getInstance().getText("famille_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneFamilleDeTestsExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneFamilleDeTestsExecutionCamp = true;
					numeroColonneFamilleDeTestsExecutionCamp = i;
				}
			}

			//test presence des Suite de tests
			st = new StringTokenizer(Language.getInstance().getText("suite_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneSuiteDeTestsExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneSuiteDeTestsExecutionCamp = true;
					numeroColonneSuiteDeTestsExecutionCamp = i;
				}
			}

			// test presence des colonnes Cas de tests
			st = new StringTokenizer(Language.getInstance().getText("cas_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneCasDeTestsExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneCasDeTestsExecutionCamp = true;
					numeroColonneCasDeTestsExecutionCamp = i;
				}
			}
			// test presence des colonnes ReSULTAT DU TEST EXeCUTe
			st = new StringTokenizer(Language.getInstance().getText("Resultat_test_execute_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneResultatTestExecuteExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneResultatTestExecuteExecutionCamp = true;
					numeroColonneResultatTestExecuteExecutionCamp = i;
				}
			}
			// test presence des colonnes numero
			st = new StringTokenizer(Language.getInstance().getText("numero_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNumeroExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNumeroExecutionCamp = true;
					numeroColonneNumeroExecutionCamp = i;
				}
			}
			// test presence des colonnes ACTION EXeCUTeE 
			st = new StringTokenizer(Language.getInstance().getText("action_executee_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneActionExecuteeExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneActionExecuteeExecutionCamp = true;
					numeroColonneActionExecuteeExecutionCamp = i;
				}
			}
			// test presence des colonnes ACTION OBTENUE 
			st = new StringTokenizer(Language.getInstance().getText("action_obtenue_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneActionObtenueExecutionCamp == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneActionObtenueExecutionCamp = true;
					numeroColonneActionObtenueExecutionCamp = i;
				}
			}	

			// test presence des colonnes Lien Hypertexte Test Execute
			st = new StringTokenizer(Language.getInstance().getText("Lien_Hypertexte_Test_Execute_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneLienHypertexteExecutionCampTestExecute == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneLienHypertexteExecutionCampTestExecute = true;
					numeroColonneLienHypertexteExecutionCampTestExecute = i;
				}
			}

			// test presence des colonnes Piece Jointe Test Execute
			st = new StringTokenizer(Language.getInstance().getText("Piece_Jointe_Test_Execute_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonnePieceJointeExecutionCampTestExecute == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonnePieceJointeExecutionCampTestExecute = true;
					numeroColonnePieceJointeExecutionCampTestExecute = i;
				}
			}

		}
		if ((isPresenceColonneNomCampagneExecutionCamp == false)||(isPresenceColonneNomExecutionExecutionCamp == false)||(isPresenceColonneNomEnvironnementExecutionCamp == false)||(isPresenceColonneJeuDeDonneesExecutionCamp	== false)) {
			isErreurTraitementImport = true;
			closeXmlAndXlsFiles();
			JOptionPane.showMessageDialog(null, 
					Language.getInstance().getText("Stop_No_Campaign_Name_Column"), 
					Language.getInstance().getText("Erreur_"), 
					JOptionPane.ERROR_MESSAGE);
			PopUpFormalismeExcel p = new PopUpFormalismeExcel(pIPlugObject);

		}

	}


	/**
	 * read url and files for all spreadsheets
	 * @param ElementAAttachements Element XML
	 * @param feuilleExcel Feuille Excel
	 * @param ligneALire ligne a lire
	 * @param presenceColonneLienHypertexte presence Colonne Lien Hypertexte
	 * @param numeroColonneLienHypertexte numero Colonne Lien Hypertexte
	 * @param presenceColonnePieceJointe presence colonne Piece Jointe
	 * @param numeroColonnePieceJointe numero colonne Piece Jointe
	 * @param repertoirePieceJointe Repertoire de stockage des Piece Jointe
	 */
	public void litPJetURL(Element ElementAAttachements, Sheet feuilleExcel, int ligneALire, boolean presenceColonneLienHypertexte, int numeroColonneLienHypertexte, boolean presenceColonnePieceJointe, int numeroColonnePieceJointe, String repertoirePieceJointe) {
		//		lit Lien Hypertexte
		if (presenceColonneLienHypertexte == true) {
			celluleLu = feuilleExcel.getCell(numeroColonneLienHypertexte, ligneALire);
			if (celluleLu.getType() == CellType.NUMBER_FORMULA
					|| celluleLu.getType() == CellType.STRING_FORMULA
					|| celluleLu.getType() == CellType.BOOLEAN_FORMULA
					|| celluleLu.getType() == CellType.DATE_FORMULA
					|| celluleLu.getType() == CellType.FORMULA_ERROR) {
				FormulaCell nfc = (FormulaCell) celluleLu;
				StringBuffer sb = new StringBuffer();
				try {
					StringTokenizer st = new StringTokenizer(nfc.getFormula(), "\"");
					st.nextToken();
					valeurLienHypertexte.add(st.nextToken());
				} catch (FormulaException e) {
					JOptionPane.showMessageDialog(null, 
							Language.getInstance().getText("malformed_formula") + sb.toString() + ": " + e.getMessage(),
							Language.getInstance().getText("Erreur_"),
							JOptionPane.ERROR_MESSAGE);
				}
			} else {
				StringTokenizer st = new StringTokenizer(celluleLu.getContents(), "\n");
				while (st.hasMoreTokens()) {
					valeurLienHypertexte.add(st.nextToken());
				}
			}
			if (!valeurLienHypertexte.isEmpty()) {
				for (int z = 0; z < valeurLienHypertexte.size(); z++) {
					try {
						URL url = new URL(valeurLienHypertexte.get(z).toString());
					} catch (MalformedURLException mue) {
						JOptionPane.showMessageDialog(null, 
								Language.getInstance().getText("malformed_URL") + valeurLienHypertexte.get(z).toString(), 
								Language.getInstance().getText("Erreur_"),
								JOptionPane.ERROR_MESSAGE);
						valeurLienHypertexte.remove(z);
					}
				}

			} else {
				valeurLienHypertexte.clear();
			}
		}

		// lit Piece Jointe
		if (presenceColonnePieceJointe == true) {
			celluleLu = feuilleExcel.getCell(numeroColonnePieceJointe, ligneALire);
			if (celluleLu.getType() == CellType.NUMBER_FORMULA
					|| celluleLu.getType() == CellType.STRING_FORMULA
					|| celluleLu.getType() == CellType.BOOLEAN_FORMULA
					|| celluleLu.getType() == CellType.DATE_FORMULA
					|| celluleLu.getType() == CellType.FORMULA_ERROR) {
				FormulaCell nfc = (FormulaCell) celluleLu;
				StringBuffer sb = new StringBuffer();

				try {
					StringTokenizer st = new StringTokenizer(nfc.getFormula(), "\"");
					st.nextToken();
					String RecupereCheminRelatif;
					try {
						RecupereCheminRelatif = copyFileAttachements(st.nextToken().replaceFirst("file:///", ""), repertoirePieceJointe, null);
						valeurPieceJointe.add(RecupereCheminRelatif);
						valeurPieceJointe.remove(null);
					} catch (Exception e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
				} catch (FormulaException e) {
					JOptionPane.showMessageDialog(null, 
							Language.getInstance().getText("malformed_formula") + sb.toString() + ": " + e.getMessage(),
							Language.getInstance().getText("Erreur_"),
							JOptionPane.ERROR_MESSAGE);
				}
			} else {
				StringTokenizer st = new StringTokenizer(celluleLu.getContents(), "\n");
				while (st.hasMoreTokens()) {
					String RecupereCheminRelatif;
					try {
						RecupereCheminRelatif = copyFileAttachements(st.nextToken(), repertoirePieceJointe, null);
						valeurPieceJointe.add(RecupereCheminRelatif);
						valeurPieceJointe.remove(null);
					} catch (Exception e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
				}
			}

			if (valeurPieceJointe.isEmpty()) {
				valeurPieceJointe.clear();
			}
		}
		//Ecrit Lien hypertexte si present et piece jointe si present
		if ((!valeurLienHypertexte.isEmpty())|| (!valeurPieceJointe.isEmpty())) {
			Element Attachement = ElementAAttachements.addElement("Attachements");
			for (int z = 0; z < valeurLienHypertexte.size(); z++) {
				Element UrlAttachement = Attachement.addElement("UrlAttachement")
				.addAttribute("url", valeurLienHypertexte.get(z).toString());
			}
			for (int z = 0; z < valeurPieceJointe.size(); z++) {
				if (!valeurPieceJointe.get(z).toString().equals(null)) {
					Element FileAttachement = Attachement
					.addElement("FileAttachement")
					.addAttribute("nom",valeurPieceJointe.get(z).toString().substring(valeurPieceJointe.get(z).toString().lastIndexOf(fs) + 1))
					.addAttribute("dir",valeurPieceJointe.get(z).toString());
				}
			}
			valeurLienHypertexte.clear();
			valeurPieceJointe.clear();
		}
	}

	/**
	 * Read all the spreadsheet for the campaigns
	 * @param selectionImportExigence selection Import Exigence
	 * @param selectionExecutionCampagnes selection Execution Campagnes
	 * @throws java.lang.Exception Exception
	 */
	public void readXlsTableCampagnes( boolean selectionImportExigence, boolean selectionImportParametre, boolean selectionExecutionCampagnes) throws Exception {
		// Gestion des CampagnesTests
		Element CampagneTests  = projetVT.addElement("CampagneTests");

		for (int i = ligneDebutTableauCampagne + 1; i < nombreLigneTableauCampagne; i++) {
			celluleLu = campagneSheet.getCell(numeroColonneNomCampagne, i);
			if (celluleLu.getContents().length()>0){
				// lit le nom de la campagne
				CampagneTest  = CampagneTests.addElement("CampagneTest")
				.addAttribute("id_camp", "Camp_" + indiceCampagne);
				Element Concepteur = CampagneTest.addElement("Concepteur");
				Element NomConcepteur = Concepteur.addElement("Nom")
				.addText(Language.getInstance().getText("pluginxlsxml"));
				// Generation de la date
				DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.MONTH_FIELD);
				Element dateCrea = CampagneTest.addElement("Date_crea").addText(dateFormat.format(new Date()));

				celluleLu = campagneSheet.getCell(numeroColonneNomCampagne, i);

				valeurNomCampagne = celluleLu.getContents();
				Element Campagne  = CampagneTest.addElement("Nom")
				.addText(valeurNomCampagne);
				campagneID.add(valeurNomCampagne);
				campagneID.add(Integer.toString(indiceCampagne));

				//Lit la description de la campagne
				if (isPresenceColonneDescriptionCampagne){
					celluleLu = campagneSheet.getCell(numeroColonneDescriptionCampagne, i);
					valeurDescriptionCampagne = celluleLu.getContents();
					addHTMLDescription(CampagneTest,valeurDescriptionCampagne);
				}

				litPJetURL(CampagneTest, campagneSheet, i, isPresenceColonneLienHypertexteCampagne, numeroColonneLienHypertexteCampagne, isPresenceColonnePieceJointeCampagne, numeroColonnePieceJointeCampagne, Language.getInstance().getText("Campagne") + fs + indiceCampagne);


				if (valeurNomCampagne.length() > 0) {
					hauteurCampagne = 0;
					debutCampagne = i;

					celluleLu = campagneSheet.getCell(numeroColonneNomCampagne, i	+ hauteurCampagne);

					while (((celluleLu.getContents().equals(valeurNomCampagne) || celluleLu.getContents().length() == 0)) && (hauteurCampagne + debutCampagne < nombreLigneTableauCampagne - 1)) {
						hauteurCampagne++;
						celluleLu = campagneSheet.getCell(numeroColonneNomCampagne, i + hauteurCampagne);

					}

					if ((debutCampagne == nombreLigneTableauCampagne - 1) && (campagneSheet.getCell(numeroColonneNomCampagne,nombreLigneTableauCampagne - 1).getContents().length() != 0)) {
						hauteurCampagne++;
					}
					if ((debutCampagne + hauteurCampagne == nombreLigneTableauCampagne - 1) && (campagneSheet.getCell(numeroColonneNomCampagne,nombreLigneTableauCampagne - 1).getContents().length() == 0)) {
						hauteurCampagne++;
					}

					for (int boucle = debutCampagne; boucle < debutCampagne + hauteurCampagne; boucle++) {
						if (isPresenceColonneJeuDeDonneesCampagne){
							celluleLu = campagneSheet.getCell(numeroColonneJeuDeDonneesCampagne, boucle);
							ValeurNomJeuDeDonnees = celluleLu.getContents();
							if(ValeurNomJeuDeDonnees.length()>0){
								Element JeuxDonnees = CampagneTest.addElement("JeuxDonnees");
								Element JeuDonnees = JeuxDonnees.addElement("JeuDonnees")
								.addAttribute("id_jeu", "Jeu_" + indiceJeuDeDonnees);
								Element NomJeuDonnees = JeuDonnees.addElement("Nom")
								.addText(celluleLu.getContents());
								jeuDeDonneesID.add(ValeurNomJeuDeDonnees);
								jeuDeDonneesID.add(Integer.toString(indiceJeuDeDonnees));
								indiceJeuDeDonnees++;

								//Calcule nb parametres jeux donnees
								hauteurJeuxDonnees = 0;
								debutJeuxDonnees = boucle;

								celluleLu = campagneSheet.getCell(numeroColonneJeuDeDonneesCampagne, debutJeuxDonnees + hauteurJeuxDonnees);

								while (((celluleLu.getContents().equals(ValeurNomJeuDeDonnees) || celluleLu.getContents().length() == 0)) && (hauteurJeuxDonnees + debutJeuxDonnees < debutCampagne + hauteurCampagne)&& (hauteurJeuxDonnees + debutJeuxDonnees < nombreLigneTableauCampagne - 1)) {
									hauteurJeuxDonnees++;
									celluleLu = campagneSheet.getCell(numeroColonneJeuDeDonneesCampagne, debutJeuxDonnees + hauteurJeuxDonnees);
								}

								if ((debutJeuxDonnees == nombreLigneTableauCampagne - 1) && (campagneSheet.getCell(numeroColonneJeuDeDonneesCampagne,nombreLigneTableauCampagne - 1).getContents().length() != 0)) {
									hauteurJeuxDonnees++;
								}
								if ((debutJeuxDonnees + hauteurJeuxDonnees == nombreLigneTableauCampagne - 1) && (campagneSheet.getCell(numeroColonneJeuDeDonneesCampagne,nombreLigneTableauCampagne - 1).getContents().length() == 0)) {
									hauteurJeuxDonnees++;
								}

								for (int boucleParametre = debutJeuxDonnees; boucleParametre < debutJeuxDonnees + hauteurJeuxDonnees; boucleParametre++) {
									if (isPresenceColonneNomParametreCampagne){
										celluleLu = campagneSheet.getCell(numeroColonneNomParametreCampagne, boucleParametre);
										if(celluleLu.getContents().length()>0){
											Element ValeurParams = JeuDonnees.addElement("ValeurParams");
											if(listeParametre.contains(celluleLu.getContents())){
												nomParametreCampagne = celluleLu.getContents();
												IDParametreCampagne = listeParametre.get(listeParametre.indexOf(celluleLu.getContents())+1);
											} else {
												//Rajoute le parametre
												Element param  = params.addElement("Param")
												.addAttribute("id_param", "Param_" + indiceParametre);
												Element nomParam  = param.addElement("Nom")
												.addText(celluleLu.getContents());
												listeParametre.add(celluleLu.getContents());
												listeParametre.add(Integer.toString(indiceParametre));
												nomParametreCampagne = celluleLu.getContents();
												IDParametreCampagne = Integer.toString(indiceParametre);
												indiceParametre++;
											}
											Element ValeurParam = ValeurParams.addElement("ValeurParam")
											.addAttribute("ref", "Param_" + IDParametreCampagne)
											.addAttribute("valeur", campagneSheet.getCell(numeroColonneValeurParametreCampagne, boucleParametre).getContents());
											Element NomParametre = ValeurParam.addElement("Nom")
											.addText(nomParametreCampagne);			
										}
									}
								}

								if (isPresenceColonneDescriptionJeuDeDonneesCampagne){
									celluleLu = campagneSheet.getCell(numeroColonneDescriptionJeuDeDonneesCampagne, boucle);
									if(celluleLu.getContents().length()>0){
										valeurDescriptionJeuDonnees = celluleLu.getContents();
										addHTMLDescription(JeuDonnees,valeurDescriptionJeuDonnees);
									}
								}

							}
						}
					}

					if (selectionImportExigence){
						LinkRequirement= CampagneTest.addElement("LinkRequirement");
						// Partie lien Exigence
						for (int boucle = debutCampagne; boucle < debutCampagne + hauteurCampagne; boucle++) {
							if (isPresenceColonneFamilleTestCampagne && isPresenceColonneSuiteTestCampagne && isPresenceColonneCasDeTestCampagne){
								celluleLu = campagneSheet.getCell(numeroColonneCasDeTestCampagne, boucle);
								if(celluleLu.getContents().length()>0){
									for (int j = 0; j < listeTestsPourCampagne.size(); j=j+8){
										if (listeTestsPourCampagne.get(j).equals(campagneSheet.getCell(numeroColonneFamilleTestCampagne, boucle).getContents())
												&&	listeTestsPourCampagne.get(j+2).equals(campagneSheet.getCell(numeroColonneSuiteTestCampagne, boucle).getContents())
												&&	listeTestsPourCampagne.get(j+4).equals(campagneSheet.getCell(numeroColonneCasDeTestCampagne, boucle).getContents())){
											if ((listeTestsPourCampagne.get(j+6)!=null)){
												Element RequirementRef = LinkRequirement.addElement("RequirementRef")
												.addAttribute("ref", "Req_" + listeTestsPourCampagne.get(j+7));
												Element nomRequirementRef = RequirementRef.addElement("Nom")
												.addText(listeTestsPourCampagne.get(j+6));
											}
										}
									}
								}
							}
						}
					}

					// Partie Famille
					Element FamillesCamp = CampagneTest.addElement("FamillesCamp");
					for (int boucle = debutCampagne; boucle < debutCampagne + hauteurCampagne; boucle++) {
						if (isPresenceColonneFamilleTestCampagne && isPresenceColonneSuiteTestCampagne && isPresenceColonneCasDeTestCampagne){
							celluleLu = campagneSheet.getCell(numeroColonneCasDeTestCampagne, boucle);
							if(celluleLu.getContents().length()>0){
								boolean testTrouve = false;
								for (int j = 0; j < listeTestsPourCampagne.size(); j=j+8){
									if (listeTestsPourCampagne.get(j).equals(campagneSheet.getCell(numeroColonneFamilleTestCampagne, boucle).getContents())
											&&	listeTestsPourCampagne.get(j+2).equals(campagneSheet.getCell(numeroColonneSuiteTestCampagne, boucle).getContents())
											&&	listeTestsPourCampagne.get(j+4).equals(campagneSheet.getCell(numeroColonneCasDeTestCampagne, boucle).getContents()) && !testTrouve){
										Element FamilleRef = FamillesCamp.addElement("FamilleRef")
										.addAttribute("ref", "Fam_" + listeTestsPourCampagne.get(j+1));
										Element NomFamilleRef = FamilleRef.addElement("Nom")
										.addText(listeTestsPourCampagne.get(j));
										Element SuiteTestsCamp = FamilleRef.addElement("SuiteTestsCamp");
										Element SuiteTestRef = SuiteTestsCamp.addElement("SuiteTestRef")
										.addAttribute("ref", "SuiteTest_" + listeTestsPourCampagne.get(j+3));
										Element NomSuiteTestRef = SuiteTestRef.addElement("Nom")
										.addText(listeTestsPourCampagne.get(j+2));
										Element TestsCamp = SuiteTestRef.addElement("TestsCamp");
										Element TestRef = TestsCamp.addElement("TestRef")
										.addAttribute("ref", "Test_" + listeTestsPourCampagne.get(j+5))
										.addAttribute("loginAssigned", Language.getInstance().getText("pluginxlsxml"));
										Element NomTestRef = TestRef.addElement("Nom")
										.addText(listeTestsPourCampagne.get(j+4));
										testTrouve=true;
									}
								}
							}
						}
					}


				}
				if (selectionExecutionCampagnes == true && !isErreurTraitementImport) {
					readXlsTableExecutionCampagnes(valeurNomCampagne);
				}
				indiceCampagne++;
			}
		}


	}
	/**
	 * Function that Verify the presence of parameters columns in the paremeter spreadsheet
	 */
	public void testColumnsPresenceCampagnes() {

		StringTokenizer st;
		// Recupere ligne debut tableau
		boolean CampagnesTrouve = false;
		for (int j = 0; j < nombreLigneTableauCampagne; j++) {
			for (int i = 0; i < nombreColonneTableauCampagne; i++) {
				celluleLu = campagneSheet.getCell(i, j);
				st = new StringTokenizer(Language.getInstance().getText("nom_Campagne_Liste").toLowerCase(), ",");
				while (st.hasMoreTokens() && CampagnesTrouve == false) {
					if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
						ligneDebutTableauCampagne = celluleLu.getRow();
						CampagnesTrouve = true;
					}
				}

			}
		}

		// test presence des differents colonnes
		for (int i = 0; i < nombreColonneTableauCampagne; i++) {
			celluleLu = campagneSheet.getCell(i, ligneDebutTableauCampagne);

			// test presence  nom Campagne
			st = new StringTokenizer(Language.getInstance().getText("nom_Campagne_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomCampagne = true;
					numeroColonneNomCampagne = i;
				}
			}
			//test presence description Campagne
			st = new StringTokenizer(Language.getInstance().getText("description_Campagne_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneDescriptionCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneDescriptionCampagne = true;
					numeroColonneDescriptionCampagne = i;
				}
			}
			//test presence Jeu de donnees Campagne
			st = new StringTokenizer(Language.getInstance().getText("jeu_de_donnees_Campagne_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneJeuDeDonneesCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneJeuDeDonneesCampagne = true;
					numeroColonneJeuDeDonneesCampagne = i;
				}
			}
			//test presence Description du Jeu de donnees Campagne
			st = new StringTokenizer(Language.getInstance().getText("description_jeu_de_donnees_Campagne_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneDescriptionJeuDeDonneesCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneDescriptionJeuDeDonneesCampagne = true;
					numeroColonneDescriptionJeuDeDonneesCampagne = i;
				}
			}
			// test presence nom parametre
			st = new StringTokenizer(Language.getInstance().getText("nom_Parametres_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomParametreCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomParametreCampagne = true;
					numeroColonneNomParametreCampagne = i;
				}
			}
			// test presence Valeur parametre
			st = new StringTokenizer(Language.getInstance().getText("valeur_Parametres_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneValeurParametreCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneValeurParametreCampagne = true;
					numeroColonneValeurParametreCampagne = i;
				}
			}

			//test presence Famille de tests Campagne
			st = new StringTokenizer(Language.getInstance().getText("famille_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneFamilleTestCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneFamilleTestCampagne = true;
					numeroColonneFamilleTestCampagne = i;
				}
			}
			//test presence suite de tests Campagne
			st = new StringTokenizer(Language.getInstance().getText("suite_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneSuiteTestCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneSuiteTestCampagne = true;
					numeroColonneSuiteTestCampagne = i;
				}
			}
			//test presence cas de tests Campagne
			st = new StringTokenizer(Language.getInstance().getText("cas_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneCasDeTestCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneCasDeTestCampagne = true;
					numeroColonneCasDeTestCampagne = i;
				}
			}
			// test presence des colonnes Lien Hypertexte
			st = new StringTokenizer(Language.getInstance().getText("Lien_Hypertexte_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneLienHypertexteCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneLienHypertexteCampagne = true;
					numeroColonneLienHypertexteCampagne = i;
				}
			}

			// test presence des colonnes Piece Jointe
			st = new StringTokenizer(Language.getInstance().getText("Piece_Jointe_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonnePieceJointeCampagne == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonnePieceJointeCampagne = true;
					numeroColonnePieceJointeCampagne = i;
				}
			}
		}
		if ((isPresenceColonneNomCampagne == false)) {
			isErreurTraitementImport = true;
			closeXmlAndXlsFiles();
			JOptionPane.showMessageDialog(null, 
					Language.getInstance().getText("Stop_No_Campaign_Name_Column"), 
					Language.getInstance().getText("Erreur_"), 
					JOptionPane.ERROR_MESSAGE);
			PopUpFormalismeExcel p = new PopUpFormalismeExcel(pIPlugObject);

		}

	}

	/**
	 * Read all the spreadsheet for the environments
	 * 
	 * @throws java.lang.Exception
	 *             Null pointer exception
	 */
	public void readXlsTableEnvironnement(boolean selectionImportParametre, boolean selectionImportTest) throws Exception {
		if (!selectionImportParametre && !selectionImportTest){
			params  = projetVT.addElement("Params");
		}
		// Gestion des Environnements
		Environnements  = projetVT.addElement("Environnements");

		for (int i = ligneDebutTableauEnvironnement + 1; i < nombreLigneTableauEnvironnements; i++) {
			celluleLu = enviroSheet.getCell(numeroColonneNomEnvironnement, i);
			if (celluleLu.getContents().length()>0){
				// lit le nom de l'environnement
				Element Environnement  = Environnements.addElement("Environnement")
				.addAttribute("idEnv", "Env_" + indiceEnvironnement);
				celluleLu = enviroSheet.getCell(numeroColonneNomEnvironnement, i);
				valeurNomEnvironnement = celluleLu.getContents();
				Element nomEnvironnement  = Environnement.addElement("Nom")
				.addText(valeurNomEnvironnement);
				environnementID.add(valeurNomEnvironnement);
				environnementID.add(Integer.toString(indiceEnvironnement));

				//Lit la description de l'environnement
				if (isPresenceColonneDescriptionEnvironnement){
					celluleLu = enviroSheet.getCell(numeroColonneDescriptionEnvironnement, i);
					valeurDescriptionEnviro = celluleLu.getContents();
					addHTMLDescription(Environnement,valeurDescriptionEnviro);
				}
				Element ValeurParams = Environnement.addElement("ValeurParams");
				litPJetURL(Environnement, enviroSheet, i, isPresenceColonneLienHypertexteEnvironnement, numeroColonneLienHypertexteEnvironnement, isPresenceColonnePieceJointeEnvironnement, numeroColonnePieceJointeEnvironnement, Language.getInstance().getText("Environnements") + fs + indiceEnvironnement);

				if (valeurNomEnvironnement.length() > 0) {
					hauteurEnvironnement = 0;
					debutEnvironnement = i;

					celluleLu = enviroSheet.getCell(numeroColonneNomEnvironnement, i	+ hauteurEnvironnement);

					while (((celluleLu.getContents().equals(valeurNomEnvironnement) || celluleLu.getContents().length() == 0)) && (hauteurEnvironnement + debutEnvironnement < nombreLigneTableauEnvironnements - 1)) {
						hauteurEnvironnement++;
						celluleLu = enviroSheet.getCell(numeroColonneNomEnvironnement, i + hauteurEnvironnement);

					}

					if ((debutEnvironnement == nombreLigneTableauEnvironnements - 1)
							&& (enviroSheet.getCell(numeroColonneNomEnvironnement,nombreLigneTableauEnvironnements - 1).getContents().length() != 0)) {
						hauteurEnvironnement++;
					}
					if ((debutEnvironnement + hauteurEnvironnement == nombreLigneTableauEnvironnements - 1) && (enviroSheet.getCell(numeroColonneNomEnvironnement,nombreLigneTableauEnvironnements - 1).getContents().length() == 0)) {
						hauteurEnvironnement++;
					}
					for (int boucle = debutEnvironnement; boucle < debutEnvironnement+ hauteurEnvironnement; boucle++) {
						if (isPresenceColonneNomParametreEnvironnement){
							celluleLu = enviroSheet.getCell(numeroColonneNomParametreEnvironnement, boucle);
							if(celluleLu.getContents().length()>0){
								if(listeParametre.contains(celluleLu.getContents())){
									nomParametreEnvironnement = celluleLu.getContents();
									IDParametreEnvironnement = listeParametre.get(listeParametre.indexOf(celluleLu.getContents())+1);
								} else {
									//Rajoute le parametre
									Element param  = params.addElement("Param")
									.addAttribute("id_param", "Param_" + indiceParametre);
									Element nomParam  = param.addElement("Nom")
									.addText(celluleLu.getContents());
									listeParametre.add(celluleLu.getContents());
									listeParametre.add(Integer.toString(indiceParametre));
									nomParametreEnvironnement = celluleLu.getContents();
									IDParametreEnvironnement = Integer.toString(indiceParametre);
									indiceParametre++;
								}

								if (isPresenceColonneValeurParametreEnvironnement){
									celluleLu = enviroSheet.getCell(numeroColonneValeurParametreEnvironnement, boucle);
									valeurParametreEnvironnement = celluleLu.getContents();
									Element ValeurParam = ValeurParams.addElement("ValeurParam")
									.addAttribute("ref", "Param_" + IDParametreEnvironnement)
									.addAttribute("valeur", valeurParametreEnvironnement);
									Element Nom = ValeurParam.addElement("Nom").addText(nomParametreEnvironnement);
								} else {
									valeurParametreEnvironnement = "";
								}

							}
						}
					}
				}
				indiceEnvironnement++;
			}}
	}


	/**
	 * Function that Verify the presence of environments columns in the enviroment spreadsheet
	 */
	public void testColumnsPresenceEnvironnement() {

		StringTokenizer st;
		// Recupere ligne debut tableau
		boolean EnvironnementTrouve = false;
		for (int j = 0; j < nombreLigneTableauEnvironnements; j++) {
			for (int i = 0; i < nombreColonneTableauEnvironnements; i++) {
				celluleLu = enviroSheet.getCell(i, j);
				st = new StringTokenizer(Language.getInstance().getText("nom_Environnements_Liste").toLowerCase(), ",");
				while (st.hasMoreTokens() && EnvironnementTrouve == false) {
					if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
						ligneDebutTableauEnvironnement = celluleLu.getRow();
						EnvironnementTrouve = true;
					}
				}
			}
		}

		// test presence des differents colonnes
		for (int i = 0; i < nombreColonneTableauEnvironnements; i++) {
			celluleLu = enviroSheet.getCell(i, ligneDebutTableauEnvironnement);

			// test presence nom Environnements
			st = new StringTokenizer(Language.getInstance().getText("nom_Environnements_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomEnvironnement == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomEnvironnement = true;
					numeroColonneNomEnvironnement = i;
				}
			}
			//test presence description Environnements
			st = new StringTokenizer(Language.getInstance().getText("description_Environnement_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneDescriptionEnvironnement == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneDescriptionEnvironnement = true;
					numeroColonneDescriptionEnvironnement = i;
				}
			}
			// test presence nom parametre
			st = new StringTokenizer(Language.getInstance().getText("nom_Parametres_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomParametreEnvironnement == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomParametreEnvironnement = true;
					numeroColonneNomParametreEnvironnement = i;
				}
			}
			// test presence Valeur parametre
			st = new StringTokenizer(Language.getInstance().getText("valeur_Parametres_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneValeurParametreEnvironnement == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneValeurParametreEnvironnement = true;
					numeroColonneValeurParametreEnvironnement = i;
				}
			}
			// test presence des colonnes Lien Hypertexte
			st = new StringTokenizer(Language.getInstance().getText("Lien_Hypertexte_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneLienHypertexteEnvironnement == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneLienHypertexteEnvironnement = true;
					numeroColonneLienHypertexteEnvironnement = i;
				}
			}

			// test presence des colonnes Piece Jointe
			st = new StringTokenizer(Language.getInstance().getText("Piece_Jointe_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonnePieceJointeEnvironnement == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonnePieceJointeEnvironnement = true;
					numeroColonnePieceJointeEnvironnement = i;
				}
			}
		}

		if (isPresenceColonneNomEnvironnement == false) {
			isErreurTraitementImport = true;
			closeXmlAndXlsFiles();
			JOptionPane.showMessageDialog(null, 
					Language.getInstance().getText("Stop_No_Environnement_Name_Column"), 
					Language.getInstance().getText("Erreur_"), 
					JOptionPane.ERROR_MESSAGE);
			PopUpFormalismeExcel p = new PopUpFormalismeExcel(pIPlugObject);

		}

	}


	/**
	 * Read all the spreadsheet for the parameters
	 * 
	 * @throws java.lang.Exception
	 *             Null pointer exception
	 */
	public void readXlsTableParametre() throws Exception {

		// Gestion des parametres
		params  = projetVT.addElement("Params");

		for (int i = ligneDebutTableauParametre + 1; i < nombreLigneTableauParametres; i++) {
			// lit le parametre
			celluleLu = paramSheet.getCell(numeroColonneNomParametre, i);
			if (celluleLu.getContents().length()>0){
				Element param  = params.addElement("Param")
				.addAttribute("id_param", "Param_" + indiceParametre);
				Element nomParam  = param.addElement("Nom")
				.addText(celluleLu.getContents());
				listeParametre.add(celluleLu.getContents());
				listeParametre.add(Integer.toString(indiceParametre));
				if (isPresenceColonneDescriptionParametre){
					celluleLu = paramSheet.getCell(numeroColonneDescriptionParametre, i);
					valeurDescriptionParam = celluleLu.getContents();
					addHTMLDescription(param,valeurDescriptionParam);

				}
				indiceParametre++;
			}
		}
	}

	/**
	 * Function that Verify the presence of parameters columns in the paremeter spreadsheet
	 */
	public void testColumnsPresenceParametre() {

		StringTokenizer st;
		// Recupere ligne debut tableau
		boolean parametreTrouve = false;
		for (int j = 0; j < nombreLigneTableauParametres; j++) {
			for (int i = 0; i < nombreColonneTableauParametres; i++) {
				celluleLu = paramSheet.getCell(i, j);
				st = new StringTokenizer(Language.getInstance().getText("nom_Parametres_Liste").toLowerCase(), ",");
				while (st.hasMoreTokens() && parametreTrouve == false) {
					if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
						ligneDebutTableauParametre = celluleLu.getRow();
						parametreTrouve = true;
					}
				}

			}
		}

		// test presence des differents colonnes
		for (int i = 0; i < nombreColonneTableauParametres; i++) {
			celluleLu = paramSheet.getCell(i, ligneDebutTableauParametre);

			// test presence  nom parametre
			st = new StringTokenizer(Language.getInstance().getText("nom_Parametres_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNomParametre == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNomParametre = true;
					numeroColonneNomParametre = i;
				}
			}
			//test presence description parametre
			st = new StringTokenizer(Language.getInstance().getText("description_Parametres_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneDescriptionParametre == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneDescriptionParametre = true;
					numeroColonneDescriptionParametre = i;
				}
			}

		}

		if ((isPresenceColonneNomParametre == false)) {
			isErreurTraitementImport = true;
			closeXmlAndXlsFiles();
			JOptionPane.showMessageDialog(null, 
					Language.getInstance().getText("Stop_No_Parameter_Name_Column"), 
					Language.getInstance().getText("Erreur_"), 
					JOptionPane.ERROR_MESSAGE);
			PopUpFormalismeExcel p = new PopUpFormalismeExcel(pIPlugObject);

		}

	}

	/**
	 * Fonction that generate campaigns
	 * 
	 * @param creationCampagne
	 *            type of camapaign to create
	 */
	void creeCampagnes(String creationCampagne, boolean selectionImportEnvironnement) {
		// Generation d'un environnement vide
		if (!selectionImportEnvironnement){
			Environnements = projetVT.addElement("Environnements");

			Element environnement = Environnements.addElement("Environnement")
			.addAttribute("idEnv", "Env_0");
			Element nomEnvironnement = environnement.addElement("Nom")
			.addText(Language.getInstance().getText("environnement_reel"));
			environnement = Environnements.addElement("Environnement")
			.addAttribute("idEnv", "Env_1");
			nomEnvironnement = environnement.addElement("Nom")
			.addText(Language.getInstance().getText("environnement_simule"));
		}

		if (creationCampagne == Language.getInstance().getText("Campagne_Par_Projet")) {
			creeCampagne(Language.getInstance().getText("Projet"), listeTestsPourCampagne, selectionImportEnvironnement);
		}

		if (creationCampagne == Language.getInstance().getText("Campagne_Par_Famille")) {
			listeFamille = new ArrayList();
			for (int i = 0; i < listeTestsPourCampagne.size(); i += 8) {
				if (!listeFamille.contains(listeTestsPourCampagne.get(i))) {
					listeFamille.add(listeTestsPourCampagne.get(i));
				}
			}
			for (int i = 0; i < listeFamille.size(); i++) {
				listePourCampagne.clear();
				for (int j = 0; j < listeTestsPourCampagne.size(); j += 8) {
					if (listeTestsPourCampagne.get(j) == listeFamille.get(i)) {
						for (int k = 0; k < 8; k++) {
							listePourCampagne.add(listeTestsPourCampagne.get(j + k));
						}
					}
				}
				creeCampagne(listeFamille.get(i).toString(),listePourCampagne, selectionImportEnvironnement);
			}
		}

		if (creationCampagne == Language.getInstance().getText("Campagne_Par_Exigence")) {
			for (int i = 0; i < listeTestsPourCampagne.size(); i += 8) {
				if (listeTestsPourCampagne.get(i + 6) != null){
					if (!listeFamille.contains(listeTestsPourCampagne.get(i + 6))) {
						listeFamille.add(listeTestsPourCampagne.get(i + 6));
					}
				} 
			}
			for (int i = 0; i < listeFamille.size(); i++) {
				listePourCampagne.clear();
				for (int j = 0; j < listeTestsPourCampagne.size(); j += 8) {
					if (listeTestsPourCampagne.get(j + 6) == listeFamille.get(i)) {
						for (int k = 0; k < 8; k++) {
							listePourCampagne.add(listeTestsPourCampagne.get(j + k));
						}
					}
				}

				creeCampagne(listeFamille.get(i).toString(),listePourCampagne, selectionImportEnvironnement);
			}
		}
	}

	/**
	 * Fonction that generate acampaign
	 * 
	 * @param nomCampagne
	 *            name of campaign to create
	 * @param vectorElementsofCampaign
	 *            vector containing all elements to create a campaign
	 */
	void creeCampagne(String nomCampagne, ArrayList vectorElementsofCampaign, boolean selectionImportEnvironnement) {
		Element CampagneTests = projetVT.addElement("CampagneTests");
		CampagneTest = CampagneTests.addElement("CampagneTest")
		.addAttribute("id_camp", "Camp_" + indiceCampagne);
		Element Concepteur = CampagneTest.addElement("Concepteur");
		Element NomConcepteur = Concepteur.addElement("Nom").addText(
				Language.getInstance().getText("pluginxlsxml"));
		Element nomXMLCampagne = CampagneTest.addElement("Nom").addText(
				Language.getInstance().getText("Campagne") + " " + nomCampagne);
		// Generation de la date
		DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.MONTH_FIELD);
		Element dateCrea = CampagneTest.addElement("Date_crea").addText(dateFormat.format(new Date()));
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()){
			listeExigencesCampagnes.clear();
			Element LinkRequirement = CampagneTest.addElement("LinkRequirement");
			for (int i = 0; i < vectorElementsofCampaign.size(); i = i + 8) {
				if ((!listeExigencesCampagnes.contains(vectorElementsofCampaign.get(i + 6)))) {
					if (vectorElementsofCampaign.get(i + 6) != null){
						Element RequirementRef = LinkRequirement.addElement("RequirementRef")
						.addAttribute("ref","Req_"+ vectorElementsofCampaign.get(i + 7));
						Element nomRequirementRef = RequirementRef.addElement("Nom")
						.addText(vectorElementsofCampaign.get(i + 6).toString());
						listeExigencesCampagnes.add((String) vectorElementsofCampaign.get(i + 6));
					}

				}
			}
		}
		String famillePrecedente=null;
		String suitePrecedente=null;
		Element SuiteTestsCamp=null;
		Element TestsCamp=null;
		Element FamillesCamp = CampagneTest.addElement("FamillesCamp");
		for (int i = 0; i < vectorElementsofCampaign.size(); i += 8) {
			if (!vectorElementsofCampaign.get(i).equals(famillePrecedente)){
				Element FamilleRef = FamillesCamp.addElement("FamilleRef")
				.addAttribute("ref","Fam_" + vectorElementsofCampaign.get(i + 1).toString());
				Element nomFamilleRef = FamilleRef.addElement("Nom").addText(
						removeSpecialCharacters(vectorElementsofCampaign.get(i).toString()));
				SuiteTestsCamp = FamilleRef.addElement("SuiteTestsCamp");
				famillePrecedente=vectorElementsofCampaign.get(i).toString();
				suitePrecedente=null;
			}
			if (!vectorElementsofCampaign.get(i+2).equals(suitePrecedente)){
				Element SuiteTestRef = SuiteTestsCamp.addElement("SuiteTestRef")
				.addAttribute("ref", "SuiteTest_" + vectorElementsofCampaign.get(i + 3).toString());
				Element nomSuiteTestRef = SuiteTestRef.addElement("Nom").addText(vectorElementsofCampaign.get(i+2).toString());
				TestsCamp = SuiteTestRef.addElement("TestsCamp");
				suitePrecedente=vectorElementsofCampaign.get(i+2).toString();
			}
			Element TestRef = TestsCamp.addElement("TestRef")
			.addAttribute("ref","Test_" + vectorElementsofCampaign.get(i + 5).toString())
			.addAttribute("loginAssigned",Language.getInstance().getText("pluginxlsxml"));
			Element nomTestRef = TestRef.addElement("Nom").addText(removeSpecialCharacters(vectorElementsofCampaign.get(i + 4).toString()));
		}

		indiceExecCampagne++;
		Element ExecCampTests = CampagneTest.addElement("ExecCampTests");
		Element ExecCampTest = ExecCampTests.addElement("ExecCampTest")
		.addAttribute("id_exec_camp", "ExecCamp_" + indiceExecCampagne);
		if (!selectionImportEnvironnement){	
			Element nomExecCampTest = ExecCampTest.addElement("Nom")
			.addText(Language.getInstance().getText("Premiere_Execution"));
			Element EnvironnementEx = ExecCampTest.addElement("EnvironnementEx")
			.addAttribute("ref", "Env_1");
			Element nomEnvironnementEx = EnvironnementEx.addElement("Nom")
			.addText(Language.getInstance().getText("environnement_simule"));
		} else {
			for (int i=0; i< environnementID.size();i = i +2) {
				Element nomExecCampTest = ExecCampTest.addElement("Nom")
				.addText(Language.getInstance().getText("Execution_sur") + environnementID.get(i));
				Element EnvironnementEx = ExecCampTest.addElement("EnvironnementEx")
				.addAttribute("ref", "Env_" + environnementID.get(i+1));
				Element nomEnvironnementEx = EnvironnementEx.addElement("Nom")
				.addText(environnementID.get(i));	
			}

		}


	}


	/**
	 * Function that write a test in the XML File
	 * @param lignePourLirePJetURL lignePourLirePJetURL
	 */
	public void writeTest(int lignePourLirePJetURL) {
		if (valeurCasDeTests.length() != 0) {
			// Ecrit entete
			indiceTestTest++;
			test = tests.addElement("Test")
			.addAttribute("id_test","Test_" + indiceTestTest);
			Element Concepteur = test.addElement("Concepteur");
			Element NomConcepteur = Concepteur.addElement("Nom").addText(
					Language.getInstance().getText("pluginxlsxml"));
			Element LoginConcepteur = Concepteur.addElement("Login").addText(
					Language.getInstance().getText("pluginxlsxml"));
			/*if (listeTestsPourCampagne.contains(valeurCasDeTests)){
				int i = 0;
				while (listeTestsPourCampagne.contains(valeurCasDeTests)) {

					if (i == 0) {
						valeurCasDeTests = valeurCasDeTests	+ Language.getInstance().getText("_") + Integer.toString(i);
					} else {
						valeurCasDeTests = valeurCasDeTests.substring(0, valeurCasDeTests.lastIndexOf(Language.getInstance().getText("_"))) + Language.getInstance().getText("_") + Integer.toString(i) ;
					}

				}
			}*/

			Element NomTest = test.addElement("Nom")
			.addText(removeSpecialCharacters(valeurCasDeTests));
			// Generation de la date
			DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.MONTH_FIELD);
			Element dateCrea = test.addElement("Date_crea").addText(dateFormat.format(new Date()));
			//		Element DescriptionTest = test.addElement("Description")
			//		.addAttribute("isHTML", "true")
			//		.addText(valeurDescriptionTest);

			try {
				addHTMLDescription(test,valeurDescriptionTest);
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}

			Element Executed = test.addElement("Executed").addText("false");

			litPJetURL(test, testSheet, lignePourLirePJetURL, isPresenceColonneTestLienHypertexte, numeroColonneTestLienHypertexte, isPresenceColonneTestPieceJointe, numeroColonneTestPieceJointe, famillePrecedente + fs + Language.getInstance().getText("Suite_Par_Defaut") + fs + "RT_" + exigenceLuTest.trim() + Language.getInstance().getText("_") + valeurCasDeTests.trim());

			LinkRequirement = test.addElement("LinkRequirement");
		}
	}

	/**
	 * Write automatic tests
	 */
	public void writeActionTestAuto() {
		if ((valeurTypeTestAutomatique.toLowerCase().equals(Language.getInstance().getText("Beanshell").toLowerCase())&& TestPresencePlugin.testDeLaPresenceDuPluginBeanShell())||
				(valeurTypeTestAutomatique.toLowerCase().equals(Language.getInstance().getText("simpleJunit").toLowerCase())&& TestPresencePlugin.testDeLaPresenceDuPluginSimpleJunit())||
				(valeurTypeTestAutomatique.toLowerCase().equals(Language.getInstance().getText("abbotScriptRunner").toLowerCase())&& TestPresencePlugin.testDeLaPresenceDuPluginAbbotScriptRunner())){


			TestAuto= test.addElement("TestAuto")
			.addAttribute("plug_ext", valeurTypeTestAutomatique + ".TestDriver");
			if (valeurEmplacementTestAutomatique!=null){
				Element Script = TestAuto.addElement("Script")
				.addAttribute("type", "TEST_SCRIPT")
				.addAttribute("nom",valeurEmplacementTestAutomatique.substring(valeurEmplacementTestAutomatique.lastIndexOf(fs) + 1))
				.addAttribute("dir",valeurEmplacementTestAutomatique);
				Element Classpath = Script.addElement("Classpath")
				.addText(valeurTypeTestAutomatique + ".TestDriver");
			}
		} else {
			isErreurTraitementImport = true;
			JOptionPane.showMessageDialog(null, 
					Language.getInstance().getText("install_Plugin") + valeurTypeTestAutomatique.toLowerCase(), 
					Language.getInstance().getText("Erreur_"), 
					JOptionPane.ERROR_MESSAGE);

		}
	}

	/**
	 * Write one action for a test
	 */
	public void writeActionTestManuel() {
		if ((valeurNumeroTests.length() != 0)&& ((valeurActionARealiser.length() != 0) || (valeurActionAttendue.length() != 0))) {
			testManuel = test.addElement("TestManuel");
			actionTest = testManuel.addElement("ActionTest")
			.addAttribute("id_action", "Action_" + indiceActionTest);
			Element NomActionTest = actionTest.addElement("Nom")
			.addText(removeSpecialCharacters(valeurNumeroTests));
			Element DescriptionActionTest = actionTest.addElement("Description")
			.addText(removeSpecialCharacters(valeurActionARealiser));
			Element ResultAttenduActionTest = actionTest.addElement("ResultAttendu")
			.addText(removeSpecialCharacters(valeurActionAttendue));
			actionID.add(Integer.toString(indiceTestTest));
			actionID.add(removeSpecialCharacters(valeurNumeroTests));
			actionID.add(Integer.toString(indiceActionTest));
			actionID.add(removeSpecialCharacters(valeurActionARealiser));
			actionID.add(removeSpecialCharacters(valeurActionAttendue));
			indiceActionTest++;
		}

	}

	/**
	 * Write a requirement linked to a test
	 */
	public void writeRequirementLinkToTest() {

		if (exigenceID.contains(familleEnCoursTests + Language.getInstance().getText("_") + removeSpecialCharacters(exigenceLuTest))) {
			int temp = exigenceID.indexOf(familleEnCoursTests + Language.getInstance().getText("_") + removeSpecialCharacters(exigenceLuTest)) + 1;

			String IdExigenceEnCours;
			if (!exigenceID.get(temp).contains(Language.getInstance().getText("_"))){
				IdExigenceEnCours = exigenceID.get(temp);
			}else{
				IdExigenceEnCours = exigenceID.get(temp).substring(exigenceID.get(temp).lastIndexOf(Language.getInstance().getText("_"))+Language.getInstance().getText("_").length());	
			}
			Element RequirementRef = LinkRequirement.addElement("RequirementRef")
			.addAttribute("ref","Req_" + IdExigenceEnCours);
			Element NomRequirementRef = RequirementRef.addElement("Nom")
			.addText(removeSpecialCharacters(exigenceLuTest));
		} else {
			exigenceNonTrouvePourTest = exigenceNonTrouvePourTest + exigenceLuTest + "\n";
		}
	}

	/**
	 * Function that write a family test in the XML File
	 */
	public void writeFamilyTest() {

		if (!familleIDSuiteID.contains(valeurFamilleDeTests)){
			indiceFamilleTest++;
			famille = familles.addElement("Famille").addAttribute("id_famille",	"Fam_" + indiceFamilleTest);
			Element NomFamilleTest = famille.addElement("Nom").addText(removeSpecialCharacters(valeurFamilleDeTests));
		} else {
			famille = familles.addElement("Famille").addAttribute("id_famille",	"Fam_" + familleIDSuiteID.get(familleIDSuiteID.indexOf(valeurFamilleDeTests)+1));
			Element NomFamilleTest = famille.addElement("Nom").addText(removeSpecialCharacters(valeurFamilleDeTests));
		}
		if (isPresenceColonneDescriptionFamilleDeTests == true){
			try {
				addHTMLDescription(famille,valeurDescriptionFamilleDeTests);
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}	
		}


	}

	/**
	 * write suite test
	 */
	public void writeSuiteTest() {
		boolean familleSuiteExisteDeja = false;
		for (int i = 0; i < familleIDSuiteID.size(); i = i+4){
			if (familleIDSuiteID.get(i).equals(valeurFamilleDeTests) && familleIDSuiteID.get(i+2).equals(valeurSuiteDeTests)){
				familleSuiteExisteDeja= true;
				Element SuiteTests = famille.addElement("SuiteTests");
				SuiteTest = SuiteTests.addElement("SuiteTest").addAttribute("id_suite", "SuiteTest_" + familleIDSuiteID.get(i+3));
				Element NomTest = SuiteTest.addElement("Nom").addText(removeSpecialCharacters(valeurSuiteDeTests));
				//Element DescriptionTest = SuiteTest.addElement("Description");
				tests = SuiteTest.addElement("Tests");
			}
		}

		if (familleSuiteExisteDeja == false){
			Element SuiteTests = famille.addElement("SuiteTests");
			SuiteTest = SuiteTests.addElement("SuiteTest").addAttribute("id_suite", "SuiteTest_" + indiceSuiteTest);
			Element NomTest = SuiteTest.addElement("Nom").addText(removeSpecialCharacters(valeurSuiteDeTests));
			//Element DescriptionTest = SuiteTest.addElement("Description");
			tests = SuiteTest.addElement("Tests");
			familleIDSuiteID.add(valeurFamilleDeTests);
			familleIDSuiteID.add(Integer.toString(indiceFamilleTest));
			familleIDSuiteID.add(valeurSuiteDeTests);
			familleIDSuiteID.add(Integer.toString(indiceSuiteTest));
			indiceSuiteTest++;
		}
		if (isPresenceColonneDescriptionSuiteDeTests == true){
			try {
				addHTMLDescription(SuiteTest,valeurDescriptionSuiteDeTests);
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}	
		}


	}

	/**
	 * read a family for a test
	 * 
	 * @param i
	 *            numbre of line read
	 */
	public void readFamilyTest(int i) {
		// lit Famille
		boolean changementFamille = false;
		celluleLu = testSheet.getCell(numeroColonneFamilleDeTests, i);
		valeurFamilleDeTests = celluleLu.getContents();
		if (isPresenceColonneDescriptionFamilleDeTests == true){
			celluleLu = testSheet.getCell(numeroColonneDescriptionFamilleDeTests, i);
			valeurDescriptionFamilleDeTests = celluleLu.getContents();	
		}
		if (valeurFamilleDeTests != famillePrecedente) {
			if (valeurFamilleDeTests.length() == 0 || isPresenceColonneFamilleDeTests == false) {
				valeurFamilleDeTests = Language.getInstance().getText("Famille_par_defaut");
			}
			famillePrecedente = valeurFamilleDeTests;
			changementFamille = true;
			writeFamilyTest();
		}

		//lit suite
		celluleLu = testSheet.getCell(numeroColonneSuiteDeTests, i);
		valeurSuiteDeTests = celluleLu.getContents();
		if (isPresenceColonneDescriptionSuiteDeTests == true){
			celluleLu = testSheet.getCell(numeroColonneDescriptionSuiteDeTests, i);
			valeurDescriptionSuiteDeTests = celluleLu.getContents();	
		}
		if (valeurSuiteDeTests.length() == 0 || isPresenceColonneSuiteDeTests == false) {
			valeurSuiteDeTests = Language.getInstance().getText("Suite_Par_Defaut");
		}
		if (!valeurSuiteDeTests.equals(suitePrecedente) || changementFamille)  {
			writeSuiteTest();
			suitePrecedente = valeurSuiteDeTests;
		}

	}

	/**
	 * Read all requirements linked to a test
	 * 
	 * @param debutCasDeTest
	 *            integer
	 * @param hauteurCasDeTest
	 *            integer
	 */

	public void readRequirementTest(int debutCasDeTest, int hauteurCasDeTest) {
		// lit Famille
		boolean nouveauTest=true;
		for (int v = debutCasDeTest; v < debutCasDeTest + hauteurCasDeTest; v++) {
			if (testSheet.getCell(numeroColonneExigenceTests, v).getContents().length() != 0) {
				if (isPresenceColonneBrancheTests == false) {
					familleEnCoursTests = Language.getInstance().getText("Famille_par_defaut");
				} else {
					StringTokenizer st = new StringTokenizer(numeroColonneBrancheTests, Language.getInstance().getText("_"));
					familleEnCoursTests="";
					while (st.hasMoreTokens()) {
						celluleLu = testSheet.getCell(Integer.parseInt(st.nextToken()), v);
						if (celluleLu.getContents().length()!=0) {
							if (familleEnCoursTests==""){
								familleEnCoursTests = celluleLu.getContents();	
							}else {
								familleEnCoursTests =  familleEnCoursTests + Language.getInstance().getText("_") + celluleLu.getContents();
							}
						}
					}
				}
			}
			celluleLu = testSheet.getCell(numeroColonneExigenceTests, v);
			exigenceLuTest = celluleLu.getContents();
			while (exigenceLuTest.startsWith(Language.getInstance().getText("_"))) {
				exigenceLuTest = exigenceLuTest.substring(1);
			}

			if (exigenceLuTest.length()>0){
				if (nouveauTest ||(!exigenceAEcrire.equals(familleEnCoursTests + Language.getInstance().getText("_") + exigenceLuTest))){
					writeRequirementLinkToTest();
					exigenceAEcrire = familleEnCoursTests + Language.getInstance().getText("_") + exigenceLuTest;
					nouveauTest=false;
				}
			}

			//	if ((!exigenceAEcrire.equals(familleEnCoursTests + Language.getInstance().getText("_") + exigenceLuTest)) && (exigenceLuTest.length()>0)) {
			//		writeRequirementLinkToTest();
			//		exigenceAEcrire = familleEnCoursTests + Language.getInstance().getText("_") + exigenceLuTest;
			//	}


			// creation d'un vecteur
			// Famille-NumeroFamille-Suite-NumeroSuite-CasTest-NumeroCasTest-ExigenceVide-NumeroExigenceVide

			if (listeTestsPourCampagne.size()>0){
				if((!listeTestsPourCampagne.get(listeTestsPourCampagne.size()-8).equals(valeurFamilleDeTests)) ||
						(!listeTestsPourCampagne.get(listeTestsPourCampagne.size()-6).equals(valeurSuiteDeTests))||
						(!listeTestsPourCampagne.get(listeTestsPourCampagne.size()-4).equals(valeurCasDeTests))){
					// creation d'un vecteur
					// Famille-NumeroFamille-Suite-NumeroSuite-CasTest-NumeroCasTest-ExigenceVide-NumeroExigenceVide
					listeTestsPourCampagne.add(valeurFamilleDeTests);
					listeTestsPourCampagne.add(Integer.toString(indiceFamilleTest));
					listeTestsPourCampagne.add(valeurSuiteDeTests);
					listeTestsPourCampagne.add(Integer.toString(indiceSuiteTest));
					listeTestsPourCampagne.add(valeurCasDeTests);
					listeTestsPourCampagne.add(Integer.toString(indiceTestTest));
					if (exigenceID.indexOf(removeSpecialCharacters(familleEnCoursTests + Language.getInstance().getText("_") + exigenceLuTest)) >0) {
						listeTestsPourCampagne.add(exigenceLuTest);
						String IDexigenceAEcrire = exigenceID.get(exigenceID.indexOf(removeSpecialCharacters(familleEnCoursTests + Language.getInstance().getText("_") + exigenceLuTest)) + 1);						
						IDexigenceAEcrire = IDexigenceAEcrire.substring(IDexigenceAEcrire.lastIndexOf(Language.getInstance().getText("_"))+Language.getInstance().getText("_").length());
						listeTestsPourCampagne.add(IDexigenceAEcrire);
					}else {
						listeTestsPourCampagne.add(null);
						listeTestsPourCampagne.add(null);
					}

				}
			}else{
				listeTestsPourCampagne.add(valeurFamilleDeTests);
				listeTestsPourCampagne.add(Integer.toString(indiceFamilleTest));
				listeTestsPourCampagne.add(valeurSuiteDeTests);
				listeTestsPourCampagne.add(Integer.toString(indiceSuiteTest));
				listeTestsPourCampagne.add(valeurCasDeTests);
				listeTestsPourCampagne.add(Integer.toString(indiceTestTest));
				if (exigenceID.indexOf(familleEnCoursTests + Language.getInstance().getText("_") + exigenceLuTest) >0) {
					listeTestsPourCampagne.add(exigenceLuTest);
					String IDexigenceAEcrire = exigenceID.get(exigenceID.indexOf(removeSpecialCharacters(familleEnCoursTests + Language.getInstance().getText("_") + exigenceLuTest)) + 1);						
					IDexigenceAEcrire = IDexigenceAEcrire.substring(IDexigenceAEcrire.lastIndexOf(Language.getInstance().getText("_"))+Language.getInstance().getText("_").length());
					listeTestsPourCampagne.add(IDexigenceAEcrire);
				}else {
					listeTestsPourCampagne.add(null);
					listeTestsPourCampagne.add(null);
				}

			}

		}
	}


	/**
	 * Read all the spreadsheet for the test
	 * @param selectionImportExigence selectionImportExigence
	 * @throws java.lang.Exception Exception
	 */
	public void readXlsTableTest(boolean selectionImportExigence, boolean selectionAssociationExigencesSalome, boolean selectionImportParametre) throws Exception {
		if (!selectionImportParametre){
			params  = projetVT.addElement("Params");
		}

		int hauteurCasDeTest = 0;
		int debutCasDeTest = 0;

		// Gestion des tests
		familles = projetVT.addElement("Familles");

		famillePrecedente = Language.getInstance().getText("Pas_De_Famille");
		suitePrecedente = Language.getInstance().getText("Pas_De_Famille");

		// fonction qui ne marche pas si le tableau n'est pas trie par Famille

		exigenceLuTest = "";
		for (int i = ligneDebutTableauTest + 1; i < nombreLigneTableauTests; i++) {
			// lit Cas de tests
			if (isPresenceColonneCasDeTests == true) {
				celluleLu = testSheet.getCell(numeroColonneCasDeTests, i);
				valeurCasDeTests = celluleLu.getContents();

			} else {
				valeurCasDeTests = "";
			}
			//Correction anomalie 2 cas de tests ayant le même nom mais dans deux suites diffèrentes
			if (isPresenceColonneSuiteDeTests == true) {
				celluleLu = testSheet.getCell(numeroColonneSuiteDeTests, i);
				valeurSuiteDeTests = celluleLu.getContents();

			} else {
				valeurSuiteDeTests = "";
			}
			if (isPresenceColonneFamilleDeTests == true) {
				celluleLu = testSheet.getCell(numeroColonneFamilleDeTests, i);
				valeurFamilleDeTests = celluleLu.getContents();

			} else {
				valeurFamilleDeTests = "";
			}

			if (isPresenceColonneDescriptionTest == true) {
				celluleLu = testSheet.getCell(numeroColonneDescriptionTest, i);
				valeurDescriptionTest = celluleLu.getContents();
				//		valeurDescriptionTest = transformeEnHTML(valeurDescriptionTest);
			} else {
				valeurDescriptionTest = "";
			}

			if (valeurCasDeTests.length() > 0) {
				readFamilyTest(i);
				hauteurCasDeTest = 0;
				debutCasDeTest = i;

				celluleLu = testSheet.getCell(numeroColonneCasDeTests, i + hauteurCasDeTest);
				Cell celluleLu2 = testSheet.getCell(numeroColonneSuiteDeTests, i + hauteurCasDeTest);
				Cell celluleLu3 = testSheet.getCell(numeroColonneFamilleDeTests, i + hauteurCasDeTest);

				//Correction anomalie 2 cas de tests ayant le meme nom mais dans deux suites diffèrentes
				while (((celluleLu.getContents().equals(valeurCasDeTests) || celluleLu.getContents().length() == 0)) &&
						((celluleLu2.getContents().equals(valeurSuiteDeTests) || celluleLu2.getContents().length() == 0))  &&
						((celluleLu3.getContents().equals(valeurFamilleDeTests) || celluleLu3.getContents().length() == 0)) &&
						(hauteurCasDeTest + debutCasDeTest < nombreLigneTableauTests - 1)) {
					hauteurCasDeTest++;
					celluleLu = testSheet.getCell(numeroColonneCasDeTests, i + hauteurCasDeTest);
					celluleLu2 = testSheet.getCell(numeroColonneSuiteDeTests, i + hauteurCasDeTest);
					celluleLu3 = testSheet.getCell(numeroColonneFamilleDeTests, i + hauteurCasDeTest);

				}

				if ((debutCasDeTest == nombreLigneTableauTests - 1) && (testSheet.getCell(numeroColonneCasDeTests, nombreLigneTableauTests - 1).getContents().length() != 0)) {
					hauteurCasDeTest++;
				}
				if ((debutCasDeTest + hauteurCasDeTest == nombreLigneTableauTests - 1) && (testSheet.getCell(numeroColonneCasDeTests, nombreLigneTableauTests - 1).getContents().length() == 0)) {
					hauteurCasDeTest++;
				}
				writeTestCase(debutCasDeTest, hauteurCasDeTest);

				if ((isPresenceColonneExigenceTests == true && selectionImportExigence == true) || (isPresenceColonneExigenceTests == true && selectionAssociationExigencesSalome == true )) {
					readRequirementTest(debutCasDeTest, hauteurCasDeTest);
				} else {
					// creation d'un vecteur
					// Famille-NumeroFamille-Suite-NumeroSuite-CasTest-NumeroCasTest-ExigenceVide-NumeroExigenceVide
					listeTestsPourCampagne.add(valeurFamilleDeTests);
					listeTestsPourCampagne.add(Integer.toString(indiceFamilleTest));
					listeTestsPourCampagne.add(valeurSuiteDeTests);
					listeTestsPourCampagne.add(Integer.toString(indiceSuiteTest));
					listeTestsPourCampagne.add(valeurCasDeTests);
					listeTestsPourCampagne.add(Integer.toString(indiceTestTest));
					listeTestsPourCampagne.add(null);
					listeTestsPourCampagne.add(null);
				}

			}

		}

	}

	/**
	 * Write a coplete test case
	 * 
	 * @param debutCasDeTest
	 *            Integer
	 * @param hauteurCasDeTest
	 *            Integer
	 */
	public void writeTestCase(int debutCasDeTest, int hauteurCasDeTest) {
		writeTest(debutCasDeTest);
		Element ParamsT = test.addElement("ParamsT");
		numeroActionDesTests.clear();
		for (int boucle = debutCasDeTest; boucle < debutCasDeTest + hauteurCasDeTest; boucle++) {
			//lit type test automatique
			if	(isPresenceColonneTypeTestAutomatique == true) {
				celluleLu = testSheet.getCell(numeroColonneTypeTestAutomatique, boucle);
				valeurTypeTestAutomatique = celluleLu.getContents();
			} else {
				valeurTypeTestAutomatique = "";
			}
			//lit Emplacement test automatique
			if	(isPresenceColonneEmplacementTestAutomatique == true) {
				String repertoirePieceJointe = famillePrecedente + fs + suitePrecedente+ fs +  valeurCasDeTests + fs + Language.getInstance().getText("Script");
				celluleLu = testSheet.getCell(numeroColonneEmplacementTestAutomatique, boucle);
				if (celluleLu.getType() == CellType.NUMBER_FORMULA
						|| celluleLu.getType() == CellType.STRING_FORMULA
						|| celluleLu.getType() == CellType.BOOLEAN_FORMULA
						|| celluleLu.getType() == CellType.DATE_FORMULA
						|| celluleLu.getType() == CellType.FORMULA_ERROR) {
					FormulaCell nfc = (FormulaCell) celluleLu;
					StringBuffer sb = new StringBuffer();

					try {
						StringTokenizer st = new StringTokenizer(nfc.getFormula(), "\"");
						st.nextToken();
						String RecupereCheminRelatif;
						try {
							RecupereCheminRelatif = copyFileAttachements(st.nextToken().replaceFirst("file:///", ""), repertoirePieceJointe, null);
							valeurEmplacementTestAutomatique =RecupereCheminRelatif;
						} catch (Exception e) {
							// TODO Auto-generated catch block
							e.printStackTrace();
						}
					} catch (FormulaException e) {
						JOptionPane.showMessageDialog(null, 
								Language.getInstance().getText("malformed_formula") + sb.toString() + ": " + e.getMessage(),
								Language.getInstance().getText("Erreur_"),
								JOptionPane.ERROR_MESSAGE);
					}
				} else {
					StringTokenizer st = new StringTokenizer(celluleLu.getContents(), "\n");
					while (st.hasMoreTokens()) {
						String RecupereCheminRelatif;
						try {
							RecupereCheminRelatif = copyFileAttachements(st.nextToken(), repertoirePieceJointe, null);
							valeurEmplacementTestAutomatique =RecupereCheminRelatif;
						} catch (Exception e) {
							// TODO Auto-generated catch block
							e.printStackTrace();
						}
					}
				}
			} else {
				valeurEmplacementTestAutomatique = "";
			}
			// lit NmeroAction
			if (isPresenceColonneNumeroTests == true) {
				celluleLu = testSheet.getCell(numeroColonneNumeroTests, boucle);
				valeurNumeroTests = celluleLu.getContents();	
				if (valeurNumeroTests.length() == 0) {
					int i = 1;
					while (numeroActionDesTests.contains(Integer.toString(boucle - debutCasDeTest +i ))){
						i++;
					}
					valeurNumeroTests = Integer.toString(boucle - debutCasDeTest +i );
					numeroActionDesTests.add(valeurNumeroTests);
				}else {
					if (numeroActionDesTests.contains(valeurNumeroTests)){
						int i = 1;
						while (numeroActionDesTests.contains(Integer.toString(boucle - debutCasDeTest +i ))){
							i++;
						}
						valeurNumeroTests = Integer.toString(boucle - debutCasDeTest +i );
						numeroActionDesTests.add(valeurNumeroTests);
					}
				}

			} else {
				valeurNumeroTests = Integer.toString(boucle - debutCasDeTest +1);
			}
			// lit Action a realiser
			if (isPresenceColonneActionARealiser == true) {
				celluleLu = testSheet.getCell(numeroColonneActionARealiser, boucle);
				valeurActionARealiser = celluleLu.getContents();
			} else {
				valeurActionARealiser = "";
			}
			// lit Action attendue
			if (isPresenceColonneResultatAttendu == true) {
				celluleLu = testSheet.getCell(numeroColonneResultatAttendu, boucle);
				valeurActionAttendue = celluleLu.getContents();
			} else {
				valeurActionAttendue = "";
			}
			if (valeurTypeTestAutomatique.length()>0){
				writeActionTestAuto();
			} 

			//Gestion des parametres dans les actions des tests
			StringTokenizer st = new StringTokenizer(valeurActionARealiser, Language.getInstance().getText("Dollar"));
			if (valeurActionARealiser.startsWith(Language.getInstance().getText("Dollar"))){
				parametreActionsTests.add(" ");
			}while (st.hasMoreTokens()){
				parametreActionsTests.add(st.nextToken());
			}
			for (int j=1; j< parametreActionsTests.size(); j+=2){
				if(listeParametre.contains(parametreActionsTests.get(j))){
					Element ParamT = ParamsT.addElement("ParamT")
					.addAttribute("ref", "Param_" + listeParametre.get(listeParametre.indexOf(parametreActionsTests.get(j))+1));
					Element nomParamT  = ParamT.addElement("Nom")
					.addText(parametreActionsTests.get(j));
				} else {
					//Rajoute le parametre
					Element param  = params.addElement("Param")
					.addAttribute("id_param", "Param_" + indiceParametre);
					Element nomParam  = param.addElement("Nom")
					.addText(parametreActionsTests.get(j));
					Element ParamT = ParamsT.addElement("ParamT")
					.addAttribute("ref", "Param_" + indiceParametre);
					Element nomParamT  = ParamT.addElement("Nom")
					.addText(parametreActionsTests.get(j));
					listeParametre.add(parametreActionsTests.get(j));
					listeParametre.add(Integer.toString(indiceParametre));
					indiceParametre++;
				}			
			}
			parametreActionsTests.clear();
			StringTokenizer st2 = new StringTokenizer(valeurActionAttendue, Language.getInstance().getText("Dollar"));
			if (valeurActionAttendue.startsWith(Language.getInstance().getText("Dollar"))){
				parametreActionsTests.add(" ");
			}
			while (st2.hasMoreTokens()){
				parametreActionsTests.add(st2.nextToken());
			}
			for (int j=1; j< parametreActionsTests.size(); j+=2){
				if(listeParametre.contains(parametreActionsTests.get(j))){
					Element ParamT = ParamsT.addElement("ParamT")
					.addAttribute("ref", "Param_" + listeParametre.get(listeParametre.indexOf(parametreActionsTests.get(j))+1));
					Element nomParamT  = ParamT.addElement("Nom")
					.addText(parametreActionsTests.get(j));
				} else {
					//Rajoute le parametre
					Element param  = params.addElement("Param")
					.addAttribute("id_param", "Param_" + indiceParametre);
					Element nomParam  = param.addElement("Nom")
					.addText(parametreActionsTests.get(j));
					Element ParamT = ParamsT.addElement("ParamT")
					.addAttribute("ref", "Param_" + indiceParametre);
					Element nomParamT  = ParamT.addElement("Nom")
					.addText(parametreActionsTests.get(j));
					listeParametre.add(parametreActionsTests.get(j));
					listeParametre.add(Integer.toString(indiceParametre));
					indiceParametre++;
				}			
			}
			parametreActionsTests.clear();
		
			
			
			writeActionTestManuel();

			litPJetURL(actionTest, testSheet, boucle, isPresenceColonneTestLienHypertexteAction, numeroColonneTestLienHypertexteAction, isPresenceColonneTestPieceJointeAction, numeroColonneTestPieceJointeAction, famillePrecedente.trim() + fs + suitePrecedente.trim() + fs + valeurCasDeTests +fs + valeurNumeroTests);

		}
	}

	/**
	 * Function that Verify the presence of test columns in the test spreadsheet
	 */
	public void testColumnsPresenceTests() {
		StringTokenizer st;
		// Recupere ligne debut tableau
		boolean casDeTestTrouve = false;
		for (int j = 0; j < nombreLigneTableauTests; j++) {
			for (int i = 0; i < nombreColonneTableauTests; i++) {
				celluleLu = testSheet.getCell(i, j);
				st = new StringTokenizer(Language.getInstance().getText("cas_de_tests_Liste").toLowerCase(), ",");
				while (st.hasMoreTokens() && casDeTestTrouve == false) {
					if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
						ligneDebutTableauTest = celluleLu.getRow();
						casDeTestTrouve = true;
					}
				}

			}
		}

		// test presence des differents colonnes
		for (int i = 0; i < nombreColonneTableauTests; i++) {
			celluleLu = testSheet.getCell(i, ligneDebutTableauTest);

			// test presence des Famille de tests
			st = new StringTokenizer(Language.getInstance().getText("famille_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneFamilleDeTests == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneFamilleDeTests = true;
					numeroColonneFamilleDeTests = i;
				}
			}

			// test presence Description Famille de tests
			st = new StringTokenizer(Language.getInstance().getText("Description_Famille_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneDescriptionFamilleDeTests == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneDescriptionFamilleDeTests = true;
					numeroColonneDescriptionFamilleDeTests = i;
				}
			}

			//test presence des Suite de tests
			st = new StringTokenizer(Language.getInstance().getText("suite_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneSuiteDeTests == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneSuiteDeTests = true;
					numeroColonneSuiteDeTests = i;
				}
			}
			// test presence Description Suite de tests
			st = new StringTokenizer(Language.getInstance().getText("Description_Suite_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneDescriptionSuiteDeTests == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneDescriptionSuiteDeTests = true;
					numeroColonneDescriptionSuiteDeTests = i;
				}
			}
			// test presence des colonnes Cas de tests
			st = new StringTokenizer(Language.getInstance().getText("cas_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneCasDeTests == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneCasDeTests = true;
					numeroColonneCasDeTests = i;
				}
			}

			// test presence des colonnes numero
			st = new StringTokenizer(Language.getInstance().getText("numero_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneNumeroTests == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneNumeroTests = true;
					numeroColonneNumeroTests = i;
				}
			}

			// test presence des colonnes Action a realiser
			st = new StringTokenizer(Language.getInstance().getText("Action_A_Realiser_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneActionARealiser == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneActionARealiser = true;
					numeroColonneActionARealiser = i;
				}
			}
			// test presence des colonnes Action attendue
			st = new StringTokenizer(Language.getInstance().getText("Resultat_Attendu_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneResultatAttendu == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneResultatAttendu = true;
					numeroColonneResultatAttendu = i;
				}
			}
			// test presence des colonnes Description
			st = new StringTokenizer(Language.getInstance().getText("Description_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneDescriptionTest == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneDescriptionTest = true;
					numeroColonneDescriptionTest = i;
				}
			}

			// test presence des colonnes Lien Hypertexte
			st = new StringTokenizer(Language.getInstance().getText("Lien_Hypertexte_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneTestLienHypertexte == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneTestLienHypertexte = true;
					numeroColonneTestLienHypertexte = i;
				}
			}

			// test presence des colonnes Piece Jointe
			st = new StringTokenizer(Language.getInstance().getText("Piece_Jointe_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneTestPieceJointe == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneTestPieceJointe = true;
					numeroColonneTestPieceJointe = i;
				}
			}

			// test presence des colonnes Lien Hypertexte Action
			st = new StringTokenizer(Language.getInstance().getText("Lien_Hypertexte_Action_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneTestLienHypertexteAction == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneTestLienHypertexteAction = true;
					numeroColonneTestLienHypertexteAction = i;
				}
			}

			// test presence des colonnes Piece Jointe Action
			st = new StringTokenizer(Language.getInstance().getText("Piece_Jointe_Action_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneTestPieceJointeAction == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneTestPieceJointeAction = true;
					numeroColonneTestPieceJointeAction = i;
				}
			}


			// test presence des colonnes Type Test automatique
			st = new StringTokenizer(Language.getInstance().getText("Type_Test_Automatique_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneTypeTestAutomatique == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneTypeTestAutomatique = true;
					numeroColonneTypeTestAutomatique = i;
				}
			}

			// test presence des colonnes emplacement Test automatique
			st = new StringTokenizer(Language.getInstance().getText("Emplacement_Test_Automatique_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneEmplacementTestAutomatique == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneEmplacementTestAutomatique = true;
					numeroColonneEmplacementTestAutomatique = i;
				}
			}
		}

		// test de presence des colonnes Famille et Exigence
		for (int i = 0; i < nombreColonneTableauTests; i++) {
			celluleLu = testSheet.getCell(i, ligneDebutTableauTest);
			st = new StringTokenizer(Language.getInstance().getText("Exigence_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneExigenceTests == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneExigenceTests = true;
					numeroColonneExigenceTests = i;
				}
			}

			st = new StringTokenizer(Language.getInstance().getText("Theme_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneBrancheTests = true;
					if (numeroColonneBrancheTests==null){
						numeroColonneBrancheTests = Integer.toString(i);
					}else {
						numeroColonneBrancheTests = numeroColonneBrancheTests + Language.getInstance().getText("_") + Integer.toString(i);
					}

				}
			}

		}

		if ((isPresenceColonneCasDeTests == false) || (isPresenceColonneActionARealiser == false) || (isPresenceColonneResultatAttendu == false)) {
			isErreurTraitementImport = true;
			closeXmlAndXlsFiles();
			JOptionPane.showMessageDialog(null, Language.getInstance().getText("Stop_No_TestCase_Or_Action"), Language.getInstance().getText("Erreur_"), JOptionPane.ERROR_MESSAGE);
			PopUpFormalismeExcel p = new PopUpFormalismeExcel(pIPlugObject);

		}

	}

	/**
	 * Function that write a family Requirement in the XML File
	 */
	public void writeFamilyRequirement(String familleEnCours2) {
		String parent="0";
		String enfant="0";
		String idExigences="0";

//		if (vecteurBrancheID.contains(familleEnCours)){
//		idExigences = vecteurBrancheID.get(vecteurBrancheID.indexOf(familleEnCours)+1);
//		}
		if (exigenceID.contains(familleEnCours2)){
			idExigences = exigenceID.get(exigenceID.indexOf(familleEnCours2)+1);
		}
		//20100121 - Dbut modification Forge ORTF
		
		StringTokenizer stfamille = new StringTokenizer(removeSpecialCharacters(familleEnCours2),Language.getInstance().getText("_"));
		StringTokenizer stId = new StringTokenizer(idExigences,Language.getInstance().getText("_"));

		enfant = stId.nextToken();
		familyRequirement = requirements.addElement("RequirementFamily")
		.addAttribute("id_req","Req_" + enfant)
		.addAttribute("id_req_parent", "Req_" + parent);
		familyRequirementName = familyRequirement.addElement("Nom").addText(replaceSpecialCharBy_(stfamille.nextToken()));
		if (brancheDescriptionID.contains(enfant)){
			try {
				addHTMLDescription(familyRequirement,brancheDescriptionID.get(brancheDescriptionID.indexOf(enfant)+1));
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		} else {
			try {
				addHTMLDescription(familyRequirement,"");
			} catch (Exception e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}

		while (stfamille.hasMoreTokens()&& stId.hasMoreTokens()){
			parent = enfant;
			enfant = stId.nextToken();
			familyRequirement = requirements.addElement("RequirementFamily")
			.addAttribute("id_req","Req_" + enfant)
			.addAttribute("id_req_parent", "Req_" + parent);
			familyRequirementName = familyRequirement.addElement("Nom").addText(replaceSpecialCharBy_(stfamille.nextToken()));
			//20100121 - Fin modification Forge ORTF
			if (brancheDescriptionID.contains(enfant)){
				try {
					addHTMLDescription(familyRequirement,brancheDescriptionID.get(brancheDescriptionID.indexOf(enfant)+1));
				} catch (Exception e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}else{
				try {
					addHTMLDescription(familyRequirement,"");
				} catch (Exception e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
			}
		}

		indiceRequirementFamilleEnCours=enfant;
	}

	/**
	 * Function that write a Requirement in the XML File
	 * @param lignePourLirePJetURL lignePourLirePJetURL
	 * @param familleExiste boolean
	 * @param exigenceLu string
	 * @param descriptionLu string
	 */
	public void writeRequirement(boolean familleExiste, String exigenceLu, int lignePourLirePJetURL) {
		if (!exigenceID.contains(exigenceLu)){
			exigenceID.add(exigenceLu);
			while (exigenceID.contains(indiceRequirement)){
				indiceRequirement++;
			}
			exigenceID.add(exigenceID.get(exigenceID.indexOf(familleEnCours)+1) + Language.getInstance().getText("_") + String.valueOf(indiceRequirement));
			indiceRequirement++;	
			exigenceID.add("Requirement");
		}

		String idValue = exigenceID.get(exigenceID.indexOf(exigenceLu)+1);
		idValue = idValue.substring(idValue.lastIndexOf(Language.getInstance().getText("_"))+Language.getInstance().getText("_").length());

		String exigenceAEcrire = exigenceID.get(exigenceID.indexOf(exigenceLu));
		if (exigenceLu.contains(Language.getInstance().getText("_"))){
			exigenceAEcrire = exigenceAEcrire.substring(exigenceID.get(exigenceID.indexOf(exigenceLu)).lastIndexOf(Language.getInstance().getText("_"))+Language.getInstance().getText("_").length());	
		}
		
		//System.out.println("exigenceAEcrire : " + exigenceAEcrire);

		Element Requirement;
		if (familleExiste) {
			Requirement = familyRequirement
			.addElement("Requirement")
			.addAttribute("priority", valeurPriorite)
			.addAttribute("category", valeurCategorie)
			.addAttribute("complexity", valeurComplexite)
			.addAttribute("state", valeurEtat)
			//20100121 - Dbut modification Forge ORTF
			.addAttribute("understanding", valeurUnderstanding)
			.addAttribute("owner", valeurOwner)
			.addAttribute("criticity", valeurCritical)
			.addAttribute("checkedBy", valeurValidBy)
			//20100121 - Fin modification Forge ORTF
			.addAttribute("origine", valeurOrigine)
			.addAttribute("version", valeurVersion)
			.addAttribute("reference", valeurReference)
			.addAttribute("verifway", valeurVerifWay)
			.addAttribute("id_req","Req_"+ idValue)
			.addAttribute("id_req_parent","Req_" + indiceRequirementFamilleEnCours);

		} else {
			Requirement = requirements
			.addElement("Requirement")
			.addAttribute("priority", valeurPriorite)
			.addAttribute("category", valeurCategorie)
			.addAttribute("complexity", valeurComplexite)
			.addAttribute("state", valeurEtat)
			//20100121 - Dbut modification Forge ORTF
			.addAttribute("understanding", valeurUnderstanding)
			.addAttribute("owner", valeurOwner)
			.addAttribute("criticity", valeurCritical)
			.addAttribute("checkedBy", valeurValidBy)
			//20100121 - Fin modification Forge ORTF
			.addAttribute("origine", valeurOrigine)
			.addAttribute("version", valeurVersion)
			.addAttribute("reference", valeurReference)
			.addAttribute("verifway", valeurVerifWay)
			.addAttribute("id_req", "Req_" + idValue)
			.addAttribute("id_req_parent", "Req_0");
		}
		// enleve possibilite 2 underscore qui se suivent :
		//exigenceLu = exigenceLu.replaceAll(Language.getInstance().getText("_") + Language.getInstance().getText("_"), Language.getInstance().getText("_"));

		Element RequirementName = Requirement.addElement("Nom")
		.addText(exigenceAEcrire);

		try {
			if (valeurDescription.length()>0){
				addHTMLDescription(Requirement,valeurDescription);	
			}
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}


		if (lignePourLirePJetURL !=65536){
			litPJetURL(Requirement, requirementSheet, lignePourLirePJetURL, isPresenceColonneLienHypertexte, numeroColonneLienHypertexte, isPresenceColonnePieceJointe, numeroColonnePieceJointe, "Requirements");
		}
	}

	/**
	 * Function that read each cells of the requirement spreadsheet
	 * 
	 * @throws java.lang.Exception
	 *             Language Exception
	 */
	public void readXlsTableRequirement() throws Exception {
		// Gestion des exigences
		requirements = projetVT.addElement("Requirements")
		.addAttribute("id_req", "Req_0");
		for (int i = ligneDebutTableauRequirement + 1; i < nombreLigneTableau; i++) {
			// lit Famille
			if (isPresenceColonneBranche == false) {
				familleEnCours = Language.getInstance().getText("Famille_par_defaut");
			} else {
				//StringTokenizer st = new StringTokenizer(numeroColonneBranche, Language.getInstance().getText("_"));
				//StringTokenizer stDesc = new StringTokenizer(numeroColonneBrancheDescription, Language.getInstance().getText("_"));
				//20100121 - Dbut modification Forge ORTF
				familleEnCours=null;
				for (int k=0; k <  numeroColonneBranche.size();k++){
					//while (st.hasMoreTokens()) {
					//celluleLu = requirementSheet.getCell(Integer.parseInt(st.nextToken()), i);
					celluleLu = requirementSheet.getCell(Integer.parseInt(numeroColonneBranche.get(k)), i);
					if (familleEnCours==null){
						familleEnCours = replace_BySpecialChar(celluleLu.getContents());
						if (familleEnCours.length()!=0) {
							if (!exigenceID.contains(familleEnCours)){
								exigenceID.add(familleEnCours);
								while (exigenceID.contains(Integer.toString(indiceRequirement))){
									indiceRequirement++;
								}
								exigenceID.add(Integer.toString(indiceRequirement));
								exigenceID.add("RequirementFamily");
								if(!brancheDescriptionID.contains(Integer.toString(indiceRequirement))){
									if(k<numeroColonneBrancheDescription.size()){		
										String NumColonneDescBranche = numeroColonneBrancheDescription.get(k);
										if (!NumColonneDescBranche.equals(Language.getInstance().getText("Pas_De_Description_De_Branche"))){
											brancheDescriptionID.add(Integer.toString(indiceRequirement));
											celluleLu = requirementSheet.getCell(Integer.parseInt(NumColonneDescBranche), i);
											brancheDescriptionID.add(removeSpecialCharacters(celluleLu.getContents()));	
										}	
									}
								}
								indiceRequirement++;

							}
						}
					}else {
						if (celluleLu.getContents().length()!=0) {
							if (!exigenceID.contains(familleEnCours+ Language.getInstance().getText("_") + celluleLu.getContents())){
								int j =  exigenceID.indexOf(familleEnCours);
								familleEnCours =  familleEnCours + Language.getInstance().getText("_") + replace_BySpecialChar(celluleLu.getContents());
								exigenceID.add(familleEnCours);
								while (exigenceID.contains(exigenceID.get(j+1) + Language.getInstance().getText("_") + Integer.toString(indiceRequirement))){
									indiceRequirement++;
								}
								exigenceID.add(exigenceID.get(j+1) + Language.getInstance().getText("_")+ Integer.toString(indiceRequirement));
								if(!brancheDescriptionID.contains(Integer.toString(indiceRequirement))){
									String NumColonneDescBranche = numeroColonneBrancheDescription.get(k);
									if (!NumColonneDescBranche.equals(Language.getInstance().getText("Pas_De_Description_De_Branche"))){
										brancheDescriptionID.add(Integer.toString(indiceRequirement));
										celluleLu = requirementSheet.getCell(Integer.parseInt(NumColonneDescBranche), i);
										brancheDescriptionID.add(celluleLu.getContents());	
									}			
								}
								exigenceID.add("RequirementFamily");
								indiceRequirement++;
							} else {
								familleEnCours =  familleEnCours + Language.getInstance().getText("_") + replace_BySpecialChar(celluleLu.getContents());
								//20100121 - Fin modification Forge ORTF
							}
						}
					}

				}
			}


			if ((!familleEnCours.equals(famillePrecedente)) && (familleEnCours.length() > 0) && isPresenceColonneBranche) {
				writeFamilyRequirement(familleEnCours);
				famillePrecedente = familleEnCours;
			}

			// Lit Exigence
			celluleLu = requirementSheet.getCell(numeroColonneExigence, i);
			exigenceLu = celluleLu.getContents();

			while (exigenceLu.startsWith(Language.getInstance().getText("_"))) {
				exigenceLu = exigenceLu.substring(1);
			}
			
			//20100121 - Dbut modification Forge ORTF
			// lit Priorite
			if (isPresenceColonnePriorite == true) {
				//boolean setValeurPriorite = false;
				celluleLu = requirementSheet.getCell(numeroColonnePriorite, i);
				valeurPriorite = celluleLu.getContents();
				if (valeurPriorite.equals("")){
					valeurPriorite = null;
				}
			} else {
				valeurPriorite = null;
			}

			// lit Version
			if (isPresenceColonneVersion == true) {
				celluleLu = requirementSheet.getCell(numeroColonneVersion, i);
				valeurVersion = celluleLu.getContents();
			} else {
				valeurVersion = "1";
			}
			// lit Origine
			if (isPresenceColonneOrigine == true) {
				celluleLu = requirementSheet.getCell(numeroColonneOrigine, i);
				valeurOrigine = celluleLu.getContents();
			} else {
				valeurOrigine = "MOE";
			}
			// lit VerifWay
			if (isPresenceColonneVerifWay == true) {
				celluleLu = requirementSheet.getCell(numeroColonneVerifWay, i);
				valeurVerifWay = celluleLu.getContents();
			} else {
				valeurVerifWay = "";
			}
			// lit Reference
			if (isPresenceColonneReference == true) {
				celluleLu = requirementSheet.getCell(numeroColonneReference, i);
				valeurReference = celluleLu.getContents();
			} else {
				valeurReference = "";
			}
			// lit Description
			if (isPresenceColonneDescription == true) {
				celluleLu = requirementSheet.getCell(numeroColonneDescription, i);
				valeurDescription = celluleLu.getContents();
				//		valeurDescription = transformeEnHTML(valeurDescription);
			} else {
				valeurDescription = "";
			}

			// lit Categorie
			if (isPresenceColonneCategorie == true) {
				celluleLu = requirementSheet.getCell(numeroColonneCategorie, i);
				valeurCategorie = celluleLu.getContents();
				if (valeurCategorie.equals("")){
					valeurCategorie = null;
				}
			} else {
				valeurCategorie = null;
			}
			// lit complexite
			if (isPresenceColonneComplexite == true) {
				celluleLu = requirementSheet.getCell(numeroColonneComplexite, i);
				valeurComplexite = celluleLu.getContents();
				if (valeurComplexite.equals("")){
					valeurComplexite = null;
				}
			} else {
				valeurComplexite = null;
			}

			// lit Etat
			if (isPresenceColonneEtat == true) {
				celluleLu = requirementSheet.getCell(numeroColonneEtat, i);
				valeurEtat = celluleLu.getContents();
				if (valeurEtat.equals("")){
					valeurEtat = null;
				}
			} else {
				valeurEtat = null;
			}
			
			if (isPresenceColonneCritical == true) {
				celluleLu = requirementSheet.getCell(numeroColonneCritical, i);
				valeurCritical = celluleLu.getContents();
				if (valeurCritical.equals("")){
					valeurCritical = null;
				}
			} else {
				valeurCritical = null;
			}
			if (isPresenceColonneUnderstanding == true) {
				celluleLu = requirementSheet.getCell(numeroColonneUnderstanding, i);
				valeurUnderstanding = celluleLu.getContents();
				if (valeurUnderstanding.equals("")){
					valeurUnderstanding = null;
				}
			} else {
				valeurUnderstanding = null;
			}
			if (isPresenceColonneOwner == true) {
				celluleLu = requirementSheet.getCell(numeroColonneOwner, i);
				valeurOwner = celluleLu.getContents();
				if (valeurOwner.equals("")){
					valeurOwner = null;
				}
			} else {
				valeurOwner = null;
			}
			if (isPresenceColonneValidBy == true) {
				celluleLu = requirementSheet.getCell(numeroColonneValidBy, i);
				valeurValidBy = celluleLu.getContents();
				if (valeurValidBy.equals("")){
					valeurValidBy = null;
				}
			} else {
				valeurValidBy = null;
			}
			//20100121 - Dbut modification Forge ORTF

			boolean ExigenceAttacheFamille;
			if (exigenceLu.length() >0){
				if (familleEnCours.length() > 0 && isPresenceColonneBranche) {
					ExigenceAttacheFamille = true;
					writeRequirement(ExigenceAttacheFamille, familleEnCours + Language.getInstance().getText("_") + removeSpecialCharacters(exigenceLu), i);
				} else {
					ExigenceAttacheFamille = false;
					writeRequirement(ExigenceAttacheFamille, removeSpecialCharacters(exigenceLu), i);
				}
			}
		}
	}



	private void addHTMLDescription(Element parentElem, String description) throws Exception {
		String desc = description.replaceAll("<br>", "<br />");
		desc = "<html><head></head><body>" + desc + "</body></html>";
		try {
			Document document = DocumentHelper.parseText(desc);
			Element bodyElem = (Element)document.selectSingleNode("//body");
			Element descElem = bodyElem.createCopy("Description");
			if (descElem.isTextOnly()) {
				String text = descElem.getText();
				if (text.trim().length() != 0) {
					descElem.addAttribute("isHTML", "true");
					parentElem.add(descElem);						
				}
			} else {
				descElem.addAttribute("isHTML", "true");
				parentElem.add(descElem);					
			}
		} catch (Exception e) {
			parentElem.addElement("Description").setText(desc.replaceAll("\n", "\\\\n"));
		}
	}
	/**
	 * Function that verify the presence of requirement columns in the
	 * requirement spreadsheet
	 */
	public void testColumnsPresenceRequirement() {
		StringTokenizer st;

		// Recupere ligne debut tableau
		boolean exigenceTrouve = false;
		for (int j = 0; j < nombreLigneTableau; j++) {
			for (int i = 0; i < nombreColonneTableau; i++) {
				celluleLu = requirementSheet.getCell(i, j);
				st = new StringTokenizer(Language.getInstance().getText("Exigence_Liste").toLowerCase(), ",");
				while (st.hasMoreTokens() && exigenceTrouve == false) {
					if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
						ligneDebutTableauRequirement = celluleLu.getRow();
						exigenceTrouve = true;
					}
				}
			}
		}

		// test presences des colonnes version,priorite et Description
		for (int i = 0; i < nombreColonneTableau; i++) {
			celluleLu = requirementSheet.getCell(i, ligneDebutTableauRequirement);
			// test presences des colonnes priorite
			st = new StringTokenizer(Language.getInstance().getText("Priorite_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonnePriorite == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonnePriorite = true;
					numeroColonnePriorite = i;
				}
			}
			// test presences des colonnes version
			st = new StringTokenizer(Language.getInstance().getText("Version_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneVersion == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneVersion = true;
					numeroColonneVersion = i;
				}
			}

			// test presences des colonnes Description
			st = new StringTokenizer(Language.getInstance().getText("Description_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneDescription == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneDescription = true;
					numeroColonneDescription = i;
				}
			}

			// test presences des colonnes Lien Hypertexte
			st = new StringTokenizer(Language.getInstance().getText("Lien_Hypertexte_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()
					&& isPresenceColonneLienHypertexte == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneLienHypertexte = true;
					numeroColonneLienHypertexte = i;
				}
			}

			// test presences des colonnes Piece Jointe
			st = new StringTokenizer(Language.getInstance().getText("Piece_Jointe_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonnePieceJointe == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonnePieceJointe = true;
					numeroColonnePieceJointe = i;
				}
			}

			// test presences des colonnes Categorie
			st = new StringTokenizer(Language.getInstance().getText("Categorie_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneCategorie == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneCategorie = true;
					numeroColonneCategorie = i;
				}
			}

			// test presences des colonnes Complexite
			st = new StringTokenizer(Language.getInstance().getText("Complexite_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneComplexite == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneComplexite = true;
					numeroColonneComplexite = i;
				}
			}

			// test presences des colonnes Etat
			st = new StringTokenizer(Language.getInstance().getText("Etat_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneEtat == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneEtat = true;
					numeroColonneEtat = i;
				}
			}
			
			//20100121 - Dbut modification Forge ORTF
			// test presences des colonnes criticite
			st = new StringTokenizer(Language.getInstance().getText("Criticite_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneCritical == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneCritical = true;
					numeroColonneCritical = i;
				}
			}
			
			// test presences des colonnes comprehension
			st = new StringTokenizer(Language.getInstance().getText("Comprehension_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneUnderstanding == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneUnderstanding = true;
					numeroColonneUnderstanding = i;
				}
			}
			
			// test presences des colonnes proprietaire
			st = new StringTokenizer(Language.getInstance().getText("Proprietaire_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneOwner == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneOwner = true;
					numeroColonneOwner = i;
				}
			}
			
			// test presences des colonnes valide par
			st = new StringTokenizer(Language.getInstance().getText("Valide_par_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneValidBy == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneValidBy = true;
					numeroColonneValidBy = i;
				}
			}
			//20100121 - Fin modification Forge ORTF
			
			// test presences des colonnes Origine
			st = new StringTokenizer(Language.getInstance().getText("Origine_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneOrigine == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneOrigine = true;
					numeroColonneOrigine = i;
				}
			}

			// test presences des colonnes VerifWay
			st = new StringTokenizer(Language.getInstance().getText("VerifWay_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneVerifWay == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneVerifWay = true;
					numeroColonneVerifWay = i;
				}
			}
			// test presences des colonnes Refecence
			st = new StringTokenizer(Language.getInstance().getText("Reference_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneReference == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneReference = true;
					numeroColonneReference = i;
				}
			}

		}

		// test de presence des colonnes Famille et Exigence
		for (int i = 0; i < nombreColonneTableau; i++) {
			celluleLu = requirementSheet.getCell(i, ligneDebutTableauRequirement);
			st = new StringTokenizer(Language.getInstance().getText("Exigence_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens() && isPresenceColonneExigence == false) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneExigence = true;
					numeroColonneExigence = i;
				}
			}
			isPresenceColonneBrancheDescription = false;
			st = new StringTokenizer(Language.getInstance().getText("Theme_Liste").toLowerCase(), ",");
			StringTokenizer stDescription = new StringTokenizer(Language.getInstance().getText("Description_Branche_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()) {
				if (celluleLu.getContents().trim().toLowerCase().equals(st.nextToken().toString())) {
					isPresenceColonneBranche = true;
					if (numeroColonneBranche.size()==0){
						numeroColonneBranche.add(Integer.toString(i));
						celluleLu = requirementSheet.getCell(i+1, ligneDebutTableauRequirement);
						while (stDescription.hasMoreTokens()) {
							if (celluleLu.getContents().trim().toLowerCase().equals(stDescription.nextToken().toString())) {
								//numeroColonneBrancheDescription = Integer.toString(i+1);
								numeroColonneBrancheDescription.clear();
								numeroColonneBrancheDescription.add(Integer.toString(i+1));
								isPresenceColonneBrancheDescription = true;
							}
						}
						if (isPresenceColonneBrancheDescription==false){
							numeroColonneBrancheDescription.add(Language.getInstance().getText("Pas_De_Description_De_Branche"));
						}
					}else {
						numeroColonneBranche.add(Integer.toString(i));
						celluleLu = requirementSheet.getCell(i+1, ligneDebutTableauRequirement);
						while (stDescription.hasMoreTokens()) {
							if (celluleLu.getContents().trim().toLowerCase().equals(stDescription.nextToken().toString())) {
								//numeroColonneBrancheDescription = numeroColonneBrancheDescription + Language.getInstance().getText("_") + Integer.toString(i+1);
								numeroColonneBrancheDescription.add(Integer.toString(i+1));
								isPresenceColonneBrancheDescription = true;
							}
						}
						if (isPresenceColonneBrancheDescription==false){
							numeroColonneBrancheDescription.add(Language.getInstance().getText("Pas_De_Description_De_Branche"));
						}

					}

				}
			}

		}

		if ((isPresenceColonneExigence == false)) {
			PopUpFormalismeExcel aide = new PopUpFormalismeExcel(null);
			closeXmlAndXlsFiles();
			JOptionPane.showMessageDialog(null, Language.getInstance().getText(
			"Stop_No_Requirement_Column_Or_Family"), Language
			.getInstance().getText("Erreur_"),
			JOptionPane.ERROR_MESSAGE);
			isErreurTraitementImport = true;
		}

	}

	/**
	 * Function that write the XML Heading (common to every XML files)
	 */
	public void writeXmlHeading() {
		// Creation du document XML
		documentXml = DocumentHelper.createDocument();

		// Gestion de l'entete XML commune
		Element root = documentXml.addElement("SalomeDynamique");
		projetVT = root.addElement("ProjetVT");
		Element nomProjet = projetVT.addElement("Nom").addText("pluginxlsxml");

		// Generation de la date
		DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.MONTH_FIELD);
		Element dateCrea = projetVT.addElement("Date_crea")
		.addText(dateFormat.format(new Date()));
		Element groupesDePersonnes = projetVT.addElement("GroupesDePersonnes")
		.addText("");
		Element groupeDePersonnes = groupesDePersonnes.addElement(
		"GroupeDePersonnes").addText("");
		Element nomGroupe = groupeDePersonnes.addElement("Nom").addText(
		"OutilExcelXml");
		Element descriptionGroupe = groupeDePersonnes.addElement("Description")
		.addText("Groupe de transfert des exigences");



	}

	/**
	 * Function that create the XML file from the name typed in the swing
	 * component
	 * 
	 * @param nomFichierXml
	 *            Name of the XML file
	 * @return the real name of the created XML File
	 */
	public String createXmlFile(String nomFichierXml) {
		
		// Cree nom Fichier XML a partir nom Excel
		nomFichierXml = nomFichierXml.substring(0, nomFichierXml
				.lastIndexOf(".xls"))
				+ ".xml";
		
		// Tente de creer le fichier XML
		fichierDeSortieXML = new File(nomFichierXml);
		int i = 0;
		while (fichierDeSortieXML.exists()) {

			if (i == 0) {
				System.out.println(Language.getInstance().getText("FileName_Already_Exists"));

				nomFichierXml = nomFichierXml.substring(0, nomFichierXml
						.lastIndexOf("."))
						+ Language.getInstance().getText("Underscore")
						+ Integer.toString(i) + ".xml";

			} else {
				nomFichierXml = nomFichierXml.substring(0, nomFichierXml
						.lastIndexOf(Language.getInstance().getText("Underscore")))
						+ Language.getInstance().getText("Underscore")
						+ Integer.toString(i) + ".xml";

			}

			fichierDeSortieXML = new File(nomFichierXml);
			i++;
		}
		
//		try {
//			fichierDeSortieXML = File.createTempFile("importXls", "toto");
//		} catch (IOException e) {
//			System.out.println(Language.getInstance().getText(
//			"Erreur_Fichier_Sortie_XML")
//			+ nomFichierXml);
//			e.printStackTrace();
//		}
		System.out.println(Language.getInstance().getText("Fichier_Sortie_XML")
				+ fichierDeSortieXML.toString());
		try {
			fichierDeSortieXML.createNewFile();
		} catch (IOException ex) {
			System.out.println(Language.getInstance().getText(
			"Erreur_Fichier_Sortie_XML")
			+ fichierDeSortieXML.toString());
			ex.printStackTrace();
		}
		return fichierDeSortieXML.toString();
	}

	/**
	 * Function testing the presence of the XLS file and open it
	 * 
	 * @param FichierExcel
	 *            Name of the XLS File
	 * 
	 */
	public void openXLSFile(String FichierExcel) {

		// Recupere le fichier excel et tente de l'ouvrir, sinon, erreur
		try {
			// recupere fichier Excel
			workbook = Workbook.getWorkbook(new File(FichierExcel));
		} catch (IOException e) {
			System.out.println(Language.getInstance().getText("Erreur_Fichier_Excel_Existe_Pas") + FichierExcel);
		} catch (BiffException e) {
			e.printStackTrace();
		}

		// recupere le nombre de feuilles du classeur
		String[] nombreFeuilles = workbook.getSheetNames();
		for (int i = 0; i < nombreFeuilles.length; i++) {
			// Recupere la feuille Exigence
			StringTokenizer st = new StringTokenizer(Language.getInstance().getText("Exigence_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()) {
				if (nombreFeuilles[i].toLowerCase().equals(st.nextToken().toString())) {
					Util.debug("Requirements sheet found.");
					// Recupere la feuille Exigence
					requirementSheet = workbook.getSheet(nombreFeuilles[i]);
					// Recupere les dimensions du tableau
					nombreColonneTableau = requirementSheet.getColumns();
					nombreLigneTableau = requirementSheet.getRows();
					presenceFeuilleExigence = true;
				}
			}
			st = new StringTokenizer(Language.getInstance().getText("cas_de_tests_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()) {
				if (nombreFeuilles[i].toLowerCase().equals(st.nextToken().toString())) {
					// Recupere la feuille tests
					testSheet = workbook.getSheet(nombreFeuilles[i]);
					// Recupere les dimensions du tableau
					nombreColonneTableauTests = testSheet.getColumns();
					nombreLigneTableauTests = testSheet.getRows();
					presenceFeuilleTest=true;
				}
			}
			st = new StringTokenizer(Language.getInstance().getText("nom_Parametres_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()) {
				if (nombreFeuilles[i].toLowerCase().equals(st.nextToken().toString())) {
					// Recupere la feuille tests
					paramSheet = workbook.getSheet(nombreFeuilles[i]);
					// Recupere les dimensions du tableau
					nombreColonneTableauParametres = paramSheet.getColumns();
					nombreLigneTableauParametres = paramSheet.getRows();
					presenceFeuilleParametres=true;
				}
			}
			st = new StringTokenizer(Language.getInstance().getText("nom_Environnements_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()) {
				if (nombreFeuilles[i].toLowerCase().equals(st.nextToken().toString())) {
					// Recupere la feuille tests
					enviroSheet = workbook.getSheet(nombreFeuilles[i]);
					// Recupere les dimensions du tableau
					nombreColonneTableauEnvironnements = enviroSheet.getColumns();
					nombreLigneTableauEnvironnements = enviroSheet.getRows();
					presenceFeuilleEnvironnements=true;

				} 
			}
			st = new StringTokenizer(Language.getInstance().getText("nom_Campagne_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()) {
				if (nombreFeuilles[i].toLowerCase().equals(st.nextToken().toString())) {
					// Recupere la feuille tests
					campagneSheet = workbook.getSheet(nombreFeuilles[i]);
					// Recupere les dimensions du tableau
					nombreColonneTableauCampagne = campagneSheet.getColumns();
					nombreLigneTableauCampagne = campagneSheet.getRows();
					presenceFeuilleCampagne=true;

				} 
			}
			st = new StringTokenizer(Language.getInstance().getText("nom_Execution_Campagne_Liste").toLowerCase(), ",");
			while (st.hasMoreTokens()) {
				if (nombreFeuilles[i].toLowerCase().equals(st.nextToken().toString())) {
					// Recupere la feuille tests
					execCampSheet = workbook.getSheet(nombreFeuilles[i]);
					// Recupere les dimensions du tableau
					nombreColonneTableauExecutionCamp = execCampSheet.getColumns();
					nombreLigneTableauExecutionCamp = execCampSheet.getRows();
					presenceFeuilleExecutionCamp=true;

				} 
			}
		}

		try {
			if (presenceFeuilleExigence){
				celluleLu = requirementSheet.getCell(0, 0);
			}
			if (presenceFeuilleTest){
				celluleLu = testSheet.getCell(0, 0);
			}
			if (presenceFeuilleParametres){
				celluleLu = paramSheet.getCell(0, 0);
			}
			if (presenceFeuilleEnvironnements){
				celluleLu = enviroSheet.getCell(0, 0);
			}
			if (presenceFeuilleCampagne){
				celluleLu = campagneSheet.getCell(0, 0);
			}
			if (presenceFeuilleExecutionCamp){
				celluleLu = execCampSheet.getCell(0, 0);
			}
		} catch (NullPointerException e) {

			PopUpFormalismeExcel aide = new PopUpFormalismeExcel(null);
			isErreurFormalismeExcel = true;
			workbook.close();

		}

	}

	/**
	 * Function that close the XLS and the XML file This function tries to
	 * delete empties spreadsheet's columns
	 */
	public void closeXmlAndXlsFiles() {
		XMLWriter writer;
		try {
			// Pretty print the document to System.out
			OutputFormat format = OutputFormat.createPrettyPrint();
			format.setEncoding("ISO-8859-15");
			writer = new XMLWriter(new FileWriter(nomFichierXML), format);
			writer.write(documentXml);
			writer.close();
		} catch (IOException ex) {
			ex.printStackTrace();
		}
		// Finished - close the workbook and free up memory
		workbook.close();
	}

	/**
	 * Function that only return the name of the files that had not been
	 * imported
	 * 
	 * @return Name of files
	 */
	public String getFichiersNonImportes() {
		return fichiersNonImportes;
	}

	/**
	 * Function that only return the npath of the xlm created by this function
	 * 
	 * @return path
	 */
	public String getXmlDir() {
		return xmlDir;
	}

	/**
	 * Function that only return true if there has been an error during import
	 * 
	 * @return path
	 */
	public boolean getIsErreurTraitementImport() {
		return isErreurTraitementImport;
	}

	/**
	 * Function that only return the name of the XML File
	 * 
	 * @return Name of the XML File
	 */
	public String getXMLFileName() {
		return nomFichierXML;
	}

	/**
	 * Function that only return the list of requirements that don't exist
	 * 
	 * @return list of requirements that don't exist
	 */
	public String getExigenceNonTrouvePourTest() {
		return exigenceNonTrouvePourTest;
	}

	/**
	 * listeCampagneNonTrouve
	 * @return listeCampagneNonTrouve
	 */
	public String getListeCampagneNonTrouve() {
		return listeCampagneNonTrouve;
	}

	/**
	 * Function that return if the transformation in a XML File was OK
	 * 
	 * @return boolean
	 */
	public boolean getErreurImportFichier() {
		return isErreurImportFichier;
	}

	/**
	 * Function that verify if attachements are accessible and copy them into a
	 * same directory tree
	 * 
	 * @param listePJ
	 *            File
	 * @param type
	 *            Requirement or test
	 * @param exigenceLu
	 *            Requirement linket to file
	 * @throws java.lang.Exception
	 *             Language Exception
	 * @return New file diectory tree
	 */
	public String copyFileAttachements(String listePJ, String type, String exigenceLu) throws Exception {
		xmlDir = nomFichierXML.substring(0, nomFichierXML.lastIndexOf(fs));
		Sortie = Language.getInstance().getText("Attachements") + fs + type;

		if (exigenceLu != null) {
			Sortie = Sortie + fs + exigenceLu;
		}

		listePJ = restorePath(listePJ);
		xmlDir = restorePath(xmlDir);
		Sortie = restorePath(Sortie);

		File f1 = new File(listePJ);
		File f1bis;

		if (listePJ.startsWith(fs)) {
			f1bis = new File(xmlDir +listePJ);
		}else {
			f1bis = new File(xmlDir +fs + listePJ);
		}
		File f2 = new File(xmlDir + fs + Sortie);
		File f3 = new File(f2.toString() + fs + listePJ.substring(listePJ.lastIndexOf(fs) + 1));

		if (f1bis.exists()){
			f1 = f1bis;
		}

		if (!f1.exists()) {
			if (isErreurImportFichier = false) {
				fichiersNonImportes = f1.toString() + "\n";
			} else {
				fichiersNonImportes = fichiersNonImportes + f1.toString()+ "\n";
			}
			isErreurImportFichier = true;
			return null;

		} else {

			FileChannel in = null; // canal d'entree
			FileChannel out = null; // canal de sortie

			try {
				f2.mkdirs();
				// Init
				in = new FileInputStream(f1.toString()).getChannel();
				out = new FileOutputStream(f3.toString()).getChannel();
				// Copie depuis le in vers le out
				in.transferTo(0, in.size(), out);
			} catch (Exception e) {
				e.printStackTrace(); // n'importe quelle exception
			} finally { // finalement on ferme
				if (in != null) {
					try {
						in.close();
					} catch (IOException e) {
					}
				}
				if (out != null) {
					try {
						out.close();
					} catch (IOException e) {
					}
				}
			}
			return Sortie + fs + listePJ.substring(listePJ.lastIndexOf(fs) + 1);
		}

	}

	/**
	 * Modify a string to pass special characters like quote
	 * 
	 * @param chaineAModifier
	 *            A string for argument
	 * @return A string
	 */
	public String removeSpecialCharacters(String chaineAModifier) {
		chaineAModifier = chaineAModifier.replaceAll("", "'");
		chaineAModifier = chaineAModifier.replaceAll("", "-");
		return chaineAModifier;
	}

	String restorePath(String path) throws Exception {
		if (fs.equals("\\")) {
			// Unix2Windows
			return path.replace('/', '\\');
		} else {
			return path.replace('\\', '/');
		}
	}

	/**
	 * Get chosenRoot
	 * 
	 * @return Returns the chosenRoot.
	 */
	public DefaultMutableTreeNode getChosenRoot() {
		return chosenRoot;
	}

	/**
	 * Set chosenRoot
	 * 
	 * @param chosenRoot
	 *            The chosenRoot to set.
	 */
	public void setChosenRoot(DefaultMutableTreeNode chosenRoot) {
		this.chosenRoot = chosenRoot;
	}

	/**
	 * Get familySelectionList
	 * 
	 * @return Returns the familySelectionList.
	 */
	public ArrayList getFamilySelectionList() {
		return familySelectionList;
	}

	/**
	 * Set familySelectionList
	 * 
	 * @param familySelectionList
	 *            The familySelectionList to set.
	 */
	public void setFamilySelectionList(ArrayList familySelectionList) {
		this.familySelectionList = familySelectionList;
	}

	/**
	 * Get suiteSelectionList
	 * 
	 * @return Returns the suiteSelectionList.
	 */
	public ArrayList getSuiteSelectionList() {
		return suiteSelectionList;
	}

	/**
	 * Set suiteSelectionList
	 * 
	 * @param suiteSelectionList
	 *            The suiteSelectionList to set.
	 */
	public void setSuiteSelectionList(ArrayList suiteSelectionList) {
		this.suiteSelectionList = suiteSelectionList;
	}

	/**
	 * Get testSelectionList
	 * 
	 * @return Returns the testSelectionList.
	 */
	public ArrayList getTestSelectionList() {
		return testSelectionList;
	}

	/**
	 * Set testSelectionList
	 * 
	 * @param testSelectionList
	 *            The testSelectionList to set.
	 */
	public void setTestSelectionList(ArrayList testSelectionList) {
		this.testSelectionList = testSelectionList;
	}

	/**
	 * Get isInitSelection
	 * 
	 * @return Returns the isInitSelection.
	 */
	public boolean isInitSelection() {
		return isInitSelection;
	}

	/**
	 * Return true si case a cocher tests est selectionnee
	 * 
	 * @return true
	 */
	public boolean getTestSelection() {
		return false;
	}

	/**
	 * Return true si case a cocher Exigence est selectionnee
	 * 
	 * @return isSelectionExportExigence
	 */
	public boolean getExigenceSelection() {
		return isSelectionExportExigence;
	}

	/**
	 * Set isInitSelection
	 * @param initSelection initSelection
	 */
	public void setInitSelection(boolean initSelection) {
		this.isInitSelection = initSelection;
	}

	/**
	 * Permet d'enlever les espaces en trop d'une chaine de caracteres pour la cellule Description
	 * @param valeurDescription chaine a modifier
	 * @return chaine modifiee
	 */
	public String RemiseEnFormeDescription (String valeurDescription){
		if(valeurDescription!=null)	{
			while (valeurDescription.contains("  ")){
				valeurDescription = valeurDescription.replace("  ", " ");
			}

			valeurDescription = valeurDescription.replaceAll("<Description isHTML=\"true\">", "");
			valeurDescription = valeurDescription.replaceAll("<Description isHTML=\"true\"/>", "");
			valeurDescription = valeurDescription.replaceAll("</Description>", "");
			valeurDescription = valeurDescription.replaceAll("<Description>", "");
			valeurDescription = valeurDescription.replaceAll("\n ", "\n");
			valeurDescription = valeurDescription.replaceAll("’", "'");
			valeurDescription = valeurDescription.replaceAll("–", "-");
			if (valeurDescription.endsWith("\n")){
				valeurDescription = valeurDescription.substring(0, valeurDescription.lastIndexOf("\n"));		
			}
			return valeurDescription;
		} else {
			return "";
		}
	}

	//20100121 - Dbut modification Forge ORTF
	public String replace_BySpecialChar(String value){
		String newValue = value.replaceAll("_", "#/#");
		return newValue;
	}
	
	public String replaceSpecialCharBy_(String value){
		String newValue = value.replaceAll("#/#", "_");
		return newValue;
	}
	//20100121 - Fin modification Forge ORTF
	
	/*	public void litVariable(String nom, int variable){
		System.out.println("int " + nom + " : " + variable);
	}
	public void litVariable(String nom, String variable){
		System.out.println("String " + nom + " : " + variable);
}
	public void litVariable(String nom, boolean variable){
	System.out.println("boolean " + nom + " : " + variable);
}
	 */
}
