//20100128 - D�but modification Forge ORTF v1.0.0
package salomeTMF_plug.pluginxlsxml.Import;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.net.URL;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Properties;

import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import jxl.Cell;
import jxl.Sheet;
import jxl.Workbook;

import org.objectweb.salome_tmf.api.Api;
import org.objectweb.salome_tmf.api.ApiConstants;
import org.objectweb.salome_tmf.api.Util;
import org.objectweb.salome_tmf.data.DataLoader;
import org.objectweb.salome_tmf.data.Family;
import org.objectweb.salome_tmf.data.ManualTest;
import org.objectweb.salome_tmf.data.Project;
import org.objectweb.salome_tmf.data.Test;
import org.objectweb.salome_tmf.data.TestList;
import org.objectweb.salome_tmf.databaseSQL.WebDavUtils;
import org.objectweb.salome_tmf.ihm.main.SalomeTMFContext;
import org.objectweb.salome_tmf.ihm.main.datawrapper.DataModel;
import org.objectweb.salome_tmf.plugins.core.ReqManager;

import salomeTMF_plug.pluginxlsxml.language.Language;
import salomeTMF_plug.pluginxlsxml.sqlWrapper.SQLWrapper;
import salomeTMF_plug.requirements.ReqPlugin;
import salomeTMF_plug.requirements.data.ReqFamily;
import salomeTMF_plug.requirements.data.ReqLeaf;
import salomeTMF_plug.requirements.data.Requirement;

/**
 * @author hchauvin
 *
 */
public class ImportCMMIDialog extends JDialog {

	/**
	 * Exigences sheet name
	 */
	private final static String EXI_SHEET_NAME = "Exigences";

	/**
	 * Row number of the title row of the model.
	 */
	private final static int TITLE_ROW = 8;

	/**
	 * Label used int the title of family and sub family columns in the model.
	 */
	private final static String FAMILY_LABEL = "Famille";

	private final static int ID_COLUMN = 0;
	private final static int NAME_COLUMN = 1; // match description in excel...
	private final static int STAT_COLUMN = 2;
	private final static int VERSION_COLUMN = 3;
	private final static int SRC_DOC_COLUMN = 4;
	private final static int VAL_BY_COLUMN = 5;
	private final static int PRIORITY_COLUMN = 6;
	private final static int COMPLEXITY_COLUMN = 7;
	private final static int CRITICITY_COLUMN = 8;
	private final static int COMPREHENTION_COLUMN = 9;
	private final static int OWNER_COLUMN = 10;
	private final static int TEST_CASE_COLUMN = 11;

	/**
	 * The excel exigences sheet.
	 */
	private Sheet exiSheet;

	/**
	 * Total exigence number.
	 */
	private int nbOfExi = 0;

	/**
	 * List of row in error.
	 */
	private DefaultListModel importInError = new DefaultListModel();

	/**
	 * Number of family and sub family column.
	 */
	private int nbOfSSFamilles;

	/**
	 * The requirement tree root.
	 */
	private DefaultMutableTreeNode reqRootNode;

	private JProgressBar progress;

	private JLabel countLabel;

	private JList errorList;

	private boolean close = false;

	private ReqManager reqManager;

	/**
	 * @param reportFile Excel file to read.
	 * @param reqManager The requirement plugin manager.
	 */
	public ImportCMMIDialog(String reportFile, ReqManager reqManager) {
		super(SalomeTMFContext.getInstance().getSalomeFrame(), true);
		setTitle(Language.getInstance().getText("Import_CMMI_Title"));
		this.reqManager = reqManager;
		if (reportFile != "") {
			try {
				Workbook wb = Workbook.getWorkbook(new File(reportFile));
				if (wb != null) {
					exiSheet = wb.getSheet(0);
					System.out.println("Exigences sheet found: "
							+ exiSheet.getName());
					if (exiSheet.getName().trim().equalsIgnoreCase(
							EXI_SHEET_NAME)) {
						if (setReqRootNode(reqManager)) {
							JPanel progressPanel = new JPanel(
									new BorderLayout());
							progressPanel.add(new JLabel(Language.getInstance()
									.getText("Import_CMMI_Launch")),
									BorderLayout.NORTH);
							final JButton okButton = new JButton(Language
									.getInstance().getText("OK"));
							okButton.addActionListener(new ActionListener() {
								public void actionPerformed(ActionEvent e) {
									Thread t = new Thread(new Runnable() {
										public void run() {
											if(close){
												dispose();
											} else {
												try {
													okButton.setEnabled(false);
													launchImport();
													DataModel.reloadFromBase(true);
												}catch(Exception e){
													// nothing todo
												}
												countLabel.setText(countLabel.getText() + " " + importInError.getSize() + "/" + nbOfExi);
												errorList.repaint();
												okButton.setEnabled(true);
												close = true;
											}
										}
									});
									t.start();
								}
							});
							progress = new JProgressBar();
							progressPanel.add(progress, BorderLayout.CENTER);
							progressPanel.add(okButton, BorderLayout.SOUTH);
							countLabel = new JLabel(Language.getInstance().getText("Import_CMMI_error_label"));
							errorList = new JList(importInError);
							JScrollPane scroll = new JScrollPane(errorList);
							JPanel errorPanel = new JPanel(new BorderLayout());
							errorPanel.add(countLabel, BorderLayout.NORTH);
							errorPanel.add(scroll, BorderLayout.CENTER);
							this.getContentPane().add(progressPanel,
									BorderLayout.CENTER);
							this.getContentPane().add(errorPanel,
									BorderLayout.SOUTH);
							centerScreen();
						}
					} else {
						// Not valid file
						JPanel errorPanel = new JPanel(new BorderLayout());
						errorPanel.add(new JLabel(Language.getInstance()
								.getText("Import_CMMI_MODEL_error")),
								BorderLayout.CENTER);
						JButton okButton = new JButton(Language.getInstance()
								.getText("OK"));
						okButton.addActionListener(new ActionListener() {
							public void actionPerformed(ActionEvent e) {
								dispose();
							}
						});
						errorPanel.add(okButton, BorderLayout.SOUTH);
						this.getContentPane().add(errorPanel,
								BorderLayout.CENTER);
						centerScreen();
					}
				}
			} catch (Exception e1) {
				JPanel errorPanel = new JPanel(new BorderLayout());
				errorPanel.add(new JLabel(Language.getInstance().getText(
						"Import_CMMI_file_error")), BorderLayout.CENTER);
				JButton okButton = new JButton(Language.getInstance().getText(
						"OK"));
				okButton.addActionListener(new ActionListener() {
					public void actionPerformed(ActionEvent e) {
						dispose();
					}
				});
				errorPanel.add(okButton, BorderLayout.SOUTH);
				this.getContentPane().add(errorPanel, BorderLayout.CENTER);
				centerScreen();
			}
		}
	}

	void centerScreen() {
		Dimension dim = getToolkit().getScreenSize();
		this.pack();
		Rectangle abounds = getBounds();
		setLocation((dim.width - abounds.width) / 2,
				(dim.height - abounds.height) / 2);
		this.setVisible(true);
		requestFocus();
	}

	/**
	 * Retrieve the requirement tree root.
	 *
	 * @param reqManager
	 * @return
	 */
	private boolean setReqRootNode(ReqManager reqManager) {
		String projectName = DataModel.getCurrentProject().getNameFromModel();
		reqRootNode = (DefaultMutableTreeNode) ((DefaultTreeModel) reqManager
				.getTreeRequirement().getModel()).getRoot();
		return ((ReqFamily) reqRootNode.getUserObject()).getNameFromModel()
				.equalsIgnoreCase("Requirements_" + projectName);
	}

	private void init() {
		int i = 0;
		Cell cell;
		do {
			cell = exiSheet.getCell(i, TITLE_ROW);
			i++;
		} while (cell.getContents().endsWith(FAMILY_LABEL));
		nbOfSSFamilles = i - 1;
		this.parents = new String[nbOfSSFamilles];
		for (int j = 0; j < parents.length; j++)
			parents[j] = "";
		Util.log("Number of SS familles: " + nbOfSSFamilles);
		progress.setMaximum(exiSheet.getRows() - 9);
		progress.setValue(0);
	}

	/**
	 * Launch the import CMMI treatment.
	 */
	private void launchImport() {
		init();
		for (int i = 9; i < exiSheet.getRows(); i++) {
			Util.log("TREAT ROW: " + i);
			if (testRow(i)) {
				treatRow(i);
				nbOfExi++;
			}
			progress.setValue(progress.getValue() + 1);
		}
	}

	/**
	 * Verify that it is a row fill with a requirement.
	 *
	 * @param row
	 * @return
	 */
	private boolean testRow(int row) {
		String name = exiSheet.getCell(NAME_COLUMN + nbOfSSFamilles, row)
				.getContents();
		return name != null && !name.equalsIgnoreCase("");// &&
															// !name.equalsIgnoreCase("xxxxxxx");
	}

	private String[] parents;

	/**
	 * Update Family parent list for the actual row.
	 *
	 * @param row
	 */
	private void initFamily(int row) {
		for (int i = 0; i < parents.length; i++) {
			String family = exiSheet.getCell(i, row).getContents().trim();
			if (family != null && !family.equalsIgnoreCase("")) {
				parents[i] = family;
				for (int j = i + 1; j < parents.length; j++) {
					parents[j] = "";
				}
			}
		}
	}

	/**
	 * Get the requirement tree node matching the family. Create it if necessary.
	 *
	 * @param parent
	 * @param family
	 * @return
	 */
	private DefaultMutableTreeNode getParentRequirement(
			DefaultMutableTreeNode parent, String family) {
		DefaultMutableTreeNode reqNode = null;
		Requirement req = null;
		boolean found = false;
		int i = 0;
		while (i < parent.getChildCount() && !found) {
			reqNode = (DefaultMutableTreeNode) parent.getChildAt(i);
			req = (Requirement) reqNode.getUserObject();
			if (req.getNameFromModel().equalsIgnoreCase(family)) {
				found = true;
			}
			i++;
		}
		if (found)
			return reqNode;
		Util.debug("Create Family : " + family);
		req = new ReqFamily(family, "", (ReqFamily) parent.getUserObject());
		try {
			req.addInDB();
		} catch (Exception e) {
			Util.err(e);
		}
		reqNode = new DefaultMutableTreeNode(req);
		parent.add(reqNode);
		return reqNode;
	}

	/**
	 * Get the requirement node matching with path, name and version.
	 * Return null if does not exist.
	 *
	 * @param parent
	 * @param name
	 * @param version
	 * @return
	 */
	private ReqLeaf getMatchingRequirement(DefaultMutableTreeNode parent,
			String name, String version) {
		Requirement req;
		ReqLeaf leaf;
		for (int i = 0; i < parent.getChildCount(); i++) {
			req = (Requirement) ((DefaultMutableTreeNode) parent.getChildAt(i))
					.getUserObject();
			if (req instanceof ReqLeaf) {
				leaf = (ReqLeaf) req;
				if (leaf.getNameFromModel().equalsIgnoreCase(name)
						&& leaf.getVersionFromModel().equalsIgnoreCase(version)) {
					return leaf;
				}
			}
		}
		return null;
	}

	/**
	 * Test if requirement node matching with path and name exist.
	 *
	 * @param parent
	 * @param name
	 * @return
	 */
	private boolean hasMatchingRequirement(DefaultMutableTreeNode parent,
			String name) {
		Requirement req;
		ReqLeaf leaf;
		for (int i = 0; i < parent.getChildCount(); i++) {
			req = (Requirement) ((DefaultMutableTreeNode) parent.getChildAt(i))
					.getUserObject();
			if (req instanceof ReqLeaf) {
				leaf = (ReqLeaf) req;
				if (leaf.getNameFromModel().equalsIgnoreCase(name))
					return true;
			}
		}
		return false;
	}

	/**
	 * Update Model and DB with data from the Excel row.
	 *
	 * @param row
	 */
	private void treatRow(int row) {
		Util.log("Row " + row + " is an exigeance");
		initFamily(row);
		ReqManager reqMan = this.reqManager;
		DefaultMutableTreeNode parentNode = reqRootNode;
		int i = 0;
		while (i < parents.length && !parents[i].equalsIgnoreCase("")) {
			parentNode = getParentRequirement(parentNode, parents[i]);
			i++;
		}
		String id = exiSheet.getCell(ID_COLUMN + nbOfSSFamilles, row)
				.getContents();
		String name = exiSheet.getCell(NAME_COLUMN + nbOfSSFamilles, row)
				.getContents();
		String state = exiSheet.getCell(STAT_COLUMN + nbOfSSFamilles, row)
				.getContents();
		String version = exiSheet.getCell(VERSION_COLUMN + nbOfSSFamilles, row)
				.getContents();
		String reference = exiSheet.getCell(SRC_DOC_COLUMN + nbOfSSFamilles,
				row).getContents();
		String validatePerson = exiSheet.getCell(
				VAL_BY_COLUMN + nbOfSSFamilles, row).getContents();
		String priority = exiSheet.getCell(PRIORITY_COLUMN + nbOfSSFamilles,
				row).getContents();
		String complexe = exiSheet.getCell(COMPLEXITY_COLUMN + nbOfSSFamilles,
				row).getContents();
		String criticity = exiSheet.getCell(CRITICITY_COLUMN + nbOfSSFamilles,
				row).getContents();
		String comprehension = exiSheet.getCell(
				COMPREHENTION_COLUMN + nbOfSSFamilles, row).getContents();
		String owner = exiSheet.getCell(OWNER_COLUMN + nbOfSSFamilles, row)
				.getContents();
		String testCase = exiSheet.getCell(TEST_CASE_COLUMN + nbOfSSFamilles,
				row).getContents();
		// String impactedDoc = exiSheet.getCell(IMPACTED_DOC_COLUMN +
		// nbOfSSFamilles, row).getContents();
		// String history = exiSheet.getCell(HISTORY_COLUMN + nbOfSSFamilles,
		// row).getContents();
		ReqLeaf reqLeaf = getMatchingRequirement(parentNode, name, version);
		if (hasMatchingRequirement(parentNode, name)) {
			if (version.equalsIgnoreCase("")) {
				name += "_?";
				version = "1";
			} else {
				if (reqLeaf == null) {
					name += "_" + version;
				}
			}
		} else {
			version = "1";
		}
		try {
			if (reqLeaf == null) {
				Util.log("Create leaf requirement: " + name
						+ " Version: " + version);
				String description = "";
				if (id != null && !id.equalsIgnoreCase("")) {
					description = new String("N&deg; ID CMMI: ".getBytes()) + id;
				}
				ReqFamily parent;
				if (parentNode == reqRootNode) {
					parent = new ReqFamily("Requirements_" + ReqPlugin.getProjectRef().getNameFromModel(), "");
					Util.debug("Parent is root");
				} else {
					parent = (ReqFamily) parentNode.getUserObject();
				}
				reqLeaf = new ReqLeaf(name, description, parent, 0);
				reqLeaf.addInDB();
				parentNode.add(new DefaultMutableTreeNode(reqLeaf));
			}
			PreparedStatement prep;
			ResultSet stmtRes;
			int value = 1;
			// STATE
			if (!state.equalsIgnoreCase("")) {
				prep = SQLWrapper.getSQLSelectQuery("recupStateID");
				prep.setString(1, state);
				stmtRes = SQLWrapper.runSelectQuery(prep);
				if (stmtRes.next()) {
					value = stmtRes.getInt("id");
				} else {
					prep = SQLWrapper.getSQLSelectQuery("insertStateInDB");
					prep.setString(1, state);
					prep.executeUpdate();
					prep = SQLWrapper.getSQLSelectQuery("recupStateID");
					prep.setString(1, state);
					stmtRes = SQLWrapper.runSelectQuery(prep);
					if (stmtRes.next()) {
						value = stmtRes.getInt("id");
					} else {
						throw new Exception("Could not update database.");
					}
				}
				reqMan.updateReqHMI(reqMan.STATE, state);
				reqLeaf.updateStateInDBAndModel(value);
			}
			// VERSION
			reqLeaf.updateVersionInDBAndModel(version);
			// SRC_DOC
			if (!reference.equalsIgnoreCase("")){
				String[] line = reference.split("\n");
				String[] secondLine;
				Collection<String> attachs = new ArrayList<String>();
				for (int j = 0; j < line.length; j++) {
					secondLine = line[j].split("\012 ");
					for (int k = 0; k < secondLine.length; k++) {
						attachs.add(secondLine[k]);
					}
				}
				org.objectweb.salome_tmf.data.FileAttachment fAttach = null;
				org.objectweb.salome_tmf.data.UrlAttachment uAttach = null;
				String attch = null;
				for(Iterator iter = attachs.iterator(); iter.hasNext();){
					attch = (String) iter.next();
					if(attch.startsWith("url:")){
						attch = attch.substring(4, attch.length());
						uAttach = new org.objectweb.salome_tmf.data.UrlAttachment(attch,"");
						uAttach.setUrl(new URL(attch));
						reqLeaf.addAttachementInDBAndModel(uAttach);
					} else {
						WebDavUtils webdav = new WebDavUtils(Api.getAttachementRepo());
						if (webdav.searchFile(attch, Api.getAttachementRepo())) {
							Properties sys = System.getProperties();
							String fs = sys.getProperty("file.separator");
							// Repertoire temporaire systeme
							String tmpDir = sys.getProperty("java.io.tmpdir");
							tmpDir = tmpDir + fs + ApiConstants.PATH_TO_ADD_TO_TEMP + fs + DataModel.getCurrentProject().getNameFromModel() + fs;
							File temp = new File(tmpDir, attch);
							temp.getParentFile().mkdirs();
							webdav.downloadFile(Api.getAttachementRepo(), temp.getAbsolutePath(), attch);
							fAttach = new org.objectweb.salome_tmf.data.FileAttachment(temp, "Imported file");
							reqLeaf.addAttachementInDBAndModel(fAttach);
						}
					}
				}
			}
			// VALIDBY
			if (!validatePerson.equalsIgnoreCase("")) {
				prep = SQLWrapper.getSQLSelectQuery("recupValidByID");
				prep.setString(1, validatePerson);
				stmtRes = SQLWrapper.runSelectQuery(prep);
				if (stmtRes.next()) {
					value = stmtRes.getInt("id");
				} else {
					prep = SQLWrapper.getSQLSelectQuery("insertValidByInDB");
					prep.setString(1, validatePerson);
					prep.executeUpdate();
					prep = SQLWrapper.getSQLSelectQuery("recupValidByID");
					prep.setString(1, validatePerson);
					stmtRes = SQLWrapper.runSelectQuery(prep);
					if (stmtRes.next()) {
						value = stmtRes.getInt("id");
					} else {
						throw new Exception("Could not update database.");
					}
				}
				reqMan.updateReqHMI(reqMan.VALID_BY, validatePerson);
				reqLeaf.updateValidByInDBAndModel(value);
			}
			// PRIORITY
			if (!priority.equalsIgnoreCase("")) {
				prep = SQLWrapper.getSQLSelectQuery("recupPriorityID");
				prep.setString(1, priority);
				stmtRes = SQLWrapper.runSelectQuery(prep);
				if (stmtRes.next()) {
					value = stmtRes.getInt("id");
				} else {
					prep = SQLWrapper.getSQLSelectQuery("insertPriorityInDB");
					prep.setString(1, priority);
					prep.executeUpdate();
					prep = SQLWrapper.getSQLSelectQuery("recupPriorityID");
					prep.setString(1, priority);
					stmtRes = SQLWrapper.runSelectQuery(prep);
					if (stmtRes.next()) {
						value = stmtRes.getInt("id");
					} else {
						throw new Exception("Could not update database.");
					}
				}
				reqMan.updateReqHMI(reqMan.PRIORITY, priority);
				reqLeaf.updatePriorityInDBAndModel(value);
			}
			// COMPLEXITY
			if (!complexe.equalsIgnoreCase("")) {
				prep = SQLWrapper.getSQLSelectQuery("recupComplexeID");
				prep.setString(1, complexe);
				stmtRes = SQLWrapper.runSelectQuery(prep);
				if (stmtRes.next()) {
					value = stmtRes.getInt("id");
				} else {
					prep = SQLWrapper.getSQLSelectQuery("insertComplexeInDB");
					prep.setString(1, complexe);
					prep.executeUpdate();
					prep = SQLWrapper.getSQLSelectQuery("recupComplexeID");
					prep.setString(1, complexe);
					stmtRes = SQLWrapper.runSelectQuery(prep);
					if (stmtRes.next()) {
						value = stmtRes.getInt("id");
					} else {
						throw new Exception("Could not update database.");
					}
				}
				reqMan.updateReqHMI(reqMan.COMPLEXE, complexe);
				reqLeaf.updateComplexeInDBAndModel(value);
			}
			// CRITICAL
			if (!criticity.equalsIgnoreCase("")) {
				prep = SQLWrapper.getSQLSelectQuery("recupCriticalID");
				prep.setString(1, criticity);
				stmtRes = SQLWrapper.runSelectQuery(prep);
				if (stmtRes.next()) {
					value = stmtRes.getInt("id");
				} else {
					prep = SQLWrapper.getSQLSelectQuery("insertCriticalInDB");
					prep.setString(1, criticity);
					prep.executeUpdate();
					prep = SQLWrapper.getSQLSelectQuery("recupCriticalID");
					prep.setString(1, criticity);
					stmtRes = SQLWrapper.runSelectQuery(prep);
					if (stmtRes.next()) {
						value = stmtRes.getInt("id");
					} else {
						throw new Exception("Could not update database.");
					}
				}
				reqMan.updateReqHMI(reqMan.CRITICAL, criticity);
				reqLeaf.updateCriticalInDBAndModel(value);
			}
			// COMPREHENSION
			if (!comprehension.equalsIgnoreCase("")) {
				prep = SQLWrapper.getSQLSelectQuery("recupUnderstandingID");
				prep.setString(1, comprehension);
				stmtRes = SQLWrapper.runSelectQuery(prep);
				if (stmtRes.next()) {
					value = stmtRes.getInt("id");
				} else {
					prep = SQLWrapper
							.getSQLSelectQuery("insertUnderstandingInDB");
					prep.setString(1, comprehension);
					prep.executeUpdate();
					prep = SQLWrapper.getSQLSelectQuery("recupUnderstandingID");
					prep.setString(1, comprehension);
					stmtRes = SQLWrapper.runSelectQuery(prep);
					if (stmtRes.next()) {
						value = stmtRes.getInt("id");
					} else {
						throw new Exception("Could not update database.");
					}
				}
				reqMan.updateReqHMI(reqMan.UNDERSTANDING, comprehension);
				reqLeaf.updateUnderstandingInDBAndModel(value);
			}
			// OWNER
			if (!owner.equalsIgnoreCase("")) {
				prep = SQLWrapper.getSQLSelectQuery("recupOwnerID");
				prep.setString(1, owner);
				stmtRes = SQLWrapper.runSelectQuery(prep);
				if (stmtRes.next()) {
					value = stmtRes.getInt("id");
				} else {
					prep = SQLWrapper.getSQLSelectQuery("insertOwnerInDB");
					prep.setString(1, owner);
					prep.executeUpdate();
					prep = SQLWrapper.getSQLSelectQuery("recupOwnerID");
					prep.setString(1, owner);
					stmtRes = SQLWrapper.runSelectQuery(prep);
					if (stmtRes.next()) {
						value = stmtRes.getInt("id");
					} else {
						throw new Exception("Could not update database.");
					}
				}
				reqMan.updateReqHMI(reqMan.OWNER, owner);
				reqLeaf.updateOwnerInDBAndModel(value);
			}
			// TEST CASE
			if (!testCase.equalsIgnoreCase("")) {
				String[] line = testCase.split("\n");
				String[] secondLine;
				Collection<String> testCases = new ArrayList<String>();
				for (int j = 0; j < line.length; j++) {
					secondLine = line[j].split("\012 ");
					for (int k = 0; k < secondLine.length; k++) {
						testCases.add(secondLine[k]);
					}
				}
				String testCas;
				String[] path;
				int familyId;
				int suiteId;
				int tcId;
				Family family;
				TestList tList;
				Test test;
				Project project = DataModel.getCurrentProject();
				for (Iterator<String> iter = testCases.iterator(); iter
						.hasNext();) {
					family = null;
					tList = null;
					testCas = iter.next();
					path = testCas.split("/");
					if (path.length == 3) {
						prep = SQLWrapper
								.getSQLSelectQuery("recupFamilleByName");
						prep.setString(1, path[0]);
						prep
								.setInt(2, DataModel.getCurrentProject()
										.getIdBdd());
						stmtRes = SQLWrapper.runSelectQuery(prep);
						if (stmtRes.next()) {
							familyId = stmtRes.getInt("id_famille");
						} else{
							family = new Family(path[0],"");
							project = DataModel.getCurrentProject();
							project.addFamilyInDBAndModel(family);
							familyId = family.getIdBdd();
						}
						if(family == null){
							family = project.getFamilyFromModel(path[0]);
						}
						prep = SQLWrapper
								.getSQLSelectQuery("recupSuiteTestByName");
						prep.setString(1, path[1]);
						prep.setInt(2, familyId);
						stmtRes = SQLWrapper.runSelectQuery(prep);
						if (stmtRes.next()) {
							suiteId = stmtRes.getInt("id_suite");
						} else{
							tList = new TestList(path[1],"");
							family.addTestListInDBAndModel(tList);
							suiteId = tList.getIdBdd();
						}
						if(tList == null){
							tList = family.getTestListInModel(path[1]);
						}
						prep = SQLWrapper
								.getSQLSelectQuery("recupCaseTestByName");
						prep.setString(1, path[2]);
						prep.setInt(2, suiteId);
						stmtRes = SQLWrapper.runSelectQuery(prep);
						if (stmtRes.next()) {
							tcId = stmtRes.getInt("id_cas");
						} else {
							test = new ManualTest(path[2], "");
							test.setConceptorLoginInModel(DataLoader.getCurrentUser().getLoginFromModel());
							tList.addTestInDBAndModel(test);
							tcId = test.getIdBdd();
						}
						reqLeaf.addTestCoverInDB(tcId, true);
					}
				}
			}
		} catch (Exception e) {
			importInError.addElement(name + " "
					+ Language.getInstance().getText("line") + " " + row);
			Util.err(e);
		}

	}
}
//20100128 - Fin modification Forge ORTF v1.0.0