/*
 * SalomeTMF is a Test Management Framework
 * Copyright (C) 2007 EDF / France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * @author Jeremie DEFAYE
 *
 * Contact: mikael.marche@rd.francetelecom.com
 */

package salomeTMF_plug.pluginxlsxml.Import;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.FileInputStream;
import java.net.URL;
import java.util.ArrayList;
import java.util.Vector;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JRadioButton;
import javax.swing.JTabbedPane;
import javax.swing.JTextField;
import javax.swing.border.TitledBorder;
import javax.swing.tree.DefaultMutableTreeNode;

import org.dom4j.Document;
import org.dom4j.io.SAXReader;
import org.java.plugin.Extension;
import org.objectweb.salome_tmf.data.AdminVTData;
import org.objectweb.salome_tmf.data.Family;
import org.objectweb.salome_tmf.data.Test;
import org.objectweb.salome_tmf.data.TestList;
import org.objectweb.salome_tmf.ihm.main.SalomeTMFContext;
import org.objectweb.salome_tmf.ihm.main.datawrapper.DataModel;
import org.objectweb.salome_tmf.ihm.models.ScriptFileFilter;
import org.objectweb.salome_tmf.ihm.tools.Tools;
import org.objectweb.salome_tmf.plugins.IPlugObject;
import org.objectweb.salome_tmf.plugins.JPFManager;
import org.objectweb.salome_tmf.plugins.core.ReqManager;
import org.objectweb.salome_tmf.plugins.core.XMLLoaderPlugin;
import org.objectweb.salome_tmf.plugins.core.XMLPrinterPlugin;

import salomeTMF_plug.pluginxlsxml.Commun.TestPresencePlugin;
import salomeTMF_plug.pluginxlsxml.language.Language;
import salomeTMF_plug.requirements.ImportXMLReq;
import salomeTMF_plug.requirements.ReqPlugin;
import salomeTMF_plug.requirements.ihm.RequirementPanel;
import salomeTMF_plug.pluginxlsxml.Import.ImportXML2;

/**
 * Open a dialog box for selecting a XlS file to import data
 */
public class ImportXLSDialog extends JDialog {

	ImportXMLReq pImportXMLReq;
	ReqPlugin pReqPlugin;
	RequirementPanel pRequirementPanel;
	XMLLoaderPlugin pXMLLoader;

	private XMLPrinterPlugin pXMLPrinterPlugin;
	private XMLLoaderPlugin pXMLLoaderPlugin;
	private ReqManager pReqManager;
	private Vector listXMLPlugin = new Vector();
	private Vector panelsPluginsForImport = new Vector();
	private Vector panelsPluginsForExport = new Vector();

	// Salome GUI
	IPlugObject pIhm = null;
	private URL urlDeBase;
	private String url_text;
	private String xlsFile;
	private JTextField xlsSauvTF;
	private JButton xlsSauvButton;
	private String xlsErrorMessage = "";
	private String exigenceNonTrouvePourTest;
	private Document xlsDoc;
	private JProgressBar xlsProgress;
	private JCheckBox importTest;
	private JCheckBox associationExigencesSalome;
	private JCheckBox importExigence;
	private JCheckBox importParametre;
	private JCheckBox importEnvironnement;
	private JCheckBox importExecutionCampagnes;
	// private boolean selectionAssociationExigencesSalome=true;
	private JButton xlsValider;
	private JButton xlsAnnuler;
	private boolean ok;
	private boolean xlsAnnule = false;
	private boolean xlsErreurTraitement = false;
	private ArrayList<TestList> suiteSelectionList = new ArrayList<TestList>();
	private ArrayList<Family> familySelectionList = new ArrayList<Family>();
	private ArrayList<Test> testSelectionList = new ArrayList<Test>();
	private boolean isErreurTraitementImport = false;

	// partie campagne
	private JLabel campagneLabel;
	private JRadioButton CampagneneRienFaire;
	private JLabel CampagneneRienFaireLabel;
	private JRadioButton CampagneImport;
	private JLabel CampagneImportLabel;
	private JRadioButton CampagneUneParFamille;
	private JLabel CampagneUneParFamilleLabel;
	private JRadioButton CampagneUneParExigence;
	private JLabel CampagneUneParExigenceLabel;
	private JRadioButton CampagneUneParProjet;
	private JLabel CampagneUneParProjetLabel;
	private ButtonGroup buttonGroupCampagne;

	// Partie Gestion Conflit
	private JLabel conflitLabel;
	private JCheckBox suppr;
	private JRadioButton keepOriginal;
	private JRadioButton keepOriginalAndImport;
	private JRadioButton keepOriginalAndUpdate;
	private JRadioButton updateOriginal;
	private JRadioButton eraseOriginalAndImport;

	private String fs = System.getProperties().getProperty("file.separator");
	ImportXML2 traitement;
	DefaultMutableTreeNode chosenRoot;

	/**
	 * Creates a new instance of ExportDialog
	 *
	 * @param vt
	 *            Interface Homme Machine
	 * @throws Exception
	 *             Exception for super command
	 */
	public ImportXLSDialog(IPlugObject vt) throws Exception {
		super(SalomeTMFContext.getInstance().getSalomeFrame(), true);
		setTitle(Language.getInstance().getText("Import_des_exigences"));
		// super(vt);
		pIhm = vt;

		// Rajout SalomeV3
		Vector<Extension> listExtXMLPlugin = pIhm.getXMLPrintersExtension();
		for (Extension pXMLExt : listExtXMLPlugin) {
			JPFManager pJPFManager = pIhm.getPluginManager();
			try {
				XMLPrinterPlugin pXMLPrinterPlugin = (XMLPrinterPlugin) pJPFManager
						.activateExtension(pXMLExt);
				JPanel pPanel = pXMLPrinterPlugin.getImportOptionPanel();
				if (pPanel != null && !panelsPluginsForImport.contains(pPanel)) {
					panelsPluginsForImport.add(pPanel);
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		int size = listExtXMLPlugin.size();
		for (int i = 0; i < size; i++) {
			Extension pXMLExt = (Extension) listExtXMLPlugin.elementAt(i);
			JPFManager pJPFManager = pIhm.getPluginManager();
			try {
				XMLPrinterPlugin pXMLPrinterPlugin = (XMLPrinterPlugin) pJPFManager
						.activateExtension(pXMLExt);
				JPanel pPanel = pXMLPrinterPlugin.getExportOptionPanel();
				if (pPanel != null && !panelsPluginsForExport.contains(pPanel)) {
					panelsPluginsForExport.add(pPanel);
				}
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
		// Fin rajout

		urlDeBase = SalomeTMFContext.getInstance().getUrlBase();
		String _urlBase = urlDeBase.toString();
		url_text = _urlBase.substring(0, _urlBase.lastIndexOf("/"));

		DataModel.reloadFromBase(false);

		xlsSauvTF = new JTextField(30);
		xlsSauvButton = new JButton(Language.getInstance().getText("Choisir"));
		xlsSauvButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				JFileChooser fileChooser = new JFileChooser();
				fileChooser.addChoosableFileFilter(new ScriptFileFilter(
						Language.getInstance().getText("Fichier_XLS____xls_"),
						".xls"));
				int returnVal = fileChooser.showDialog(ImportXLSDialog.this,
						Language.getInstance().getText("Selectionner"));
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					xlsFile = fileChooser.getSelectedFile().getAbsolutePath();
					if (xlsFile.indexOf(".") != -1) {
						if (!xlsFile.substring(xlsFile.lastIndexOf("."))
								.equals(".xls")) {
							xlsFile += ".xls";
						}
					} else {
						xlsFile += ".xls";
					}
					xlsSauvTF.setText(xlsFile);
				}
			}
		});

		JPanel xlsSauvTFPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		xlsSauvTFPanel.add(xlsSauvTF);
		JPanel xlsSauvButtonPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		xlsSauvButtonPanel.add(xlsSauvButton);

		JPanel xlsSauvPanel = new JPanel();
		xlsSauvPanel.setLayout(new BoxLayout(xlsSauvPanel, BoxLayout.Y_AXIS));
		xlsSauvPanel.setBorder(BorderFactory.createTitledBorder(Language
				.getInstance().getText("Fichier_a_importer")));
		xlsSauvPanel.add(xlsSauvTFPanel);
		xlsSauvPanel.add(xlsSauvButtonPanel);

		// concerne la gestion des conflits
		suppr = new JCheckBox(
				Language
						.getInstance()
						.getText(
								"Supprimer_les_elements_qui_ne_sont_pas_dans_le_document_Excel"));
		suppr.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				try {
					if (!selectionSuppr() && selectionImportTest()) {
						associationExigencesSalome.setEnabled(true);
					} else {
						associationExigencesSalome.setEnabled(false);
						associationExigencesSalome.setSelected(false);
					}
				} catch (Exception ex) {
					Tools.ihmExceptionView(ex);
				}
			}
		});
		conflitLabel = new JLabel(Language.getInstance().getText(
				"En_cas_de_conflit__"));
		keepOriginal = new JRadioButton(Language.getInstance().getText(
				"Conserver_l_original"));
		keepOriginalAndImport = new JRadioButton(Language.getInstance()
				.getText("Garder_une_copie_et_importer_le_nouvel_element"));
		keepOriginalAndUpdate = new JRadioButton(
				Language
						.getInstance()
						.getText(
								"Garder_un_copie_et_mettre_a_jour_une_copie_de_l_original_avec_l_element_importe"));
		updateOriginal = new JRadioButton(Language.getInstance().getText(
				"Mettre_a_jour_l_original_avec_l_element_importe"));
		eraseOriginalAndImport = new JRadioButton(Language.getInstance()
				.getText("Remplacer_l_original_par_l_element_importe"));
		keepOriginal.setSelected(true);
		keepOriginalAndUpdate.setEnabled(false);
		updateOriginal.setEnabled(false);
		eraseOriginalAndImport.setEnabled(false);

		// Parte creation groupe icone
		campagneLabel = new JLabel(Language.getInstance().getText(
				"Creation_des_campagnes"));
		CampagneneRienFaire = new JRadioButton();
		CampagneneRienFaireLabel = new JLabel(Language.getInstance().getText(
				"Pas_Campagne"));
		CampagneneRienFaire.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				importExecutionCampagnes.setEnabled(false);
				importExecutionCampagnes.setSelected(false);
				keepOriginalAndUpdate.setEnabled(true);
				updateOriginal.setEnabled(true);
				eraseOriginalAndImport.setEnabled(true);
			}
		});
		CampagneUneParFamille = new JRadioButton();
		CampagneUneParFamilleLabel = new JLabel(Language.getInstance().getText(
				"Creer_une_campagne_par_Famille"));
		CampagneUneParFamille.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				importExecutionCampagnes.setEnabled(false);
				importExecutionCampagnes.setSelected(false);
				keepOriginalAndUpdate.setEnabled(true);
				updateOriginal.setEnabled(true);
				eraseOriginalAndImport.setEnabled(true);
			}
		});
		CampagneUneParExigence = new JRadioButton();
		CampagneUneParExigenceLabel = new JLabel(Language.getInstance()
				.getText("Creer_une_campagne_par_exigence"));
		CampagneUneParExigence.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				importExecutionCampagnes.setEnabled(false);
				importExecutionCampagnes.setSelected(false);
				keepOriginalAndUpdate.setEnabled(true);
				updateOriginal.setEnabled(true);
				eraseOriginalAndImport.setEnabled(true);
			}
		});
		CampagneUneParProjet = new JRadioButton();
		CampagneUneParProjetLabel = new JLabel(Language.getInstance().getText(
				"Creer_une_seule_campagne_pour_tout_le_projet"));
		CampagneUneParProjet.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				importExecutionCampagnes.setEnabled(false);
				importExecutionCampagnes.setSelected(false);
				keepOriginalAndUpdate.setEnabled(true);
				updateOriginal.setEnabled(true);
				eraseOriginalAndImport.setEnabled(true);
			}
		});
		CampagneImport = new JRadioButton();
		CampagneImportLabel = new JLabel(Language.getInstance().getText(
				"Importer_Campagnes"));
		CampagneImport.setSelected(true);
		CampagneImport.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				importExecutionCampagnes.setEnabled(true);
				importExecutionCampagnes.setSelected(true);
				keepOriginalAndUpdate.setEnabled(false);
				updateOriginal.setEnabled(false);
				eraseOriginalAndImport.setEnabled(false);
				keepOriginal.setSelected(true);
			}
		});

		buttonGroupCampagne = new ButtonGroup();
		buttonGroupCampagne.add(CampagneneRienFaire);
		buttonGroupCampagne.add(CampagneUneParFamille);
		buttonGroupCampagne.add(CampagneUneParExigence);
		buttonGroupCampagne.add(CampagneUneParProjet);
		buttonGroupCampagne.add(CampagneImport);

		importExecutionCampagnes = new JCheckBox(Language.getInstance()
				.getText("Execution_Des_Campagnes"));
		importExecutionCampagnes.setSelected(true);

		JPanel campagnePanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		campagnePanel.add(campagneLabel);

		JPanel campagneneRienFairePanel = new JPanel(new FlowLayout(
				FlowLayout.LEFT));
		campagneneRienFairePanel.add(CampagneneRienFaire);
		campagneneRienFairePanel.add(CampagneneRienFaireLabel);

		JPanel campagneUneParFamillePanel = new JPanel(new FlowLayout(
				FlowLayout.LEFT));
		campagneUneParFamillePanel.add(CampagneUneParFamille);
		campagneUneParFamillePanel.add(CampagneUneParFamilleLabel);

		JPanel campagneUneParExigencePanel = new JPanel(new FlowLayout(
				FlowLayout.LEFT));
		campagneUneParExigencePanel.add(CampagneUneParExigence);
		campagneUneParExigencePanel.add(CampagneUneParExigenceLabel);

		JPanel campagneUneParProjetPanel = new JPanel(new FlowLayout(
				FlowLayout.LEFT));
		campagneUneParProjetPanel.add(CampagneUneParProjet);
		campagneUneParProjetPanel.add(CampagneUneParProjetLabel);

		JPanel CampagneImportPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		CampagneImportPanel.add(CampagneImport);
		CampagneImportPanel.add(CampagneImportLabel);

		JPanel ExecCampagneImportPanel = new JPanel(new FlowLayout(
				FlowLayout.LEFT));
		ExecCampagneImportPanel.add(importExecutionCampagnes);

		JPanel gestionChoixCampagne = new JPanel();
		gestionChoixCampagne.setLayout(new BoxLayout(gestionChoixCampagne,
				BoxLayout.Y_AXIS));
		gestionChoixCampagne.add(campagnePanel);
		gestionChoixCampagne.add(campagneneRienFairePanel);
		gestionChoixCampagne.add(campagneUneParFamillePanel);
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()) {
			gestionChoixCampagne.add(campagneUneParExigencePanel);
		}
		gestionChoixCampagne.add(campagneUneParProjetPanel);
		gestionChoixCampagne.add(CampagneImportPanel);
		gestionChoixCampagne.add(ExecCampagneImportPanel);

		ButtonGroup conflictGroup = new ButtonGroup();
		conflictGroup.add(keepOriginal);
		conflictGroup.add(keepOriginalAndImport);
		conflictGroup.add(keepOriginalAndUpdate);
		conflictGroup.add(updateOriginal);
		conflictGroup.add(eraseOriginalAndImport);

		JPanel supprOptionPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		supprOptionPanel.add(suppr);
		JPanel conflictPanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
		conflictPanel.add(conflitLabel);
		JPanel conflictOption1Panel = new JPanel(
				new FlowLayout(FlowLayout.LEFT));
		conflictOption1Panel.add(Box.createHorizontalStrut(10));
		conflictOption1Panel.add(keepOriginal);
		JPanel conflictOption2Panel = new JPanel(
				new FlowLayout(FlowLayout.LEFT));
		conflictOption2Panel.add(Box.createHorizontalStrut(10));
		conflictOption2Panel.add(keepOriginalAndImport);
		JPanel conflictOption3Panel = new JPanel(
				new FlowLayout(FlowLayout.LEFT));
		conflictOption3Panel.add(Box.createHorizontalStrut(10));
		conflictOption3Panel.add(keepOriginalAndUpdate);
		JPanel conflictOption4Panel = new JPanel(
				new FlowLayout(FlowLayout.LEFT));
		conflictOption4Panel.add(Box.createHorizontalStrut(10));
		conflictOption4Panel.add(updateOriginal);
		JPanel conflictOption5Panel = new JPanel(
				new FlowLayout(FlowLayout.LEFT));
		conflictOption5Panel.add(Box.createHorizontalStrut(10));
		conflictOption5Panel.add(eraseOriginalAndImport);

		xlsValider = new JButton(Language.getInstance().getText("OK"));
		xlsValider.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				// if ((selectionImportTest == false) &&
				// (selectionImportExigence == false) &&
				// (selectionImportParametre== false)&&
				// (selectionImportEnvironnement== false)) {
				if ((!selectionImportTest()) && (!selectionImportExigence())
						&& (!selectionImportParametre())
						&& (!selectionImportEnvironnement())) {
					JOptionPane
							.showMessageDialog(
									ImportXLSDialog.this,
									Language
											.getInstance()
											.getText(
													"Vous_devez_selectionner_un_element_a_importer"),
									Language.getInstance().getText("Erreur_"),
									JOptionPane.ERROR_MESSAGE);
				} else if (xlsSauvTF.getText().equals("")) {

					JOptionPane.showMessageDialog(ImportXLSDialog.this,
							Language.getInstance().getText(
									"Vous_devez_entrez_un_nom_de_fichier"),
							Language.getInstance().getText("Erreur_"),
							JOptionPane.ERROR_MESSAGE);
					ok = false;
				} else {
					Thread t = new Thread() {
						public void run() {
							// Instanciation et lancement du traitement
							try {
								xlsSauvTF.setEnabled(false);
								CampagneneRienFaire.setEnabled(false);
								CampagneUneParFamille.setEnabled(false);
								CampagneUneParExigence.setEnabled(false);
								CampagneUneParProjet.setEnabled(false);
								CampagneImport.setEnabled(false);
								xlsProgress.setIndeterminate(true);
								xlsSauvButton.setEnabled(false);
								xlsValider.setEnabled(false);
								xlsAnnuler.setEnabled(false);
								importTest.setEnabled(false);
								importExigence.setEnabled(false);
								importParametre.setEnabled(false);
								importEnvironnement.setEnabled(false);
								importExecutionCampagnes.setEnabled(false);
								associationExigencesSalome.setEnabled(false);
								suppr.setEnabled(false);
								keepOriginal.setEnabled(false);
								keepOriginalAndImport.setEnabled(false);
								keepOriginalAndUpdate.setEnabled(false);
								updateOriginal.setEnabled(false);
								eraseOriginalAndImport.setEnabled(false);

								importXLS();

							} catch (Exception ex) {
								Tools.ihmExceptionView(ex);
							}
						}
					};
					t.start();

				}
			}
		});

		xlsAnnuler = new JButton(Language.getInstance().getText("Annuler"));
		xlsAnnuler.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				ImportXLSDialog.this.dispose();
			}
		});

		// Choix donnes a importer
		importTest = new JCheckBox(Language.getInstance().getText("Tests"));
		importTest.setSelected(true);
		importTest.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				try {
					if (!importTest.isSelected()) {
						buttonGroupCampagne.setSelected(CampagneneRienFaire
								.getModel(), true);
						CampagneneRienFaire.setEnabled(false);
						CampagneUneParFamille.setEnabled(false);
						CampagneUneParExigence.setEnabled(false);
						CampagneUneParProjet.setEnabled(false);
						CampagneImport.setEnabled(false);
						importExecutionCampagnes.setEnabled(false);
						importExecutionCampagnes.setSelected(false);
						associationExigencesSalome.setSelected(false);
						associationExigencesSalome.setEnabled(false);
						if (!suppr.isEnabled()) {
							suppr.setEnabled(true);
						}

					} else {
						if (!suppr.isSelected()) {
							associationExigencesSalome.setEnabled(true);
						}
						CampagneneRienFaire.setEnabled(true);
						CampagneUneParFamille.setEnabled(true);
						CampagneUneParExigence.setEnabled(true);
						CampagneUneParProjet.setEnabled(true);
						CampagneImport.setEnabled(true);
						if (CampagneImport.isSelected()) {
							importExecutionCampagnes.setEnabled(true);
						}

					}
				} catch (Exception ex) {
					Tools.ihmExceptionView(ex);
				}
			}
		});
		associationExigencesSalome = new JCheckBox(Language.getInstance()
				.getText("Association_test_exigences_Salome"));
		associationExigencesSalome.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				try {
					if (!selectionAssociationExigencesSalome()) {
						suppr.setEnabled(true);
					} else {
						suppr.setEnabled(false);
						suppr.setSelected(false);
					}
				} catch (Exception ex) {
					Tools.ihmExceptionView(ex);
				}
			}
		});

		importExigence = new JCheckBox(Language.getInstance().getText(
				"Exigences"));
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()) {
			importExigence.setSelected(true);

			importExigence.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					try {
						if (!importExigence.isSelected()) {
							if (listXMLPlugin.contains(pXMLPrinterPlugin)) {
								listXMLPlugin.remove(pXMLPrinterPlugin);
							}
						} else {
							if (!listXMLPlugin.contains(pXMLPrinterPlugin)) {
								listXMLPlugin.add(pXMLPrinterPlugin);
							}
						}
					} catch (Exception ex) {
						Tools.ihmExceptionView(ex);
					}
				}
			});
		} else {
			importExigence.setSelected(false);
			// selectionImportExigence = false;
		}

		importParametre = new JCheckBox(Language.getInstance().getText(
				"Parametres"));
		importParametre.setSelected(true);

		importEnvironnement = new JCheckBox(Language.getInstance().getText(
				"Environnements"));
		importEnvironnement.setSelected(true);

		JPanel optionTest = new JPanel();
		optionTest.setLayout(new FlowLayout(FlowLayout.LEFT));
		optionTest.add(associationExigencesSalome);

		JPanel optionsPanel = new JPanel();
		optionsPanel.setLayout(new BoxLayout(optionsPanel, BoxLayout.Y_AXIS));
		optionsPanel.setBorder(new TitledBorder(Language.getInstance().getText(
				"Options")));
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()) {
			optionsPanel.add(optionTest);
		} else {
			associationExigencesSalome.setSelected(false);
		}
		optionsPanel.add(supprOptionPanel);
		// optionsPanel.add(Box.createVerticalStrut(10));
		optionsPanel.add(conflictPanel);
		optionsPanel.add(conflictOption1Panel);
		optionsPanel.add(conflictOption2Panel);
		optionsPanel.add(conflictOption3Panel);
		optionsPanel.add(conflictOption4Panel);
		optionsPanel.add(conflictOption5Panel);

		JPanel xlsChoixSelectTestPanel = new JPanel();
		xlsChoixSelectTestPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		xlsChoixSelectTestPanel.add(importTest);

		JPanel xlsChoixSelectExigencePanel = new JPanel();
		xlsChoixSelectExigencePanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		xlsChoixSelectExigencePanel.add(importExigence);

		JPanel xlsChoixSelectParametrePanel = new JPanel();
		xlsChoixSelectParametrePanel.setLayout(new FlowLayout(FlowLayout.LEFT));
		xlsChoixSelectParametrePanel.add(importParametre);

		JPanel xlsChoixSelectEnvironnementPanel = new JPanel();
		xlsChoixSelectEnvironnementPanel.setLayout(new FlowLayout(
				FlowLayout.LEFT));
		xlsChoixSelectEnvironnementPanel.add(importEnvironnement);

		JPanel xlsChoixSelectPanel = new JPanel();
		xlsChoixSelectPanel.setLayout(new BoxLayout(xlsChoixSelectPanel,
				BoxLayout.Y_AXIS));
		// xlsChoixSelectPanel.add(xlsChoixImportTestPanel);
		xlsChoixSelectPanel.add(xlsChoixSelectTestPanel);
		if (TestPresencePlugin.testDeLaPresenceDuPluginRequirement()) {
			xlsChoixSelectPanel.add(xlsChoixSelectExigencePanel);
		} else {
			importExigence.setSelected(false);
		}
		xlsChoixSelectPanel.add(xlsChoixSelectParametrePanel);
		xlsChoixSelectPanel.add(xlsChoixSelectEnvironnementPanel);

		JPanel xlsChoixTestEtCampagne = new JPanel();
		xlsChoixTestEtCampagne.setLayout(new BoxLayout(xlsChoixTestEtCampagne,
				BoxLayout.X_AXIS));
		xlsChoixTestEtCampagne
				.setBorder(BorderFactory.createTitledBorder(Language
						.getInstance().getText("Importer")));
		xlsChoixTestEtCampagne.add(xlsChoixSelectPanel);
		xlsChoixTestEtCampagne.add(gestionChoixCampagne);

		JPanel xlsButtons = new JPanel();
		xlsButtons.add(xlsValider);
		xlsButtons.add(xlsAnnuler);

		// Gestion de la progressbar
		xlsProgress = new JProgressBar();
		JPanel xlsProgression = new JPanel(new FlowLayout(FlowLayout.CENTER));
		xlsProgression.add(xlsProgress);

		JPanel xlsPage = new JPanel();
		xlsPage.setLayout(new BoxLayout(xlsPage, BoxLayout.Y_AXIS));
		xlsPage.add(Box.createVerticalStrut(10));
		xlsPage.add(xlsSauvPanel);
		xlsPage.add(Box.createVerticalStrut(10));
		xlsPage.add(xlsChoixTestEtCampagne);
		xlsPage.add(Box.createVerticalStrut(10));
		// xlsPage.add(optionTest);
		xlsPage.add(optionsPanel);
		xlsPage.add(Box.createVerticalStrut(10));
		xlsPage.add(xlsProgression);
		xlsPage.add(xlsButtons);

		Container xlsContentPaneFrame = this.getContentPane();
		xlsContentPaneFrame.add(xlsPage, BorderLayout.CENTER);
		centerScreen();
		this.setTitle(Language.getInstance().getText("Import_des_exigences")
				+ " " + Language.getInstance().getText("Version_Plugin"));
	}

	protected void centerScreen() {
		Dimension dim = getToolkit().getScreenSize();
		this.pack();
		Rectangle abounds = getBounds();
		setLocation((dim.width - abounds.width) / 2,
				(dim.height - abounds.height) / 2);
		this.setVisible(true);
		requestFocus();
	}

	/**
	 * parse XML document from the "path"
	 *
	 * @param path
	 *            Xml directory
	 * @return un document DOM4J
	 * @throws Exception
	 *             Exception
	 */
	public Document xmlParser(String path) throws Exception {
		SAXReader reader = new SAXReader(false);
		Document doc = reader.read(new FileInputStream(new File(path)));
		return doc;
	}

	/**
	 * launch all process to import data from a XLS spreadsheet to SalomeTMF
	 */
	public void importXLS() {
		boolean erreurImportFichier = false;
		String fichiersNonImportes = null;
		String saveFileName = xlsSauvTF.getText().trim();
		String xmlTempFile;
		String creationCampagne = null;
		if (CampagneUneParFamille.isSelected()) {
			creationCampagne = Language.getInstance().getText(
					"Campagne_Par_Famille");
		} else if (CampagneUneParExigence.isSelected()) {
			creationCampagne = Language.getInstance().getText(
					"Campagne_Par_Exigence");
		} else if (CampagneUneParProjet.isSelected()) {
			creationCampagne = Language.getInstance().getText(
					"Campagne_Par_Projet");
		} else if (CampagneImport.isSelected()) {
			creationCampagne = Language.getInstance().getText(
					"Importer_Campagnes");
		} else {
			creationCampagne = Language.getInstance()
					.getText("Pas_De_Campagne");
		}
		ok = true;

		if (xlsSauvTF.getText().equals("")) {

			JOptionPane.showMessageDialog(ImportXLSDialog.this, Language
					.getInstance().getText(
							"Vous_devez_entrez_un_nom_de_fichier"), Language
					.getInstance().getText("Erreur_"),
					JOptionPane.ERROR_MESSAGE);
			ok = false;

		} else {

			try {
				FromExcelToXml Transformation = new FromExcelToXml(
						saveFileName, selectionImportExigence(),
						selectionImportTest(), selectionImportParametre(),
						selectionImportEnvironnement(), creationCampagne,
						selectionExecutionCampagnes(),
						selectionAssociationExigencesSalome(), pIhm);
				xmlTempFile = Transformation.getXMLFileName();
				erreurImportFichier = Transformation.getErreurImportFichier();
				fichiersNonImportes = Transformation.getFichiersNonImportes();
				exigenceNonTrouvePourTest = Transformation
						.getExigenceNonTrouvePourTest();
				isErreurTraitementImport = Transformation
						.getIsErreurTraitementImport();
				System.out
						.println("Recuperation Retour Nom Fichier Temporaire XML : "
								+ xmlTempFile);
				String xmlFile = xmlTempFile;
				if (xmlFile == null || xmlFile.equals("")) {
					JOptionPane
							.showMessageDialog(
									ImportXLSDialog.this,
									Language
											.getInstance()
											.getText(
													"Probleme_lors_de_l_import_des_donnees_du_document_XML"),
									Language.getInstance().getText("Erreur_"),
									JOptionPane.ERROR_MESSAGE);
					CampagneneRienFaire.setEnabled(true);
					CampagneUneParFamille.setEnabled(true);
					CampagneUneParExigence.setEnabled(true);
					CampagneUneParProjet.setEnabled(true);
					CampagneImport.setEnabled(true);
					suppr.setEnabled(true);
					keepOriginal.setEnabled(true);
					keepOriginalAndImport.setEnabled(true);
					keepOriginalAndUpdate.setEnabled(true);
					updateOriginal.setEnabled(true);
					eraseOriginalAndImport.setEnabled(true);
					xlsProgress.setIndeterminate(false);
					xlsSauvButton.setEnabled(true);
					xlsValider.setEnabled(true);
					xlsAnnuler.setEnabled(true);
					importTest.setEnabled(true);
					importExigence.setEnabled(true);
					importParametre.setEnabled(true);
					importEnvironnement.setEnabled(true);
					importExecutionCampagnes.setEnabled(true);
					xlsSauvTF.setEnabled(true);
					associationExigencesSalome.setEnabled(true);

					ok = false;

					if (erreurImportFichier == true) {
						File file = new File(xmlFile);
						file.delete();
					}

				} else {
					try {
						String dirXml = xmlFile.substring(0, xmlFile
								.lastIndexOf(fs));
						if (xlsSauvTF.getText().equals("")) {
							JOptionPane
									.showMessageDialog(
											ImportXLSDialog.this,
											Language
													.getInstance()
													.getText(
															"Vous_devez_entrez_un_nom_de_fichier_pour_le_document_genere"),
											Language.getInstance().getText(
													"Erreur_"),
											JOptionPane.ERROR_MESSAGE);
							CampagneneRienFaire.setEnabled(true);
							CampagneUneParFamille.setEnabled(true);
							CampagneUneParExigence.setEnabled(true);
							CampagneUneParProjet.setEnabled(true);
							CampagneImport.setEnabled(true);
							suppr.setEnabled(true);
							keepOriginal.setEnabled(true);
							keepOriginalAndImport.setEnabled(true);
							keepOriginalAndUpdate.setEnabled(true);
							updateOriginal.setEnabled(true);
							eraseOriginalAndImport.setEnabled(true);
							xlsProgress.setIndeterminate(false);
							xlsSauvButton.setEnabled(true);
							xlsValider.setEnabled(true);
							xlsAnnuler.setEnabled(true);
							importTest.setEnabled(true);
							importExigence.setEnabled(true);
							importParametre.setEnabled(true);
							importEnvironnement.setEnabled(true);
							importExecutionCampagnes.setEnabled(true);
							associationExigencesSalome.setEnabled(true);
							xlsSauvTF.setEnabled(true);

						} else {

							File file = new File(xmlFile);

							if (isErreurTraitementImport == false) {
								try {

									SAXReader reader = new SAXReader();
									Document doc = reader
											.read(new FileInputStream(file));

									try {
										traitement = new ImportXML2(
												ImportXLSDialog.this, doc,
												familySelectionList,
												suiteSelectionList,
												testSelectionList, null, pIhm);

									} catch (Exception e) {
										e.printStackTrace();
										xlsErrorMessage += Language
												.getInstance()
												.getText(
														"Probleme_lors_de_l_import_des_donnees_du_document_XML");
										showErrorMessage();
										traitement.setAnnule(true);
									}
									traitement.setDirXml(dirXml);
									traitement.setInitSelection(false);
									traitement.setImportCampaign(true);
									traitement.importInProject();

								} catch (Exception ex) {

									xlsErreurTraitement = true;
									ex.printStackTrace();
									JOptionPane
											.showMessageDialog(
													ImportXLSDialog.this,
													Language
															.getInstance()
															.getText(
																	"Probleme_lors_de_l_import_des_donnees_du_document_XML"),
													Language.getInstance()
															.getText("Erreur_"),
													JOptionPane.ERROR_MESSAGE);
									traitement.setAnnule(true);
									CampagneneRienFaire.setEnabled(true);
									CampagneUneParFamille.setEnabled(true);
									CampagneUneParExigence.setEnabled(true);
									CampagneUneParProjet.setEnabled(true);
									CampagneImport.setEnabled(true);
									xlsProgress.setIndeterminate(false);
									suppr.setEnabled(true);
									keepOriginal.setEnabled(true);
									keepOriginalAndImport.setEnabled(true);
									keepOriginalAndUpdate.setEnabled(true);
									updateOriginal.setEnabled(true);
									eraseOriginalAndImport.setEnabled(true);
									xlsSauvButton.setEnabled(true);
									xlsValider.setEnabled(true);
									xlsAnnuler.setEnabled(true);
									importTest.setEnabled(true);
									importExigence.setEnabled(true);
									importParametre.setEnabled(true);
									importEnvironnement.setEnabled(true);
									importExecutionCampagnes.setEnabled(true);
									associationExigencesSalome.setEnabled(true);
									xlsSauvTF.setEnabled(true);

								}
							}
							// Supprime fichier temporaire XML à la fin du
							// programme
							file.delete();

							if (isErreurTraitementImport == true) {
								xlsErreurTraitement = true;
								erreurImportFichier = false;
								ok = false;
								ImportXLSDialog.this.dispose();
								// suprime le fichier XML
								file = new File(xmlFile);
								if (file.exists()) {
									file.delete();
								}
							}
							if (!traitement.isAnnule()) {

								if (xlsErreurTraitement == true) {

									CampagneneRienFaire.setEnabled(true);
									CampagneUneParFamille.setEnabled(true);
									CampagneUneParExigence.setEnabled(true);
									CampagneUneParProjet.setEnabled(true);
									CampagneImport.setEnabled(true);
									xlsProgress.setIndeterminate(false);
									suppr.setEnabled(true);
									keepOriginal.setEnabled(true);
									keepOriginalAndImport.setEnabled(true);
									keepOriginalAndUpdate.setEnabled(true);
									updateOriginal.setEnabled(true);
									eraseOriginalAndImport.setEnabled(true);
									xlsSauvButton.setEnabled(true);
									xlsValider.setEnabled(true);
									xlsAnnuler.setEnabled(true);
									importTest.setEnabled(true);
									importExigence.setEnabled(true);
									importParametre.setEnabled(true);
									importEnvironnement.setEnabled(true);
									importExecutionCampagnes.setEnabled(true);
									associationExigencesSalome.setEnabled(true);
									xlsSauvTF.setEnabled(true);

									JOptionPane
											.showMessageDialog(
													ImportXLSDialog.this,
													Language
															.getInstance()
															.getText(
																	"Probleme_lors_de_l_import_des_donnees_du_document_XML"),
													Language.getInstance()
															.getText("Erreur_"),
													JOptionPane.ERROR_MESSAGE);
									ok = false;
									ImportXLSDialog.this.dispose();
								}
							}

						}
					} catch (Exception ex) {

						Tools.ihmExceptionView(ex);
						ex.printStackTrace();
					}
				}
				// suprime le fichier XML
				File file = new File(xmlFile);
				if (file.exists()) {
					file.delete();
				}
			} catch (Exception ex) {

				ex.printStackTrace();
			}
		}

		if (erreurImportFichier == true) {
			JOptionPane
					.showMessageDialog(
							ImportXLSDialog.this,
							Language
									.getInstance()
									.getText(
											"Probleme_lors_de_l_import_des_donnees_du_document_XML")
									+ "\n "
									+ Language.getInstance().getText(
											"malformed_File")
									+ "\n "
									+ fichiersNonImportes, Language
									.getInstance().getText("Erreur_"),
							JOptionPane.ERROR_MESSAGE);
		}
		if (exigenceNonTrouvePourTest.length() > 0 && selectionImportExigence()) {
			JOptionPane
					.showMessageDialog(
							ImportXLSDialog.this,
							Language
									.getInstance()
									.getText(
											"Probleme_lors_de_l_import_des_donnees_du_document_XML")
									+ "\n "
									+ Language.getInstance().getText(
											"requirements_dont_exist")
									+ "\n "
									+ exigenceNonTrouvePourTest, Language
									.getInstance().getText("Erreur_"),
							JOptionPane.ERROR_MESSAGE);
		}

		if (ok && !xlsAnnule) {
			CampagneneRienFaire.setEnabled(true);
			CampagneUneParFamille.setEnabled(true);
			CampagneUneParExigence.setEnabled(true);
			CampagneUneParProjet.setEnabled(true);
			CampagneImport.setEnabled(true);
			xlsProgress.setIndeterminate(false);
			suppr.setEnabled(true);
			keepOriginal.setEnabled(true);
			keepOriginalAndImport.setEnabled(true);
			keepOriginalAndUpdate.setEnabled(true);
			updateOriginal.setEnabled(true);
			eraseOriginalAndImport.setEnabled(true);
			xlsSauvButton.setEnabled(true);
			xlsValider.setEnabled(true);
			xlsAnnuler.setEnabled(true);
			importTest.setEnabled(true);
			importExigence.setEnabled(true);
			importParametre.setEnabled(true);
			importEnvironnement.setEnabled(true);
			importExecutionCampagnes.setEnabled(true);
			associationExigencesSalome.setEnabled(true);
			xlsSauvTF.setEnabled(true);

			JOptionPane
					.showMessageDialog(
							ImportXLSDialog.this,
							Language
									.getInstance()
									.getText(
											"L_import_des_exigences_s_est_termine_avec_succes"),
							Language.getInstance().getText("Information"),
							JOptionPane.INFORMATION_MESSAGE);
			ImportXLSDialog.this.dispose();
		}

	}

	/**
	 * Return true if there is an error during import
	 *
	 * @param erreur
	 *            boolean
	 */
	public void setXlsErreurTraitement(boolean erreur) {
		ok = erreur;
	}

	/**
	 * Delete a directory tree (files and folders)
	 *
	 * @param path
	 *            Directory tree to delete
	 * @return true if there is no error during delete
	 */
	static public boolean deleteDirectory(File path) {
		boolean resultat = true;

		if (path.exists()) {
			File[] files = path.listFiles();
			for (int i = 0; i < files.length; i++) {
				if (files[i].isDirectory()) {
					resultat &= deleteDirectory(files[i]);
				} else {
					resultat &= files[i].delete();
				}
			}
		}
		resultat &= path.delete();
		return (resultat);
	}

	/**
	 * @return Returns the supprElement.
	 */
	public boolean isSupprElement() {
		return suppr.isSelected();
	}

	/**
	 * Show error meesage
	 */
	public void showErrorMessage() {
		JOptionPane.showMessageDialog(ImportXLSDialog.this, xlsErrorMessage,
				Language.getInstance().getText("Erreur_"),
				JOptionPane.ERROR_MESSAGE);
		ImportXLSDialog.this.dispose();
	}

	/**
	 * Returns the suiteList.
	 *
	 * @return Returns the suiteList.
	 */
	public ArrayList getSuiteSelectionList() {
		return suiteSelectionList;
	}

	/**
	 * Set the suiteList.
	 *
	 * @param suiteSelectionList
	 *            Set the suiteList.
	 */
	public void setSuiteSelectionList(ArrayList suiteSelectionList) {
		this.suiteSelectionList = suiteSelectionList;
	}

	/**
	 * Returns the familyList.
	 *
	 * @return Returns the familyList.
	 */
	public ArrayList getFamilySelectionList() {
		return familySelectionList;
	}

	/**
	 * Set the familyList.
	 *
	 * @param familySelectionList
	 *            Set the familyList.
	 */
	public void setFamilySelectionList(ArrayList familySelectionList) {
		this.familySelectionList = familySelectionList;
	}

	/**
	 * Returns the testList.
	 *
	 * @return Returns the testList.
	 */
	public ArrayList getTestSelectionList() {
		return testSelectionList;
	}

	/**
	 * The testList to set.
	 *
	 * @param testSelectionList
	 *            The testList to set.
	 */
	public void setTestSelectionList(ArrayList testSelectionList) {
		this.testSelectionList = testSelectionList;
	}

	/**
	 * Returns the chosenRoot
	 *
	 * @return Returns the chosenRoot.
	 */
	public DefaultMutableTreeNode getChosenRoot() {
		return chosenRoot;
	}

	/**
	 * The chosenRoot to set.
	 *
	 * @param chosenRoot
	 *            The chosenRoot to set.
	 */
	public void setChosenRoot(DefaultMutableTreeNode chosenRoot) {
		this.chosenRoot = chosenRoot;
	}

	/**
	 * Returns the errorMessage.
	 *
	 * @return Returns the errorMessage.
	 */
	public String getErrorMessage() {
		return xlsErrorMessage;
	}

	/**
	 * The errorMessage to set.
	 *
	 * @param errorMessage
	 *            The errorMessage to set.
	 */
	public void setErrorMessage(String errorMessage) {
		this.xlsErrorMessage = errorMessage;
	}

	/**
	 * @return selected
	 */
	public boolean isKeepOriginalOption() {
		return keepOriginal.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean isKeepOriginalAndImportOption() {
		return keepOriginalAndImport.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean isKeepOriginalAndUpdateOption() {
		return keepOriginalAndUpdate.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean isUpdateOriginalOption() {
		return updateOriginal.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean isEraseOriginalAndImport() {
		return eraseOriginalAndImport.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean selectionImportExigence() {
		return importExigence.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean selectionImportTest() {
		return importTest.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean selectionImportParametre() {
		return importParametre.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean selectionImportEnvironnement() {
		return importEnvironnement.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean selectionExecutionCampagnes() {
		return importExecutionCampagnes.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean selectionAssociationExigencesSalome() {
		return associationExigencesSalome.isSelected();
	}

	/**
	 * @return selected
	 */
	public boolean selectionSuppr() {
		return suppr.isSelected();
	}

}